(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     29715,       1172]*)
(*NotebookOutlinePosition[     40185,       1476]*)
(*  CellTagsIndexPosition[     39999,       1466]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["6. Basic Programming", "Title",
  CellTags->{"M50.6.1", "M50.6.2", "M50.6.4", "M50.6.3", "M50.6.5"}],

Cell[CellGroupData[{

Cell["Overview", "Section",
  CellTags->"M50.6.1"],

Cell["In this section we will cover:", "Text",
  CellTags->"M50.6.1"],

Cell["How to assign values to variables", "BulletItem",
  CellTags->"M50.6.1"],

Cell["How to clear definitions", "BulletItem",
  CellTags->"M50.6.1"],

Cell["How to define functions", "BulletItem",
  CellTags->"M50.6.1"],

Cell["Why we need to think about the order of operations", "BulletItem",
  CellTags->"M50.6.1"],

Cell["How to restrict our definitions to particular arguments", "BulletItem",
  CellTags->"M50.6.1"],

Cell["Some simple recursive definitions", "BulletItem",
  CellTags->"M50.6.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definitions and Assignments", "Section",
  CellTags->"M50.6.2"],

Cell[CellGroupData[{

Cell["Definitions", "Subsection",
  CellTags->"M50.6.2"],

Cell["\<\
The simplest programs are definitions. Definitions are introduced using \
assignments.\
\>", "Text",
  CellTags->"M50.6.2"],

Cell[TextData[{
  "For example, the assignment ",
  StyleBox["x\[ThinSpace]=\[ThinSpace]3", "MR"],
  " assigns 3 as the value of ",
  StyleBox["x", "MR"],
  ". It is a good idea not to think of this as \[OpenCurlyDoubleQuote]x \
equals three\[CloseCurlyDoubleQuote], but instead to think of \
\[OpenCurlyDoubleQuote]setting x to the value three\[CloseCurlyDoubleQuote]."
}], "Text",
  CellTags->"M50.6.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x = 3\)], "Input",
  CellTags->"M50.6.2"],

Cell[BoxData[
    \(3\)], "Output",
  CellTags->"M50.6.2"]
}, Open  ]],

Cell[TextData[{
  "That assignment tells ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to replace ",
  StyleBox["x", "MR"],
  " by 3 whenever ",
  StyleBox["x", "MR"],
  " is encountered during evaluation."
}], "Text",
  CellTags->"M50.6.2"],

Cell["For example:", "Text",
  CellTags->"M50.6.2"],

Cell[CellGroupData[{

Cell["{x, 3 x + 5}", "Input",
  CellTags->"M50.6.2"],

Cell[BoxData[
    \({3, 14}\)], "Output",
  CellTags->"M50.6.2"]
}, Open  ]],

Cell["\<\
It is good practice to clear assigned values after the definitions are no \
longer needed, so that assigned values will not interfere with subsequent \
calculations.\
\>", "Text",
  CellTags->"M50.6.2"],

Cell["Clear[x]", "Input",
  CellTags->"M50.6.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining Functions", "Subsection",
  CellTags->"M50.6.2"],

Cell["Assignments are also used to define functions. For example,", "Text",
  CellTags->"M50.6.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[x_] = \ x\ Sin[x]\)], "Input",
  CellTags->"M50.6.2"],

Cell[BoxData[
    \(x\ Sin[x]\)], "Output",
  CellTags->"M50.6.2"]
}, Open  ]],

Cell["\<\
This definition is used when a corresponding function is evaluated.\
\>", "Text",
  CellTags->"M50.6.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[3]\)], "Input",
  CellTags->"M50.6.2"],

Cell[BoxData[
    \(3\ Sin[3]\)], "Output",
  CellTags->"M50.6.2"]
}, Open  ]],

Cell[TextData[{
  "The expression ",
  StyleBox["f[x_]", "MR"],
  " on the left side of this assignment is a ",
  StyleBox["pattern",
    FontSlant->"Italic"],
  " that specifies the class of expressions for which this definition should \
be used."
}], "Text",
  CellTags->"M50.6.2"],

Cell[TextData[{
  "The pattern ",
  StyleBox["f[x_]", "MR"],
  " matches ",
  StyleBox["f[", "MR"],
  StyleBox["any expression", "IT"],
  StyleBox["]", "MR"],
  "."
}], "Text",
  CellTags->"M50.6.2"],

Cell[TextData[{
  "The definition ",
  StyleBox["f[x_]\[ThinSpace]=\[ThinSpace]x Sin[x]", "MR"],
  " will be applied whenever an expression that matches ",
  StyleBox["f[x_]", "MR"],
  " is encountered during evaluation."
}], "Text",
  CellTags->"M50.6.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining Functions", "Subsection",
  CellTags->"M50.6.2"],

Cell[TextData[{
  "Sometimes you will want to use a definition for a function that can best \
be presented as a sequence of definitions. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will allow you to do this. In this example we want our function to give \
the argument times the sine of some multiple of the argument. It would be \
awkward if we had to add 1 as an argument when the multiple was 1."
}], "Text",
  CellTags->"M50.6.2"],

Cell[BoxData[
    \(\(f[x_] = \ x\ Sin[x];\)\)], "Input",
  CellTags->"M50.6.2"],

Cell[BoxData[
    \(\(f[x_, a_] = \ x\ Sin[a\ x];\)\)], "Input",
  CellTags->"M50.6.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[3]\)], "Input",
  CellTags->"M50.6.2"],

Cell[BoxData[
    \(3\ Sin[3]\)], "Output",
  CellTags->"M50.6.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[3, 5]\)], "Input",
  CellTags->"M50.6.2"],

Cell[BoxData[
    \(3\ Sin[15]\)], "Output",
  CellTags->"M50.6.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order of Operations", "Section",
  CellTags->"M50.6.3"],

Cell[TextData[{
  "We spend a good deal of time in algebra classes teaching the importance of \
the correct order of evaluation. The same principles apply when you are \
writing a program. There are two ways of making assignments in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ": using ",
  StyleBox["Set", "MR"],
  " or ",
  StyleBox["SetDelayed", "MR"],
  ". Although it may not appear obvious at first, the use of these functions \
requires some knowledge of the order in which ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " evaluates expressions."
}], "Text",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{

Cell["Set", "Subsection",
  CellTags->"M50.6.3"],

Cell[TextData[{
  "Assignments can be ",
  StyleBox["immediate",
    FontSlant->"Italic"],
  " or ",
  StyleBox["delayed",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Set", "MR"],
  " is used to make an immediate assignment."
}], "Text",
  CellTags->"M50.6.3"],

Cell[TextData[{
  "In an immediate assignment (",
  StyleBox["lhs\[ThinSpace]", "IT"],
  StyleBox["=", "MR"],
  StyleBox["\[ThinSpace]rhs", "IT"],
  "), the right side of the assignment is evaluated before the definition is \
constructed."
}], "Text",
  CellTags->"M50.6.3"],

Cell[TextData[{
  "In a delayed assignment (",
  StyleBox["lhs\[ThinSpace]", "IT"],
  StyleBox[":=", "MR"],
  StyleBox["\[ThinSpace]rhs", "IT"],
  "), the right side of the assignment is not evaluated until the definition \
is used."
}], "Text",
  CellTags->"M50.6.3"],

Cell[TextData[{
  "Here is a simple example using the ",
  StyleBox["Random", "MR"],
  " function that generates a pseudorandom number between zero and one. Note \
that all the entries in the first column of the table are the same while \
those in the second column vary."
}], "Text",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ran1\  = \ Random[]\)], "Input",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(0.45864691270336155`\)], "Output",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[BoxData[
    \(ran2\  := \ Random[]\)], "Input",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{ran1, ran2}, {3}] // TableForm\)], "Input",
  CellTags->"M50.6.3"],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.45864691270336155`", "0.7667885652784515`"},
          {"0.45864691270336155`", "0.5382553337439454`"},
          {"0.45864691270336155`", "0.9464456939015596`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[BoxData[
    \(Clear[ran1, ran2]\)], "Input",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Set", "Subsection"]], "Subsection",
  CellTags->"M50.6.3"],

Cell["\<\
The following function is defined after expanding the polynomial on the right \
side of the immediate assignment.\
\>", "Text",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[p_] = Expand[\((1 + p)\)^3]\)], "Input",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(1 + 3\ p + 3\ p\^2 + p\^3\)], "Output",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[1 + x]\)], "Input",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(1 + 3\ \((1 + x)\) + 3\ \((1 + x)\)\^2 + \((1 + x)\)\^3\)], "Output",
  CellTags->"M50.6.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SetDelayed", "Subsection",
  CellTags->"M50.6.3"],

Cell[TextData[{
  StyleBox["SetDelayed", "MR"],
  " gives a delayed assignment."
}], "Text",
  CellTags->"M50.6.3"],

Cell["\<\
With a delayed assignment, the expansion on the right side of the following \
definition is postponed until the definition is used.\
\>", "Text",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(f[p_] := Expand[\((1 + p)\)^3]\)], "Input",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[1 + x]\)], "Input",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(8 + 12\ x + 6\ x\^2 + x\^3\)], "Output",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[TextData[{
  "Clear the definition of ",
  StyleBox["f", "MR"],
  " before continuing."
}], "Text",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(Clear[f]\)], "Input",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using Delayed Assignments", "Subsection",
  CellTags->"M50.6.3"],

Cell["\<\
When creating assignments, you need to decide whether the right side of the \
rule should be evaluated now or when the rule is used and then use the \
appropriate type of assignment.\
\>", "Text",
  CellTags->"M50.6.3"],

Cell["\<\
Assignments for constants or simple functions are usually done using \
immediate assignments, since there is no need in such cases to postpone \
evaluation of the right side of the assignment. For example,\
\>", "Text",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(n = 7\)], "Input",
  Evaluatable->False,
  CellTags->"M50.6.3"],

Cell["\<\
Assignments for nontrivial programs are usually done using delayed \
assignments, since most programs can\[CloseCurlyQuote]t run as intended until \
the values of the arguments are known. For example,\
\>", "Text",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(f[n_] := Expand[\((1 + x)\)^n]\)], "Input",
  Evaluatable->False,
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["When Set Works", "Subsection",
  CellTags->"M50.6.3"],

Cell[TextData[{
  "It is not difficult to find examples where delayed assignments are not \
what you want to use for function definitions, because the definition is \
evaluated before the program has enough information. For example, the \
function ",
  StyleBox["D", "MR"],
  " is used to take derivatives. The first argument is the function to be \
differentiated and the second is the variable of differentiation."
}], "Text",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(f[x_]\  := \ x\ Sin[x]\)], "Input",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(fprime[x_] := \ D[f[x], x]\)], "Input",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fprime[4]\)], "Input",
  CellTags->"M50.6.3"],

Cell[BoxData[
    RowBox[{\(General::"ivar"\), \(\(:\)\(\ \)\), "\<\"\\!\\(4\\) is not a \
valid variable. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::ivar\\\"]\\)\"\>"}]], "Message",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(\[PartialD]\_4\((4\ Sin[4])\)\)], "Output",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[TextData[{
  "Because we used ",
  StyleBox["SetDelayed", "MR"],
  " here, all the occurences of ",
  StyleBox["x", "MR"],
  " on the right of the definition were replaced by the number 4 ",
  StyleBox["before",
    FontSlant->"Italic"],
  " the differentiation was attempted. Since one of those ",
  StyleBox["x", "MR"],
  "\[CloseCurlyQuote]s specified the variable of differentiation, our \
definition fails."
}], "Text",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(Clear[f, fprime]\)], "Input",
  CellTags->"M50.6.3"],

Cell[TextData[{
  "We can make this definition work by using ",
  StyleBox["Set", "MR"],
  "."
}], "Text",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[x_] = x\ Sin[x]\)], "Input",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(x\ Sin[x]\)], "Output",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fprime[x_] = D[f[x], x]\)], "Input",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(x\ Cos[x] + Sin[x]\)], "Output",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fprime[3]\)], "Input",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(3\ Cos[3] + Sin[3]\)], "Output",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell["\<\
This works because the derivative is computed first and then the value of the \
argument is substituted.\
\>", "Text",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(Clear[f, fprime]\)], "Input",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["When SetDelayed Works", "Subsection",
  CellTags->"M50.6.3"],

Cell[TextData[{
  "There are situations when ",
  StyleBox["Set", "MR"],
  " will cause problems in your definitions, usually because ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not have enough information to do what is required. Here is a \
function to create an ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Cross]n\)]],
  " matrix of pseudorandom numbers."
}], "Text",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeMatrix[n_] = \ Table[Random[], {n}, {n}]\)], "Input",
  CellTags->"M50.6.3"],

Cell[BoxData[
    RowBox[{\(Table::"iterb"\), \(\(:\)\(\ \)\), "\<\"Iterator \\!\\({n}\\) \
does not have appropriate bounds. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::iterb\\\"]\\)\"\>"}]], "Message",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(Table[Random[], {n}, {n}]\)], "Output",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[TextData[{
  "The difficulty here is that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is trying to construct a matrix before knowing how large the matrix \
should be. Note that in this case things fail before we have a chance to try \
out our function; in fact, they fail when the ",
  StyleBox["MakeMatrix", "MR"],
  " function is first defined."
}], "Text",
  CellTags->"M50.6.3"],

Cell[TextData[{
  "If we use the same definition with ",
  StyleBox["SetDelayed", "MR"],
  " everything works fine."
}], "Text",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(MakeMatrix[n_] := \ Table[Random[], {n}, {n}]\)], "Input",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeMatrix[3]\)], "Input",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \({{0.6783708882177351`, 0.1695443522080856`, 
        0.679567770571385`}, {0.3450302278322847`, 0.6087872924094153`, 
        0.19698999201180692`}, {0.9888002501352956`, 0.6758669602203159`, 
        0.7641989106911593`}}\)], "Output",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[TextData[{
  "This works because ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knows what size the matrix is to be before trying to construct it."
}], "Text",
  CellTags->"M50.6.3"],

Cell[BoxData[
    \(Clear[MakeMatrix]\)], "Input",
  CellTags->"M50.6.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise 1", "Section"],

Cell[TextData[{
  "Define a function ",
  StyleBox["f[x]", "MR"],
  " that returns ",
  StyleBox["x\[ThinSpace]Sin[x]", "MR"],
  ". Evaluate ",
  StyleBox["f[x]", "MR"],
  " for various values of ",
  StyleBox["x", "MR"],
  " to verify that your definition is working."
}], "Exercise"],

Cell[TextData[{
  "Plot ",
  StyleBox["f[\[Theta]]", "MR"],
  " for ",
  StyleBox["\[Theta]", "MR"],
  " between ",
  Cell[BoxData[
      \(TraditionalForm\`\(-10\)\)]],
  " and 10. Does it make any difference that the variable of the plot is ",
  StyleBox["\[Theta]", "MR"],
  " and not ",
  StyleBox["x", "MR"],
  "?"
}], "Exercise"],

Cell[TextData[{
  "Clear your definition of ",
  StyleBox["f", "MR"],
  " before continuing."
}], "Exercise"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions with Integer Arguments", "Section",
  CellTags->"M50.6.4"],

Cell[TextData[{
  "Using functions like our ",
  StyleBox["MakeMatrix", "MR"],
  " function or ",
  StyleBox["Factorial", "MR"],
  " or ",
  StyleBox["Fibonacci", "MR"],
  " with noninteger arguments would not make any sense. "
}], "Text",
  CellTags->"M50.6.4"],

Cell[BoxData[
    \(MakeMatrix[n_] := \ Table[Random[], {n}, {n}]\)], "Input",
  Evaluatable->False,
  CellTags->"M50.6.4"],

Cell[TextData[{
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "will allow us to define our functions in such a way that trying to use \
inappropriate arguments will cause them not to evaluate. We will not explain \
how this works in detail but will illustrate the process with some examples."
}], "Text",
  CellTags->"M50.6.4"],

Cell[CellGroupData[{

Cell["MakeMatrix", "Subsection",
  CellTags->"M50.6.4"],

Cell[TextData[{
  "We can set up our functions to accept only positive integer arguments by \
adding ",
  StyleBox["Integer?Positive", "MR"],
  " immediately after the underscore character. This will check that the \
argument passed to ",
  StyleBox["MakeMatrix", "MR"],
  " is an integer and also passes the ",
  StyleBox["Positive", "MR"],
  " test. We will give two forms for the function so we can construct \
matrices that are not square."
}], "Text",
  CellTags->"M50.6.4"],

Cell[BoxData[
    \(MakeMatrix[n_Integer?Positive] := \ 
      Table[Random[], {n}, {n}]\)], "Input",
  CellTags->"M50.6.4"],

Cell[BoxData[
    \(MakeMatrix[n_Integer?Positive, m_Integer?Positive] := \ 
      Table[Random[], {n}, {m}]\)], "Input",
  CellTags->"M50.6.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeMatrix[2] // MatrixForm\)], "Input",
  CellTags->"M50.6.4"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.8279885175965805`", "0.6462023624546924`"},
            {"0.45438990373091287`", "0.21695534592568055`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  CellTags->"M50.6.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeMatrix[2, 3] // MatrixForm\)], "Input",
  CellTags->"M50.6.4"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.7872999617997308`", "0.5299832877838422`", 
              "0.5070332020353389`"},
            {"0.9256316638469565`", "0.851985828928541`", 
              "0.9278204111650366`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  CellTags->"M50.6.4"]
}, Open  ]],

Cell["\<\
Here we see the argument checking works since the function does not evaluate \
when the arguments are not integers.\
\>", "Text",
  CellTags->"M50.6.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeMatrix[4/3]\)], "Input",
  CellTags->"M50.6.4"],

Cell[BoxData[
    \(MakeMatrix[4\/3]\)], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  CellTags->"M50.6.4"]
}, Open  ]],

Cell[BoxData[
    \(Clear[MakeMatrix]\)], "Input",
  CellTags->"M50.6.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Recursion", "Section",
  CellTags->"M50.6.5"],

Cell["\<\
Some of the most fun examples for the classroom rely on the idea of \
recursion. Factorials and the Fibonacci numbers are two examples which come \
easily to mind.\
\>", "Text",
  CellTags->"M50.6.5"],

Cell[CellGroupData[{

Cell["Factorials", "Subsection",
  CellTags->"M50.6.5"],

Cell["\<\
It is easy to define factorials using recursion. First we give a base case.\
\>", "Text",
  CellTags->"M50.6.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fac[1] = \ 1\)], "Input",
  CellTags->"M50.6.5"],

Cell[BoxData[
    \(1\)], "Output",
  CellTags->"M50.6.5"]
}, Open  ]],

Cell[TextData[{
  "Now we define the general case. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is programmed to automatically carry out the recursion so we do not have \
to use special programming techniques to make this work. Note that we insist \
the argument be a positive integer."
}], "Text",
  CellTags->"M50.6.5"],

Cell[BoxData[
    \(fac[n_Integer?Positive]\  := \ n\ fac[n - 1]\)], "Input",
  CellTags->"M50.6.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fac[6]\)], "Input",
  CellTags->"M50.6.5"],

Cell[BoxData[
    \(720\)], "Output",
  CellTags->"M50.6.5"]
}, Open  ]],

Cell[BoxData[
    \(Clear[fac]\)], "Input",
  CellTags->"M50.6.5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise 2", "Section"],

Cell["\<\
Write a definition for Fibonacci numbers which only takes positive integer \
arguments. If you have forgotten the definition of Fibonacci numbers you \
want:\
\>", "Exercise"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(fib(1) = 1\)},
          {\(fib(2) = 1\)},
          {\(fib(n) = fib(n - 1) + fib(n - 2)\)}
          }], TraditionalForm]]]], "DisplayFormula",
  GridBoxOptions->{ColumnAlignments->{"="}}],

Cell[TextData[{
  "Here is a list of the first 11 Fibonacci numbers: {",
  Cell[BoxData[
      \(TraditionalForm\`1, 1, 2, 3, 5, 8, 13, 21, 34, 55, 89\)]],
  "}."
}], "Text"],

Cell[CellGroupData[{

Cell["Fibonacci Numbers (Dynamic Programming)", "ExerciseHeading",
  CounterAssignments->{{"Chapter", 6}, {"ExerciseNumber", 2}}],

Cell[TextData[{
  "While the definition given in the preceding exercise is correct, it does \
have one problem that we might want to consider. It calculates each Fibonacci \
number from scratch which means that it can take a very long time if we wish \
to calculate a number of values. It would be nice if we could store the \
values as they are calculated. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will allow us to do that. Consider the following function."
}], "Exercise"],

Cell[BoxData[{
    \(\(AddSquare[1] = \ 1;\)\), "\n", 
    \(AddSquare[
        n_] := \ \(AddSquare[
          n] = \((n + \ AddSquare[n - 1])\)\^2\)\)}], "Input"],

Cell["\<\
Let\[CloseCurlyQuote]s look at the rules associated with this function.\
\>", "Text"],

Cell[BoxData[
    \(\(?AddSquare\)\)], "Input"],

Cell["\<\
Now let\[CloseCurlyQuote]s evaluate the function and see what happens.\
\>", "Text"],

Cell[BoxData[
    \(AddSquare[3]\)], "Input"],

Cell[BoxData[
    \(\(?AddSquare\)\)], "Input"],

Cell[TextData[{
  "Notice that new information has been added to what ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knows. In particular, the program has stored all of the values it has \
calculated. This is called ",
  StyleBox["dynamic programming",
    FontSlant->"Italic"],
  " and can greatly speed up the execution of a program. It does have a \
penalty though; it requires more memory. Define a new function ",
  StyleBox["fib2", "MR"],
  " using dynamic programming, and then compare the times needed to calculate \
a table of the first 100 Fibonacci numbers using both of the functions."
}], "Text"],

Cell[BoxData[{
    \(\(fib2[0] = 0;\)\), "\n", 
    \(\(fib2[1] = 1;\)\), "\n", 
    \(fib2[n_] := \ \(fib2[n] = fib2[n - 1] + fib2[n - 2]\)\)}], "Input"],

Cell["\<\
Let\[CloseCurlyQuote]s compare the timing for the two versions of our \
function.\
\>", "Text"],

Cell[BoxData[
    \(Timing[\(Table[fib[n], {n, 0, 25}];\)]\)], "Input"],

Cell[BoxData[
    \(Timing[\(Table[fib2[n], {n, 0, 100}];\)]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise 3 - A Distance Function", "Section",
  CounterAssignments->{{"Chapter", 6}, {"ExerciseNumber", 3}}],

Cell["\<\
There are many places where it is handy to have a distance function, such as \
when we are working with the Pythagorian theorem. It is also useful if the \
distance function we define will work in several dimensions. An easy way to \
do this is to remember that the length of a vector can be found using the dot \
product (This sounds as if this is a case for the Help Browser.). For \
example, your function should give the following:\
\>", "Exercise"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Distance[{1, 2}, {4, 5}]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    RowBox[{"3", 
      FormBox[\(\@2\),
        "TraditionalForm"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Distance[{1, 2, 3}, {3, 5, 4}]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    RowBox[{" ", 
      FormBox[\(\@14\),
        "TraditionalForm"]}]], "Output"]
}, Open  ]],

Cell["\<\
Define a function which gives the distance between two points as long as the \
points both have the same dimensions.\
\>", "Exercise"],

Cell[TextData[{
  "Use your function with ",
  StyleBox["Solve", "MR"],
  " to find functions which define a circle with center (",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(x\_0\),
            "TraditionalForm"], ",", \(y\_0\)}], TraditionalForm]]],
  ") and radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ". Define a pair of functions which can be used in ",
  StyleBox["ParametricPlot", "MR"],
  " to plot your circle."
}], "Exercise"],

Cell["Can you do something similar for ellipses?", "Exercise"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Exercise 4 - Curve Sketching \[FivePointedStar]\[FivePointedStar]\
\>", "Section",
  CounterAssignments->{{"Chapter", 6}, {"ExerciseNumber", 3}}],

Cell[TextData[{
  "One of the primary areas of investigation in an introductory calculus \
course concerns the relationship between a function and its derivatives. We \
can do this easily with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Define the function ",
  StyleBox["f", "MR"],
  " and the first two derivatives ",
  StyleBox["fprm", "MR"],
  " and ",
  StyleBox["fdblprm", "MR"],
  " (look for ",
  StyleBox["D", "MR"],
  " in the Help Browser) for:"
}], "Exercise"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      StyleBox[\(y = \(81\ x\)\/64 + \(27\ x\^2\)\/32 - \(23\ x\^3\)\/8 + 
            x\^4\),
        FontFamily->"Times"]]]
}], "DisplayFormula"],

Cell["\<\
Test your derivative functions by evaluating them for a symbolic argument. Do \
they work for numerical arguments? If not, why not?\
\>", "Exercise"],

Cell[TextData[{
  "Making use of such functions as ",
  StyleBox["Solve", "MR"],
  ", ",
  StyleBox["Which", "MR"],
  ", and ",
  StyleBox["TableForm,", "MR"],
  " construct a table showing where f is increasing, decreasing, has a point \
of inflection, etc."
}], "Exercise"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise 5 - Riemann Sums", "Section",
  CounterAssignments->{{"Chapter", 6}, {"ExerciseNumber", 5}}],

Cell[TextData[{
  "It is easy to construct a table of values using the ",
  StyleBox["Table", "MR"],
  " function. You can give a starting value, an ending value, and a step size \
for your iterator. Here is an example."
}], "Exercise"],

Cell[BoxData[
    \(Table[x + 1, {x, 3, 5, 1/4}]\)], "Input"],

Cell[TextData[{
  "Use the table function to define a ",
  StyleBox["RiemannSum", "MR"],
  " function to approximate the area between the sine function and the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-axis on the interval (0, \[Pi]/2). Your function should take as its \
argument the number of subintervals you want to use and give as output the \
areas of the individual rectangles used to approximate the area. (If you want \
to get the sum of the rectangles you can use ",
  StyleBox["Apply[Plus,{", "MR"],
  StyleBox["rectangles", "IT"],
  StyleBox["}]", "MR"],
  ".)"
}], "Exercise"],

Cell[TextData[{
  "You can get some idea of how quickly this is converging by using ",
  StyleBox["Apply[Plus,RiemannSum[1000]]", "MR"],
  "."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{495, 561},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "WolframEducation.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "M50.6.1"->{
    Cell[1776, 53, 106, 1, 74, "Title",
      CellTags->{"M50.6.1", "M50.6.2", "M50.6.4", "M50.6.3", "M50.6.5"}],
    Cell[1907, 58, 50, 1, 44, "Section",
      CellTags->"M50.6.1"],
    Cell[1960, 61, 69, 1, 30, "Text",
      CellTags->"M50.6.1"],
    Cell[2032, 64, 78, 1, 36, "BulletItem",
      CellTags->"M50.6.1"],
    Cell[2113, 67, 69, 1, 36, "BulletItem",
      CellTags->"M50.6.1"],
    Cell[2185, 70, 68, 1, 36, "BulletItem",
      CellTags->"M50.6.1"],
    Cell[2256, 73, 95, 1, 36, "BulletItem",
      CellTags->"M50.6.1"],
    Cell[2354, 76, 100, 1, 36, "BulletItem",
      CellTags->"M50.6.1"],
    Cell[2457, 79, 78, 1, 36, "BulletItem",
      CellTags->"M50.6.1"]},
  "M50.6.2"->{
    Cell[1776, 53, 106, 1, 74, "Title",
      CellTags->{"M50.6.1", "M50.6.2", "M50.6.4", "M50.6.3", "M50.6.5"}],
    Cell[2572, 85, 69, 1, 44, "Section",
      CellTags->"M50.6.2"],
    Cell[2666, 90, 56, 1, 63, "Subsection",
      CellTags->"M50.6.2"],
    Cell[2725, 93, 133, 4, 48, "Text",
      CellTags->"M50.6.2"],
    Cell[2861, 99, 405, 9, 67, "Text",
      CellTags->"M50.6.2"],
    Cell[3291, 112, 61, 2, 32, "Input",
      CellTags->"M50.6.2"],
    Cell[3355, 116, 58, 2, 39, "Output",
      CellTags->"M50.6.2"],
    Cell[3428, 121, 254, 10, 49, "Text",
      CellTags->"M50.6.2"],
    Cell[3685, 133, 51, 1, 30, "Text",
      CellTags->"M50.6.2"],
    Cell[3761, 138, 52, 1, 32, "Input",
      CellTags->"M50.6.2"],
    Cell[3816, 141, 64, 2, 39, "Output",
      CellTags->"M50.6.2"],
    Cell[3895, 146, 212, 5, 66, "Text",
      CellTags->"M50.6.2"],
    Cell[4110, 153, 48, 1, 32, "Input",
      CellTags->"M50.6.2"],
    Cell[4195, 159, 63, 1, 63, "Subsection",
      CellTags->"M50.6.2"],
    Cell[4261, 162, 98, 1, 30, "Text",
      CellTags->"M50.6.2"],
    Cell[4384, 167, 75, 2, 32, "Input",
      CellTags->"M50.6.2"],
    Cell[4462, 171, 66, 2, 39, "Output",
      CellTags->"M50.6.2"],
    Cell[4543, 176, 114, 3, 30, "Text",
      CellTags->"M50.6.2"],
    Cell[4682, 183, 60, 2, 32, "Input",
      CellTags->"M50.6.2"],
    Cell[4745, 187, 66, 2, 39, "Output",
      CellTags->"M50.6.2"],
    Cell[4826, 192, 283, 9, 67, "Text",
      CellTags->"M50.6.2"],
    Cell[5112, 203, 199, 9, 31, "Text",
      CellTags->"M50.6.2"],
    Cell[5314, 214, 256, 7, 50, "Text",
      CellTags->"M50.6.2"],
    Cell[5607, 226, 63, 1, 63, "Subsection",
      CellTags->"M50.6.2"],
    Cell[5673, 229, 448, 9, 102, "Text",
      CellTags->"M50.6.2"],
    Cell[6124, 240, 80, 2, 32, "Input",
      CellTags->"M50.6.2"],
    Cell[6207, 244, 87, 2, 32, "Input",
      CellTags->"M50.6.2"],
    Cell[6319, 250, 60, 2, 32, "Input",
      CellTags->"M50.6.2"],
    Cell[6382, 254, 66, 2, 39, "Output",
      CellTags->"M50.6.2"],
    Cell[6485, 261, 63, 2, 32, "Input",
      CellTags->"M50.6.2"],
    Cell[6551, 265, 67, 2, 39, "Output",
      CellTags->"M50.6.2"]},
  "M50.6.4"->{
    Cell[1776, 53, 106, 1, 74, "Title",
      CellTags->{"M50.6.1", "M50.6.2", "M50.6.4", "M50.6.3", "M50.6.5"}],
    Cell[17967, 738, 74, 1, 44, "Section",
      CellTags->"M50.6.4"],
    Cell[18044, 741, 262, 9, 50, "Text",
      CellTags->"M50.6.4"],
    Cell[18309, 752, 123, 3, 32, "Input",
      Evaluatable->False,
      CellTags->"M50.6.4"],
    Cell[18435, 757, 336, 7, 84, "Text",
      CellTags->"M50.6.4"],
    Cell[18796, 768, 55, 1, 63, "Subsection",
      CellTags->"M50.6.4"],
    Cell[18854, 771, 479, 12, 105, "Text",
      CellTags->"M50.6.4"],
    Cell[19336, 785, 124, 3, 52, "Input",
      CellTags->"M50.6.4"],
    Cell[19463, 790, 144, 3, 72, "Input",
      CellTags->"M50.6.4"],
    Cell[19632, 797, 83, 2, 32, "Input",
      CellTags->"M50.6.4"],
    Cell[19718, 801, 376, 10, 53, "Output",
      CellTags->"M50.6.4"],
    Cell[20131, 816, 86, 2, 32, "Input",
      CellTags->"M50.6.4"],
    Cell[20220, 820, 449, 12, 53, "Output",
      CellTags->"M50.6.4"],
    Cell[20684, 835, 162, 4, 48, "Text",
      CellTags->"M50.6.4"],
    Cell[20871, 843, 71, 2, 32, "Input",
      CellTags->"M50.6.4"],
    Cell[20945, 847, 125, 4, 52, "Output",
      CellTags->"M50.6.4"],
    Cell[21085, 854, 73, 2, 32, "Input",
      CellTags->"M50.6.4"]},
  "M50.6.3"->{
    Cell[1776, 53, 106, 1, 74, "Title",
      CellTags->{"M50.6.1", "M50.6.2", "M50.6.4", "M50.6.3", "M50.6.5"}],
    Cell[6679, 274, 61, 1, 44, "Section",
      CellTags->"M50.6.3"],
    Cell[6743, 277, 611, 16, 121, "Text",
      CellTags->"M50.6.3"],
    Cell[7379, 297, 48, 1, 63, "Subsection",
      CellTags->"M50.6.3"],
    Cell[7430, 300, 262, 11, 49, "Text",
      CellTags->"M50.6.3"],
    Cell[7695, 313, 274, 8, 49, "Text",
      CellTags->"M50.6.3"],
    Cell[7972, 323, 268, 8, 49, "Text",
      CellTags->"M50.6.3"],
    Cell[8243, 333, 307, 7, 85, "Text",
      CellTags->"M50.6.3"],
    Cell[8575, 344, 75, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[8653, 348, 77, 2, 39, "Output",
      CellTags->"M50.6.3"],
    Cell[8745, 353, 76, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[8846, 359, 93, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[8942, 363, 439, 12, 71, "Output",
      CellTags->"M50.6.3"],
    Cell[9396, 378, 73, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[9506, 385, 82, 1, 63, "Subsection",
      CellTags->"M50.6.3"],
    Cell[9591, 388, 160, 4, 48, "Text",
      CellTags->"M50.6.3"],
    Cell[9776, 396, 85, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[9864, 400, 82, 2, 39, "Output",
      CellTags->"M50.6.3"],
    Cell[9983, 407, 64, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[10050, 411, 112, 2, 39, "Output",
      CellTags->"M50.6.3"],
    Cell[10211, 419, 55, 1, 63, "Subsection",
      CellTags->"M50.6.3"],
    Cell[10269, 422, 115, 4, 31, "Text",
      CellTags->"M50.6.3"],
    Cell[10387, 428, 178, 4, 48, "Text",
      CellTags->"M50.6.3"],
    Cell[10568, 434, 86, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[10679, 440, 64, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[10746, 444, 83, 2, 39, "Output",
      CellTags->"M50.6.3"],
    Cell[10844, 449, 127, 5, 31, "Text",
      CellTags->"M50.6.3"],
    Cell[10974, 456, 64, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[11075, 463, 70, 1, 63, "Subsection",
      CellTags->"M50.6.3"],
    Cell[11148, 466, 229, 5, 66, "Text",
      CellTags->"M50.6.3"],
    Cell[11380, 473, 252, 5, 66, "Text",
      CellTags->"M50.6.3"],
    Cell[11635, 480, 83, 3, 32, "Input",
      Evaluatable->False,
      CellTags->"M50.6.3"],
    Cell[11721, 485, 247, 5, 66, "Text",
      CellTags->"M50.6.3"],
    Cell[11971, 492, 108, 3, 32, "Input",
      Evaluatable->False,
      CellTags->"M50.6.3"],
    Cell[12116, 500, 59, 1, 63, "Subsection",
      CellTags->"M50.6.3"],
    Cell[12178, 503, 451, 9, 103, "Text",
      CellTags->"M50.6.3"],
    Cell[12632, 514, 78, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[12713, 518, 82, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[12820, 524, 65, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[12888, 528, 293, 5, 48, "Message",
      CellTags->"M50.6.3"],
    Cell[13184, 535, 86, 2, 39, "Output",
      CellTags->"M50.6.3"],
    Cell[13285, 540, 452, 13, 86, "Text",
      CellTags->"M50.6.3"],
    Cell[13740, 555, 72, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[13815, 559, 129, 5, 31, "Text",
      CellTags->"M50.6.3"],
    Cell[13969, 568, 73, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[14045, 572, 66, 2, 39, "Output",
      CellTags->"M50.6.3"],
    Cell[14148, 579, 79, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[14230, 583, 75, 2, 39, "Output",
      CellTags->"M50.6.3"],
    Cell[14342, 590, 65, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[14410, 594, 75, 2, 39, "Output",
      CellTags->"M50.6.3"],
    Cell[14500, 599, 151, 4, 48, "Text",
      CellTags->"M50.6.3"],
    Cell[14654, 605, 72, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[14763, 612, 66, 1, 63, "Subsection",
      CellTags->"M50.6.3"],
    Cell[14832, 615, 415, 12, 85, "Text",
      CellTags->"M50.6.3"],
    Cell[15272, 631, 100, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[15375, 635, 313, 5, 48, "Message",
      CellTags->"M50.6.3"],
    Cell[15691, 642, 82, 2, 39, "Output",
      CellTags->"M50.6.3"],
    Cell[15788, 647, 402, 10, 85, "Text",
      CellTags->"M50.6.3"],
    Cell[16193, 659, 151, 5, 31, "Text",
      CellTags->"M50.6.3"],
    Cell[16347, 666, 101, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[16473, 672, 69, 2, 32, "Input",
      CellTags->"M50.6.3"],
    Cell[16545, 676, 279, 5, 81, "Output",
      CellTags->"M50.6.3"],
    Cell[16839, 684, 199, 6, 48, "Text",
      CellTags->"M50.6.3"],
    Cell[17041, 692, 73, 2, 32, "Input",
      CellTags->"M50.6.3"]},
  "M50.6.5"->{
    Cell[1776, 53, 106, 1, 74, "Title",
      CellTags->{"M50.6.1", "M50.6.2", "M50.6.4", "M50.6.3", "M50.6.5"}],
    Cell[21207, 862, 51, 1, 44, "Section",
      CellTags->"M50.6.5"],
    Cell[21261, 865, 210, 5, 66, "Text",
      CellTags->"M50.6.5"],
    Cell[21496, 874, 55, 1, 63, "Subsection",
      CellTags->"M50.6.5"],
    Cell[21554, 877, 122, 3, 30, "Text",
      CellTags->"M50.6.5"],
    Cell[21701, 884, 68, 2, 32, "Input",
      CellTags->"M50.6.5"],
    Cell[21772, 888, 58, 2, 39, "Output",
      CellTags->"M50.6.5"],
    Cell[21845, 893, 335, 8, 84, "Text",
      CellTags->"M50.6.5"],
    Cell[22183, 903, 100, 2, 32, "Input",
      CellTags->"M50.6.5"],
    Cell[22308, 909, 62, 2, 32, "Input",
      CellTags->"M50.6.5"],
    Cell[22373, 913, 60, 2, 39, "Output",
      CellTags->"M50.6.5"],
    Cell[22448, 918, 66, 2, 32, "Input",
      CellTags->"M50.6.5"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"M50.6.1", 30349, 1188},
  {"M50.6.2", 31047, 1207},
  {"M50.6.4", 33236, 1270},
  {"M50.6.3", 34516, 1306},
  {"M50.6.5", 39090, 1437}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 106, 1, 74, "Title",
  CellTags->{"M50.6.1", "M50.6.2", "M50.6.4", "M50.6.3", "M50.6.5"}],

Cell[CellGroupData[{
Cell[1907, 58, 50, 1, 44, "Section",
  CellTags->"M50.6.1"],
Cell[1960, 61, 69, 1, 30, "Text",
  CellTags->"M50.6.1"],
Cell[2032, 64, 78, 1, 36, "BulletItem",
  CellTags->"M50.6.1"],
Cell[2113, 67, 69, 1, 36, "BulletItem",
  CellTags->"M50.6.1"],
Cell[2185, 70, 68, 1, 36, "BulletItem",
  CellTags->"M50.6.1"],
Cell[2256, 73, 95, 1, 36, "BulletItem",
  CellTags->"M50.6.1"],
Cell[2354, 76, 100, 1, 36, "BulletItem",
  CellTags->"M50.6.1"],
Cell[2457, 79, 78, 1, 36, "BulletItem",
  CellTags->"M50.6.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2572, 85, 69, 1, 44, "Section",
  CellTags->"M50.6.2"],

Cell[CellGroupData[{
Cell[2666, 90, 56, 1, 63, "Subsection",
  CellTags->"M50.6.2"],
Cell[2725, 93, 133, 4, 48, "Text",
  CellTags->"M50.6.2"],
Cell[2861, 99, 405, 9, 67, "Text",
  CellTags->"M50.6.2"],

Cell[CellGroupData[{
Cell[3291, 112, 61, 2, 32, "Input",
  CellTags->"M50.6.2"],
Cell[3355, 116, 58, 2, 39, "Output",
  CellTags->"M50.6.2"]
}, Open  ]],
Cell[3428, 121, 254, 10, 49, "Text",
  CellTags->"M50.6.2"],
Cell[3685, 133, 51, 1, 30, "Text",
  CellTags->"M50.6.2"],

Cell[CellGroupData[{
Cell[3761, 138, 52, 1, 32, "Input",
  CellTags->"M50.6.2"],
Cell[3816, 141, 64, 2, 39, "Output",
  CellTags->"M50.6.2"]
}, Open  ]],
Cell[3895, 146, 212, 5, 66, "Text",
  CellTags->"M50.6.2"],
Cell[4110, 153, 48, 1, 32, "Input",
  CellTags->"M50.6.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4195, 159, 63, 1, 63, "Subsection",
  CellTags->"M50.6.2"],
Cell[4261, 162, 98, 1, 30, "Text",
  CellTags->"M50.6.2"],

Cell[CellGroupData[{
Cell[4384, 167, 75, 2, 32, "Input",
  CellTags->"M50.6.2"],
Cell[4462, 171, 66, 2, 39, "Output",
  CellTags->"M50.6.2"]
}, Open  ]],
Cell[4543, 176, 114, 3, 30, "Text",
  CellTags->"M50.6.2"],

Cell[CellGroupData[{
Cell[4682, 183, 60, 2, 32, "Input",
  CellTags->"M50.6.2"],
Cell[4745, 187, 66, 2, 39, "Output",
  CellTags->"M50.6.2"]
}, Open  ]],
Cell[4826, 192, 283, 9, 67, "Text",
  CellTags->"M50.6.2"],
Cell[5112, 203, 199, 9, 31, "Text",
  CellTags->"M50.6.2"],
Cell[5314, 214, 256, 7, 50, "Text",
  CellTags->"M50.6.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5607, 226, 63, 1, 63, "Subsection",
  CellTags->"M50.6.2"],
Cell[5673, 229, 448, 9, 102, "Text",
  CellTags->"M50.6.2"],
Cell[6124, 240, 80, 2, 32, "Input",
  CellTags->"M50.6.2"],
Cell[6207, 244, 87, 2, 32, "Input",
  CellTags->"M50.6.2"],

Cell[CellGroupData[{
Cell[6319, 250, 60, 2, 32, "Input",
  CellTags->"M50.6.2"],
Cell[6382, 254, 66, 2, 39, "Output",
  CellTags->"M50.6.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6485, 261, 63, 2, 32, "Input",
  CellTags->"M50.6.2"],
Cell[6551, 265, 67, 2, 39, "Output",
  CellTags->"M50.6.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6679, 274, 61, 1, 44, "Section",
  CellTags->"M50.6.3"],
Cell[6743, 277, 611, 16, 121, "Text",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{
Cell[7379, 297, 48, 1, 63, "Subsection",
  CellTags->"M50.6.3"],
Cell[7430, 300, 262, 11, 49, "Text",
  CellTags->"M50.6.3"],
Cell[7695, 313, 274, 8, 49, "Text",
  CellTags->"M50.6.3"],
Cell[7972, 323, 268, 8, 49, "Text",
  CellTags->"M50.6.3"],
Cell[8243, 333, 307, 7, 85, "Text",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{
Cell[8575, 344, 75, 2, 32, "Input",
  CellTags->"M50.6.3"],
Cell[8653, 348, 77, 2, 39, "Output",
  CellTags->"M50.6.3"]
}, Open  ]],
Cell[8745, 353, 76, 2, 32, "Input",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{
Cell[8846, 359, 93, 2, 32, "Input",
  CellTags->"M50.6.3"],
Cell[8942, 363, 439, 12, 71, "Output",
  CellTags->"M50.6.3"]
}, Open  ]],
Cell[9396, 378, 73, 2, 32, "Input",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9506, 385, 82, 1, 63, "Subsection",
  CellTags->"M50.6.3"],
Cell[9591, 388, 160, 4, 48, "Text",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{
Cell[9776, 396, 85, 2, 32, "Input",
  CellTags->"M50.6.3"],
Cell[9864, 400, 82, 2, 39, "Output",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9983, 407, 64, 2, 32, "Input",
  CellTags->"M50.6.3"],
Cell[10050, 411, 112, 2, 39, "Output",
  CellTags->"M50.6.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10211, 419, 55, 1, 63, "Subsection",
  CellTags->"M50.6.3"],
Cell[10269, 422, 115, 4, 31, "Text",
  CellTags->"M50.6.3"],
Cell[10387, 428, 178, 4, 48, "Text",
  CellTags->"M50.6.3"],
Cell[10568, 434, 86, 2, 32, "Input",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{
Cell[10679, 440, 64, 2, 32, "Input",
  CellTags->"M50.6.3"],
Cell[10746, 444, 83, 2, 39, "Output",
  CellTags->"M50.6.3"]
}, Open  ]],
Cell[10844, 449, 127, 5, 31, "Text",
  CellTags->"M50.6.3"],
Cell[10974, 456, 64, 2, 32, "Input",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11075, 463, 70, 1, 63, "Subsection",
  CellTags->"M50.6.3"],
Cell[11148, 466, 229, 5, 66, "Text",
  CellTags->"M50.6.3"],
Cell[11380, 473, 252, 5, 66, "Text",
  CellTags->"M50.6.3"],
Cell[11635, 480, 83, 3, 32, "Input",
  Evaluatable->False,
  CellTags->"M50.6.3"],
Cell[11721, 485, 247, 5, 66, "Text",
  CellTags->"M50.6.3"],
Cell[11971, 492, 108, 3, 32, "Input",
  Evaluatable->False,
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12116, 500, 59, 1, 63, "Subsection",
  CellTags->"M50.6.3"],
Cell[12178, 503, 451, 9, 103, "Text",
  CellTags->"M50.6.3"],
Cell[12632, 514, 78, 2, 32, "Input",
  CellTags->"M50.6.3"],
Cell[12713, 518, 82, 2, 32, "Input",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{
Cell[12820, 524, 65, 2, 32, "Input",
  CellTags->"M50.6.3"],
Cell[12888, 528, 293, 5, 48, "Message",
  CellTags->"M50.6.3"],
Cell[13184, 535, 86, 2, 39, "Output",
  CellTags->"M50.6.3"]
}, Open  ]],
Cell[13285, 540, 452, 13, 86, "Text",
  CellTags->"M50.6.3"],
Cell[13740, 555, 72, 2, 32, "Input",
  CellTags->"M50.6.3"],
Cell[13815, 559, 129, 5, 31, "Text",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{
Cell[13969, 568, 73, 2, 32, "Input",
  CellTags->"M50.6.3"],
Cell[14045, 572, 66, 2, 39, "Output",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14148, 579, 79, 2, 32, "Input",
  CellTags->"M50.6.3"],
Cell[14230, 583, 75, 2, 39, "Output",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14342, 590, 65, 2, 32, "Input",
  CellTags->"M50.6.3"],
Cell[14410, 594, 75, 2, 39, "Output",
  CellTags->"M50.6.3"]
}, Open  ]],
Cell[14500, 599, 151, 4, 48, "Text",
  CellTags->"M50.6.3"],
Cell[14654, 605, 72, 2, 32, "Input",
  CellTags->"M50.6.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14763, 612, 66, 1, 63, "Subsection",
  CellTags->"M50.6.3"],
Cell[14832, 615, 415, 12, 85, "Text",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{
Cell[15272, 631, 100, 2, 32, "Input",
  CellTags->"M50.6.3"],
Cell[15375, 635, 313, 5, 48, "Message",
  CellTags->"M50.6.3"],
Cell[15691, 642, 82, 2, 39, "Output",
  CellTags->"M50.6.3"]
}, Open  ]],
Cell[15788, 647, 402, 10, 85, "Text",
  CellTags->"M50.6.3"],
Cell[16193, 659, 151, 5, 31, "Text",
  CellTags->"M50.6.3"],
Cell[16347, 666, 101, 2, 32, "Input",
  CellTags->"M50.6.3"],

Cell[CellGroupData[{
Cell[16473, 672, 69, 2, 32, "Input",
  CellTags->"M50.6.3"],
Cell[16545, 676, 279, 5, 81, "Output",
  CellTags->"M50.6.3"]
}, Open  ]],
Cell[16839, 684, 199, 6, 48, "Text",
  CellTags->"M50.6.3"],
Cell[17041, 692, 73, 2, 32, "Input",
  CellTags->"M50.6.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17163, 700, 29, 0, 44, "Section"],
Cell[17195, 702, 285, 10, 48, "Exercise"],
Cell[17483, 714, 335, 13, 48, "Exercise"],
Cell[17821, 729, 109, 4, 29, "Exercise"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17967, 738, 74, 1, 44, "Section",
  CellTags->"M50.6.4"],
Cell[18044, 741, 262, 9, 50, "Text",
  CellTags->"M50.6.4"],
Cell[18309, 752, 123, 3, 32, "Input",
  Evaluatable->False,
  CellTags->"M50.6.4"],
Cell[18435, 757, 336, 7, 84, "Text",
  CellTags->"M50.6.4"],

Cell[CellGroupData[{
Cell[18796, 768, 55, 1, 63, "Subsection",
  CellTags->"M50.6.4"],
Cell[18854, 771, 479, 12, 105, "Text",
  CellTags->"M50.6.4"],
Cell[19336, 785, 124, 3, 52, "Input",
  CellTags->"M50.6.4"],
Cell[19463, 790, 144, 3, 72, "Input",
  CellTags->"M50.6.4"],

Cell[CellGroupData[{
Cell[19632, 797, 83, 2, 32, "Input",
  CellTags->"M50.6.4"],
Cell[19718, 801, 376, 10, 53, "Output",
  CellTags->"M50.6.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20131, 816, 86, 2, 32, "Input",
  CellTags->"M50.6.4"],
Cell[20220, 820, 449, 12, 53, "Output",
  CellTags->"M50.6.4"]
}, Open  ]],
Cell[20684, 835, 162, 4, 48, "Text",
  CellTags->"M50.6.4"],

Cell[CellGroupData[{
Cell[20871, 843, 71, 2, 32, "Input",
  CellTags->"M50.6.4"],
Cell[20945, 847, 125, 4, 52, "Output",
  CellTags->"M50.6.4"]
}, Open  ]],
Cell[21085, 854, 73, 2, 32, "Input",
  CellTags->"M50.6.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21207, 862, 51, 1, 44, "Section",
  CellTags->"M50.6.5"],
Cell[21261, 865, 210, 5, 66, "Text",
  CellTags->"M50.6.5"],

Cell[CellGroupData[{
Cell[21496, 874, 55, 1, 63, "Subsection",
  CellTags->"M50.6.5"],
Cell[21554, 877, 122, 3, 30, "Text",
  CellTags->"M50.6.5"],

Cell[CellGroupData[{
Cell[21701, 884, 68, 2, 32, "Input",
  CellTags->"M50.6.5"],
Cell[21772, 888, 58, 2, 39, "Output",
  CellTags->"M50.6.5"]
}, Open  ]],
Cell[21845, 893, 335, 8, 84, "Text",
  CellTags->"M50.6.5"],
Cell[22183, 903, 100, 2, 32, "Input",
  CellTags->"M50.6.5"],

Cell[CellGroupData[{
Cell[22308, 909, 62, 2, 32, "Input",
  CellTags->"M50.6.5"],
Cell[22373, 913, 60, 2, 39, "Output",
  CellTags->"M50.6.5"]
}, Open  ]],
Cell[22448, 918, 66, 2, 32, "Input",
  CellTags->"M50.6.5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22563, 926, 29, 0, 44, "Section"],
Cell[22595, 928, 185, 4, 64, "Exercise"],
Cell[22783, 934, 252, 6, 61, "DisplayFormula"],
Cell[23038, 942, 174, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[23237, 951, 129, 1, 78, "ExerciseHeading",
  CounterAssignments->{{"Chapter", 6}, {"ExerciseNumber", 2}}],
Cell[23369, 954, 492, 9, 118, "Exercise"],
Cell[23864, 965, 164, 4, 72, "Input"],
Cell[24031, 971, 95, 2, 30, "Text"],
Cell[24129, 975, 47, 1, 32, "Input"],
Cell[24179, 978, 94, 2, 30, "Text"],
Cell[24276, 982, 45, 1, 32, "Input"],
Cell[24324, 985, 47, 1, 32, "Input"],
Cell[24374, 988, 621, 13, 139, "Text"],
Cell[24998, 1003, 154, 3, 72, "Input"],
Cell[25155, 1008, 105, 3, 30, "Text"],
Cell[25263, 1013, 71, 1, 32, "Input"],
Cell[25337, 1016, 73, 1, 32, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25459, 1023, 114, 1, 44, "Section",
  CounterAssignments->{{"Chapter", 6}, {"ExerciseNumber", 3}}],
Cell[25576, 1026, 463, 7, 136, "Exercise"],

Cell[CellGroupData[{
Cell[26064, 1037, 79, 2, 32, "Input",
  Evaluatable->False],
Cell[26146, 1041, 95, 3, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26278, 1049, 85, 2, 32, "Input",
  Evaluatable->False],
Cell[26366, 1053, 96, 3, 40, "Output"]
}, Open  ]],
Cell[26477, 1059, 144, 3, 46, "Exercise"],
Cell[26624, 1064, 477, 15, 66, "Exercise"],
Cell[27104, 1081, 62, 0, 28, "Exercise"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27203, 1086, 155, 3, 44, "Section",
  CounterAssignments->{{"Chapter", 6}, {"ExerciseNumber", 3}}],
Cell[27361, 1091, 488, 15, 102, "Exercise"],
Cell[27852, 1108, 186, 6, 33, "DisplayFormula"],
Cell[28041, 1116, 159, 3, 46, "Exercise"],
Cell[28203, 1121, 275, 9, 65, "Exercise"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28515, 1135, 107, 1, 44, "Section",
  CounterAssignments->{{"Chapter", 6}, {"ExerciseNumber", 5}}],
Cell[28625, 1138, 236, 5, 65, "Exercise"],
Cell[28864, 1145, 61, 1, 32, "Input"],
Cell[28928, 1148, 602, 14, 139, "Exercise"],
Cell[29533, 1164, 154, 4, 49, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

