(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    543785,      10279]*)
(*NotebookOutlinePosition[    550958,      10485]*)
(*  CellTagsIndexPosition[    550822,      10477]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["8. Programming II", "Title",
  CellTags->{"M50.8.1", "M50.8.2", "M50.8.3"}],

Cell[CellGroupData[{

Cell["Overview", "Section",
  CellTags->"M50.8.1"],

Cell["In this section we will cover:", "Text",
  CellTags->"M50.8.1"],

Cell[TextData[{
  "How to use the function ",
  StyleBox["Nest", "MR"],
  " for iterative operations"
}], "BulletItem",
  CellTags->"M50.8.1"],

Cell[TextData[{
  "How to use ",
  StyleBox["Map", "MR"],
  " and ",
  StyleBox["Apply", "MR"]
}], "BulletItem",
  CellTags->"M50.8.1"],

Cell["Special notation for functions", "BulletItem",
  CellTags->"M50.8.1"],

Cell["How to localize variables", "BulletItem",
  CellTags->"M50.8.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pure Functions", "Section",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{

Cell["Iteration with Nest", "Subsection",
  CellTags->"M50.8.2"],

Cell[TextData[{
  "In many examples we need to apply a function repeatedly to the outcome of \
the function. Working with compound interest provides a good example. Suppose \
we put $100 in a savings account paying 4% interest per year. How much will \
we have after 5 years? We can find the answer quickly using the ",
  StyleBox["Nest", "MR"],
  " function. The first argument is the function to apply repeatedly; the \
second is the initial value; and the third argument is the number of times \
(periods) to iterate the function."
}], "Text",
  CellTags->"M50.8.2"],

Cell[BoxData[
    \(f[x_] := \ 1.04\ x\)], "Input",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Nest[f, 100, 5]\)], "Input",
  CellTags->"M50.8.2"],

Cell[BoxData[
    \(121.66529024000002`\)], "Output",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[TextData[{
  "If you want to see all the intermediate values, use ",
  StyleBox["NestList", "MR"],
  "."
}], "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NestList[f, 100, 5]\)], "Input",
  CellTags->"M50.8.2"],

Cell[BoxData[
    \({100, 104.`, 108.16`, 112.4864`, 116.98585600000001`, 
      121.66529024000002`}\)], "Output",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[BoxData[
    \(Clear[f]\)], "Input",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some Special Notation", "Subsection",
  CellTags->"M50.8.2"],

Cell["\<\
There are times when it would be convenient to be able to use functions \
without defining them first; that is, use them \[OpenCurlyDoubleQuote]on the \
fly,\[CloseCurlyDoubleQuote] so to speak. We introduce some special notation \
for this purpose.\
\>", "Text",
  CellTags->"M50.8.2"],

Cell[TextData[{
  "We will use the ",
  StyleBox["#", "MR"],
  " sign to represent the argument of our function."
}], "BulletItem",
  CellTags->"M50.8.2"],

Cell[TextData[{
  "We will use the ",
  StyleBox["&", "MR"],
  " sign to tell ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that we have a function."
}], "BulletItem",
  CellTags->"M50.8.2"],

Cell[TextData[{
  "The general form of our notation will be ",
  StyleBox["f[#]&[5],", "MR"],
  " which we will explain in the next slide."
}], "Text",
  CellTags->"M50.8.2"],

Cell[TextData[{
  "The following is intended to help you understand how anonymous functions \
work. We use the analogy of a machine to a function to describe what happens \
with an anonymous function and then give you a chance to test your \
understanding with the ",
  StyleBox["FunctionTestMachine", "MR"],
  " function. (These functions are not built into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ";",
  StyleBox[" ",
    FontSlant->"Italic"],
  "they are defined in this notebook.)"
}], "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(FunctionMachine[Sin[#] &, 7];\)\)], "Input",
  CellTags->"M50.8.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 504 453.6 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0214286 0.47619 [
[.5 .9125 -96.6562 0 ]
[.5 .9125 96.6562 17.0625 ]
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .9125 -157.656 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 18.062 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.600 0.600 setrgbcolor
0.000 0.000 rmoveto
63.000 18.062 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.600 0.600 setrgbcolor
(The) show
99.875 18.062 moveto
(Function) show
180.500 18.062 moveto
(Machine) show
252.312 18.062 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.600 0.600 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.009 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.009 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.0238095 0.0214286 0.498812 0.448931 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.38778e-17 0.173913 -5.55112e-17 0.257143 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .9 .125 0 ]
[ 1 0 .125 0 ]
[.5 .9125 -38 0 ]
[.5 .9125 38 25.8125 ]
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .9 L
s
0 .9 m
1 .9 L
s
1 0 m
1 .9 L
s
gsave
.5 .9125 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.000 13.000 moveto
(function) show
135.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 26.500 moveto
0.000 0.000 rmoveto
63.000 26.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(is) show
81.000 26.500 moveto
(evaluated) show
135.000 26.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
0.000 0.000 0.000 setrgbcolor
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
.85 g
.08696 .12857 m
.08696 .51429 L
.52174 .51429 L
.52174 .12857 L
F
.08696 .64286 m
.26087 .64286 L
.17391 .38571 L
F
.34783 .38571 m
.6087 .38571 L
.56522 .19286 L
F
0 g
gsave
.30435 .19286 -100.781 -12.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sin) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
88.000 17.438 moveto
(@) show
94.500 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(#1) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
112.500 17.438 moveto
(D) show
123.625 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(&) show
138.562 17.438 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4 g
[(7)] .17391 .77143 0 0 Mshowa
.5 Mabswid
.17391 .70714 m
.17391 .51429 L
s
% Start of user PostScript
1. 2.75 1. 2. MAarrowhead1
% End of user PostScript
gsave
.13043 .45 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(Sin) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
81.000 13.000 moveto
(@) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(#1) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
99.000 13.000 moveto
(D) show
108.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(&) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
114.000 13.000 moveto
(@) show
120.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(7) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
126.000 13.000 moveto
(D) show
132.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.13043 .38571 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(#1) show
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
75.000 13.000 moveto
(\\256) show
88.188 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(7) show
94.188 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 g
gsave
.13043 .32143 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sin) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(@) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.501188 0.0214286 0.97619 0.448931 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.38778e-17 0.173913 -5.55112e-17 0.257143 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .9 .125 0 ]
[ 1 0 .125 0 ]
[.5 .9125 -32 0 ]
[.5 .9125 32 26.125 ]
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .9 L
s
0 .9 m
1 .9 L
s
1 0 m
1 .9 L
s
gsave
.5 .9125 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
93.000 13.000 moveto
0.000 0.000 rmoveto
63.000 26.500 moveto
0.000 0.000 rmoveto
63.000 26.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.000 26.500 moveto
(result) show
123.000 26.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
0.000 0.000 0.000 setrgbcolor
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
.85 g
.08696 .12857 m
.08696 .51429 L
.52174 .51429 L
.52174 .12857 L
F
.08696 .64286 m
.26087 .64286 L
.17391 .38571 L
F
.34783 .38571 m
.6087 .38571 L
.56522 .19286 L
F
0 g
gsave
.30435 .19286 -100.781 -12.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sin) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
88.000 17.438 moveto
(@) show
94.500 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(#1) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
112.500 17.438 moveto
(D) show
123.625 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(&) show
138.562 17.438 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4 g
[(7)] .17391 .77143 0 0 Mshowa
.5 Mabswid
.17391 .70714 m
.17391 .51429 L
s
% Start of user PostScript
1. 2.75 1. 2. MAarrowhead1
% End of user PostScript
gsave
.13043 .45 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(Sin) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
81.000 13.000 moveto
(@) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(#1) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
99.000 13.000 moveto
(D) show
108.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(&) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
114.000 13.000 moveto
(@) show
120.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(7) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
126.000 13.000 moveto
(D) show
132.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.13043 .38571 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(#1) show
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
75.000 13.000 moveto
(\\256) show
88.188 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(7) show
94.188 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.13043 .32143 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(Sin) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
81.000 13.000 moveto
(@) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(7) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34783 .32143 m
.52174 .32143 L
s
% Start of user PostScript
2. 1.25 3. 1.25 MAarrowhead1
% End of user PostScript
0 g
gsave
.5913 .32143 -61 -11.0312 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sin) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
88.125 14.438 moveto
(@) show
96.500 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
104.875 14.438 moveto
(D) show
113.250 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.451069 0.498812 0.878571 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.38778e-17 0.173913 -5.55112e-17 0.257143 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .9 .125 0 ]
[ 1 0 .125 0 ]
[.5 .9125 -71 0 ]
[.5 .9125 71 25.8125 ]
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .9 L
s
0 .9 m
1 .9 L
s
1 0 m
1 .9 L
s
gsave
.5 .9125 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
99.000 13.000 moveto
(argument) show
153.000 13.000 moveto
(is) show
171.000 13.000 moveto
(fed) show
189.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 26.500 moveto
0.000 0.000 rmoveto
63.000 26.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(to) show
81.000 26.500 moveto
(the) show
105.000 26.500 moveto
(function) show
159.000 26.500 moveto
(machine) show
201.000 26.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
0.000 0.000 0.000 setrgbcolor
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
.85 g
.08696 .12857 m
.08696 .51429 L
.52174 .51429 L
.52174 .12857 L
F
.08696 .64286 m
.26087 .64286 L
.17391 .38571 L
F
.34783 .38571 m
.6087 .38571 L
.56522 .19286 L
F
0 g
gsave
.30435 .19286 -100.781 -12.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sin) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
88.000 17.438 moveto
(@) show
94.500 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(#1) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
112.500 17.438 moveto
(D) show
123.625 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(&) show
138.562 17.438 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4 g
[(7)] .17391 .77143 0 0 Mshowa
.5 Mabswid
.17391 .70714 m
.17391 .51429 L
s
% Start of user PostScript
1. 2.75 1. 2. MAarrowhead1
% End of user PostScript
0 g
gsave
.13043 .45 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sin) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(@) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(#1) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.000 moveto
(D) show
108.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(&) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
114.000 13.000 moveto
(@) show
120.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
126.000 13.000 moveto
(D) show
132.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.501188 0.451069 0.97619 0.878571 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.38778e-17 0.173913 -5.55112e-17 0.257143 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .9 .125 0 ]
[ 1 0 .125 0 ]
[.5 .9125 -68 0 ]
[.5 .9125 68 25.625 ]
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .9 L
s
0 .9 m
1 .9 L
s
1 0 m
1 .9 L
s
gsave
.5 .9125 -129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.000 13.000 moveto
(#) show
99.000 13.000 moveto
(sign) show
129.000 13.000 moveto
(is) show
147.000 13.000 moveto
(replaced) show
195.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
78.500 26.375 moveto
0.000 0.000 rmoveto
78.500 26.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(by) show
96.500 26.375 moveto
(the) show
120.500 26.375 moveto
(argument) show
174.500 26.375 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
%%BeginResource: font Times-Bold-MISO
%%BeginFont: Times-Bold-MISO
/Times-Bold /Times-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Bold-MISO
%%IncludeFont: Times-Bold-MISO
/Times-Bold-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(7) show
179.500 26.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
0.000 0.000 0.000 setrgbcolor
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
.85 g
.08696 .12857 m
.08696 .51429 L
.52174 .51429 L
.52174 .12857 L
F
.08696 .64286 m
.26087 .64286 L
.17391 .38571 L
F
.34783 .38571 m
.6087 .38571 L
.56522 .19286 L
F
0 g
gsave
.30435 .19286 -100.781 -12.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sin) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
88.000 17.438 moveto
(@) show
94.500 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(#1) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
112.500 17.438 moveto
(D) show
123.625 17.438 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(&) show
138.562 17.438 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4 g
[(7)] .17391 .77143 0 0 Mshowa
.5 Mabswid
.17391 .70714 m
.17391 .51429 L
s
% Start of user PostScript
1. 2.75 1. 2. MAarrowhead1
% End of user PostScript
gsave
.13043 .45 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(Sin) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
81.000 13.000 moveto
(@) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(#1) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
99.000 13.000 moveto
(D) show
108.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(&) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
114.000 13.000 moveto
(@) show
120.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
(7) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
126.000 13.000 moveto
(D) show
132.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.400 0.400 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 g
gsave
.13043 .38571 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(#1) show
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(\\256) show
88.188 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
94.188 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{609, 548},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009Q000292000`400?l00000o`00003oo`3ooooo
0?ooof<0oooo003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo
003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo003o0?ooool0
ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo003o0?ooool0ooooH`3oool0
0?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo000[0?ooooD00000803ooooe000002`0oooo
000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?oo
o`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?oo
o`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000
003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000
003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0
oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0
oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0
oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[
0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a
0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`03
0000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`03
0000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003o
ool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003o
ool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo
0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo
02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo
000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?oo
o`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?oo
o`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000
003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000
003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0
oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0
oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0
oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[
0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool04`3ooomY0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?oo
o`3oool04P3ooomZ0=WIfGD0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?oo
ofT0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooofX0
fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0ooooJ@3IfMUe0?ooo`03
0000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool04`3ooomY0=WIfGD0oooo00<000000?ooo`3oool0
:P3oool002/0oooo00<000000?ooo`3oool04P3ooomZ0=WIfGD0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0C0?ooofT0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool0
0`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo01<0ooooJ@3IfMUe0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo
0180ooooJP3IfMUe0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3ooomY0=WI
fGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooolY0=WIf@@0
00005@3IfMT4000002@0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0
oooo:@3IfMT4000001@0fMWI1000000T0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo
00<000000?ooo`3oool04P3ooolY0=WIf@8000006@3IfMT2000002@0fMWIM@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo01<0oooo:@3IfMT2000001P0fMWI0P00000T0=WIfGD0oooo
00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooolY0=WIf@8000006@3I
fMT2000002@0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo:@3I
fMT2000001P0fMWI0P00000T0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<00000
0?ooo`3oool04P3ooolY0=WIf@8000006@3IfMT2000002@0fMWIM@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01<0oooo:@3IfMT2000001P0fMWI0P00000T0=WIfGD0oooo00<00000
0?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3oool@0=WIf@070000002o_kl0^;Rh
05QHF0000000F5QH0;Rh^0020=WIf@X0000000<0fMWI0000000000000P0000000`3IfMT000000000
00050=WIf@050492@P3IfMT0fMWI0=WIf@12@T80103IfMT7000000@0fMWI0P0000080=WIf@0;0:6Q
X@1HF5P000000000001gMgL0/K6a0<c<c02>SXh0@T920000002QXJ404@3IfMUe0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool04`3oool@0=WIf@070000002o_kl0^;Rh05QHF0000000
F5QH0;Rh^0020=WIf@X0000000<0fMWI0000000000000P0000000`3IfMT00000000000040=WIf@05
0492@P3IfMT0fMWI0=WIf@12@T80103IfMT7000000@0fMWI0P0000080=WIf@0;0:6QX@1HF5P00000
0000001gMgL0/K6a0<c<c02>SXh0@T920000002QXJ404@3IfMUe0?ooo`030000003oool0oooo02X0
oooo000[0?ooo`030000003oool0oooo0180oooo403IfMT2000000030:VYZ@3IfMT0ZJVY00800000
00<0^;Rh0=WIf@3IfMT00`0000020=WIf@<000000P3IfMT300000080fMWI0P0000050=WIf@0607Mg
M`2o_kl0fMWI0=WIf@1gMgL0_kno103IfMT01@3<c<`00000000000000000c<c<00D0fMWI0P000007
0=WIf@0709RHV000000000000492@P2o_kl0fMWI09RHV005000000030;Rh^03IfMT0fMWI00h0fMWI
M@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo403IfMT2000000030:VY
Z@3IfMT0ZJVY0080000000<0^;Rh0=WIf@3IfMT00`0000020=WIf@<000000P3IfMT300000080fMWI
0P0000040=WIf@0607MgM`2o_kl0fMWI0=WIf@1gMgL0_kno103IfMT01@3<c<`00000000000000000
c<c<00D0fMWI0P0000070=WIf@0709RHV000000000000492@P2o_kl0fMWI09RHV005000000030;Rh
^03IfMT0fMWI00h0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?oo
o`0B0?oooa00fMWI00<000000:6QX@3IfMT00P3IfMT20000000306UYJ@3IfMT0fMWI00<000000P3I
fMT300000080fMWI0`0000020=WIf@8000001@3IfMT01P2HV9P0ZJVY0=WIf@3IfMT0V9RH0:VYZ@D0
fMWI0`0000060=WIf@8000001`3IfMT3000000040:6QX@3IfMT0fMWI06UYJ@80000000@0JFUY0<c<
c02o_kl0SXj>403IfMUe0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3oool@
0=WIf@030000002QXJ40fMWI0080fMWI0P0000000`1YJFT0fMWI0=WIf@0300000080fMWI0`000002
0=WIf@<000000P3IfMT2000000@0fMWI00H0V9RH0:VYZ@3IfMT0fMWI09RHV02YZJT50=WIf@<00000
1P3IfMT2000000L0fMWI0`000000102QXJ40fMWI0=WIf@1YJFT20000000406UYJ@3<c<`0_kno08j>
SQ00fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?oooa00
fMWI00D000000<c<c03IfMT0fMWI0<c<c00300000080fMWI0`0000020=WIf@<000000P3IfMT30000
0080fMWI0P0000040=WIf@T000000`3IfMT3000000H0fMWI0P0000070=WIf@0605QHF00000000000
0<c<c03IfMT0MgMg0P0000000`1YJFT0ZJVY0=WIf@0B0=WIfGD0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0C0?oooa00fMWI00D000000<c<c03IfMT0fMWI0<c<c00300000080fMWI
0`0000020=WIf@<000000P3IfMT300000080fMWI0P0000030=WIf@T000000`3IfMT3000000H0fMWI
0P0000070=WIf@0605QHF000000000000<c<c03IfMT0MgMg0P0000000`1YJFT0ZJVY0=WIf@0B0=WI
fGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooolD0=WIf@04
06UYJ@000000000005QHF080fMWI0`0000020=WIf@<000000P3IfMT300000080fMWI0P0000050=WI
f@060;no_`1gMgL0fMWI0=WIf@2o_kl0MgMg1@3IfMT3000000H0fMWI0P0000070=WIf@050;Rh^000
000000000=WIf@2YZJT00P000000101YJFT0fMWI0000002h^;PB0=WIfGD0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0C0?oooa@0fMWI00@0JFUY000000000000F5QH0P3IfMT30000
0080fMWI0`0000020=WIf@<000000P3IfMT2000000@0fMWI00H0_kno07MgM`3IfMT0fMWI0;no_`1g
MgL50=WIf@<000001P3IfMT2000000L0fMWI00D0^;Rh000000000000fMWI0:VYZ@020000000406UY
J@3IfMT000000;Rh^180fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo
0?ooo`0B0?oooa80fMWI00H0a/K606UYJ@00000000000492@P36a/H20=WIf@<000000P3IfMT30000
0080fMWI0`0000020=WIf@8000001P3IfMT01@12@T80fMWI0=WIf@3IfMT0@T9200D0fMWI0`000006
0=WIf@800000203IfMT01P2a/K4000000;Rh^012@T8000000492@P80c<c<00<000000492@P3<c<`0
4@3IfMT:0?ooo`80fMWIJ@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo
4P3IfMT01P36a/H0JFUY000000000000@T920<K6aP80fMWI0`0000020=WIf@<000000P3IfMT30000
0080fMWI0P0000050=WIf@050492@P3IfMT0fMWI0=WIf@12@T801@3IfMT3000000H0fMWI0P000008
0=WIf@060;6a/@000000^;Rh0492@P000000@T920P3<c<`00`000000@T920<c<c00A0=WIf@X0oooo
0P3IfMUY0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180oooo4@3I
fMT01@2HV9P00000000000000000MgMg00@0fMWI0`0000020=WIf@<0000000D0/K6a0=WIf@000000
000005QHF0020=WIf@8000001P3IfMT01@12@T80fMWI0=WIf@3IfMT0@T9200D0fMWI0`0000060=WI
f@8000002@3IfMT01P3<c<`0JFUY000000000000ZJVY0=WIf@@000004@3IfMT90?ooo`<0fMWIJ@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo4@3IfMT01@2HV9P000000000
00000000MgMg00@0fMWI0`0000020=WIf@<0000000D0/K6a0=WIf@000000000005QHF0020=WIf@80
00001@3IfMT01@12@T80fMWI0=WIf@3IfMT0@T9200D0fMWI0`0000060=WIf@8000002@3IfMT01P3<
c<`0JFUY000000000000ZJVY0=WIf@@000004@3IfMT90?ooo`<0fMWIJ@3oool00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?oooa00fMWI00D0V9RH00000000000000000:VY
Z@040=WIf@@0000000<0fMWI0000000000000P0000001@2h^;P0JFUY0000001HF5P0a/K60080fMWI
0P0000040=WIf@T000000`3IfMT3000000H0fMWI0P00000:0=WIf@0506UYJ@000000JFUY08>3P`2h
^;P05@3IfMT80?ooo`@0fMWIJ@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0
oooo403IfMT01@2HV9P00000000000000000ZJVY00@0fMWI100000000`3IfMT00000000000020000
00050;Rh^01YJFT0000005QHF036a/H00P3IfMT2000000<0fMWI2@0000030=WIf@<000001P3IfMT2
000000X0fMWI00D0JFUY0000001YJFT0Ph>30;Rh^00E0=WIf@P0oooo103IfMUY0?ooo`030000003o
ool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180oooo403IfMT3000000040;6a/@3IfMT0
fMWI00000180fMWI0P0000060=WIf@0609RHV02YZJT0fMWI0=WIf@2HV9P0ZJVY103IfMT3000000H0
fMWI0P00000:0=WIf@80000000@0/K6a0=WIf@000000XJ6Q503IfMT70?ooo`D0fMWIJ@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo403IfMT3000000040;6a/@3IfMT0fMWI
00000180fMWI0P0000050=WIf@0609RHV02YZJT0fMWI0=WIf@2HV9P0ZJVY103IfMT3000000H0fMWI
0P00000:0=WIf@80000000@0/K6a0=WIf@000000XJ6Q503IfMT70?ooo`D0fMWIJ@3oool00`000000
oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?oooa00fMWI00<0@T92000000000000
0P3IfMT00`2a/K4000000=WIf@020=WIf@030:6QX@000000XJ6Q00`0fMWI0P0000060=WIf@060:VY
Z@2HV9P0fMWI0=WIf@2YZJT0V9RH0P3IfMT206UYJ@<000001P3IfMT2000000X0fMWI00H0@T920000
003IfMT0fMWI00000012@T8D0=WIf@H0oooo1`3IfMUX0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool04`3oool@0=WIf@030492@P00000000000080fMWI00<0/K6a0000003IfMT00P3I
fMT00`2QXJ4000000:6QX@0<0=WIf@8000001@3IfMT01P2YZJT0V9RH0=WIf@3IfMT0ZJVY09RHV080
fMWI0P1YJFT3000000H0fMWI0P00000:0=WIf@060492@P000000fMWI0=WIf@000000@T92503IfMT6
0?ooo`L0fMWIJ03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?oo
oa00fMWI00L0XJ6Q000000000000_kno0<c<c01HF5P0000000<0fMWI0`00000<0=WIf@8000001P3I
fMT01P2o_kl0MgMg0=WIf@3IfMT0_kno07MgM`80fMWI00<0a/K608j>SP0000000P0000060=WIf@80
00002P3IfMT01P2QXJ4000000<K6aP2YZJT0000005QHF1@0fMWI1@3oool80=WIfFP0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?oooa00fMWI00L0XJ6Q000000000000_kno0<c<
c01HF5P0000000<0fMWI0`00000<0=WIf@8000001@3IfMT01P2o_kl0MgMg0=WIf@3IfMT0_kno07Mg
M`80fMWI00<0a/K608j>SP0000000P0000060=WIf@8000002P3IfMT01P2QXJ4000000<K6aP2YZJT0
000005QHF1@0fMWI1@3oool80=WIfFP0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<00000
0?ooo`3oool04P3ooolA0=WIf@0609RHV012@T80@T9209RHV03<c<`000000`3IfMT00`2QXJ400000
0:6QX@0<0=WIf@@000001@3IfMT01@12@T80fMWI0=WIf@3IfMT0@T9200D0fMWI00<0XJ6Q05QHF03I
fMT00`3IfMT4000000/0fMWI00D0XJ6Q05QHF0000000F5QH0<K6aP0D0=WIf@@0oooo2@3IfMUX0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3ooolA0=WIf@0609RHV012@T80@T92
09RHV03<c<`000000`3IfMT00`2QXJ4000000:6QX@0<0=WIf@@00000103IfMT01@12@T80fMWI0=WI
f@3IfMT0@T9200D0fMWI00<0XJ6Q05QHF03IfMT00`3IfMT4000000/0fMWI00D0XJ6Q05QHF0000000
F5QH0<K6aP0D0=WIf@@0oooo2@3IfMUX0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000
003oool0oooo0180ooooJP3IfMT20?ooo`/0fMWIJ03oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo01<0ooooJ@3IfMT20?ooo`/0fMWIJ03oool00`000000oooo0?ooo`0Z0?ooo`00:`3o
ool00`000000oooo0?ooo`0B0?ooofX0fMWI00<0oooo0=WIf@3IfMT02P3IfMUX0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool04`3ooomY0=WIf@030?ooo`3IfMT0fMWI00/0fMWII`3o
ool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooogP0fMWII`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0ooooM`3IfMUW0?ooo`030000003oool0
oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooN03IfMUW0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool04`3ooomg0=WIfFL0oooo00<000000?ooo`3oool0:P3oool002/0
oooo00<000000?ooo`3oool04P3ooomh0=WIfFL0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0C0?ooogL0fMWII`3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo
0?ooo`0B0?ooogP0fMWII`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo
N03IfMUV0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooN03I
fMUW0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3ooomh0=WIfFH0oooo00<0
00000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooomi0=WIfFH0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooogP0fMWIIP3oool00`000000oooo0?ooo`0Z
0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooogT0fMWIIP3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo01<0ooooN03IfMUV0?ooo`030000003oool0oooo02X0oooo000[0?ooo`03
0000003oool0oooo0180ooooN@3IfMUV0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool04`3ooomh0=WIfFH0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0
4P3ooomi0=WIfFH0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooogT0fMWI
I@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooogX0fMWII@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0ooooN@3IfMUU0?ooo`030000003o
ool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooNP3IfMUU0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool04`3ooomi0=WIfFD0oooo00<000000?ooo`3oool0:P3oool0
02/0oooo00<000000?ooo`3oool04P3ooomj0=WIfFD0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0C0?ooogT0fMWII@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000
oooo0?ooo`0B0?ooogX0fMWII@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0
ooooNP3IfMUT0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180oooo
NP3IfMUU0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3ooomj0=WIfF@0oooo
00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooomk0=WIfF@0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooogX0fMWII03oool00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooog/0fMWII03oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01<0ooooNP3IfMUT0?ooo`030000003oool0oooo02X0oooo000[0?oo
o`030000003oool0oooo0180ooooN`3IfMUT0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool04`3ooomk0=WIfAh0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`0Z0?oo
o`00:`3oool00`000000oooo0?ooo`0B0?ooob80fMWI0P0000080=WIf@800000C@3IfMUT0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool04`3ooolQ0=WIf@80IVIV203IfMT206IVITh0
fMWI7P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooolR0=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT0B`3IfMUT0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
4`3ooolQ0=WIf@0306IVIP3IfMT0fMWI00P0fMWI00<0IVIV0=WIf@3IfMT0C03IfMTN0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0Z0?ooo`00:`3o
ool00`000000oooo0?ooo`0B0?ooo`h0fMWI0`0000040=WIf@<0000000<0fMWI0000000000000P3I
fMT2000000<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI04`0fMWIH`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo3@3I
fMT306IVIP@0fMWI0`1VIVH00`3IfMT0IVIV06IVIP020=WIf@80IVIV0`3IfMT00`1VIVH0fMWI0=WI
f@030=WIf@0306IVIP3IfMT0fMWI0080fMWI00<0IVIV0=WIf@3IfMT0<`3IfMT206IVIQL0fMWI0P3o
ool00`000000oooo00000002000000<0oooo1`0000001@3oool00000000000000000oooo00<00000
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooo`h0fMWI00@0
00000=WIf@3IfMT00000103IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0C03IfMUS0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3oool=0=WIf@04
06IVIP3IfMT0fMWI06IVIP@0fMWI00D0IVIV0=WIf@3IfMT0fMWI06IVIP020=WIf@0306IVIP3IfMT0
fMWI0080fMWI00<0IVIV0=WIf@3IfMT00`3IfMT00`1VIVH0fMWI0=WIf@020=WIf@0306IVIP3IfMT0
fMWI03D0fMWI101VIVHD0=WIf@030?ooo`000000000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?oooa40fMWI00<000000=WIf@3IfMT00P3IfMT0
1@000000fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0C03IfMUS0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool04`3oool@0=WIf@0306IVIP3IfMT0fMWI0080fMWI00D0
IVIV0=WIf@3IfMT0fMWI06IVIP020=WIf@0306IVIP3IfMT0fMWI0080fMWI00<0IVIV0=WIf@3IfMT0
0`3IfMT00`1VIVH0fMWI0=WIf@020=WIf@0306IVIP3IfMT0fMWI0100fMWI:`1VIVHB0=WIf@H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooo`l0fMWI
0P0000040=WIf@8000000P3IfMT4000000D0fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI
0=WIf@3IfMT0000004h0fMWIH`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0
oooo3P3IfMT206IVIP@0fMWI0P1VIVH20=WIf@@0IVIV1@3IfMT00`1VIVH0fMWI0=WIf@040=WIf@05
06IVIP3IfMT0fMWI0=WIf@1VIVH0=`3IfMT406IVIQ@0fMWI1P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo02X0oooo000[0?ooo`030000003oool0oooo0180oooo3P3IfMT010000000fMWI0=WIf@00000@
0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT01@000000fMWI0=WIf@3IfMT0000004l0fMWI
HP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo3@3IfMT0101VIVH0fMWI
0=WIf@1VIVH@0=WIf@0506IVIP3IfMT0fMWI0=WIf@1VIVH00P3IfMT01@1VIVH0fMWI0=WIf@3IfMT0
IVIV03D0fMWI0P1VIVHH0=WIf@80oooo100000060?ooo`030000003oool0oooo00<0oooo0P000002
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?oo
o`3oool04P3oool>0=WIf@@00000103IfMT00`000000fMWI0=WIf@090=WIf@8000000P3IfMT40000
0080fMWI0P00001?0=WIfF80oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?oo
o`d0fMWI101VIVH40=WIf@0306IVIP3IfMT0fMWI00T0fMWI0P1VIVH20=WIf@@0IVIV0P3IfMT206IV
ITl0fMWI00<0oooo0000003oool01`3oool3000000@0oooo0P0000000`3oool00000000000070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooO@3IfMUR0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool04`3ooomm0=WIf@040000003oool0oooo0?oo
o`8000005P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooogd0
fMWIHP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0ooooO@3IfMT01P3oool0
0000000000000000oooo000000D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooO@3IfMUR0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3ooomm0=WIfA`0oooo0P0000040?oo
o`H000000`3oool2000003@0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3o
ool04P3ooomn0=WIfF40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooogd0
fMWIH@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooogh0fMWI
H@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0ooooOP3IfMUP0?ooo`030000
003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooOP3IfMUQ0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool04`3ooomn0=WIfF00oooo00<000000?ooo`3oool0:P3o
ool002/0oooo00<000000?ooo`3oool04P3ooomn0=WIfF40oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0C0?ooogh0fMWIH03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`00
0000oooo0?ooo`0B0?ooogh0fMWIH@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01<0ooooOP3IfMUP0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180
ooooO`3IfMUP0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3ooomo0=WIfEl0
oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3oool=0=WIf@0306IV
IP3IfMT0IVIV00h0fMWI00<0IVIV0=WIf@3IfMT0GP3IfMUP0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool04`3oool<0=WIf@0306IVIP3IfMT0IVIV00h0fMWI00<0IVIV0=WIf@3IfMT0
G`3IfMUO0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180oooo3P3I
fMT00`1VIVH0fMWI06IVIP030=WIf@D0IVIV1P3IfMT00`1VIVH0fMWI0=WIf@070=WIf@0306IVIP3I
fMT0fMWI05<0fMWIH03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo3@3I
fMT00`1VIVH0fMWI06IVIP030=WIf@D0IVIV1P3IfMT00`1VIVH0fMWI0=WIf@070=WIf@0306IVIP3I
fMT0fMWI05@0fMWIG`3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B
0?ooo`d0fMWI1@1VIVH40=WIf@0306IVIP3IfMT0fMWI00L0IVIV2@3IfMT00`1VIVH0fMWI0=WIf@1C
0=WIfF00oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooo``0fMWI1@1VIVH4
0=WIf@0306IVIP3IfMT0fMWI00L0IVIV2@3IfMT00`1VIVH0fMWI0=WIf@1D0=WIfEl0oooo00<00000
0?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3oool>0=WIf@0306IVIP3IfMT0IVIV
00D0fMWI00<0IVIV0=WIf@3IfMT01P3IfMT00`1VIVH0fMWI0=WIf@070=WIf@0306IVIP3IfMT0fMWI
05<0fMWIH03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo3@3IfMT00`1V
IVH0fMWI06IVIP050=WIf@0306IVIP3IfMT0fMWI00H0fMWI00<0IVIV0=WIf@3IfMT01`3IfMT00`1V
IVH0fMWI0=WIf@1D0=WIfEl0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3o
ool04P3oool>0=WIf@0306IVIP3IfMT0IVIV00D0fMWI00<0IVIV0=WIf@3IfMT01@3IfMT00`1VIVH0
fMWI0=WIf@090=WIf@0306IVIP3IfMT0fMWI03d0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01<0oooo3@3IfMT00`1VIVH0fMWI06IVIP050=WIf@0306IVIP3IfMT0fMWI00D0
fMWI00<0IVIV0=WIf@3IfMT02@3IfMT00`1VIVH0fMWI0=WIf@0m0=WIfGD0oooo00<000000?ooo`3o
ool0:P3oool002/0oooo00<000000?ooo`3oool04P3oool=0=WIf@D0IVIV103IfMT00`1VIVH0fMWI
0=WIf@0>0=WIf@0406IVIP3IfMT0fMWI06IVISl0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01<0oooo303IfMT506IVIP@0fMWI00<0IVIV0=WIf@3IfMT03P3IfMT0101VIVH0
fMWI0=WIf@1VIVHo0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3o
ool04P3oool>0=WIf@0306IVIP3IfMT0IVIV00@0fMWI0P1VIVH@0=WIf@@0IVIV?`3IfMUe0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool04`3oool=0=WIf@0306IVIP3IfMT0IVIV00@0
fMWI0P1VIVH@0=WIf@@0IVIV?`3IfMUe0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000
003oool0oooo0180oooo3`3IfMT00`1VIVH0fMWI06IVIP1H0=WIfGD0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0C0?ooo`h0fMWI00<0IVIV0=WIf@1VIVH0F03IfMUe0?ooo`030000
003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool04`3ooomY0=WIfGD0oooo00<000000?ooo`3oool0:P3o
ool002/0oooo00<000000?ooo`3oool04P3ooomZ0=WIfGD0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0C0?ooofT0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`00
0000oooo0?ooo`0B0?ooofX0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01<0ooooJ@3IfMUe0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180
ooooJP3IfMUe0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3ooomY0=WIfGD0
oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooomZ0=WIfGD0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooofT0fMWIM@3oool00`000000oooo
0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo01<0ooooJ@3IfMUe0?ooo`030000003oool0oooo02X0oooo000[
0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool04`3ooomY0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?oo
o`3oool04P3ooolR0=WIf@80IVIV3P3IfMT206IVIPl0fMWI0P1VIVH80=WIf@80IVIV6`3IfMUe0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3ooolQ0=WIf@80IVIV3P3IfMT206IV
IPl0fMWI0P1VIVH80=WIf@80IVIV6`3IfMUe0?ooo`030000003oool0oooo02X0oooo000[0?ooo`03
0000003oool0oooo0180oooo8P3IfMT01P1VIVH0fMWI0=WIf@1VIVH0fMWI06IVIP/0fMWI00<0IVIV
0=WIf@3IfMT03@3IfMT00`1VIVH0fMWI0=WIf@080=WIf@0306IVIP3IfMT0fMWI01T0fMWIM@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo8@3IfMT01P1VIVH0fMWI0=WIf@1V
IVH0fMWI06IVIP/0fMWI00<0IVIV0=WIf@3IfMT03@3IfMT00`1VIVH0fMWI0=WIf@080=WIf@0306IV
IP3IfMT0fMWI01T0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?oo
o`0B0?ooo`h0fMWI0`1VIVH40=WIf@<0IVIV00<0fMWI06IVIP1VIVH00P3IfMT206IVIP<0fMWI00L0
IVIV0=WIf@3IfMT0fMWI06IVIP3IfMT0IVIV00<0fMWI1@1VIVH20=WIf@0306IVIP3IfMT0fMWI00D0
fMWI101VIVH40=WIf@0306IVIP3IfMT0fMWI00<0fMWI00<0IVIV0=WIf@3IfMT00P3IfMT00`1VIVH0
fMWI0=WIf@0I0=WIfGD0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooo`d0
fMWI0`1VIVH40=WIf@<0IVIV00<0fMWI06IVIP1VIVH00P3IfMT206IVIP<0fMWI00L0IVIV0=WIf@3I
fMT0fMWI06IVIP3IfMT0IVIV00<0fMWI1@1VIVH20=WIf@0306IVIP3IfMT0fMWI00D0fMWI101VIVH4
0=WIf@0306IVIP3IfMT0fMWI00<0fMWI00<0IVIV0=WIf@3IfMT00P3IfMT00`1VIVH0fMWI0=WIf@0I
0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3oool>0=WI
f@0406IVIP3IfMT0fMWI06IVIP@0fMWI00D0IVIV0=WIf@3IfMT0fMWI06IVIP020=WIf@0306IVIP3I
fMT0fMWI0080fMWI00<0IVIV0=WIf@3IfMT01@1VIVH40=WIf@0306IVIP3IfMT0fMWI0080fMWI00<0
IVIV0=WIf@3IfMT01@3IfMT0101VIVH0fMWI06IVIP1VIVH40=WIf@0306IVIP3IfMT0fMWI00<0fMWI
00<0IVIV0=WIf@3IfMT00P3IfMT00`1VIVH0fMWI0=WIf@0I0=WIfGD0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0C0?ooo`d0fMWI00@0IVIV0=WIf@3IfMT0IVIV103IfMT01@1VIVH0
fMWI0=WIf@3IfMT0IVIV0080fMWI00<0IVIV0=WIf@3IfMT00P3IfMT00`1VIVH0fMWI0=WIf@0506IV
IP@0fMWI00<0IVIV0=WIf@3IfMT00P3IfMT00`1VIVH0fMWI0=WIf@050=WIf@0406IVIP3IfMT0IVIV
06IVIP@0fMWI00<0IVIV0=WIf@3IfMT00`3IfMT00`1VIVH0fMWI0=WIf@020=WIf@0306IVIP3IfMT0
fMWI01T0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?oo
oa40fMWI00<0IVIV0=WIf@3IfMT00P3IfMT01@1VIVH0fMWI0=WIf@3IfMT0IVIV0080fMWI00<0IVIV
0=WIf@3IfMT00P3IfMT01`1VIVH0fMWI0=WIf@3IfMT0IVIV0=WIf@1VIVH01@3IfMT00`1VIVH0fMWI
0=WIf@020=WIf@0306IVIP3IfMT0fMWI00H0fMWI00<0IVIV0=WIf@3IfMT0103IfMT00`1VIVH0fMWI
0=WIf@030=WIf@0306IVIP3IfMT0fMWI0080fMWI00<0IVIV0=WIf@3IfMT06@3IfMUe0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool04`3oool@0=WIf@0306IVIP3IfMT0fMWI0080fMWI
00D0IVIV0=WIf@3IfMT0fMWI06IVIP020=WIf@0306IVIP3IfMT0fMWI0080fMWI00L0IVIV0=WIf@3I
fMT0fMWI06IVIP3IfMT0IVIV00D0fMWI00<0IVIV0=WIf@3IfMT00P3IfMT00`1VIVH0fMWI0=WIf@06
0=WIf@0306IVIP3IfMT0fMWI00@0fMWI00<0IVIV0=WIf@3IfMT00`3IfMT00`1VIVH0fMWI0=WIf@02
0=WIf@0306IVIP3IfMT0fMWI01T0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`00
0000oooo0?ooo`0B0?ooo`l0fMWI0P1VIVH40=WIf@80IVIV0P3IfMT406IVIPD0fMWI00L0IVIV0=WI
f@3IfMT0fMWI06IVIP3IfMT0IVIV00D0fMWI00<0IVIV0=WIf@3IfMT00P3IfMT00`1VIVH0fMWI0=WI
f@060=WIf@0306IVIP3IfMT0fMWI00@0fMWI00<0IVIV0=WIf@3IfMT0103IfMT01@1VIVH0fMWI0=WI
f@3IfMT0IVIV01/0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo
3P3IfMT206IVIP@0fMWI0P1VIVH20=WIf@@0IVIV1@3IfMT01`1VIVH0fMWI0=WIf@3IfMT0IVIV0=WI
f@1VIVH01@3IfMT00`1VIVH0fMWI0=WIf@020=WIf@0306IVIP3IfMT0fMWI00H0fMWI00<0IVIV0=WI
f@3IfMT0103IfMT00`1VIVH0fMWI0=WIf@040=WIf@0506IVIP3IfMT0fMWI0=WIf@1VIVH06`3IfMUe
0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180oooo3P3IfMT0101V
IVH0fMWI0=WIf@1VIVH@0=WIf@0306IVIP3IfMT0fMWI00D0IVIV103IfMT00`1VIVH0fMWI0=WIf@02
0=WIf@0306IVIP3IfMT0fMWI00H0fMWI0`1VIVH40=WIf@0506IVIP3IfMT0fMWI0=WIf@1VIVH00P3I
fMT01@1VIVH0fMWI0=WIf@3IfMT0IVIV01/0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo01<0oooo3@3IfMT0101VIVH0fMWI0=WIf@1VIVH@0=WIf@0306IVIP3IfMT0fMWI00D0
IVIV103IfMT00`1VIVH0fMWI0=WIf@020=WIf@0306IVIP3IfMT0fMWI00H0fMWI0`1VIVH40=WIf@05
06IVIP3IfMT0fMWI0=WIf@1VIVH00P3IfMT01@1VIVH0fMWI0=WIf@3IfMT0IVIV01/0fMWIM@3oool0
0`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooo`h0fMWI101VIVH40=WI
f@0306IVIP3IfMT0fMWI00T0fMWI0P1VIVH20=WIf@0306IVIP3IfMT0IVIV00@0fMWI0P1VIVH30=WI
f@80IVIV3`3IfMT206IVIP80fMWI101VIVH20=WIf@80IVIV6`3IfMUe0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool04`3oool=0=WIf@@0IVIV103IfMT00`1VIVH0fMWI0=WIf@090=WI
f@80IVIV0P3IfMT00`1VIVH0fMWI06IVIP040=WIf@80IVIV0`3IfMT206IVIPl0fMWI0P1VIVH20=WI
f@@0IVIV0P3IfMT206IVIQ/0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000
oooo0?ooo`0B0?ooobL0fMWI00<0IVIV0=WIf@1VIVH0@03IfMUe0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool04`3ooolV0=WIf@0306IVIP3IfMT0IVIV0400fMWIM@3oool00`000000
oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo01<0ooooJ@3IfMUe0?ooo`030000003oool0oooo02X0oooo
000[0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool04`3ooomY0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<00000
0?ooo`3oool04P3ooomZ0=WIfGD0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C
0?ooofT0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?oo
ofX0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0ooooJ@3IfMUe0?oo
o`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool04`3ooomY0=WIfGD0oooo00<000000?ooo`3o
ool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooomZ0=WIfGD0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0C0?ooofT0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3o
ool00`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01<0ooooJ@3IfMUe0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0
oooo0180ooooJP3IfMUe0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3ooomY
0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooomZ0=WI
fGD0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooofT0fMWIM@3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo01<0ooooJ@3IfMUe0?ooo`030000003oool0oooo02X0
oooo000[0?ooo`030000003oool0oooo0180oooo5@3IfMT00`1VIVH0fMWI0=WIf@1B0=WIfGD0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?oooaD0fMWI00<0IVIV0=WIf@3IfMT0
D@3IfMUe0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo01d0oooo2P3I
fMT00`1VIVH0fMWI0=WIf@090=WIfKh0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0N0?ooo`X0fMWI00<0IVIV0=WIf@3IfMT0203IfMVn0?ooo`030000003oool0oooo02X0oooo000[
0?ooo`030000003oool0oooo01`0oooo2P3IfMT206IVIP/0fMWI_P3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01d0oooo2P3IfMT206IVIP/0fMWI_@3oool00`000000oooo0?ooo`0Z
0?ooo`00:`3oool00`000000oooo0?ooo`0L0?ooo`X0fMWI0`1VIVH:0=WIfKh0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`X0fMWI0`1VIVH:0=WIfKd0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool0703oool:0=WIf@<0IVIV2`3IfMVm0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool:0=WIf@<0IVIV2P3IfMVm0?ooo`03
0000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo01/0oooo2`3IfMT306IVIP/0fMWI
_@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01`0oooo2`3IfMT306IVIP/0fMWI
_03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0K0?ooo`X0fMWI101V
IVH;0=WIfKd0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0L0?ooo`X0fMWI101V
IVH;0=WIfK`0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool06`3oool:
0=WIf@0506IVIP3IfMT0IVIV0=WIf@1VIVH02`3IfMVl0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0703oool:0=WIf@0506IVIP3IfMT0IVIV0=WIf@1VIVH02P3IfMVl0?ooo`030000
003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo01X0oooo2`3IfMT01@1VIVH0fMWI06IV
IP3IfMT0IVIV00/0fMWI_03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01/0oooo
2`3IfMT01@1VIVH0fMWI06IVIP3IfMT0IVIV00/0fMWI^`3oool00`000000oooo0?ooo`0Z0?ooo`00
:`3oool00`000000oooo0?ooo`0J0?ooo`d0fMWI00<0IVIV0=WIf@3IfMT02`3IfMVl0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool06`3oool=0=WIf@0306IVIP3IfMT0fMWI00/0fMWI
^`3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0J0?ooo`d0fMWI00<0
IVIV0=WIf@3IfMT0303IfMVk0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06`3o
ool=0=WIf@0306IVIP3IfMT0fMWI00/0fMWI^`3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool0
0`000000oooo0?ooo`0I0?ooo`h0fMWI00<0IVIV0=WIf@3IfMT0303IfMVk0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool06P3oool>0=WIf@0306IVIP3IfMT0fMWI00`0fMWI^P3oool0
0`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0I0?ooo`h0fMWI00<0IVIV0=WI
f@3IfMT03@3IfMVj0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06P3oool>0=WI
f@0306IVIP3IfMT0fMWI00`0fMWI^P3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000
oooo0?ooo`0I0?ooo`h0fMWI00<0IVIV0=WIf@3IfMT03@3IfMVj0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool06P3oool>0=WIf@0306IVIP3IfMT0fMWI00`0fMWI^P3oool00`000000
oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0H0?ooo`l0fMWI00<0IVIV0=WIf@3IfMT0
3@3IfMVj0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06@3oool?0=WIf@0306IV
IP3IfMT0fMWI00d0fMWI^@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?oo
o`0H0?ooo`l0fMWI00<0IVIV0=WIf@3IfMT03P3IfMVi0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool06@3oool?0=WIf@0306IVIP3IfMT0fMWI00d0fMWI^@3oool00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0H0?ooo`l0fMWI00<0IVIV0=WIf@3IfMT03P3IfMVi
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06@3oool?0=WIf@0306IVIP3IfMT0
fMWI00d0fMWI^@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0G0?oo
oa00fMWI00<0IVIV0=WIf@3IfMT03P3IfMVi0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0603oool@0=WIf@0306IVIP3IfMT0fMWI00h0fMWI^03oool00`000000oooo0?ooo`0Z0?oo
o`00:`3oool00`000000oooo0?ooo`0G0?oooa00fMWI00<0IVIV0=WIf@3IfMT03`3IfMVh0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0603oool@0=WIf@0306IVIP3IfMT0fMWI00h0
fMWI^03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0G0?oooa00fMWI
00<0IVIV0=WIf@3IfMT03`3IfMVh0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
603oool@0=WIf@0306IVIP3IfMT0fMWI00h0fMWI^03oool00`000000oooo0?ooo`0Z0?ooo`00:`3o
ool00`000000oooo0?ooo`0F0?oooa40fMWI00<0IVIV0=WIf@3IfMT03`3IfMVh0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool05`3ooolA0=WIf@0306IVIP3IfMT0fMWI00l0fMWI]`3o
ool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0F0?oooa40fMWI00<0IVIV
0=WIf@3IfMT0403IfMVg0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05`3ooolA
0=WIf@0306IVIP3IfMT0fMWI00l0fMWI]`3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`00
0000oooo0?ooo`0F0?oooa40fMWI00<0IVIV0=WIf@3IfMT0403IfMVg0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool05`3ooolA0=WIf@0306IVIP3IfMT0fMWI00l0fMWI]`3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0E0?oooa80fMWI00<0IVIV0=WIf@3I
fMT0403IfMVg0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05P3ooolB0=WIf@03
06IVIP3IfMT0fMWI0100fMWI]P3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo
0?ooo`0E0?oooa80fMWI00<0IVIV0=WIf@3IfMT04@3IfMVf0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool05P3ooolB0=WIf@0306IVIP3IfMT0fMWI0100fMWI]P3oool00`000000oooo
0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0E0?oooa80fMWI00<0IVIV0=WIf@3IfMT04@3I
fMVf0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05P3ooolB0=WIf@0306IVIP3I
fMT0fMWI0100fMWI]P3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0D
0?oooa<0fMWI00<0IVIV0=WIf@3IfMT04@3IfMVf0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool05@3ooolC0=WIf@0306IVIP3IfMT0fMWI0140fMWI]@3oool00`000000oooo0?ooo`0Z
0?ooo`00:`3oool00`000000oooo0?ooo`0D0?oooa<0fMWI00<0IVIV0=WIf@3IfMT04P3IfMVe0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool05@3ooolC0=WIf@0306IVIP3IfMT0fMWI
0140fMWI]@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0D0?oooa<0
fMWI00<0IVIV0=WIf@3IfMT04P3IfMVe0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool05@3ooolC0=WIf@0306IVIP3IfMT0fMWI0140fMWI]@3oool00`000000oooo0?ooo`0Z0?ooo`00
:`3oool00`000000oooo0?ooo`0C0?oooa@0fMWI00<0IVIV0=WIf@3IfMT04P3IfMVe0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0503ooolD0=WIf@0306IVIP3IfMT0fMWI0180fMWI
]03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0C0?oooa@0fMWI00<0
IVIV0=WIf@3IfMT04`3IfMVd0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0503o
oolD0=WIf@0306IVIP3IfMT0fMWI0180fMWI]03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool0
0`000000oooo0?ooo`0C0?oooa@0fMWI00<0IVIV0=WIf@3IfMT04`3IfMVd0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool04`3ooolE0=WIf@0306IVIP3IfMT0fMWI0180fMWI]03oool0
0`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?oooaD0fMWI00<0IVIV0=WI
f@3IfMT04`3IfMVd0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:03oool00`1V
IVH0oooo0?ooo`360?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo02L0
oooo00<0IVIV0?ooo`3oool0a`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0
oooo00<0IVIV0?ooo`3oool0aP3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo
0?ooo`0W0?ooo`0306IVIP3oool0oooo0<L0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0X0?ooo`0306IVIP3oool0oooo0<H0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<0
00000?ooo`3oool09`3oool00`1VIVH0oooo0?ooo`370?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0:03oool00`1VIVH0oooo0?ooo`360?ooo`030000003oool0oooo02X0oooo000[
0?ooo`030000003oool0oooo02L0oooo00<0IVIV0?ooo`3oool0a`3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo02P0oooo00<0IVIV0?ooo`3oool0aP3oool00`000000oooo0?ooo`0Z
0?ooo`00:`3oool00`000000oooo0?ooo`0W0?ooo`0306IVIP3oool0oooo0<L0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0X0?ooo`0306IVIP3oool0oooo0<H0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool09`3oool00`1VIVH0oooo0?ooo`370?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0:03oool00`1VIVH0oooo0?ooo`360?ooo`03
0000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo02L0oooo00<0IVIV0?ooo`3oool0
a`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo00<0IVIV0?ooo`3oool0
aP3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0W0?ooo`0306IVIP3o
ool0oooo0<L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0X0?ooo`0306IVIP3o
ool0oooo0<H0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool09`3oool0
0`1VIVH0oooo0?ooo`370?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:03oool0
0`1VIVH0oooo0?ooo`360?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo
02L0oooo00<0IVIV0?ooo`3oool0a`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
02P0oooo00<0IVIV0?ooo`3oool0aP3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000
oooo0?ooo`0W0?ooo`0306IVIP3oool0oooo0<L0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0X0?ooo`0306IVIP3oool0oooo0<H0oooo00<000000?ooo`3oool0:P3oool002/0oooo
00<000000?ooo`3oool09`3oool00`1VIVH0oooo0?ooo`370?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0:03oool00`1VIVH0oooo0?ooo`360?ooo`030000003oool0oooo02X0oooo
000[0?ooo`030000003oool0oooo02L0oooo00<0IVIV0?ooo`3oool0a`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo02P0oooo00<0IVIV0?ooo`3oool0aP3oool00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0W0?ooo`0306IVIP3oool0oooo0<L0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0X0?ooo`0306IVIP3oool0oooo0<H0oooo00<00000
0?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool09`3oool00`1VIVH0oooo0?ooo`370?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:03oool00`1VIVH0oooo0?ooo`360?oo
o`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000
003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000
003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0
oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0
oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0
oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[
0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a
0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`03
0000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`03
0000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003o
ool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003o
ool0oooo02X0oooo000[0?ooo`030000003oool0oooo02L0oooo00<0IVIV0?ooo`3oool0a`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo00<0IVIV0?ooo`3oool0aP3oool0
0`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0W0?ooo`0306IVIP3oool0oooo
0<L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0X0?ooo`0306IVIP3oool0oooo
0<H0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool09`3oool00`1VIVH0
oooo0?ooo`370?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:03oool00`1VIVH0
oooo0?ooo`360?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo02P0oooo
00<0IVIV0?ooo`3oool0aP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02T0oooo
00<0IVIV0?ooo`3oool0a@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?oo
o`0U0?ooo`0406IVIP3oool0oooo06IVI/P0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0V0?ooo`0406IVIP3oool0oooo06IVI/L0oooo00<000000?ooo`3oool0:P3oool002/0oooo
00<000000?ooo`3oool09@3oool406IVI/P0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0V0?ooo`@0IVIVa`3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?oo
o`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?oo
o`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3o
ool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3o
ool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`00
0000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo
0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo
0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z
0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00
:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool0
0`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool0
0`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000
oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000
oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?oo
o`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?oo
o`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3o
ool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3o
ool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3ooooe0000
0200oooom@00000/0?ooo`00o`3ooooo0?ooof<0oooo003o0?ooool0ooooH`3oool00?l0ooooo`3o
oomS0?ooo`00o`3ooooo0?ooof<0oooo003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooof<0oooo00230?ooo`<000000P3oool3000000X0oooo0`0000030?ooo`8000000`3o
ool5000000040?ooo`0000000000000000@0oooo100000000`3oool000000000000300000080oooo
0P0000040?ooo`<000000`3oool400000=@0oooo0`0000020?ooo`<0000000<0oooo000000000000
0P3oool3000000P0oooo100000030?ooo`<000000P3oool3000000@0oooo10000000103oool00000
0000000000040?ooo`800000R`3oool008@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`@000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo100000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00003F0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000020?ooo`050000
003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`00002:0?ooo`00Q03oool010000000
oooo0?ooo`3oool3000000T0oooo100000020?ooo`040000003oool0oooo000000D0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool0
00001@3oool400000080oooo00@000000?ooo`3oool00000eP3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo100000090?ooo`030000003oool0oooo0080oooo10000002
0?ooo`<000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0R`3oool008<0oooo0P0000030?ooo`@000002@3oool200000080oooo0P000002
0?ooo`8000000P3oool3000000<0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000000
00030?ooo`<0000000<0oooo0000000000000`0000030?ooo`800000103oool300000=H0oooo00<0
00000?ooo`3oool00P3oool3000000@0oooo0P0000090?ooo`@000000`3oool2000000<0oooo1000
0000103oool000000000003oool2000000<0oooo00@000000?ooo`3oool0oooo1@00002:0?ooo`00
Y`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
dP3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo08/0oooo00240?ooo`030000003oool0oooo01l0oooo
0P00000N0?ooo`800000e03oool5000000030?ooo`000000000002T0oooo0P00002B0?ooo`00o`3o
oooo0?ooof<0oooo003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0
oooo003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo00220?oo
o`<000000P3oool3000000030?ooo`00000000000080oooo0`0000080?ooo`@000000`3oool60000
0080oooo0P0000020?ooo`<000000`3oool2000000@0oooo0`0000030?ooo`8000000P3oool20000
0080oooo0P00003o0?oooiT0oooo00230?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`3o0?oooiP0oooo00230?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool4000000T0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0?l0ooooV03oool008<0oooo00<000000?ooo`3oool0
0P3oool3000000@0oooo0P0000090?ooo`@0000000@0oooo000000000000oooo0P0000000`3oool0
000000000002000000@0oooo0`0000000`3oool0000000000003000000<0oooo0P0000040?ooo`80
00000P3oool400000?l0ooooV`3oool00840oooo00D000000?ooo`000000oooo000000020?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooojd0
oooo00210?ooo`D0000000<0oooo0000000000004`3oool2000001`0oooo00<000000?ooo`3oool0
o`3ooonU0?ooo`00o`3ooooo0?ooof<0oooo003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS0?oo
o`00:`3ooooe00000200oooom@00000/0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3o
ool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3o
ool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`00
0000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo
0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo
0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z
0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00
:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool0
0`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool0
0`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000
oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000
oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?oo
o`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?oo
o`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3o
ool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3o
ool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`00
0000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo
0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo
0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z
0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00
:`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`3a0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool0
0`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo0180ooooJP3IfMUe0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo
0180ooooJP3IfMUe0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3ooomZ0=WI
fGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooomZ0=WIfGD0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool00`000000
oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?ooo`030000003oool0oooo02X0oooo
000[0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool04P3ooomZ0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<00000
0?ooo`3oool04P3ooomZ0=WIfGD0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B
0?ooofX0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?oo
ofX0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?oo
o`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180oooo:@3IfMT4000001D0
fMWI1000000T0=WIfGD0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooobX0
fMWI1000000D0=WIf@@00000903IfMUe0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000
003oool0oooo0180oooo:@3IfMT2000001T0fMWI0P00000T0=WIfGD0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0B0?ooobX0fMWI0P00000H0=WIf@800000903IfMUe0?ooo`030000
003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180oooo:@3IfMT2000001T0fMWI0P00
000T0=WIfGD0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooobX0fMWI0P00
000H0=WIf@800000903IfMUe0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0
oooo0180oooo:@3IfMT2000001T0fMWI0P00000T0=WIfGD0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0B0?ooobX0fMWI0P00000H0=WIf@800000903IfMUe0?ooo`030000003oool0
oooo02X0oooo000[0?ooo`030000003oool0oooo0180oooo403IfMT01`000000_kno0;Rh^01HF5P0
000005QHF02h^;P00P3IfMT:000000030=WIf@00000000000080000000<0fMWI0000000000001@3I
fMT01@12@T80fMWI0=WIf@3IfMT0@T9200@0fMWI1`0000040=WIf@800000203IfMT02`2QXJ40F5QH
000000000000MgMg0;6a/@3<c<`0SXj>0492@P000000XJ6Q0140fMWIM@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0180oooo4@3IfMT01`000000_kno0;Rh^01HF5P0000005QHF02h
^;P00P3IfMT:000000030=WIf@00000000000080000000<0fMWI000000000000103IfMT01@12@T80
fMWI0=WIf@3IfMT0@T9200@0fMWI1`0000040=WIf@800000203IfMT02`2QXJ40F5QH000000000000
MgMg0;6a/@3<c<`0SXj>0492@P000000XJ6Q0140fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00
:`3oool00`000000oooo0?ooo`0B0?oooa00fMWI0P0000000`2YZJT0fMWI0:VYZ@02000000030;Rh
^03IfMT0fMWI00<000000P3IfMT300000080fMWI0`0000020=WIf@8000001@3IfMT01P1gMgL0_kno
0=WIf@3IfMT0MgMg0;no_`@0fMWI00D0c<c<00000000000000000<c<c0050=WIf@8000001`3IfMT0
1`2HV9P0000000000012@T80_kno0=WIf@2HV9P01@0000000`2h^;P0fMWI0=WIf@0>0=WIfGD0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?oooa40fMWI0P0000000`2YZJT0fMWI
0:VYZ@02000000030;Rh^03IfMT0fMWI00<000000P3IfMT300000080fMWI0`0000020=WIf@800000
103IfMT01P1gMgL0_kno0=WIf@3IfMT0MgMg0;no_`@0fMWI00D0c<c<00000000000000000<c<c005
0=WIf@8000001`3IfMT01`2HV9P0000000000012@T80_kno0=WIf@2HV9P01@0000000`2h^;P0fMWI
0=WIf@0>0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3o
ool@0=WIf@030000002QXJ40fMWI0080fMWI0P0000000`1YJFT0fMWI0=WIf@0300000080fMWI0`00
00020=WIf@<000000P3IfMT2000000D0fMWI00H0V9RH0:VYZ@3IfMT0fMWI09RHV02YZJT50=WIf@<0
00001P3IfMT2000000L0fMWI0`000000102QXJ40fMWI0=WIf@1YJFT20000000406UYJ@3<c<`0_kno
08j>SQ00fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo4@3IfMT0
0`000000XJ6Q0=WIf@020=WIf@80000000<0JFUY0=WIf@3IfMT00`0000020=WIf@<000000P3IfMT3
00000080fMWI0P0000040=WIf@0609RHV02YZJT0fMWI0=WIf@2HV9P0ZJVY1@3IfMT3000000H0fMWI
0P0000070=WIf@<0000000@0XJ6Q0=WIf@3IfMT0JFUY0P000000101YJFT0c<c<0;no_`2>SXh@0=WI
fGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3oool@0=WIf@05
0000003<c<`0fMWI0=WIf@3<c<`00`0000020=WIf@<000000P3IfMT300000080fMWI0`0000020=WI
f@800000103IfMT9000000<0fMWI0`0000060=WIf@8000001`3IfMT01P1HF5P000000000003<c<`0
fMWI07MgM`80000000<0JFUY0:VYZ@3IfMT04P3IfMUe0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool04P3ooolA0=WIf@050000003<c<`0fMWI0=WIf@3<c<`00`0000020=WIf@<00000
0P3IfMT300000080fMWI0`0000020=WIf@8000000`3IfMT9000000<0fMWI0`0000060=WIf@800000
1`3IfMT01P1HF5P000000000003<c<`0fMWI07MgM`80000000<0JFUY0:VYZ@3IfMT04P3IfMUe0?oo
o`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180oooo503IfMT0101YJFT0
00000000001HF5P20=WIf@<000000P3IfMT300000080fMWI0`0000020=WIf@8000001@3IfMT01P2o
_kl0MgMg0=WIf@3IfMT0_kno07MgM`D0fMWI0`0000060=WIf@8000001`3IfMT01@2h^;P000000000
003IfMT0ZJVY0080000000@0JFUY0=WIf@000000^;Rh4P3IfMUe0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool04P3ooolE0=WIf@0406UYJ@000000000005QHF080fMWI0`0000020=WI
f@<000000P3IfMT300000080fMWI0P0000040=WIf@060;no_`1gMgL0fMWI0=WIf@2o_kl0MgMg1@3I
fMT3000000H0fMWI0P0000070=WIf@050;Rh^000000000000=WIf@2YZJT00P000000101YJFT0fMWI
0000002h^;PB0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0
4P3ooolB0=WIf@060<K6aP1YJFT0000000000012@T80a/K60P3IfMT300000080fMWI0`0000020=WI
f@<000000P3IfMT2000000H0fMWI00D0@T920=WIf@3IfMT0fMWI0492@P050=WIf@<000001P3IfMT2
000000P0fMWI00H0/K6a0000002h^;P0@T9200000012@T820<c<c00300000012@T80c<c<0140fMWI
2P3oool20=WIfFT0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?oooa<0fMWI
00H0a/K606UYJ@00000000000492@P36a/H20=WIf@<000000P3IfMT300000080fMWI0`0000020=WI
f@8000001@3IfMT01@12@T80fMWI0=WIf@3IfMT0@T9200D0fMWI0`0000060=WIf@800000203IfMT0
1P2a/K4000000;Rh^012@T8000000492@P80c<c<00<000000492@P3<c<`04@3IfMT:0?ooo`80fMWI
J@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?oooa40fMWI00D0
V9RH000000000000000007MgM`040=WIf@<000000P3IfMT3000000050;6a/@3IfMT000000000001H
F5P00P3IfMT2000000H0fMWI00D0@T920=WIf@3IfMT0fMWI0492@P050=WIf@<000001P3IfMT20000
00T0fMWI00H0c<c<06UYJ@00000000000:VYZ@3IfMT400000140fMWI2@3oool30=WIfFT0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?oooa80fMWI00D0V9RH0000000000000000
07MgM`040=WIf@<000000P3IfMT3000000050;6a/@3IfMT000000000001HF5P00P3IfMT2000000D0
fMWI00D0@T920=WIf@3IfMT0fMWI0492@P050=WIf@<000001P3IfMT2000000T0fMWI00H0c<c<06UY
J@00000000000:VYZ@3IfMT400000140fMWI2@3oool30=WIfFT0oooo00<000000?ooo`3oool0:P3o
ool002/0oooo00<000000?ooo`3oool04P3oool@0=WIf@0509RHV000000000000000002YZJT0103I
fMT4000000030=WIf@00000000000080000000D0^;Rh06UYJ@000000F5QH0<K6aP020=WIf@800000
103IfMT9000000<0fMWI0`0000060=WIf@8000002P3IfMT01@1YJFT0000006UYJ@23Ph<0^;Rh01D0
fMWI203oool40=WIfFT0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?oooa40
fMWI00D0V9RH00000000000000000:VYZ@040=WIf@@0000000<0fMWI0000000000000P0000001@2h
^;P0JFUY0000001HF5P0a/K60080fMWI0P0000030=WIf@T000000`3IfMT3000000H0fMWI0P00000:
0=WIf@0506UYJ@000000JFUY08>3P`2h^;P05@3IfMT80?ooo`@0fMWIJ@3oool00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?oooa00fMWI0`000000102a/K40fMWI0=WIf@00
000B0=WIf@8000001P3IfMT01P2HV9P0ZJVY0=WIf@3IfMT0V9RH0:VYZ@@0fMWI0`0000060=WIf@80
00002P3IfMT2000000040;6a/@3IfMT000000:6QXA@0fMWI1`3oool50=WIfFT0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0B0?oooa40fMWI0`000000102a/K40fMWI0=WIf@00000B
0=WIf@8000001@3IfMT01P2HV9P0ZJVY0=WIf@3IfMT0V9RH0:VYZ@@0fMWI0`0000060=WIf@800000
2P3IfMT2000000040;6a/@3IfMT000000:6QXA@0fMWI1`3oool50=WIfFT0oooo00<000000?ooo`3o
ool0:P3oool002/0oooo00<000000?ooo`3oool04P3oool@0=WIf@030492@P00000000000080fMWI
00<0/K6a0000003IfMT00P3IfMT00`2QXJ4000000:6QX@0<0=WIf@8000001P3IfMT01P2YZJT0V9RH
0=WIf@3IfMT0ZJVY09RHV080fMWI0P1YJFT3000000H0fMWI0P00000:0=WIf@060492@P000000fMWI
0=WIf@000000@T92503IfMT60?ooo`L0fMWIJ03oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0180oooo4@3IfMT00`12@T800000000000020=WIf@030;6a/@000000fMWI0080fMWI00<0
XJ6Q0000002QXJ40303IfMT2000000D0fMWI00H0ZJVY09RHV03IfMT0fMWI0:VYZ@2HV9P20=WIf@80
JFUY0`0000060=WIf@8000002P3IfMT01P12@T8000000=WIf@3IfMT000000492@Q@0fMWI1P3oool7
0=WIfFP0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3oool@0=WI
f@070:6QX@00000000000;no_`3<c<`0F5QH000000030=WIf@<00000303IfMT2000000H0fMWI00H0
_kno07MgM`3IfMT0fMWI0;no_`1gMgL20=WIf@030<K6aP2>SXh00000008000001P3IfMT2000000X0
fMWI00H0XJ6Q00000036a/H0ZJVY0000001HF5PD0=WIf@D0oooo203IfMUX0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool04P3ooolA0=WIf@070:6QX@00000000000;no_`3<c<`0F5QH
000000030=WIf@<00000303IfMT2000000D0fMWI00H0_kno07MgM`3IfMT0fMWI0;no_`1gMgL20=WI
f@030<K6aP2>SXh00000008000001P3IfMT2000000X0fMWI00H0XJ6Q00000036a/H0ZJVY0000001H
F5PD0=WIf@D0oooo203IfMUX0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0
oooo0180oooo4@3IfMT01P2HV9P0@T920492@P2HV9P0c<c<000000<0fMWI00<0XJ6Q0000002QXJ40
303IfMT4000000D0fMWI00D0@T920=WIf@3IfMT0fMWI0492@P050=WIf@030:6QX@1HF5P0fMWI00<0
fMWI1000000;0=WIf@050:6QX@1HF5P0000005QHF036a/H0503IfMT40?ooo`T0fMWIJ03oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo4P3IfMT01P2HV9P0@T920492@P2HV9P0
c<c<000000<0fMWI00<0XJ6Q0000002QXJ40303IfMT4000000@0fMWI00D0@T920=WIf@3IfMT0fMWI
0492@P050=WIf@030:6QX@1HF5P0fMWI00<0fMWI1000000;0=WIf@050:6QX@1HF5P0000005QHF036
a/H0503IfMT40?ooo`T0fMWIJ03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo
0?ooo`0B0?ooofX0fMWI0P3oool;0=WIfFP0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0B0?ooofX0fMWI0P3oool;0=WIfFP0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<0
00000?ooo`3oool04P3ooomZ0=WIf@030?ooo`3IfMT0fMWI00X0fMWIJ03oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0180ooooJP3IfMT00`3oool0fMWI0=WIf@0;0=WIfFL0oooo00<0
00000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooomh0=WIfFL0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooogP0fMWII`3oool00`000000oooo0?ooo`0Z
0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooogP0fMWII`3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo0180ooooN03IfMUW0?ooo`030000003oool0oooo02X0oooo000[0?ooo`03
0000003oool0oooo0180ooooN03IfMUW0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool04P3ooomh0=WIfFL0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0
4P3ooomh0=WIfFL0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooogT0fMWI
IP3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooogP0fMWII`3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180ooooN@3IfMUV0?ooo`030000003o
ool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooN@3IfMUV0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool04P3ooomi0=WIfFH0oooo00<000000?ooo`3oool0:P3oool0
02/0oooo00<000000?ooo`3oool04P3ooomi0=WIfFH0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0B0?ooogT0fMWIIP3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000
oooo0?ooo`0B0?ooogT0fMWIIP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180
ooooN@3IfMUV0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180oooo
N@3IfMUV0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3ooomj0=WIfFD0oooo
00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooomj0=WIfFD0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooogX0fMWII@3oool00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooogX0fMWII@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0180ooooNP3IfMUU0?ooo`030000003oool0oooo02X0oooo000[0?oo
o`030000003oool0oooo0180ooooNP3IfMUU0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool04P3ooomj0=WIfFD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3o
ool04P3ooomj0=WIfFD0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooog/0
fMWII03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooogX0fMWI
I@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180ooooN`3IfMUT0?ooo`030000
003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooN`3IfMUT0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool04P3ooomk0=WIfF@0oooo00<000000?ooo`3oool0:P3o
ool002/0oooo00<000000?ooo`3oool04P3ooomk0=WIfF@0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0B0?ooog/0fMWII03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`00
0000oooo0?ooo`0B0?ooog/0fMWII03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
0180ooooO03IfMUS0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180
ooooN`3IfMUT0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3oooml0=WIfF<0
oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooomk0=WIfF@0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooog`0fMWIH`3oool00`000000oooo
0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooog`0fMWIH`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0180ooooO03IfMUS0?ooo`030000003oool0oooo02X0oooo000[
0?ooo`030000003oool0oooo0180ooooO03IfMUS0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool04P3ooomm0=WIfF80oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?oo
o`3oool04P3oooml0=WIfF<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?oo
ogd0fMWIHP3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooog`0
fMWIH`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180ooooO@3IfMUR0?ooo`03
0000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooO@3IfMUR0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool04P3ooomm0=WIfF80oooo00<000000?ooo`3oool0
:P3oool002/0oooo00<000000?ooo`3oool04P3ooomm0=WIfF80oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0B0?ooogd0fMWIHP3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool0
0`000000oooo0?ooo`0B0?ooogd0fMWIHP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo0180ooooOP3IfMUQ0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo
0180ooooO@3IfMUR0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3ooomn0=WI
fF40oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooomm0=WIfF80
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooogh0fMWIH@3oool00`000000
oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooogh0fMWIH@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0180ooooOP3IfMUQ0?ooo`030000003oool0oooo02X0oooo
000[0?ooo`030000003oool0oooo0180ooooOP3IfMUQ0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool04P3ooomo0=WIfF00oooo00<000000?ooo`3oool0:P3oool002/0oooo00<00000
0?ooo`3oool04P3ooomn0=WIfF40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B
0?ooogl0fMWIH03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?oo
ogh0fMWIH@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180ooooO`3IfMUP0?oo
o`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooOP3IfMUQ0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool04P3ooomo0=WIfF00oooo00<000000?ooo`3o
ool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooomo0=WIfF00oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0B0?oooh00fMWIG`3oool00`000000oooo0?ooo`0Z0?ooo`00:`3o
ool00`000000oooo0?ooo`0B0?ooogl0fMWIH03oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0180oooo3@3IfMT00`000000fMWI0000000>0=WIf@030000003IfMT0fMWI05l0fMWIG`3o
ool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooogl0fMWIH03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo3P3IfMT00`000000fMWI00000003
0=WIf@D000001P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI05@0fMWIG`3oool0
0`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooogl0fMWIH03oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo3@3IfMT5000000@0fMWI00<000000=WI
f@3IfMT01`0000090=WIf@030000003IfMT0fMWI05@0fMWIG`3oool00`000000oooo0?ooo`0Z0?oo
o`00:`3oool00`000000oooo0?ooo`0B0?ooogl0fMWIH03oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0180oooo3P3IfMT00`000000fMWI000000050=WIf@030000003IfMT0fMWI00H0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@1D0=WIfEl0oooo00<000000?ooo`3o
ool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooomZ0=WIfGD0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0B0?ooo`h0fMWI00<000000=WIf@0000001@3IfMT00`000000fMWI
0=WIf@050=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0?@3IfMUe0?ooo`030000
003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool04P3oool=0=WIf@D00000103IfMT00`000000fMWI0=WI
f@0>0=WIf@040000003IfMT0fMWI000003l0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3o
ool00`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0180oooo3P3IfMT00`000000fMWI000000040=WIf@800000403IfMT4000003l0fMWIM@3o
ool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo3`3IfMT00`000000fMWI0000001H
0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooomZ0=WI
fGD0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?ooo`030000003oool0oooo02X0
oooo000[0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool04P3ooomZ0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<0
00000?ooo`3oool04P3ooomZ0=WIfGD0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0B0?ooofX0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B
0?ooofX0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180ooooJP3IfMUe
0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3ooomZ0=WIfGD0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooolR0=WIf@8000003P3IfMT2000000l0
fMWI0P0000080=WIf@8000006`3IfMUe0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool04P3ooolR0=WIf@80IVIV3P3IfMT206IVIPl0fMWI0P1VIVH80=WIf@80IVIV6`3IfMUe0?ooo`03
0000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180oooo8P3IfMT01P000000fMWI
0=WIf@000000fMWI000000/0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@080=WI
f@030000003IfMT0fMWI01T0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
0180oooo8P3IfMT01P1VIVH0fMWI0=WIf@1VIVH0fMWI06IVIP/0fMWI00<0IVIV0=WIf@3IfMT03@3I
fMT00`1VIVH0fMWI0=WIf@080=WIf@0306IVIP3IfMT0fMWI01T0fMWIM@3oool00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooo`h0fMWI0`0000040=WIf@<0000000<0fMWI
0000000000000P3IfMT2000000<0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000000<0fMWI
1@0000020=WIf@030000003IfMT0fMWI00D0fMWI100000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0I0=WIfGD0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0B0?ooo`h0fMWI0`1VIVH40=WIf@<0IVIV00<0fMWI06IVIP1VIVH0
0P3IfMT206IVIP<0fMWI00L0IVIV0=WIf@3IfMT0fMWI06IVIP3IfMT0IVIV00<0fMWI1@1VIVH20=WI
f@0306IVIP3IfMT0fMWI00D0fMWI101VIVH40=WIf@0306IVIP3IfMT0fMWI00<0fMWI00<0IVIV0=WI
f@3IfMT00P3IfMT00`1VIVH0fMWI0=WIf@0I0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0
oooo00<000000?ooo`3oool04P3oool>0=WIf@040000003IfMT0fMWI000000@0fMWI00D000000=WI
f@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01@000004
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01@3IfMT010000000fMWI00000000
00040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@0I0=WIfGD0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooo`h0fMWI00@0
IVIV0=WIf@3IfMT0IVIV103IfMT01@1VIVH0fMWI0=WIf@3IfMT0IVIV0080fMWI00<0IVIV0=WIf@3I
fMT00P3IfMT00`1VIVH0fMWI0=WIf@0506IVIP@0fMWI00<0IVIV0=WIf@3IfMT00P3IfMT00`1VIVH0
fMWI0=WIf@050=WIf@0406IVIP3IfMT0IVIV06IVIP@0fMWI00<0IVIV0=WIf@3IfMT00`3IfMT00`1V
IVH0fMWI0=WIf@020=WIf@0306IVIP3IfMT0fMWI01T0fMWIM@3oool00`000000oooo0?ooo`0Z0?oo
o`00:`3oool00`000000oooo0?ooo`0B0?oooa40fMWI00<000000=WIf@3IfMT00P3IfMT01@000000
fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT00P3IfMT01`000000fMWI0=WIf@3IfMT0
00000=WIf@0000001@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00H0fMWI00<0
00000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT06@3IfMUe0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3o
oolA0=WIf@0306IVIP3IfMT0fMWI0080fMWI00D0IVIV0=WIf@3IfMT0fMWI06IVIP020=WIf@0306IV
IP3IfMT0fMWI0080fMWI00L0IVIV0=WIf@3IfMT0fMWI06IVIP3IfMT0IVIV00D0fMWI00<0IVIV0=WI
f@3IfMT00P3IfMT00`1VIVH0fMWI0=WIf@060=WIf@0306IVIP3IfMT0fMWI00@0fMWI00<0IVIV0=WI
f@3IfMT00`3IfMT00`1VIVH0fMWI0=WIf@020=WIf@0306IVIP3IfMT0fMWI01T0fMWIM@3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooo`l0fMWI0P0000040=WIf@80
00000P3IfMT4000000D0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000000D0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000001/0fMWIM@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0180oooo3`3IfMT206IVIP@0fMWI0P1VIVH20=WIf@@0IVIV1@3I
fMT01`1VIVH0fMWI0=WIf@3IfMT0IVIV0=WIf@1VIVH01@3IfMT00`1VIVH0fMWI0=WIf@020=WIf@03
06IVIP3IfMT0fMWI00H0fMWI00<0IVIV0=WIf@3IfMT0103IfMT00`1VIVH0fMWI0=WIf@040=WIf@05
06IVIP3IfMT0fMWI0=WIf@1VIVH06`3IfMUe0?ooo`030000003oool0oooo02X0oooo000[0?ooo`03
0000003oool0oooo0180oooo3P3IfMT010000000fMWI0=WIf@00000@0=WIf@030000003IfMT0fMWI
00D00000103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00H0fMWI0`0000040=WI
f@050000003IfMT0fMWI0=WIf@0000000P3IfMT01@000000fMWI0=WIf@3IfMT0000001/0fMWIM@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo3P3IfMT0101VIVH0fMWI0=WI
f@1VIVH@0=WIf@0306IVIP3IfMT0fMWI00D0IVIV103IfMT00`1VIVH0fMWI0=WIf@020=WIf@0306IV
IP3IfMT0fMWI00H0fMWI0`1VIVH40=WIf@0506IVIP3IfMT0fMWI0=WIf@1VIVH00P3IfMT01@1VIVH0
fMWI0=WIf@3IfMT0IVIV01/0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000
oooo0?ooo`0B0?ooo`h0fMWI100000040=WIf@030000003IfMT0fMWI00T0fMWI0P0000020=WIf@03
0000003IfMT0000000@0fMWI0P0000030=WIf@8000003`3IfMT200000080fMWI100000020=WIf@80
00006`3IfMUe0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3oool>0=WIf@@0
IVIV103IfMT00`1VIVH0fMWI0=WIf@090=WIf@80IVIV0P3IfMT00`1VIVH0fMWI06IVIP040=WIf@80
IVIV0`3IfMT206IVIPl0fMWI0P1VIVH20=WIf@@0IVIV0P3IfMT206IVIQ/0fMWIM@3oool00`000000
oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooobL0fMWI00<000000=WIf@000000
@03IfMUe0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3ooolW0=WIf@0306IV
IP3IfMT0IVIV0400fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?oo
o`0B0?ooofX0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180ooooJP3I
fMUe0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooJP3IfMUe
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3ooomZ0=WIfGD0oooo00<00000
0?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooomZ0=WIfGD0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool00`000000oooo0?ooo`0Z0?oo
o`00:`3oool00`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0180ooooJP3IfMUe0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000
003oool0oooo0180ooooJP3IfMUe0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
4P3ooomZ0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3o
oomZ0=WIfGD0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooofX0fMWIM@3o
ool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?ooofX0fMWIM@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?ooo`030000003oool0
oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooJP3IfMUe0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool04P3ooomZ0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0
oooo00<000000?ooo`3oool04P3ooomZ0=WIfGD0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0B0?ooofX0fMWIM@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo
0?ooo`0B0?ooofX0fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo
JP3IfMUe0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0180ooooJP3I
fMUe0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3ooomZ0=WIfGD0oooo00<0
00000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool04P3ooolE0=WIf@0306IVIP3IfMT0
fMWI0580fMWIM@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo5P3IfMT0
0`1VIVH0fMWI0=WIf@1A0=WIfGD0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?oo
o`3oool07@3oool:0=WIf@0306IVIP3IfMT0fMWI00T0fMWI_P3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo01d0oooo2`3IfMT00`1VIVH0fMWI0=WIf@080=WIfKh0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool0703oool:0=WIf@<0IVIV2P3IfMVn0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool:0=WIf@80IVIV2`3IfMVm0?ooo`03
0000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo01`0oooo2P3IfMT306IVIP/0fMWI
_@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01`0oooo2`3IfMT206IVIP/0fMWI
_@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0L0?ooo`X0fMWI0`1V
IVH;0=WIfKd0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0L0?ooo`/0fMWI0`1V
IVH:0=WIfKd0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool06`3oool;
0=WIf@<0IVIV2`3IfMVm0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0703oool;
0=WIf@<0IVIV2`3IfMVl0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo
01/0oooo2P3IfMT01@1VIVH0fMWI06IVIP3IfMT0IVIV00/0fMWI_03oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01/0oooo2`3IfMT0101VIVH0fMWI06IVIP1VIVH;0=WIfK`0oooo00<0
00000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool06`3oool:0=WIf@0506IVIP3IfMT0
IVIV0=WIf@1VIVH02`3IfMVl0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06`3o
ool;0=WIf@0406IVIP3IfMT0IVIV06IVIP/0fMWI_03oool00`000000oooo0?ooo`0Z0?ooo`00:`3o
ool00`000000oooo0?ooo`0J0?ooo`d0fMWI00<0IVIV0=WIf@3IfMT02`3IfMVl0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool06`3oool=0=WIf@0306IVIP3IfMT0fMWI00/0fMWI^`3o
ool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0J0?ooo`d0fMWI00<0IVIV
0=WIf@3IfMT0303IfMVk0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06P3oool>
0=WIf@0306IVIP3IfMT0fMWI00/0fMWI^`3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`00
0000oooo0?ooo`0J0?ooo`d0fMWI00<0IVIV0=WIf@3IfMT0303IfMVk0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool06P3oool>0=WIf@0306IVIP3IfMT0fMWI00/0fMWI^`3oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0I0?ooo`h0fMWI00<0IVIV0=WIf@3I
fMT0303IfMVk0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06P3oool>0=WIf@03
06IVIP3IfMT0fMWI00`0fMWI^P3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo
0?ooo`0I0?ooo`h0fMWI00<0IVIV0=WIf@3IfMT03@3IfMVj0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool06@3oool?0=WIf@0306IVIP3IfMT0fMWI00`0fMWI^P3oool00`000000oooo
0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0I0?ooo`h0fMWI00<0IVIV0=WIf@3IfMT03@3I
fMVj0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06@3oool?0=WIf@0306IVIP3I
fMT0fMWI00`0fMWI^P3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0H
0?ooo`l0fMWI00<0IVIV0=WIf@3IfMT03@3IfMVj0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool06@3oool?0=WIf@0306IVIP3IfMT0fMWI00d0fMWI^@3oool00`000000oooo0?ooo`0Z
0?ooo`00:`3oool00`000000oooo0?ooo`0H0?ooo`l0fMWI00<0IVIV0=WIf@3IfMT03P3IfMVi0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0603oool@0=WIf@0306IVIP3IfMT0fMWI
00d0fMWI^@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0H0?ooo`l0
fMWI00<0IVIV0=WIf@3IfMT03P3IfMVi0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0603oool@0=WIf@0306IVIP3IfMT0fMWI00d0fMWI^@3oool00`000000oooo0?ooo`0Z0?ooo`00
:`3oool00`000000oooo0?ooo`0G0?oooa00fMWI00<0IVIV0=WIf@3IfMT03`3IfMVh0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool05`3ooolA0=WIf@0306IVIP3IfMT0fMWI00h0fMWI
^03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0G0?oooa00fMWI00<0
IVIV0=WIf@3IfMT03`3IfMVh0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05`3o
oolA0=WIf@0306IVIP3IfMT0fMWI00h0fMWI^03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool0
0`000000oooo0?ooo`0G0?oooa00fMWI00<0IVIV0=WIf@3IfMT03`3IfMVh0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool05`3ooolA0=WIf@0306IVIP3IfMT0fMWI00h0fMWI^03oool0
0`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0F0?oooa40fMWI00<0IVIV0=WI
f@3IfMT0403IfMVg0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05P3ooolB0=WI
f@0306IVIP3IfMT0fMWI00l0fMWI]`3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000
oooo0?ooo`0F0?oooa40fMWI00<0IVIV0=WIf@3IfMT0403IfMVg0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool05P3ooolB0=WIf@0306IVIP3IfMT0fMWI00l0fMWI]`3oool00`000000
oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0F0?oooa40fMWI00<0IVIV0=WIf@3IfMT0
403IfMVg0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05P3ooolB0=WIf@0306IV
IP3IfMT0fMWI00l0fMWI]`3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?oo
o`0E0?oooa80fMWI00<0IVIV0=WIf@3IfMT04@3IfMVf0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool05@3ooolC0=WIf@0306IVIP3IfMT0fMWI0100fMWI]P3oool00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0E0?oooa80fMWI00<0IVIV0=WIf@3IfMT04@3IfMVf
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05@3ooolC0=WIf@0306IVIP3IfMT0
fMWI0100fMWI]P3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0E0?oo
oa80fMWI00<0IVIV0=WIf@3IfMT04@3IfMVf0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool05@3ooolC0=WIf@0306IVIP3IfMT0fMWI0100fMWI]P3oool00`000000oooo0?ooo`0Z0?oo
o`00:`3oool00`000000oooo0?ooo`0D0?oooa<0fMWI00<0IVIV0=WIf@3IfMT04P3IfMVe0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0503ooolD0=WIf@0306IVIP3IfMT0fMWI0140
fMWI]@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0D0?oooa<0fMWI
00<0IVIV0=WIf@3IfMT04P3IfMVe0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
503ooolD0=WIf@0306IVIP3IfMT0fMWI0140fMWI]@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3o
ool00`000000oooo0?ooo`0D0?oooa<0fMWI00<0IVIV0=WIf@3IfMT04P3IfMVe0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0503ooolD0=WIf@0306IVIP3IfMT0fMWI0140fMWI]@3o
ool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0C0?oooa@0fMWI00<0IVIV
0=WIf@3IfMT04`3IfMVd0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3ooolE
0=WIf@0306IVIP3IfMT0fMWI0180fMWI]03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`00
0000oooo0?ooo`0C0?oooa@0fMWI00<0IVIV0=WIf@3IfMT04`3IfMVd0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool04`3ooolE0=WIf@0306IVIP3IfMT0fMWI0180fMWI]03oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0B0?oooaD0fMWI00<0IVIV0=WIf@3I
fMT04`3IfMVd0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3ooolF0=WIf@03
06IVIP3IfMT0fMWI0180fMWI]03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo
0?ooo`0W0?ooo`0306IVIP3oool0oooo0<L0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0X0?ooo`0306IVIP3oool0oooo0<H0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<0
00000?ooo`3oool09`3oool00`1VIVH0oooo0?ooo`370?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0:03oool00`1VIVH0oooo0?ooo`360?ooo`030000003oool0oooo02X0oooo000[
0?ooo`030000003oool0oooo02L0oooo00<0IVIV0?ooo`3oool0a`3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo02P0oooo00<0IVIV0?ooo`3oool0aP3oool00`000000oooo0?ooo`0Z
0?ooo`00:`3oool00`000000oooo0?ooo`0W0?ooo`0306IVIP3oool0oooo0<L0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0X0?ooo`0306IVIP3oool0oooo0<H0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool09`3oool00`1VIVH0oooo0?ooo`370?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0:03oool00`1VIVH0oooo0?ooo`360?ooo`03
0000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo02L0oooo00<0IVIV0?ooo`3oool0
a`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo00<0IVIV0?ooo`3oool0
aP3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0W0?ooo`0306IVIP3o
ool0oooo0<L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0X0?ooo`0306IVIP3o
ool0oooo0<H0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool09`3oool0
0`1VIVH0oooo0?ooo`370?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:03oool0
0`1VIVH0oooo0?ooo`360?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo
02L0oooo00<0IVIV0?ooo`3oool0a`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
02P0oooo00<0IVIV0?ooo`3oool0aP3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000
oooo0?ooo`0W0?ooo`0306IVIP3oool0oooo0<L0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0X0?ooo`0306IVIP3oool0oooo0<H0oooo00<000000?ooo`3oool0:P3oool002/0oooo
00<000000?ooo`3oool09`3oool00`1VIVH0oooo0?ooo`370?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0:03oool00`1VIVH0oooo0?ooo`360?ooo`030000003oool0oooo02X0oooo
000[0?ooo`030000003oool0oooo02L0oooo00<0IVIV0?ooo`3oool0a`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo02P0oooo00<0IVIV0?ooo`3oool0aP3oool00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0W0?ooo`0306IVIP3oool0oooo0<L0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0X0?ooo`0306IVIP3oool0oooo0<H0oooo00<00000
0?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool09`3oool00`1VIVH0oooo0?ooo`370?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:03oool00`1VIVH0oooo0?ooo`360?oo
o`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo02L0oooo00<0IVIV0?ooo`3o
ool0a`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo00<0IVIV0?ooo`3o
ool0aP3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0W0?ooo`0306IV
IP3oool0oooo0<L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0X0?ooo`0306IV
IP3oool0oooo0<H0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0l@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0:P3o
ool002/0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo0?40oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0l@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0:P3oool002/0
oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?40
oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0l@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0:P3oool002/0oooo00<0
00000?ooo`3oool0l@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?40oooo00<0
00000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?oo
o`3oool0l@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?40oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0?40oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0
l@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0
:P3oool002/0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0?40oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0l@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0:P3oool0
02/0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
0?40oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool09`3oool00`1VIVH0
oooo0?ooo`370?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:03oool00`1VIVH0
oooo0?ooo`360?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo02L0oooo
00<0IVIV0?ooo`3oool0a`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02P0oooo
00<0IVIV0?ooo`3oool0aP3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?oo
o`0W0?ooo`0306IVIP3oool0oooo0<L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0X0?ooo`0306IVIP3oool0oooo0<H0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<00000
0?ooo`3oool0:03oool00`1VIVH0oooo0?ooo`360?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0:@3oool00`1VIVH0oooo0?ooo`350?ooo`030000003oool0oooo02X0oooo000[0?oo
o`030000003oool0oooo02D0oooo00@0IVIV0?ooo`3oool0IVIVb03oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo02H0oooo00@0IVIV0?ooo`3oool0IVIVa`3oool00`000000oooo0?oo
o`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0U0?ooo`@0IVIVb03oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo02H0oooo101VIVK70?ooo`030000003oool0oooo02X0oooo000[0?oo
o`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?oo
o`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000
003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000
003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0
oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0
oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0
oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[
0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a
0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`03
0000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`03
0000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003o
ool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003o
ool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo
0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo
02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo
000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?oo
o`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?oo
o`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000
003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000
003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0
oooo0?40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0
oooo02X0oooo000[0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo0?40
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02X0
oooo000[0?ooooD00000803ooooe000002`0oooo003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooof<0oooo003o0?ooool0ooooH`3oool00?l0ooooT03oool2000002h0oooo
0`00002O0?ooo`00o`3ooonA0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0W03o
ool00680oooo0P0000040?ooo`8000002P3oool200000080oooo0`0000000`3oool0000000000002
0?ooo`<00000203oool4000000<0oooo1P0000020?ooo`8000000P3oool3000000<0oooo0P000004
0?ooo`<000000`3oool200000080oooo0P0000020?ooo`8000001P3oool2000000050?ooo`000000
oooo0000003oool01@0000020?ooo`<0000000D0oooo00000000000000000?ooo`0200000080oooo
0`0000000`3oool00000000000020?ooo`8000000P3oool3000009l0oooo100000050?ooo`030000
003oool0oooo00P0oooo0P0000020?ooo`<0000000<0oooo0000000000000P3oool3000000P0oooo
1@0000000`3oool0000000000002000000<0oooo0`0000030?ooo`H0000000@0oooo0000003oool0
00000P3oool3000000030?ooo`00000000000080oooo0P0000020?ooo`8000002@3oool00`3o0000
oooo0?ooo`1e0?ooo`00H@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00H0oooo00H000000?ooo`000000oooo0000003oool400000080oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`00002S0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000
203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool02@3oool4000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00L000000?ooo`000000oooo0000003oool0000000D0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`030?l0003oool0
oooo07@0oooo001Q0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo100000090?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`060?ooo`050000003oool0
00000?ooo`000000103oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@00000X03oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000020?ooo`@000002`3oool01@000000oooo0?ooo`3oool0000000@0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0
00000?ooo`000000oooo100000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`1d0?ooo`00H03oool5000000<0oooo0P0000080?ooo`D00000
0P3oool3000000@0oooo0P0000090?ooo`@0000000@0oooo000000000000oooo0P0000000`3oool0
000000000002000000@0oooo0`0000000`3oool0000000000003000000<0oooo0P0000040?ooo`80
00000P3oool4000000P0oooo0`0000000`3oool000000?ooo`020?ooo`<000000`3oool300000080
oooo0`0000040?ooo`8000000P3oool4000000@0oooo0P00002Q0?ooo`<000000P3oool300000003
0?ooo`000000000000H0oooo1@0000020?ooo`<00000103oool2000000X0oooo0`0000020?ooo`@0
00000`3oool6000000040?ooo`00000000000?ooo`<0000000<0oooo0000003oool00P3oool20000
0080oooo100000020?ooo`D000002@3oool00`3o0000oooo0?ooo`1d0?ooo`00H@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0/`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`080?ooo`040?l0003oool0oooo0?l007D0oooo001h0?ooo`8000004`3oool2000001`0
oooo00<000000?ooo`3oool0903oool2000000L0oooo00<000000?ooo`3oool0ZP3oool2000001H0
oooo0P0000160?ooo`@0o`00M@3oool00?l0ooooj@3oool40?l007D0oooo003o0?ooool0ooooH`3o
ool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo003o0?ooool0ooooH`3oool00?l0oooo
o`3ooomS0?ooo`00T@3oool300000?l0oooo5P3oool3000002`0oooo0`0000260?ooo`00U03oool0
0`000000oooo0?ooo`3i0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`250?ooo`00K@3oool300000080oooo0`0000000`3oool00000000000020?oo
o`<00000203oool5000000030?ooo`0000000000008000000`3oool3000000<0oooo1P000000103o
ool000000?ooo`0000020?ooo`<0000000<0oooo0000000000000P3oool200000080oooo0P00000:
0?ooo`<000000P3oool3000000T0oooo100000030?ooo`<000000`3oool4000009/0oooo0`000002
0?ooo`<0000000<0oooo0000000000000P3oool3000000P0oooo00<000000?ooo`0000002@3oool3
000000@0oooo0`0000030?ooo`<0000000<0oooo0000000000000P3oool2000000P0oooo0`000002
0?ooo`<000002@3oool4000000<0oooo0`0000020?ooo`<000000`3oool3000000<0oooo1@000002
0?ooo`<000000`3oool3000000<0oooo1000001U0?ooo`00KP3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool02@3oool4000000<0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00L000000?ooo`000000oooo0000003oool0000000D0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
W@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0203oool5000000/0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`@000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
IP3oool006h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`@00000
2`3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`060000003oool000000?ooo`000000oooo100000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`3oool30000
00X0oooo00<000000?ooo`3oool00P3oool400000080oooo00@000000?ooo`3oool00000W@3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo100000080?ooo`030000003o
ool0000000T0oooo0`0000050?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0oooo0`00000:0?oo
o`030000003oool0oooo0080oooo100000020?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`0000050?ooo`@000000P3oool010000000oooo0?oo
o`00001V0?ooo`00KP3oool00`000000oooo0?ooo`020?ooo`<00000103oool2000000X0oooo0`00
00020?ooo`@000000`3oool6000000040?ooo`00000000000?ooo`<0000000<0oooo0000003oool0
0P3oool200000080oooo100000020?ooo`D000002@3oool2000000<0oooo100000080?ooo`@00000
0`3oool2000000@0oooo0`00002M0?ooo`030000003oool0oooo0080oooo0`0000040?ooo`800000
2@3oool00`000000oooo000000090?ooo`@000000`3oool2000000@0oooo2000000:0?ooo`800000
0`3oool4000000P0oooo100000030?ooo`8000000P3oool4000000@0oooo00<000000?ooo`3oool0
0`3oool3000000<0oooo0`0000030?ooo`800000103oool3000006H0oooo001/0?ooo`050000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2I0?ooo`050000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`0>0?ooo`D00000B`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo06@0oooo001/0?ooo`D0000000<0oooo000000000000B@3oool00`000000oooo
0?ooo`0?0?ooo`8000002P3oool2000009/0oooo1@0000000`3oool000000000000A0?ooo`030000
003oool000000140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0O0?ooo`800000
603oool2000006H0oooo003o0?oooi<0oooo00<000000?ooo`000000c03oool00?l0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooof<0oooo003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3o
oooo0?ooof<0oooo003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0
oooo003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo003o0?oo
ool0ooooH`3oool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo003o0?ooool0ooooH`3o
ool00?l0ooooo`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo003o0?ooool0ooooH`3oool00?l0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooof<0oooo003o0?ooool0ooooH`3oool00?l0ooooo`3ooomS0?oo
o`00o`3ooooo0?ooof<0oooo003o0?ooool0ooooH`3oool00=D0oooo0`1VVIT50?ooo`<0IYVI0`3o
ool306JIV@@0oooo00H0b]_K0:C2`P1VVIT0IYVI0<;FeP3am_H70?ooo`<0IYVI2@3oool01@32e]H0
IYVI06JIV@32e]H0lOKf00<0IYVI0P3oool306JIV@<0oooo0`1VVIT30?ooo`060?Kin@32e]H0IYVI
06JIV@2`b/X0j>o_0`3oool01P3am_H0/<[:06JIV@1VVIT0^]7A0?ooo`<0IYVI103oool01@3Ah>00
Y<;206JIV@2T`/80enCT00@0oooo0`1VVIT30?ooo`<0IYVI1P3oool306JIV@80oooo00<0enCT06JI
V@3Gi>@00P3oool306JIV@<0oooo00D0b]_K06JIV@2D^;P0b]_K0?7fmP0206JIV@050<;FeP3oool0
oooo0?Kin@32e]H00P1VVIT00`2`b/X0j>o_0?ooo`020?ooo`<0IYVI0`3oool306JIV@80oooo0`1V
VIT20?ooo`<0IYVI0`3oool306JIV@@0oooo00H0b]_K0:C2`P1VVIT0IYVI0<;FeP3am_KD0?ooo`00
e@3oool306JIV@D0oooo0`1VVIT30?ooo`<0IYVI0`3oool00`2`b/X0IYVI06JIV@0306JIV@0309Bh
^03am_H0oooo00D0oooo0`1VVIT80?ooo`030<[Kf`1VVIT0IYVI0080IYVI00@0U;Rh06JIV@1VVIT0
IYVI0P3oool306JIV@<0oooo0`1VVIT30?ooo`0309Bh^01VVIT0IYVI00<0IYVI00@0j>o_0?ooo`3o
ool0/<[:0`1VVIT00`32e]H0oooo06JIV@0206JIV@<0oooo00<0/<[:06JIV@1VVIT00`1VVIT0102`
b/X0oooo0?ooo`3oool306JIV@<0oooo0`1VVIT60?ooo`<0IYVI0P3oool00`2jdM40IYVI0;[Ad@02
0?ooo`<0IYVI0P3oool00`3:fm/0IYVI06JIV@0206JIV@0409Bh^01VVIT0IYVI0?7fmP80oooo00<0
U;Rh06JIV@1VVIT00`1VVIT00`3Xknl0oooo0?ooo`0306JIV@<0oooo0`1VVIT20?ooo`<0IYVI0P3o
ool306JIV@<0oooo0`1VVIT30?ooo`030;3:bP1VVIT0IYVI00<0IYVI00<0U;Rh0?7fmP3oool0dP3o
ool00=D0oooo0`1VVIT50?ooo`<0IYVI0`3oool306JIV@80oooo00H0enCT06JIV@1VVIT0enCT0?oo
o`3Xknl206JIV@030;[Ad@3oool0oooo00@0oooo0`1VVIT80?ooo`0609Bh^01VVIT0IYVI0=gXj03o
ool0b]_K0`1VVIT20?ooo`<0IYVI0`3oool306JIV@80oooo00P0b]_K06JIV@1VVIT0b]_K0?ooo`3A
h>00IYVI0:C2`P80oooo0`1VVIT30?ooo`<0IYVI0P3oool01P3Ah>00IYVI06JIV@32e]H0oooo0<;F
eP80IYVI00<0enCT0?ooo`3oool00`1VVIT30?ooo`<0IYVI1P3oool306JIV@80oooo0`1VVIT20?oo
o`<0IYVI0P3oool306JIV@030?7fmP3Mj>P0IYVI0080IYVI0P3oool0203:fm/0IYVI06JIV@3:fm/0
oooo0=7Ph01VVIT0Y<;20P3oool306JIV@<0oooo0`1VVIT20?ooo`<0IYVI0P3oool306JIV@<0oooo
0`1VVIT20?ooo`060=OTi01VVIT0IYVI0=OTi03oool0j>o_0P1VVIT00`2jdM40oooo0?ooo`3A0?oo
o`00e@3oool306JIV@D0oooo0`1VVIT30?ooo`<0IYVI0P3oool00`2T`/80IYVI06JIV@0<0?ooo`<0
IYVI203oool306JIV@80oooo00@0m_Wi06JIV@1VVIT0IYVI0P3oool306JIV@<0oooo0`1VVIT20?oo
o`080:C2`P1VVIT0IYVI0?Kin@3oool0m_Wi0;[Ad@3]lo<20?ooo`<0IYVI0`3oool306JIV@80oooo
00H0Y<;206JIV@1VVIT0lOKf0?ooo`3am_H206JIV@030:C2`P3oool0oooo00<0IYVI0`3oool306JI
V@H0oooo0`1VVIT00`3oool0kO?c06JIV@0206JIV@030>gcl`3oool0IYVI0080IYVI0P3oool306JI
V@80oooo0`1VVIT20?ooo`080:C2`P1VVIT0IYVI0?Kin@3oool0m_Wi0;[Ad@3]lo<20?ooo`<0IYVI
0`3oool306JIV@80oooo0`1VVIT20?ooo`<0IYVI0`3oool306JIV@80oooo00<0Y<;206JIV@1VVIT0
f@3oool00=D0oooo0`1VVIT50?ooo`<0IYVI0`3oool306JIV@80oooo2@1VVIT60?ooo`<0IYVI203o
ool306JIV@<0oooo0`1VVIT20?ooo`<0IYVI0`3oool306JIV@80oooo0`1VVIT70?ooo`<0IYVI0`3o
ool306JIV@80oooo0`1VVIT30?ooo`<0IYVI0P3oool306JIV@<0oooo0`1VVIT60?ooo`<0IYVI00L0
oooo0=OTi01VVIT0^]7A06JIV@3Gi>@0oooo00<0IYVI0P3oool01@3Sk>`0IYVI06JIV@32e]H0lOKf
00<0IYVI0P3oool306JIV@L0oooo0`1VVIT30?ooo`<0IYVI0P3oool306JIV@80oooo0`1VVIT30?oo
o`<0IYVI0P3oool906JIVM<0oooo003E0?ooo`<0IYVI1@3oool306JIV@<0oooo0`1VVIT20?ooo`T0
IYVI1P3oool806JIV@<0oooo0`1VVIT30?ooo`<0IYVI0P3oool306JIV@<0oooo0`1VVIT20?ooo`<0
IYVI1`3oool306JIV@<0oooo0`1VVIT20?ooo`<0IYVI0`3oool306JIV@80oooo0`1VVIT30?ooo`<0
IYVI1P3oool306JIV@070?ooo`2jdM40IYVI0>gcl`1VVIT0^]7A0?ooo`0306JIV@<0oooo00<0lOKf
0:C2`P1VVIT0101VVIT20?ooo`<0IYVI1`3oool306JIV@<0oooo0`1VVIT20?ooo`<0IYVI0P3oool3
06JIV@<0oooo0`1VVIT20?ooo`T0IYVId`3oool00=D0oooo0`1VVIT50?ooo`<0IYVI00<0m_Wi0?oo
o`3oool00`1VVIT20?ooo`030:C2`P1VVIT0IYVI00<0oooo0P1VVIT00`2jdM40oooo0?ooo`040?oo
o`P0IYVI0`3oool306JIV@<0oooo0`1VVIT20?ooo`<0IYVI00<0m_Wi0?ooo`3oool00`1VVIT20?oo
o`080:C2`P1VVIT0IYVI0?Kin@3oool0m_Wi0;[Ad@3]lo<20?ooo`<0IYVI0`3oool306JIV@80oooo
00H0/<[:06JIV@1VVIT0lOKf0?ooo`3am_H206JIV@030:C2`P3oool0oooo00<0IYVI00<0m_Wi0?oo
o`3oool00`1VVIT60?ooo`<0IYVI00L0oooo06JIV@2T`/80oooo0:C2`P1VVIT0oooo00<0IYVI1@3o
ool00`3Mj>P0/<[:06JIV@0206JIV@80oooo00P0Y<;206JIV@1VVIT0m_Wi0?ooo`3fnOT0^]7A0>gc
l`80oooo0`1VVIT00`3fnOT0oooo0?ooo`0306JIV@80oooo0`1VVIT20?ooo`<0IYVI00<0m_Wi0?oo
o`3oool00`1VVIT20?ooo`030:C2`P1VVIT0IYVI00<0oooo0P1VVIT00`2jdM40oooo0?ooo`3A0?oo
o`00e@3oool306JIV@D0oooo0`1VVIT00`3:fm/0oooo0>?/k00206JIV@0409Bh^03oool0oooo0<[K
f`80IYVI00<0dN3P0?ooo`3Gi>@00P1VVIT00`3Gi>@0oooo0?ooo`040?ooo`P0IYVI0`3oool306JI
V@<0oooo0`1VVIT20?ooo`<0IYVI00<0b]_K0?ooo`3Mj>P00P1VVIT0102D^;P0oooo0?ooo`3:fm/2
06JIV@050<[Kf`3oool0enCT06JIV@2T`/800P3oool306JIV@<0oooo0`1VVIT20?ooo`060=OTi01V
VIT0IYVI0<;FeP3oool0`]KF0P1VVIT00`3Gi>@0oooo0?ooo`0306JIV@030<[Kf`3oool0gNSX0080
IYVI00<0U;Rh0?ooo`3oool0103oool306JIV@070>S_k`1VVIT0dN3P0?ooo`3Ah>00IYVI0>S_k`03
06JIV@80oooo00D0Y<;206JIV@3Xknl0oooo0?7fmP0306JIV@80oooo00P0b]_K06JIV@1VVIT0b]_K
0?ooo`3Gi>@0IYVI0:C2`P80oooo0`1VVIT00`3:fm/0oooo0>?/k00206JIV@0309Bh^03oool0oooo
00<0IYVI0P3oool306JIV@030<[Kf`3oool0gNSX0080IYVI00@0U;Rh0?ooo`3oool0b]_K0P1VVIT0
0`3Ah>00oooo0=OTi00206JIV@030=OTi03oool0oooo0=40oooo003E0?ooo`<0IYVI1@3oool806JI
V@050=7Ph03oool0oooo0?ooo`2D^;P01@1VVIT00`2D^;P0oooo0?ooo`050?ooo`<0IYVI203oool3
06JIV@<0oooo0`1VVIT20?ooo`<0IYVI00<0U;Rh06JIV@1VVIT00P1VVIT01@3:fm/0oooo0?ooo`3o
ool0U;Rh00D0IYVI00<0j>o_0?ooo`1VVIT01@1VVIT0103oool0IYVI06JIV@1VVIT30?ooo`030;3:
bP1VVIT0IYVI00<0IYVI00@0/<[:0?ooo`3oool0oooo0`1VVIT00`2D^;P0IYVI06JIV@0206JIV@03
0<[Kf`3oool0oooo00@0oooo0`1VVIT01`3Ah>00IYVI0>S_k`3oool0j>o_06JIV@3Ah>000`1VVIT2
0?ooo`030>S_k`1VVIT0IYVI00@0IYVI00D0`]KF0?ooo`3oool0oooo09Bh^00506JIV@030>S_k`3o
ool0oooo00P0IYVI00<0dN3P0?ooo`3oool00`1VVIT20?ooo`<0IYVI00<0U;Rh06JIV@1VVIT00P1V
VIT01@3:fm/0oooo0?ooo`3oool0U;Rh00D0IYVI00<0U;Rh0?ooo`3oool0dP3oool00=D0oooo0`1V
VIT50?ooo`<0IYVI00D0kO?c0;3:bP1VVIT0U;Rh0<[Kf`050?ooo`050<[Kf`2D^;P0IYVI09Bh^03:
fm/0203oool306JIV@P0oooo0`1VVIT30?ooo`<0IYVI0P3oool306JIV@050?7fmP32e]H0IYVI06JI
V@3:fm/0103oool01P3fnOT0`]KF06JIV@1VVIT0/<[:0>S_k`80oooo1P1VVIT0103oool0IYVI06JI
V@1VVIT40?ooo`050<[Kf`2T`/80IYVI0:C2`P3Gi>@0103oool306JIV@050?7fmP32e]H0IYVI06JI
V@3:fm/01`3oool306JIV@030;3:bP1VVIT0oooo0080oooo00<0IYVI0;3:bP1VVIT00P1VVIT30?oo
o`060>S_k`2`b/X0IYVI06JIV@2D^;P0b]_K103oool01P3fnOT0`]KF06JIV@1VVIT0/<[:0>S_k`<0
oooo0`1VVIT01@3]lo<0/<[:06JIV@2D^;P0b]_K00<0oooo0`1VVIT20?ooo`<0IYVI00D0lOKf0<;F
eP1VVIT0IYVI0<[Kf`050?ooo`050<[Kf`2D^;P0IYVI09Bh^03:fm/0e@3oool00=40oooo2`1VVIT0
103oool0IYVI06JIV@1VVITG0?ooo`T0IYVI8P3oool306JIVB80oooo101VVIT01@2jdM40oooo0?oo
o`3oool0^]7A00@0IYVI5P3oool306JIVO@0oooo003A0?ooo`/0IYVI00@0oooo06JIV@1VVIT0IYVI
5`3oool906JIVB80oooo0`1VVIT30?ooo`<0IYVI703oool406JIV@050=gXj03oool0oooo0?ooo`3M
j>P0101VVITF0?ooo`<0IYVI203oool306JIVNT0oooo003A0?ooo`/0IYVI00@0oooo06JIV@1VVIT0
IYVI5`3oool906JIVB80oooo00<0lOKf0=7Ph02T`/800`3oool306JIVA`0oooo101VVIT01@3am_H0
oooo0?ooo`3oool0lOKf00@0IYVI5P3oool306JIV@P0oooo0`1VVIWY0?ooo`00o`3ooooo0?ooof<0
oooo0000\
\>"],
  ImageRangeCache->{{{0, 608}, {547, 0}} -> {-0.0992728, -0.0450097, \
0.00361603, 0.00361603}, {{27.4375, 303.25}, {534.5, 286.25}} -> {-1.02518, \
-0.199436, 0.0235883, 0.0159534}, {{304.688, 580.5}, {534.5, 286.25}} -> \
{-7.57973, -0.199716, 0.0236215, 0.0159759}, {{27.4375, 303.25}, {285, \
36.75}} -> {-1.02518, -4.17982, 0.0235883, 0.0159534}, {{304.688, 580.5}, \
{285, 36.75}} -> {-7.55625, -4.1763, 0.0235685, 0.01594}},
  CellTags->"M50.8.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compound Interest", "Subsection",
  CellTags->"M50.8.2"],

Cell[TextData[{
  "We can use this approach to derive formulas for compound interest. Suppose \
we assume an interest rate in percent of ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ". We multiply (",
  Cell[BoxData[
      \(TraditionalForm\`1 + r/100\)]],
  ") by our argument, which we represent by the ",
  StyleBox["#", "MR"],
  " sign."
}], "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Nest[\((1 + r/100)\)\ # &, Deposit, 5]\)], "Input",
  CellTags->"M50.8.2"],

Cell[BoxData[
    \(Deposit\ \((1 + r\/100)\)\^5\)], "Output",
  CellTags->"M50.8.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["An Example", "Subsection",
  CellTags->"M50.8.2"],

Cell[TextData[{
  "With a little experimentation we can get ordered pairs for our answer. \
Here the first argument is the number of periods we have passed and the \
second argument is the value of the account with ",
  Cell[BoxData[
      \(TraditionalForm\`r = 6  %\)]],
  ". Even with this amount of interest and a small number of years, the \
increasing slope of the function becomes noticeable."
}], "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(acctvalue1 = 
      NestList[{#[\([1]\)] + 1, \((1 + 6. /100)\)\ #[\([2]\)]} &, {0, 100}, 
        10]\)], "Input",
  CellTags->"M50.8.2"],

Cell[BoxData[
    \({{0, 100}, {1, 106.`}, {2, 112.36`}, {3, 119.1016`}, {4, 
        126.247696`}, {5, 133.82255776000002`}, {6, 141.85191122560002`}, {7, 
        150.36302589913603`}, {8, 159.3848074530842`}, {9, 
        168.94789590026926`}, {10, 179.08476965428542`}}\)], "Output",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(acctplt1 = 
        ListPlot[acctvalue1, PlotJoined\  \[Rule] \ True, 
          GridLines\  \[Rule] \ Automatic];\)\)], "Input",
  CellTags->"M50.8.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -0.729554 0.00744269 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .16357 -18 -4.5 ]
[.01131 .16357 0 4.5 ]
[.01131 .31242 -18 -4.5 ]
[.01131 .31242 0 4.5 ]
[.01131 .46128 -18 -4.5 ]
[.01131 .46128 0 4.5 ]
[.01131 .61013 -18 -4.5 ]
[.01131 .61013 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .61803 L
s
.21429 0 m
.21429 .61803 L
s
.40476 0 m
.40476 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.78571 0 m
.78571 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 .01472 m
1 .01472 L
s
0 .16357 m
1 .16357 L
s
0 .31242 m
1 .31242 L
s
0 .46128 m
1 .46128 L
s
0 .61013 m
1 .61013 L
s
0 g
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16357 m
.03006 .16357 L
s
[(120)] .01131 .16357 1 0 Mshowa
.02381 .31242 m
.03006 .31242 L
s
[(140)] .01131 .31242 1 0 Mshowa
.02381 .46128 m
.03006 .46128 L
s
[(160)] .01131 .46128 1 0 Mshowa
.02381 .61013 m
.03006 .61013 L
s
[(180)] .01131 .61013 1 0 Mshowa
.125 Mabswid
.02381 .05193 m
.02756 .05193 L
s
.02381 .08914 m
.02756 .08914 L
s
.02381 .12636 m
.02756 .12636 L
s
.02381 .20078 m
.02756 .20078 L
s
.02381 .238 m
.02756 .238 L
s
.02381 .27521 m
.02756 .27521 L
s
.02381 .34964 m
.02756 .34964 L
s
.02381 .38685 m
.02756 .38685 L
s
.02381 .42406 m
.02756 .42406 L
s
.02381 .49849 m
.02756 .49849 L
s
.02381 .5357 m
.02756 .5357 L
s
.02381 .57292 m
.02756 .57292 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.11905 .05937 L
.21429 .10671 L
.30952 .15688 L
.40476 .21007 L
.5 .26645 L
.59524 .32621 L
.69048 .38955 L
.78571 .4567 L
.88095 .52787 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{224, 138.438},
  ImageMargins->{{52, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005@0000cb000`400?l00000o`00003ooooooomA
ooooo`00oooooomAooooo`00oooooomAooooo`00Eoooool6o`0003Oooooo0_l000000ol@413ooooo
ooooo`0cooooo`06onk^k_m4A4Co0000o`000?mEEEGok^k^=?ooool01_o^k^koA4A4o`000?l0003o
A4A4onk^kS7ooooo1?l000000ol@413oooooooooo`02ooooo`04okZj^_l@413o0000ogMgM`Kooooo
001Gooooo`03oiRHV?l0003oc<c<00;ooooo00?o410@ooooooooool0=_ooool00ol0003ooooooooo
o`0dooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE=?ooool01_lb<S;oMgMgonk^k_o^k^koMgMg
oc8b<S?ooooo00?o0000ooooooooool00oooool01_o<c<co<S8bonk^k_o^k^ko8B4QojVYZ@Gooooo
001Hooooo`03oiRHV?l0003oc<c<03Kooooo1_l0000eooooo`03oa0@4?oooooooooo00;ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool00oooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo001Iooooo`03ojVY
ZOl@413oc<c<03Gooooo00GoIVIVojVYZOooooooooooo`00000fooooo`03o`000?o^k^kooooo00;o
oooo00?o0000ooooooooool0<_ooool01_lb<S;oMgMgonk^k_o^k^koMgMgoc8b<S?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo001Joooo
o`03olc<c?l@413oc<c<03Cooooo00Gok^k^ob4Q8Oo^k^koooooo`00000fooooo`06o`000?mEEEGo
k^k^oooooomgMgOoEEEE=?ooool00ooMgMgo0000o`000002o`000003omgMgOoooooooooo037ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
001Kooooo`03ojVYZOlb<S;ooooo03Cooooo00CoZJVYofIVI_oooooo0000=_ooool01_lQ8B7oIVIV
o`000?l0003oEEEEonk^kSCooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb<S8cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`00G?ooool0
0ol0003oooooooooo`0dooooo`03odA4A?o<c<co000003Kooooo00?oQhN7ofIVI_ooool0=oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00oooool0
1_m4A4CoZJVYooooooooooooZJVYodA4A0Gooooo001Gooooo`06o`000?n7QhOok^k^oooooomgMgOo
<S8b=_ooool00ooMgMgoA4A4o`00000gooooo`03oc8b<_mVIVKogMgM03Kooooo00Ko<S8bofIVI_o^
k^kok^k^ofIVI_lb<S8aooooo`03o`000?m4A4Co000000Gooooo00Koc<c<oc8b<_o^k^kok^k^oc8b
<_o<c<`5ooooo`00Eoooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kSOooooo00?oQhN7o`000?oo
ool0=oooool01?mgMgOo410@o`000?lQ8B4dooooo`06onk^k_m4A4Co0000o`000?m4A4Cok^k^<Ooo
ool00oo<c<coEEEEo`000006ooooo`04okZj^_l@413o410@olc<c0Kooooo003ooooooe7ooooo000P
ooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0g
ooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09
ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001ooooo
ooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001ooooo
ooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03
o`00Oooooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03
o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0
>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0
=oooool00ol007ooooooooooo`09ooooo`006Oooooooo`0003Co00001?ooool0023ooooo00Co0000
ooooool0003o00002oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo000P
ooooo`04o`000?ooooooooooooooo`;o0000=?ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo00Wooooo000Pooooo`03o`000?oooooooooo00?ooooo0_l0000booooo`03o`00Oooooooo
oooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooo
oooo03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool01Oooool2o`00
033ooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo
03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003o
ooooooooo`07ooooo`;o0000;_ooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oo
oooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wo
oooo000Pooooo`03o`000?oooooooooo00Wooooo0_l0000/ooooo`03o`00Oooooooooooo03Sooooo
00?o001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo
00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool02oooool3o`0002Wooooo00?o
001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o
001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0>
ooooo`;o00009oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001o
ooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Poooo
o`03o`000?oooooooooo013ooooo0_l0000Uooooo`03o`00Oooooooooooo03Sooooo00?o001ooooo
ooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001ooooo
ooooool02Oooool0023ooooo00?o0000ooooooooool04_ooool2o`0002?ooooo00?o001ooooooooo
ool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001ooooooooo
ool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0Dooooo`;o0000
8Oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0
>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Pooooo`;o00005ooo
ool2o`0001oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooo
oooooooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool0
0ol0003oooooooooo`0Hooooo`;o00007Oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooo
oooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooo
oooo00Wooooo000Pooooo`03o`000?oooooooooo01[ooooo0_l0000Kooooo`03o`00Oooooooooooo
03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo
03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool07?ooool2o`0001Wo
oooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03So
oooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003ooooo
ooooo`0Nooooo`;o00005oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo
00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo
000Pooooo`03o`000?oooooooooo023ooooo0_l0000Eooooo`03o`00Oooooooooooo03Sooooo00?o
001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o
001oooooooooool02Oooool0023ooooo00?o0000ooooooooool08_ooool2o`0001?ooooo00?o001o
ooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001o
ooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0Toooo
o`;o00004Oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001ooooo
ooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03
o`000?oooooooooo02Kooooo0_l0000?ooooo`03o`00Oooooooooooo03Sooooo00?o001ooooooooo
ool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001ooooooooo
ool02Oooool0023ooooo00?o0000ooooooooool0:?ooool3o`0000cooooo00?o001oooooooooool0
>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0
=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0[ooooo`;o00002_oo
ool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0>?oo
ool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Pooooo`;o0000;_ooool2
o`0000Sooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooo
oooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0
003oooooooooo`0_ooooo`;o00001_ooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo
03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo
00Wooooo000Pooooo`03o`000?oooooooooo037ooooo0_l00004ooooo`03o`00Oooooooooooo03So
oooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oo
oooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0<oooool2o`0000;ooooo
00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo
00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003ooooooooo
o`0eooooo`;o000000?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooo
oooooooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool0
0ol0003oooooooooo`0gooooo`;o0000>Oooool00ol007ooooooooooo`0gooooo`03o`00Oooooooo
oooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0
003oooooooooo`0gooooo`04o`00Oooooooo0000o`0003Oooooo00?o001oooooooooool0=oooool0
0ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool02Oooool0
023ooooo00?o0000ooooooooool0=oooool01?l007ooooooooooooooool2o`0003Gooooo00?o001o
ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001o
ooooooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`03oooo
o`;o0000<oooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001ooooo
ooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03
o`00Oooooooooooo00Gooooo00?o0000ooooooooool0<?ooool00ol007ooooooooooo`0gooooo`03
o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`00
8?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo00Kooooo0_l0000`ooooo`03o`00
Oooooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00
Oooooooooooo00Wooooo000Pooooo`;o0000>?ooool00ol007ooooooooooo`08ooooo`;o0000;_oo
ool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=ooo
ool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooo
oooo00[ooooo0_l0000/ooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0>?ooool0
0ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo
03Oooooo00?o001oooooooooool03?ooool2o`0002[ooooo00?o001oooooooooool0=oooool00ol0
07ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool02Oooool0023o
oooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0>ooooo`;o0000:?ooool00ol007oo
ooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007oo
ooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo013ooooo
0_l0000Vooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007oooooo
ooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o
001oooooooooool04_ooool2o`0002Cooooo00?o001oooooooooool0=oooool00ol007oooooooooo
o`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000
ooooooooool0=oooool00ol007ooooooooooo`0Dooooo`03o`000?oooooooooo027ooooo00?o001o
ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001o
ooooooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0Eoooo
o`;o00008Oooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001ooooo
ooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03
o`00Oooooooooooo01Oooooo0_l0000Oooooo`03o`00Oooooooooooo03Oooooo00?o001ooooooooo
ool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo0003ooooo`Co0000
00Co410@oooooooooooooooo1_l00004ooooo`04okZj^_l@413o0000ogMgM`Oooooo00?o0000oooo
ooooool0=oooool00ol007ooooooooooo`0Iooooo`;o00007Oooool00ol007ooooooooooo`0goooo
o`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09oooo
o`001Oooool00ol0003oooooooooo`03ooooo`03oiRHV?l0003oc<c<00;ooooo00Ko410@oooooooo
ooooooooolc<c?lb<S82onk^kP03ob4Q8OnYZJWooooo00Gooooo00?o0000ooooooooool0=oooool0
0ol007ooooooooooo`0Kooooo`;o00006oooool00ol007ooooooooooo`0gooooo`03o`00Oooooooo
oooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`001Oooool00ol0
003oooooooooo`04ooooo`03oiRHV?l0003oc<c<00Gooooo00KoA4A4ojVYZOooooooooooojVYZOlb
<S86ooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool07Oooool2o`0001Wooooo00?o
001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o
001oooooooooool02Oooool000Gooooo00?o0000ooooooooool01Oooool00onYZJWo410@olc<c004
ooooo`03o`000?oooooooooo00;ooooo00?o0000o`00Ool007l01?l007l3o`0005Wo001o0_l0003>
o`00O`Cooooo0005ooooo`03o`000?oooooooooo00Kooooo00?oc<c<oa0@4?o<c<`00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool00ol0
07ooooooooooo`0Qooooo`03o`000?oooooooooo01Cooooo00?o001oooooooooool0=oooool00ol0
07ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool02Oooool000Go
oooo00?o0000ooooooooool01oooool00onYZJWo<S8booooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo02;o
oooo0_l0000Dooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007oo
ooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo0005ooooo`03o`000?oooooooooo00Sooooo
00Ko0000ooooooooooooooooodA4A?nYZJT2ooooo`03ojVYZOm4A4Cooooo00Gooooo00?o0000oooo
ooooool0=oooool00ol007ooooooooooo`0Tooooo`;o00004_ooool00ol007ooooooooooo`0goooo
o`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09oooo
o`000oooool00ol0003oA4A4o`000005ooooo`06o`000?n7QhOok^k^oooooomgMgOo<S8b0oooool0
1_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0Kooooo00?o0000ooooooooool0=oooool00ol007oooooo
ooooo`0Vooooo`;o00004?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo
00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`000oooool00oo<c<coEEEEo`00
0005ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1?ooool01?nj^[[o410@oa0@4?o<c<`7oooo
o`03o`000?oooooooooo03Oooooo00?o001oooooooooool0:?ooool2o`0000kooooo00?o001ooooo
ooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001ooooo
ooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0Zooooo`03
o`000?oooooooooo00_ooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03
o`00Oooooooooooo03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0
=oooool00ol007ooooooooooo`0[ooooo`;o00002oooool00ol007ooooooooooo`0gooooo`03o`00
Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?oo
ool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo02gooooo0_l00009ooooo`03o`00Oooo
oooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooo
oooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0;oooool2
o`0000Oooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooo
oooo03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol0
07ooooooooooo`0aooooo`;o00001Oooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo
03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool2o`0003So
oooo00?o001oooooooooool0<oooool00ol0003oooooooooo`02ooooo`03o`00Oooooooooooo03Oo
oooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wo
oooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0=?ooool2o`0000;ooooo
00?o001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo
00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007oooooooooo
o`0fooooo`;o000000?o001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooo
oooooooo03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool0
0ol007ooooooooooo`0hooooo`;o0000>?ooool00ol007ooooooooooo`0hooooo`03o`00Oooooooo
oooo03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol0
07ooooooooooo`0hooooo`04o`00Oooooooo0000o`0003Kooooo00?o001oooooooooool0>?ooool0
0ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo
03Oooooo00?o001oooooooooool0>?ooool01Ol007oooooooooooooooooo000003Gooooo00?o001o
ooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Poooo
o`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`02oooo
o`;o0000<oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001ooooo
ooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03
o`00Oooooooooooo00Cooooo0_l0000aooooo`03o`00Oooooooooooo03Sooooo00?o001ooooooooo
ool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00
Oooooooooooo03Sooooo00?o001oooooooooool01_ooool00ol0003oooooooooo`0^ooooo`03o`00
Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?oo
ool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool01ooo
ool2o`0002kooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooo
oooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool0
0ol007ooooooooooo`09ooooo`;o0000;?ooool00ol007ooooooooooo`0hooooo`03o`00Oooooooo
oooo03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol0
07ooooooooooo`0hooooo`03o`00Oooooooooooo00_ooooo0_l0000Zooooo`03o`00Oooooooooooo
03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool2o`0003So
oooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0=ooooo`03o`000?oooooooooo02Oo
oooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wo
oooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007oooooo
ooooo`0>ooooo`;o00009oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo
00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007oooooooooo
o`0hooooo`03o`00Oooooooooooo013ooooo0_l0000Uooooo`03o`00Oooooooooooo03Sooooo00?o
001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0g
ooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool04_ooool00ol0003oooooooooo`0R
ooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09
ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001ooooo
ooooool04oooool2o`0002;ooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0goooo
o`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001ooooooooo
ool0>?ooool00ol007ooooooooooo`0Eooooo`;o00008?ooool00ol007ooooooooooo`0hooooo`03
o`00Oooooooooooo03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0
=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo01Oooooo00?o0000ooooooooool0
7Oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0
2Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooo
oooooooo01Sooooo0_l0000Mooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=ooo
ool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooo
oooo03Sooooo00?o001oooooooooool06_ooool2o`0001_ooooo00?o001oooooooooool0>?ooool0
0ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo
03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0Looooo`03o`000?oooooooooo
01Sooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo
00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007oo
ooooooooo`0Mooooo`;o00006?ooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oo
oooo00?o001oooooooooool02Oooool0023ooooo0_l0000hooooo`03o`00Oooooooooooo03Sooooo
00?o001oooooooooool07oooool00ol0003oooooooooo`0Eooooo`03o`00Oooooooooooo03Sooooo
00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003ooooooooo
o`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool08?ooool2o`0001Gooooo00?o
001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000P
ooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0R
ooooo`03o`000?oooooooooo01;ooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0g
ooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001ooooo
ooooool0>?ooool00ol007ooooooooooo`0Sooooo`;o00004_ooool00ol007ooooooooooo`0hoooo
o`03o`00Oooooooooooo03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000oooooooo
ool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo02Gooooo00?o0000oooooooo
ool03oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001ooooooooo
ool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00
Oooooooooooo02Kooooo0_l0000?ooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0
=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooo
oooooooo03Sooooo00?o001oooooooooool0:?ooool2o`0000gooooo00?o001oooooooooool0>?oo
ool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooo
oooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0Zooooo`03o`000?oooooo
oooo00[ooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooo
oooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol0
07ooooooooooo`0[ooooo`;o00002_ooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo
03Oooooo00?o001oooooooooool02Oooool000?ooooo1?l000000ol@413oooooooooo`04ooooo`;o
000000?o410@ooooooooool00_ooool01?nj^[[o410@o`000?mgMgL7ooooo`03o`000?oooooooooo
03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0]ooooo`03o`000?oooooooooo
00Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo
00Wooooo0005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01_o<c<co
<S8bonk^k_o^k^ko8B4QojVYZ@Kooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0h
ooooo`03o`00Oooooooooooo02kooooo0_l00007ooooo`03o`00Oooooooooooo03Sooooo00?o001o
ooooooooool0=oooool00ol007ooooooooooo`09ooooo`001Oooool00ol0003oooooooooo`03oooo
o`Ko00000oooool01_m4A4CoZJVYooooooooooooZJVYo`006@Ko001o0ol0002Uo`00O`03o`000?l0
07oo001o087o001o1?ooool000Gooooo00?o0000ooooooooool00oooool01OmVIVKoZJVYoooooooo
oooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0aooooo`;o00001?oo
ool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool02Ooo
ool000Gooooo00?o0000ooooooooool00oooool01Oo^k^ko8B4Qonk^k_oooooo000000Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Oooooo00?o
001oooooooooool0>?ooool00ol007ooooooooooo`0cooooo`05o`000?ooooooooooooooool007l0
>_ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo0005ooooo`03o`000?oo
oooooooo00Cooooo00CoZJVYofIVI_oooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00
Oooooooooooo03Cooooo0_l000000ooooooo001oooooo`0iooooo`03o`00Oooooooooooo03Oooooo
00?o001oooooooooool02Oooool000Gooooo00?o0000ooooooooool01Oooool00om4A4Coc<c<o`00
0004ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A41_ooool00ol0003oooooooooo`0gooooo`03
o`00Oooooooooooo03Sooooo00?o001oooooooooool0=_ooool00ol0003o001oooooo`0iooooo`03
o`00Oooooooooooo03Oooooo00?o001oooooooooool02Oooool000?ooooo00?o0000odA4A?l00000
1oooool00ooMgMgoA4A4o`000004ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<1_ooool00ol0
003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool2o`00
03Wooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`000oooool00oo<c<co
EEEEo`000008ooooo`03ohN7Qol0003ooooo00Cooooo00Co^[Zjoa0@4?l@413oc<c<1oooool00ol0
003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol0
07ooooooo`00000hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool02Oooool0023o
oooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oo
oooo00?o001oooooooooool00_l0000fooooo`03o`00Oooooooooooo03Oooooo00?o001ooooooooo
ool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00
Oooooooooooo03Oooooo00?o001oooooooooool00_ooool00ol0003oooooooooo`0cooooo`03o`00
Oooooooooooo03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0=ooo
ool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool00ooo
ool2o`0003?ooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool0
0ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool0
0ol007ooooooooooo`05ooooo`03o`000?oooooooooo033ooooo00?o001oooooooooool0=oooool0
0ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo
03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`06ooooo`;o0000<?ooool00ol0
07ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Pooooo`;o0000>?ooool00ol007oo
ooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool02?ooool00ol0003o
ooooooooo`0]ooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool02Oooool0023ooooo
00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo
00?o001oooooooooool02Oooool2o`0002gooooo00?o001oooooooooool0=oooool00ol007oooooo
ooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o
001oooooooooool0=oooool00ol007ooooooooooo`0;ooooo`;o0000:oooool00ol007oooooooooo
o`0gooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001o
ooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00gooooo00?o0000
ooooooooool0:?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Poooo
o`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0goooo
o`03o`00Oooooooooooo00kooooo0_l0000Xooooo`03o`00Oooooooooooo03Oooooo00?o001ooooo
ooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03
o`00Oooooooooooo03Oooooo00?o001oooooooooool04?ooool00ol0003oooooooooo`0Uooooo`03
o`00Oooooooooooo03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0
=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0
4Oooool2o`0002Gooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?oo
ool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=ooo
ool00ol007ooooooooooo`0Cooooo`03o`000?oooooooooo02;ooooo00?o001oooooooooool0=ooo
ool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooo
oooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0Dooooo`;o00008_ooool0
0ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo
03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo
01Kooooo00?o0000ooooooooool07oooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo
00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007oo
ooooooooo`0gooooo`03o`00Oooooooooooo01Oooooo0_l0000Oooooo`03o`00Oooooooooooo03Oo
oooo00?o001oooooooooool02Oooool0023ooooo0_l0000hooooo`03o`00Oooooooooooo03Sooooo
00?o001oooooooooool0=oooool00ol007ooooooooooo`0Iooooo`03o`000?oooooooooo01cooooo
00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003ooooooooo
o`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007oooooooooo
o`0Jooooo`;o00007?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000P
ooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0g
ooooo`03o`00Oooooooooooo01cooooo00?o0000ooooooooool06Oooool00ol007ooooooooooo`0g
ooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001ooooo
ooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo01gooooo0_l0000Ioooo
o`03o`00Oooooooooooo03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000oooooooo
ool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001ooooooooo
ool07oooool00ol0003oooooooooo`0Fooooo`03o`00Oooooooooooo03Oooooo00?o001ooooooooo
ool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00
Oooooooooooo03Oooooo00?o001oooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`00
Oooooooooooo03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0=ooo
ool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool08Ooo
ool2o`0001Gooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool0
0ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool0
0ol007ooooooooooo`0Sooooo`03o`000?oooooooooo01;ooooo00?o001oooooooooool0=oooool0
0ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo
03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0Tooooo`;o00004_ooool00ol0
07ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oo
oooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo02Ko
oooo00?o0000ooooooooool03oooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wo
oooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007oooooo
ooooo`0gooooo`03o`00Oooooooooooo02Oooooo0_l0000?ooooo`03o`00Oooooooooooo03Oooooo
00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007oooooooooo
o`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0:Oooool00ol0003ooooooooo
o`0<ooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool02Oooool0023ooooo0_l0000h
ooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0Z
ooooo`03o`000?oooooooooo00_ooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09
ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001ooooo
ooooool0=oooool00ol007ooooooooooo`0[ooooo`;o00002oooool00ol007ooooooooooo`0goooo
o`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001ooooooooo
ool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo02gooooo00?o0000oooooooo
ool02?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`00
0?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00
Oooooooooooo02kooooo0_l00008ooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0
2Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooo
oooooooo03Oooooo00?o001oooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03o`00Oooo
oooooooo03Oooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool0
0ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0<Oooool2
o`0000Gooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0
003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol0
07ooooooooooo`0cooooo`03o`000?oooooooooo00;ooooo00?o001oooooooooool0=oooool00ol0
07ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03So
oooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0dooooo`05o`000?oooooooooooooo
ool007l0>Oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03
o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0eooooo`;o
000000?oooooo`00Ooooool0>?ooool00ol007ooooooooooo`09ooooo`000oooool4o`000006oa0@
4?ooooooooooooooooo^k^koA4A40_l000000omEEEGok^k^ooooo`03ooooo`04okZj^_l@413o0000
ogMgM`Oooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooo
oooo03Oooooo00?o001oooooooooool0=oooool00ol0003o001oooooo`0hooooo`03o`00Oooooooo
oooo00Wooooo0005ooooo`03o`000?oooooooooo00?ooooo00KoEEEEogMgMoooooooooooogMgMomE
EED3ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1_ooool00ol0003oooooooooo`0gooooo`03
o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`;o
0000>?ooool00ol007ooooooooooo`09ooooo`001Oooool00ol0003oooooooooo`03ooooo`03oa0@
4?oooooooooo00;ooooo00Ko0000ooooooooooooooooodA4A?nYZJT2ooooo`03ojVYZOl001Wo001o
00Go001o0ol0003Yo`00O`03o`000?l007oo001o03go001o1?ooool000Gooooo00?o0000oooooooo
ool00oooool00ol0003ok^k^ooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol0
07ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00Co001ooooooooooooo0000=_ooool0
0ol007ooooooooooo`09ooooo`001Oooool00ol0003oooooooooo`03ooooo`06o`000?mEEEGok^k^
oooooomgMgOoEEEE0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o
001oooooooooool0>?ooool01?l007ooooooooooooooool2o`0003Cooooo00?o001oooooooooool0
2Oooool000Gooooo00?o0000ooooooooool00oooool01_lQ8B7oIVIVo`000?l0003oEEEEonk^kP?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Oo
oooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03So
oooo00?o001oooooooooool00oooool00ol0003oooooooooo`0aooooo`03o`00Oooooooooooo00Wo
oooo0005ooooo`03o`000?oooooooooo00?ooooo00?oQhN7ofIVI_ooool01_ooool01_m4A4CoZJVY
ooooooooooooZJVYodA4A0Kooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hoooo
o`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`04oooo
o`03o`000?oooooooooo033ooooo00?o001oooooooooool02Oooool000?ooooo00?o0000odA4A?l0
00001_ooool00olb<S;oIVIVomgMg@05ooooo`06olc<c?lb<S;ok^k^onk^k_lb<S;oc<c<1_ooool0
0ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool0
0ol007ooooooooooo`0hooooo`03o`00Oooooooooooo00Gooooo0_l0000`ooooo`03o`00Oooooooo
oooo00Wooooo0003ooooo`03olc<c?mEEEGo000000Oooooo00CoMgMgoa0@4?l0003o8B4Q1?ooool0
1?nj^[[o410@oa0@4?o<c<`7ooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?oo
ool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool01ooo
ool00ol0003oooooooooo`0]ooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooo
oooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooo
oooo03Sooooo00?o001oooooooooool02?ooool00ol0003oooooooooo`0/ooooo`03o`00Oooooooo
oooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol0
07ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool02Oooool2o`00
02cooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007oo
ooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007oo
ooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo00?o001oooooooooool02Oooool0023ooooo
00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo
00?o001oooooooooool0>?ooool00ol007ooooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo
00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007oooooooooo
o`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007oooooooooo
o`0=ooooo`03o`000?oooooooooo02Oooooo00?o001oooooooooool02Oooool0023ooooo0_l0000h
ooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0h
ooooo`03o`00Oooooooooooo00kooooo0_l0000Wooooo`03o`00Oooooooooooo00Wooooo000Poooo
o`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0goooo
o`03o`00Oooooooooooo03Sooooo00?o001oooooooooool04?ooool00ol0003oooooooooo`0Toooo
o`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001ooooooooo
ool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001ooooooooo
ool04Oooool00ol0003oooooooooo`0Sooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`00
0?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00
Oooooooooooo03Sooooo00?o001oooooooooool04_ooool2o`0002?ooooo00?o001oooooooooool0
2Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooo
oooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0Dooooo`03o`000?oo
oooooooo023ooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool0
0ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0>?ooool0
0ol007ooooooooooo`0Eooooo`03o`000?oooooooooo01oooooo00?o001oooooooooool02Oooool0
023ooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo
03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0Fooooo`;o00007oooool00ol0
07ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03So
oooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo01So
oooo00?o0000ooooooooool07?ooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003ooooo
ooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007oooooo
ooooo`0hooooo`03o`00Oooooooooooo01Wooooo00?o0000ooooooooool06oooool00ol007oooooo
ooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o
001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo01[ooooo0_l0
000Kooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001o
ooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001o
ooooooooool07?ooool00ol0003oooooooooo`0Hooooo`03o`00Oooooooooooo00Wooooo000Poooo
o`;o0000>?ooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001ooooo
ooooool0>?ooool00ol007ooooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo00?o001ooooo
ooooool02Oooool0023ooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03
o`00Oooooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0Nooooo`03
o`000?oooooooooo01Kooooo00?o001oooooooooool02Oooool0023ooooo00?o0000ooooooooool0
=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0
>?ooool00ol007ooooooooooo`0Oooooo`;o00005_ooool00ol007ooooooooooo`09ooooo`008?oo
ool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=ooo
ool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo027ooooo00?o0000ooooooooool04ooo
ool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooo
oooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooo
oooo02;ooooo00?o0000ooooooooool04_ooool00ol007ooooooooooo`09ooooo`008?ooool00ol0
003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol0
07ooooooooooo`0hooooo`03o`00Oooooooooooo02?ooooo00?o0000ooooooooool04Oooool00ol0
07ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03So
oooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo02Co
oooo0_l0000Aooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo
00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo
00?o001oooooooooool09_ooool00ol0003oooooooooo`0>ooooo`03o`00Oooooooooooo00Wooooo
000Pooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007oooooooooo
o`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool09oooool00ol0003ooooooooo
o`0=ooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001o
ooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001o
ooooooooool0:?ooool2o`0000gooooo00?o001oooooooooool02Oooool0023ooooo00?o0000oooo
ooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001ooooo
ooooool0>?ooool00ol007ooooooooooo`0Zooooo`03o`000?oooooooooo00[ooooo00?o001ooooo
ooooool02Oooool0023ooooo0_l0000hooooo`03o`00Oooooooooooo03Sooooo00?o001ooooooooo
ool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo02_ooooo00?o0000oooooooo
ool02Oooool00ol007ooooooooooo`09ooooo`008?ooool00ol0003oooooooooo`0gooooo`03o`00
Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00
Oooooooooooo02cooooo00?o0000ooooooooool02?ooool00ol007ooooooooooo`09ooooo`008?oo
ool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=ooo
ool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo02gooooo0_l00008ooooo`03o`00Oooo
oooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool0
0ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0;oooool0
0ol0003oooooooooo`05ooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo
03Oooooo00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo
03Sooooo00?o001oooooooooool0<?ooool00ol0003oooooooooo`04ooooo`03o`00Oooooooooooo
00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007oo
ooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0<Oooool00ol0003o
ooooooooo`03ooooo`03o`00Oooooooooooo00Wooooo000Pooooo`03o`000?oooooooooo03Oooooo
00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo
00?o001oooooooooool0<_ooool2o`0000?ooooo00?o001oooooooooool02Oooool0023ooooo00?o
0000ooooooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o
001oooooooooool0>?ooool00ol007ooooooooooo`0dooooo`04o`000?ooooooooooo`00O`_ooooo
000Pooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007oooooooooo
o`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=Oooool00ol0003oooooo`00
O`0;ooooo`000oooool4o`000006oa0@4?ooooooooooooooooo^k^koA4A40_l000000om4A4Cok^k^
ooooo`03ooooo`04okZj^_l@413o0000ogMgM`Oooooo00?o0000ooooooooool0=oooool00ol007oo
ooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007oo
ooooooooo`0fooooo`03o`000?l007oooooo00[ooooo0005ooooo`03o`000?oooooooooo00?ooooo
00Ko<S8bogMgMoo^k^kok^k^ogMgMolb<S83ooooo`06olc<c?lb<S;ok^k^onk^k_lQ8B7oZJVY1_oo
ool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=ooo
ool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o0000ooooooooool02Ooo
ool000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo
oooooooooom4A4CoZJVY0_ooool00onYZJWo<S8booooo`05ooooo`03o`000?oooooooooo03Oooooo
00?o001oooooooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo
00?o001oooooooooool0=oooool00ol007ooooooooooo`09ooooo`001Oooool00ol0003ooooooooo
o`03ooooo`06oc8b<_mgMgOok^k^onk^k_mgMgOo<S8b0oooool00ol0003oooooooooo`02ooooo`03
o`000?l007oo001o00Co001o0ol0003oo`00Ob[o001o1?ooool000Gooooo00?o0000ooooooooool0
0oooool00ooMgMgo0000o`000002o`000005omgMgOooooooooooooooool000001?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0>?ooool00ol007oo
ooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o001oooooooooool0=oooool00ol007oo
ooooooooo`09ooooo`001Oooool00ol0003oooooooooo`03ooooo`06oc8b<_mVIVKok^k^onk^k_mV
IVKo<S8b0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0=oooool00ol007ooooooooooo`0hooooo`03o`00Oooooooooooo03Oooooo00?o001ooooo
ooooool0>?ooool00ol007ooooooooooo`0gooooo`03o`00Oooooooooooo00Wooooo0005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooooooooooA4A4
ojVYZ@;ooooo00?oZJVYodA4A?ooool0oooooolfooooo`000oooool00ol0003oA4A4o`000005oooo
o`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b0oooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c?oo
oooo=oooool000?ooooo00?oc<c<oeEEEOl000001Oooool01_o^k^koA4A4o`000?l0003oA4A4onk^
kPCooooo00Co^[Zjoa0@4?l@413oc<c<oooooolhooooo`00oooooomAooooo`00\
\>"],
  ImageRangeCache->{{{99.875, 255.625}, {421.688, 325.813}} -> {-8.50396, \
400.29, 0.0517001, 0.661565}},
  CellTags->"M50.8.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise - InterestEarned Revisited", "Section",
  CounterAssignments->{{"Chapter", 8}, {"ExerciseNumber", 1}}],

Cell[TextData[{
  "Redefine the ",
  StyleBox["InterestEarned", "MR"],
  " function using anonymous functions in place of the explicit function \
definition used above."
}], "Exercise"],

Cell[TextData[{
  "Can you modify the ",
  StyleBox["InterestEarned", "MR"],
  " function to work so that the base period is taken to be one year but \
compounding can take place more often?"
}], "Exercise"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise - Random Walk", "Section",
  CounterAssignments->{{"Chapter", 8}, {"ExerciseNumber", 3}}],

Cell[TextData[{
  "The ",
  StyleBox["Random", "MR"],
  " function can be used to generate pseudorandom integers as well as real \
numbers. We need to give the ",
  StyleBox["Random", "MR"],
  " function two arguments for this. The first argument specifies the type of \
number we want (",
  StyleBox["Integer", "MR"],
  ") and the second specifies the interval from which that number will be \
selected. Evaluate the following example several times to see how this \
works."
}], "Exercise"],

Cell[BoxData[
    \(Table[Random[Integer, {5, 12}], {5}]\)], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["NestList", "MR"],
  " together with ",
  StyleBox["Which", "MR"],
  " and ",
  StyleBox["Random[Integer,{1,4}]", "MR"],
  " to generate a list of points on a random walk where the only moves \
allowed are horizontal and vertical steps of length one. No diagonal moves \
should be allowed."
}], "Exercise"],

Cell[BoxData[
    \(RandomWalk[n_Integer] := 
      NestList[#\  + \ 
            Which[\((aa = \ Random[Integer, {1, 4}])\) \[Equal] 1, {1, 0}, 
              aa \[Equal] 2, {0, 1}, aa \[Equal] 3, {\(-1\), 0}, 
              aa \[Equal] 4, {0, \(-1\)}] &, {0, 0}, n]\)], "Input"],

Cell[TextData[{
  "Can you create an animation which illustrates the steps? (You want to make \
sure you only evaluate ",
  StyleBox["RandomWalk", "MR"],
  " once.) You will want to look for ",
  StyleBox["Line", "MR"],
  " and ",
  StyleBox["Point", "MR"],
  " in the Help Browser."
}], "Exercise"],

Cell[BoxData[
    \(walk\  = \ RandomWalk[25]; \)], "Input"],

Cell[TextData[{
  "When we create an animation we need to make sure all the plots are \
rendered over the same domain to keep the images from jumping around. To do \
this we get the minimal and maximal values for both variables. The easiest \
way to accomplish this is to transpose the list of ordered pairs generated by \
the RandomWalk function and then use the functions ",
  StyleBox["Min", "MR"],
  " and ",
  StyleBox["Max", "MR"],
  "."
}], "Text"],

Cell[BoxData[
    \(lists\  = \ Transpose[walk]; \)], "Input"],

Cell[BoxData[
    \({xmin, xmax} = {Min[lists[\([\)\(1\)\(]\)]] -  .1, 
        Max[lists[\([\)\(1\)\(]\)]] +  .1}; \)], "Input"],

Cell[BoxData[
    \({ymin, ymax} = {Min[lists[\([\)\(2\)\(]\)]] -  .1, 
        Max[lists[\([\)\(2\)\(]\)]] +  .1}; \)], "Input"],

Cell["\<\
Animations are rendered by showing a sequence of plots one after another. The \
easiest way to accomplish this is to use the Table function.\
\>", "Text"],

Cell[BoxData[
    \(Table[
      Show[Graphics[{AbsoluteThickness[3], Hue[ .95], 
            Line[walk[\([\)\(Range[i]\)\(]\)]], Hue[ .7], 
            AbsolutePointSize[8], Point[walk[\([\)\(i\)\(]\)]]}], 
        Axes \[Rule] \ True, AspectRatio\  \[Rule] \ Automatic, 
        PlotRange \[Rule] \ {{xmin, xmax}, {ymin, ymax}}, 
        ImageSize \[Rule] \ 5\ 72], {i, 1, Length[walk]}]; \)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise - Creating an Exercise Set", "Section",
  CounterAssignments->{{"Chapter", 8}, {"ExerciseNumber", 4}}],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " makes it easy to create exercise sets. We will illustrate how to create a \
set of factorable trinomials. The trick is to create the factored form and \
then expand it. Evaluate the following cell."
}], "Exercise"],

Cell[BoxData[
    \(\((x\  - \ Random[Integer, {\(-5\), 5}])\)\ \((x\  - \ 
          Random[Integer, {\(-5\), 5}])\)\)], "Input"],

Cell[TextData[{
  "Use the ",
  StyleBox["Table", "MR"],
  " function to create ten factor problems. Make sure you give your problem \
set a name."
}], "Exercise"],

Cell[TextData[{
  "Use ",
  StyleBox["Map", "MR"],
  " to expand the problems."
}], "Exercise"],

Cell[TextData[{
  "Display your problems using ",
  StyleBox["Partition", "MR"],
  " and ",
  StyleBox["TableForm", "MR"],
  ". You should check the options for ",
  StyleBox["TableForm", "MR"],
  " so your problems are in a workable format for use as an exercise set."
}], "Exercise"],

Cell[TextData[{
  "Using the above formulation for the problem, you will sometimes get a \
factor of (",
  Cell[BoxData[
      \(TraditionalForm\`x - 0\)]],
  "). If you use ",
  StyleBox["Random[Integer]", "MR"],
  " you will get 0 or 1. Use ",
  StyleBox["Random[Integer]", "MR"],
  " as an exponent to avoid the possibility of getting a factor of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Exercise"],

Cell[BoxData[
    \(probs = 
      Table[Expand[\((x - \(\((\(-1\))\)\^Random[Integer]\) 
                  Random[Integer, {1, 
                      9}])\) \((x - \(\((\(-1\))\)\^Random[Integer]\) 
                  Random[Integer, {1, 9}])\)], {10}]; \)], "Input"],

Cell[BoxData[
    \(TableForm[Map[TraditionalForm, Partition[probs, 2], {2}], 
      TableSpacing\  \[Rule] \ {25, 18}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Map Function", "Section",
  CellTags->"M50.8.2"],

Cell[TextData[{
  StyleBox["Map", "MR"],
  " is used to apply a function to all the elements of a list. ",
  StyleBox["Map", "MR"],
  " can take two or three arguments, the first is the function; the second is \
the list; and the third, optional argument, is a level specification. Here is \
a simple example."
}], "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[f, {a, r, 4, 3, 5.5}]\)], "Input",
  CellTags->"M50.8.2"],

Cell[BoxData[
    \({f[a], f[r], f[4], f[3], f[5.5`]}\)], "Output",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[TextData[{
  "If the second argument to ",
  StyleBox["Map", "MR"],
  " is a nested list, then we need to specify the level at which we want the \
function to operate."
}], "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[f, {{1, 2}, {3, 4}}, {2}]\)], "Input",
  CellTags->"M50.8.2"],

Cell[BoxData[
    \({{f[1], f[2]}, {f[3], f[4]}}\)], "Output",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More Map Function", "Subsection",
  CellTags->"M50.8.2"],

Cell[TextData[{
  "One of the really powerful uses of ",
  StyleBox["Map", "MR"],
  " is to use it with pure functions to carry out operations on expressions \
without the need to first create auxiliary functions. In the following \
example we use a pure function to square each element of a list and then add \
3."
}], "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[\((#\^2 + \ 3)\) &, {4, a, \(-3\), 1.3, 1/3, dog}]\)], "Input",
  CellTags->"M50.8.2"],

Cell[BoxData[
    \({19, 3 + a\^2, 12, 4.69`, 28\/9, 3 + dog\^2}\)], "Output",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["#", "MR"],
  " sign can appear more than once. In this example, we square the argument \
and add three times the square root of the argument plus 2."
}], "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[\((#\^2 + \ 3 \@ # + \ 2)\) &, {4, a, \(-3\), 1.3, 1/3, 
        dog}]\)], "Input",
  CellTags->"M50.8.2"],

Cell[BoxData[
    \({24, 2 + 3\ \@a + a\^2, 11 + 3\ \[ImaginaryI]\ \@3, 7.110526275297414`, 
      19\/9 + \@3, 2 + 3\ \@dog + dog\^2}\)], "Output",
  CellTags->"M50.8.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mapping Across Lists of Ordered Pairs", "Subsection",
  CellTags->"M50.8.2"],

Cell[TextData[{
  StyleBox["Map", "MR"],
  " is an extremely useful function, but there are cases when we have to do a \
little additional work to get it to do what we want. Consider the following."
}], "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[f, {{a, b}, {3, 4}, {1.2, 3.7}}]\)], "Input",
  CellTags->"M50.8.2"],

Cell[BoxData[
    \({f[{a, b}], f[{3, 4}], f[{1.2`, 3.7`}]}\)], "Output",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[TextData[{
  "Note that in each case the argument to ",
  StyleBox["f", "MR"],
  " is a list and not two arguments as we might expect. The function that we \
want here is ",
  StyleBox["Apply", "MR"],
  " and not ",
  StyleBox["Map", "MR"],
  "."
}], "Text",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Apply", "Subsection",
  CellTags->"M50.8.2"],

Cell[TextData[{
  "Note that when we use ",
  StyleBox["Apply", "MR"],
  " there are two arguments to ",
  StyleBox["f", "MR"],
  " and not a single argument as was the case with ",
  StyleBox["Map", "MR"],
  ". We do need to add an additional argument to ",
  StyleBox["Apply", "MR"],
  " to tell what level of the list ",
  StyleBox["f", "MR"],
  " is to operate on."
}], "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Apply[f, {{a, b}, {3, 4}, {1.2, 3.7}}, {1}]\)], "Input",
  CellTags->"M50.8.2"],

Cell[BoxData[
    \({f[a, b], f[3, 4], f[1.2`, 3.7`]}\)], "Output",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[BoxData[
    \(f1[x_, y_] := \ x\^2 + \ 2\ \(\(y\)\(\ \)\)\^2\)], "Input",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[f1, {{a, b}, {3, 4}, {1.2, 3.7}}, {1}]\)], "Input",
  CellTags->"M50.8.2"],

Cell[BoxData[
    \({f1[{a, b}], f1[{3, 4}], f1[{1.2`, 3.7`}]}\)], "Output",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Apply[f1, {{a, b}, {3, 4}, {1.2, 3.7}}, {1}]\)], "Input",
  CellTags->"M50.8.2"],

Cell[BoxData[
    \({a\^2 + 2\ b\^2, 41, 28.820000000000004`}\)], "Output",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[TextData[{
  "The differences between ",
  StyleBox["Map", "MR"],
  " and ",
  StyleBox["Apply", "MR"],
  " are subtle, but with a little practice you will learn which to use."
}], "Text",
  CellTags->"M50.8.2"],

Cell[BoxData[
    \(Clear[f1]\)], "Input",
  CellTags->"M50.8.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\[OpenCurlyDoubleQuote]Oops! I forgot to clear\[Ellipsis]\
\[CloseCurlyDoubleQuote]", "Section",
  CellTags->"M50.8.3"],

Cell[TextData[{
  "Any good programming language should provide a mechanism so that we do not \
have to clear all the variables every time we use them. In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " the function we need to accomplish this task is ",
  StyleBox["Module", "MR"],
  ". Consider the following function definition to calculate the interest \
earned on an investment of ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " dollars after ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " periods at an interest rate of ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " percent."
}], "Text",
  CellTags->"M50.8.3"],

Cell[BoxData[
    \(InterestEarned[d_, n_Integer?Positive, 
        r_] := \ \((f[x_] = \ \((1\  + \ r/100)\) x; \[IndentingNewLine]Nest[
            f, d, n] - d)\)\)], "Input",
  CellTags->"M50.8.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InterestEarned[100. , 4, 4]\)], "Input",
  CellTags->"M50.8.3"],

Cell[BoxData[
    \(16.985856000000013`\)], "Output",
  CellTags->"M50.8.3"]
}, Open  ]],

Cell[TextData[{
  "This certainly seems to work as planned, but notice that ",
  StyleBox["f", "MR"],
  " is still defined."
}], "Text",
  CellTags->"M50.8.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[7. ]\)], "Input",
  CellTags->"M50.8.3"],

Cell[BoxData[
    \(7.28`\)], "Output",
  CellTags->"M50.8.3"]
}, Open  ]],

Cell[BoxData[
    \(Clear[f, InterestEarned]\)], "Input",
  CellTags->"M50.8.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[ .7]\)], "Input",
  CellTags->"M50.8.3"],

Cell[BoxData[
    \(f[0.7`]\)], "Output",
  CellTags->"M50.8.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Module", "Subsection",
  CellTags->"M50.8.3"],

Cell[TextData[{
  "What we need here is a function that will allow us to define ",
  StyleBox["f", "MR"],
  " when we are using the ",
  StyleBox["InterestEarned", "MR"],
  " function but which will leave ",
  StyleBox["f", "MR"],
  " undefined otherwise. The first argument to ",
  StyleBox["Module", "MR"],
  " is a list of the symbols that we want to \[OpenCurlyDoubleQuote]localize\
\[CloseCurlyDoubleQuote] in this way."
}], "Text",
  CellTags->"M50.8.3"],

Cell[BoxData[
    \(InterestEarned[d_, n_Integer?Positive, 
        r_] := \[IndentingNewLine]Module[{f}, \ \((f[
              x_] = \ \((1\  + \ r/100)\) x; \[IndentingNewLine]Nest[f, d, 
              n] - d)\)\[IndentingNewLine]]\)], "Input",
  CellTags->"M50.8.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InterestEarned[100, \ 8, 5.5]\)], "Input",
  CellTags->"M50.8.3"],

Cell[BoxData[
    \(53.46865149961525`\)], "Output",
  CellTags->"M50.8.3"]
}, Open  ]],

Cell[TextData[{
  "Note that ",
  StyleBox["f", "MR"],
  " has no definition outside of ",
  StyleBox["InterestEarned", "MR"],
  "."
}], "Text",
  CellTags->"M50.8.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[3]\)], "Input",
  CellTags->"M50.8.3"],

Cell[BoxData[
    \(f[3]\)], "Output",
  CellTags->"M50.8.3"]
}, Open  ]],

Cell[BoxData[
    \(Clear[InterestEarned]\)], "Input",
  CellTags->"M50.8.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise - Identifying Local Variables", "Section",
  CounterAssignments->{{"Chapter", 8}, {"ExerciseNumber", 2}}],

Cell[TextData[{
  "Identify the two global variables in this definition. Change this \
definition so that those two variables are localized using ",
  Cell[BoxData[
      \(Module\)]],
  "."
}], "Exercise"],

Cell[BoxData[
    \(f[p_, 
        q_] := \((\[IndentingNewLine]temp = 
          Solve[p + q\ x \[Equal] 0, x]; \[IndentingNewLine]x /. 
          temp\[IndentingNewLine])\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Exercise - Understanding FindRoot \[FivePointedStar]\
\>", "Section",
  CounterAssignments->{{"Chapter", 8}, {"ExerciseNumber", 5}}],

Cell[TextData[{
  StyleBox["FindRoot", "MR"],
  " is an important tool to use for those cases ",
  StyleBox["Solve", "MR"],
  " will not handle. The choice of starting values greatly influences the \
outcome. This exercise is designed to help you see how a choice of starting \
values can influence the outcome. We begin by solving the equation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(z\^3\),
            "TraditionalForm"], "=", \(-1\)}], TraditionalForm]]],
  "."
}], "Exercise"],

Cell[CellGroupData[{

Cell[BoxData[
    \({z1, z2, z3}\  = \ z /. Solve[z\^3 \[Equal] \(-1\), z]\)], "Input"],

Cell[BoxData[
    \({\(-1\), \((\(-1\))\)\^\(1/3\), \(-\((\(-1\))\)\^\(2/3\)\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The above three solutions all lie on a unit circle in the complex plane. \
We will construct a solution for a number of points in the square in the \
complex plane bounded by ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\(5\/4\)\) < x < 5\/4\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\(5\/4\)\) < y < 5\/4\)]],
  ". To get this to work we need a couple of things. The first is the \
function ",
  StyleBox["Which", "MR"],
  ". Look ",
  StyleBox["Which", "MR"],
  " up in the Help Browser. Next, it is important to realize that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does two kinds of arithmetic: exact and numerical (approximate). ",
  StyleBox["FindRoot", "MR"],
  " gives approximate results while ",
  StyleBox["Solve", "MR"],
  " gives exact results. Try the following and describe the results."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z1\  - \ z /. 
      FindRoot[z\^3 \[Equal] \(-1\), {z, \(-1.1\) +  .1\ I}]\)], "Input"],

Cell[BoxData[
    \(\(\(0.`\)\(\[InvisibleSpace]\)\) + 
      6.784203784900702`*^-29\ \[ImaginaryI]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(0.`\)\(\[InvisibleSpace]\)\) + 
        6.784203784900702`*^-29\ \[ImaginaryI] \[Equal] 0\)], "Input"],

Cell[TextData[{
  "These results are equivalent as can be seen by using ",
  StyleBox["Chop", "MR"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop[
        0.`\[InvisibleSpace] + 
          6.784203784900702`*^-29\ \[ImaginaryI]] \[Equal] 0\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Let\[CloseCurlyQuote]s write a ",
  StyleBox["Which", "MR"],
  " statement we can use in our ",
  StyleBox["Table", "MR"],
  " to give different values to different roots."
}], "Text"],

Cell[BoxData[
    \(ff[z0_] := 
      Which[Chop[
            z1\  - \((aa = \ 
                  z /. FindRoot[z\^3 == \(-1\), {z, z0}])\)] \[Equal] 0, 
        sol1, Chop[z2 - aa] \[Equal] 0, sol2, Chop[z3\  - aa] \[Equal] 0, 
        sol3]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({ff[ .1\  + \  .1\ I], ff[\(- .1\) +  .1\ I], 
      ff[ .2 -  .3\ I]}\)], "Input"],

Cell[BoxData[
    \({sol2, sol1, sol3}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "All ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " color functions take arguments between 0 and 1. Replace ",
  StyleBox["sol1", "MR"],
  ", ",
  StyleBox["sol2", "MR"],
  " and ",
  StyleBox["sol3", "MR"],
  " with values between 0 and 1 and then sample the complex plane on the ",
  Cell[BoxData[
      \(TraditionalForm\`x + y\ \[ImaginaryI]\)]],
  " region bounded by  ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\)\/4 < x < 5\/4\)]],
  " and -",
  Cell[BoxData[
      \(TraditionalForm\`5\/4 < y < 5\/4\)]],
  ". Then use ",
  StyleBox["ListDensityPlot", "MR"],
  " to plot your results. You may want to consider a fourth case in the ",
  StyleBox["Which", "MR"],
  " statement to allow for the situation when no solution is found. You can \
give the test ",
  StyleBox["True", "MR"],
  " and any value for the color value."
}], "Exercise"],

Cell[TextData[{
  "As you can see from the results, ",
  StyleBox["FindRoot", "MR"],
  " is very sensitive to starting values. This is a well-known situation for \
all programs that use Newton\[CloseCurlyQuote]s method for finding roots. You \
may have noticed that the plot looks a lot like some Mandelbrot sets. There \
is a connection\[LongDash] one that is explored in the next exercise."
}], "Text"],

Cell[TextData[{
  "First we find values for the three roots of the equation ",
  Cell[BoxData[
      \(TraditionalForm\`z\^3\)]],
  "= -1."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({z1, z2, z3}\  = \ z /. Solve[z\^3 \[Equal] \(-1\), z]\)], "Input"],

Cell[BoxData[
    \({\(-1\), \((\(-1\))\)\^\(1/3\), \(-\((\(-1\))\)\^\(2/3\)\)}\)], "Output"]
}, Open  ]],

Cell["\<\
Here is a function which assigns values depending on which of the above roots \
the FindRoot function converges.\
\>", "Text"],

Cell[BoxData[
    \(ff2[z0_] := 
      Which[Chop[
            z1\  - \((aa = \ 
                  z /. FindRoot[z\^3 == \(-1\), {z, z0}])\)] \[Equal] 0, 0, 
        Chop[z2 - aa] \[Equal] 0, 1/3, Chop[z3\  - aa] \[Equal] 0, 2/3, True, 
        1]\)], "Input"],

Cell["This builds the matrix we will plot.", "Text"],

Cell[BoxData[
    \(mat = 
      Table[ff2[a + b\ I], {a, \(-1.25\), 1.25,  .015}, {b, \(-1.25\), 
          1.25,  .015}]; \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListDensityPlot[Transpose[mat], ColorFunction\  \[Rule] \ Hue, 
      MeshRange\  \[Rule] \ {{\(-1.25\), 1.25}, {\(-1.25\), 1.25}}, 
      Mesh\  \[Rule] \ False, 
      Epilog \[Rule] \ {AbsolutePointSize[6], Hue[1/3], 
          Point[{Re[z1], Im[z1]}], Hue[2/3], Point[{Re[z2], Im[z2]}], Hue[1], 
          Point[{Re[z3], Im[z3]}]}]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.384615 0.5 0.384615 [
[.11538 -0.0125 -6 -9 ]
[.11538 -0.0125 6 0 ]
[.30769 -0.0125 -12 -9 ]
[.30769 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -9 -9 ]
[.69231 -0.0125 9 0 ]
[.88462 -0.0125 -3 -9 ]
[.88462 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11538 -12 -4.5 ]
[-0.0125 .11538 0 4.5 ]
[-0.0125 .30769 -24 -4.5 ]
[-0.0125 .30769 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .69231 -18 -4.5 ]
[-0.0125 .69231 0 4.5 ]
[-0.0125 .88462 -6 -4.5 ]
[-0.0125 .88462 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-1)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-0.5)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(0.5)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(1)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11538 m
.00625 .11538 L
s
[(-1)] -0.0125 .11538 1 0 Mshowa
0 .30769 m
.00625 .30769 L
s
[(-0.5)] -0.0125 .30769 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .69231 m
.00625 .69231 L
s
[(0.5)] -0.0125 .69231 1 0 Mshowa
0 .88462 m
.00625 .88462 L
s
[(1)] -0.0125 .88462 1 0 Mshowa
.125 Mabswid
0 .15385 m
.00375 .15385 L
s
0 .19231 m
.00375 .19231 L
s
0 .23077 m
.00375 .23077 L
s
0 .26923 m
.00375 .26923 L
s
0 .34615 m
.00375 .34615 L
s
0 .38462 m
.00375 .38462 L
s
0 .42308 m
.00375 .42308 L
s
0 .46154 m
.00375 .46154 L
s
0 .53846 m
.00375 .53846 L
s
0 .57692 m
.00375 .57692 L
s
0 .61538 m
.00375 .61538 L
s
0 .65385 m
.00375 .65385 L
s
0 .73077 m
.00375 .73077 L
s
0 .76923 m
.00375 .76923 L
s
0 .80769 m
.00375 .80769 L
s
0 .84615 m
.00375 .84615 L
s
0 .07692 m
.00375 .07692 L
s
0 .03846 m
.00375 .03846 L
s
0 .92308 m
.00375 .92308 L
s
0 .96154 m
.00375 .96154 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .15385 m
1 .15385 L
s
.99625 .19231 m
1 .19231 L
s
.99625 .23077 m
1 .23077 L
s
.99625 .26923 m
1 .26923 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .38462 m
1 .38462 L
s
.99625 .42308 m
1 .42308 L
s
.99625 .46154 m
1 .46154 L
s
.99625 .53846 m
1 .53846 L
s
.99625 .57692 m
1 .57692 L
s
.99625 .61538 m
1 .61538 L
s
.99625 .65385 m
1 .65385 L
s
.99625 .73077 m
1 .73077 L
s
.99625 .76923 m
1 .76923 L
s
.99625 .80769 m
1 .80769 L
s
.99625 .84615 m
1 .84615 L
s
.99625 .07692 m
1 .07692 L
s
.99625 .03846 m
1 .03846 L
s
.99625 .92308 m
1 .92308 L
s
.99625 .96154 m
1 .96154 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
501 string
167 167 8 [167 0 0 167 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF000000FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF000000FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF000000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFFFF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFFFF000000FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFFFF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFFF00FFFFFF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFFFF0000FF0000FF000000FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFFFF0000FF000000FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFFFF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
00FFFF00FFFFFF000000FFFF00FFFFFF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFFFF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF000000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF000000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF000000FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000
FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF000000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFFFF000000FFFFFF000000FFFFFF0000FF000000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF000000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFFFF0000FF0000FF000000FFFFFF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF000000FFFFFF0000FF0000
FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFFFF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFFFFF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFFFF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFFFFF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000
FF000000FFFFFF0000FF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF000000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
pop
P
% End of image
0 1 0 r
6 Mabswid
.11538 .5 Mdot
0 0 1 r
.69231 .83309 Mdot
1 0 0 r
.69231 .16691 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{224, 224},
  ImageMargins->{{52, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003P0000h2000`400?l00000o`00003oh03oool0
0>00oooo003P0?ooo`00h03oool00>00oooo003P0?ooo`00h03oool00>00oooo003P0?ooo`00<P3o
ool5000001/0oooo0P0000040?ooo`800000103oool2000001/0oooo0P00000N0?ooo`800000103o
ool2000000@0oooo0P00000M0?ooo`D000005@3oool003@0oooo00<000000?ooo`3oool06P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001T0oooo00@000000?ooo`3oool0
0000703oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001h0oooo00<00000
0?ooo`3oool05@3oool003@0oooo00<000000?ooo`3oool06P3oool010000000oooo0?ooo`00000;
0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool00000703oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05@3oool002`0oooo1000
00040?ooo`030000003oool0oooo01@0oooo100000020?ooo`040000003oool0oooo000000T0oooo
0P00000J0?ooo`040000003oool0oooo000001`0oooo00@000000?ooo`3oool000002@3oool20000
01l0oooo00<000000?ooo`3oool05@3oool003@0oooo00<000000?ooo`3oool06P3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool00000703oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05@3o
ool003<0oooo0P00000M0?ooo`8000002P3oool3000001X0oooo0P00000N0?ooo`8000002P3oool3
000001d0oooo0P00000G0?ooo`00h03oool00>00oooo003P0?ooo`00h03oool00>00oooo000J0?oo
olD000000@3oool001X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01<0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`310?ooo`400000
0@3oool001X0oooo00<000000?ooo`3oool0`@3oool100000040oooo000J0?ooo`040000003oool0
oooo0?ooob`0o`0000<00?oo0?l0003o0000SP3o00030?ooo`4000000@3oool001X0oooo00@00000
0?ooo`3oool0oooo:@3o0002003ooi80o`000`3oool100000040oooo000J0?ooo`040000003oool0
oooo0?ooobT0o`001@00oon?0?l000<0oooo0@0000010?ooo`006P3oool200000080oooo:03o000:
003oo`80o`000P00oon70?l000<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooolX
0?l000X00?oo0P3o0002003oohL0o`000`3oool100000040oooo000J0?ooo`040000003oool0oooo
0?ooobP0o`002P00ool0103o00000?oo003oo`00oon70?l000<0oooo0@0000010?ooo`006P3oool0
10000000oooo0?ooo`3ooolX0?l000l00?ooQP3o00030?ooo`4000000@3oool001X0oooo00@00000
0?ooo`3oool0oooo903o00001000ool0o`000?l0003o000?003oohH0o`000`3oool100000040oooo
000J0?ooo`040000003oool0oooo0?ooobH0o`004`00oon40?l000<0oooo0@0000010?ooo`006P3o
ool010000000oooo0?ooo`3ooolX0?l001400?ooQ03o00030?ooo`4000000@3oool001X0oooo00@0
00000?ooo`3oool0oooo8`3o00000`00ool0o`000?l0000C003ooh@0o`000`3oool100000040oooo
000J0?ooo`8000000P3ooolV0?l001<00?ooQ03o00030?ooo`4000000@3oool001X0oooo00@00000
0?ooo`3oool0oooo9@3o000D003ooh@0o`000`3oool100000040oooo000J0?ooo`040000003oool0
oooo0?ooobD0o`005000oon40?l000<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3o
oolU0?l001@00?ooQ03o00030?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo9@3o
000D003ooh@0o`000`3oool100000040oooo000C0?ooo`D000000P3oool010000000oooo0?ooo`3o
oolV0?l001<00?ooQ03o00030?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`3ooolX0?l000l00?ooQP3o00030?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool00P3oool200000080oooo:03o000A003ooh@0o`000P3oool200000040oooo000=0?oo
o`@00000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooobT0o`004000oon4
0?l000<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
0?ooob`0o`002`00oon60?l000<0oooo0@0000010?ooo`00503oool2000000@0oooo00@000000?oo
o`3oool0oooo;03o000;003oohH0o`000`3oool100000040oooo000J0?ooo`040000003oool0oooo
0?ooobh0o`002@00oon60?l000<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooola
0?l000D00?ooQ`3o00030?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo<`3o0002
003oo`030?l00000ool0o`0008D0o`000`3oool100000040oooo000J0?ooo`040000003oool0oooo
0?ooocD0o`000P00oon60?l000<0oooo0@0000010?ooo`006P3oool200000080oooo=P3o0003003o
oh@0o`000`3oool100000040oooo000J0?ooo`040000003oool0oooo0?ooocL0o`000P00oon40?l0
00<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooonm0?l000<0oooo0@0000010?oo
o`006P3oool010000000oooo0?ooo`3oooll0?l00003003oo`3o0000o`0007h0o`000`3oool10000
0040oooo000J0?ooo`040000003oool0oooo0?oooc`0o`0000<00?oo0?l0003o0000OP3o00030?oo
o`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo>@3o0004003ooh00o`000`3oool10000
0040oooo000J0?ooo`040000003oool0oooo0?ooocT0o`001000oon00?l000<0oooo0@0000010?oo
o`006P3oool200000080oooo>@3o0004003ooh00o`000`3oool100000040oooo000J0?ooo`040000
003oool0oooo0?ooocX0o`001000oomo0?l000<0oooo0@0000010?ooo`006P3oool010000000oooo
0?ooo`3ooolk0?l000<00?ooO`3o00030?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0
oooo?03o0002003oogl0o`000`3oool100000040oooo000J0?ooo`040000003oool0oooo0?oooc`0
o`000`00oomn0?l000<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooolm0?l00080
0?ooOP3o00030?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo?@3o0002003oogh0
o`000`3oool100000040oooo000J0?ooo`040000003oool0oooo0?oooch0o`000`00ooml0?l000<0
oooo0@0000010?ooo`006P3oool200000080oooo?`3o0002003oog`0o`000`3oool100000040oooo
000J0?ooo`040000003oool0oooo0?oood@0o`0000@00?oo0?l0003o0000o`000P00oomc0?l000<0
oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooom10?l000800?oo203o00000`00ool0
o`000?l0001_0?l000<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooom10?l000H0
0?ooMP3o00030?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo@@3o0009003oo`03
0?l00000ool00?oo0700o`000`3oool100000040oooo000J0?ooo`040000003oool0oooo0?ooocl0
o`003`00oom_0?l000<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooolo0?l000l0
0?ooK`3o00030?ooo`4000000@3oool001X0oooo0P0000020?ooocl0o`004000oom^0?l000<0oooo
0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooolo0?l001400?ooK@3o00030?ooo`400000
0@3oool001X0oooo00@000000?ooo`3oool0oooo?`3o000A003oofd0o`000`3oool100000040oooo
000J0?ooo`040000003oool0oooo0?oooc/0o`0000@00?oo0?l0003o0000o`004@00oom]0?l000<0
oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3oooll0?l00003003oo`3o0000o`000140
0?ooK@3o00030?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo?@3o000C003oofd0
o`000`3oool100000040oooo00080?ooo`800000103oool2000000@0oooo0P0000040?ooo`040000
003oool0oooo0?ooocd0o`004`00oom]0?l000<0oooo0@0000010?ooo`001`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool0oooo?@3o000C
003oofd0o`000`3oool100000040oooo00070?ooo`040000003oool0oooo000000/0oooo00@00000
0?ooo`3oool0oooo0P0000020?ooocd0o`004`00oom]0?l00080oooo0P0000010?ooo`0000<0oooo
0000000000000P0000020?ooo`040000003oool0oooo000000T0oooo0P0000040?ooo`040000003o
ool0oooo0?oooc/0o`0000<00?oo0?l0003o00004P00oom]0?l000<0oooo0@0000010?ooo`001`3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
oooo?P3o000B003oofd0o`000`3oool100000040oooo00080?ooo`8000002P3oool3000000<0oooo
00@000000?ooo`3oool0oooo?`3o000A003oofd0o`000`3oool100000040oooo000J0?ooo`040000
003oool0oooo0?ooocl0o`004@00oom]0?l000<0oooo0@0000010?ooo`006P3oool010000000oooo
0?ooo`3ooom30?l000d00?ooK@3o00030?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0
ooooA@3o000;003oofd0o`000`3oool100000040oooo000J0?ooo`040000003oool0oooo0?ooodH0
o`002P00oom]0?l000<0oooo0@0000010?ooo`006P3oool200000080ooooAP3o000:003oofd0o`00
0`3oool100000040oooo000J0?ooo`040000003oool0oooo0?ooodP0o`001`00oom^0?l000<0oooo
0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooom:0?l000@00?ooK`3o00030?ooo`400000
0@3oool001X0oooo00@000000?ooo`3oool0ooooCP3o0002003oofd0o`000`3oool100000040oooo
000J0?ooo`040000003oool0oooo0?ooodh0o`000P00oom]0?l000<0oooo0@0000010?ooo`006P3o
ool010000000oooo0?ooo`3ooom?0?l000800?ooK03o00030?ooo`4000000@3oool001X0oooo00@0
00000?ooo`3oool0ooooD03o00000`00ool0o`000?l0001Z0?l000<0oooo0@0000010?ooo`006P3o
ool200000080ooooD@3o0002003oofX0o`000`3oool100000040oooo000J0?ooo`040000003oool0
oooo0?oooe40o`000P00oomZ0?l000<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3o
oomA0?l000800?ooJP3o00030?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0ooooD`3o
0002003oo`<0o`0000<00?oo0?l0003o0000HP3o00030?ooo`4000000@3oool001X0oooo00@00000
0?ooo`3oool0ooooD`3o0004003oofH0o`000`3oool100000040oooo000J0?ooo`040000003oool0
oooo0?oooe40o`001`00oomU0?l000<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3o
oomA0?l000L00?ooI@3o00030?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0ooooD@3o
0007003oofD0o`000`3oool100000040oooo000J0?ooo`8000000P3ooomC0?l000H00?ooI03o0003
0?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0ooooE03o0005003oocH0o`0000<00?oo
0?l0003o0000:`3o00030?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0ooooE@3o0006
003ooc80o`001000ool/0?l000<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooomE
0?l000H00?oo<P3o0004003oob`0o`000`3oool100000040oooo000J0?ooo`040000003oool0oooo
0?oooeD0o`001P00oolb0?l000@00?oo:`3o00001@00ool0oooo0?ooo`3oool000000040oooo000J
0?ooo`040000003oool0oooo0?oooeH0o`001@00oola0?l000D00?oo:`3o00001@00ool0oooo0?oo
o`3oool000000040oooo000J0?ooo`040000003oool0oooo0?oooeL0o`001@00oolf0?l00003003o
o`3o0000o`0002P0o`000`3oool100000040oooo000J0?ooo`8000000P3ooomH0?l000@00?oo>03o
0003003oobH0o`000`3oool100000040oooo000J0?ooo`040000003oool0oooo0?oooeP0o`001@00
oolg0?l000<00?oo9P3o00030?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0ooooF@3o
0004003oobL0o`000`00ool=0?l000@00?oo9@3o00030?ooo`4000000@3oool001X0oooo00@00000
0?ooo`3oool0ooooF`3o0002003ooaH0o`000P00ool=0?l00003003oo`3o0000o`000100o`001000
oolK0?l00003003oo`3o0000o`0000H0o`000`3oool100000040oooo000J0?ooo`040000003oool0
oooo0?oooe/0o`000P00oolF0?l000800?oo3@3o00000`00ool0o`000?l0000@0?l000@00?oo6`3o
00000`00ool0o`000?l000060?l000<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3o
oolB0?l000800?l0B03o0002003ooa40o`0000@00?oo0?l0003o0000o`000`00ool;0?l00003003o
o`3o0000o`0001@0o`0000<00?oo0?l0003o00008P3o00030?ooo`4000000@3oool001@0oooo0P00
00040?ooo`040000003oool0oooo0?oooa40o`001000o`180?l00003003oo`3o0000o`0000`0o`00
00<00?oo0?l0003o00001P3o00000`00ool0o`000?l0000Q0?l00003003oo`3o0000o`0000X0o`00
0`00oolD0?l000<0oooo0@0000010?ooo`004`3oool010000000oooo0?ooo`0000030?ooo`040000
003oool0oooo0?oooa00o`001P00o`1@0?l00003003oo`3o0000o`0000d0o`0000<00?oo0?l0003o
0000803o00000`00ool0o`000?l000060?l00003003oo`3o0000o`0000@0o`0000<00?oo0?l0003o
00004@3o00030?ooo`4000000@3oool001<0oooo00@000000?ooo`3oool000000`3oool200000080
oooo403o0006003o08@0o`0000<00?oo0?l0003o0000803o00020?ooo`8000000@3oool001<0oooo
00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`3ooolA0?l000@00?l0BP3o0003003o
oaD0o`001000oolP0?l000<00?oo303o0003003oo`80o`000P00ool<0?l000<0oooo0@0000010?oo
o`004`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo0?oooa80o`000P00o`1:
0?l000/00?oo3P3o0009003ooaX0o`002P00ool50?l000P00?oo303o00030?ooo`4000000@3oool0
01@0oooo0P0000040?ooo`040000003oool0oooo0?oooeh0o`003P00ool0103o00000?oo003oo`3o
0002003oo`@0o`002`00oolI0?l000`00?oo00<0o`00003oo`00ool02@00ool;0?l000<0oooo0@00
00010?ooo`006P3oool010000000oooo0?ooo`3ooomN0?l001D00?oo0P3o000=003ooaL0o`006P00
ool:0?l000<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooomN0?l001D00?oo0P3o
000=003ooaL0o`006P00ool:0?l000<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3o
oomI0?l000800?oo0P3o000V003oo`030?l00000ool00?oo01<0o`006`00ool90?l000<0oooo0@00
00010?ooo`006P3oool200000080ooooG@3o000Z003oo``0o`0000<00?oo0?l0003o00000P3o000O
003oo`H0o`000`3oool100000040oooo000J0?ooo`040000003oool0oooo0?oooed0o`00;000ool:
0?l00003003oo`3o0000o`000080o`008P00ool30?l000<0oooo0@0000010?ooo`006P3oool01000
0000oooo0?ooo`3ooomL0?l002l00?oo203o00001000ool0o`000?l0003o000T003oo`80o`000`3o
ool100000040oooo000J0?ooo`040000003oool0oooo0?oooeH0o`0000<00?oo0?l0003o00000`3o
000`003oo`050?l00000ool00?oo0?l00000ool00P3o000X003oo`80o`000`3oool100000040oooo
000J0?ooo`040000003oool0oooo0?oooe/0o`00<P00ool40?l002/00?oo00D0o`000?ooo`3oool0
oooo000000010?ooo`006P3oool010000000oooo0?ooo`3ooomK0?l003800?oo103o000[003oo`05
0?l0003oool0oooo0?ooo`0000000@3oool001X0oooo00@000000?ooo`3oool0ooooF`3o000b003o
o`@0o`00:`00ool01@3o0000oooo0?ooo`3oool000000040oooo000J0?ooo`040000003oool0oooo
0?oooe/0o`00<P00ool40?l002`00?oo0`3oool100000040oooo000J0?ooo`8000000P3ooomI0?l0
03H00?oo00<0o`00003oo`00ool0:`00ool30?ooo`4000000@3oool001X0oooo00@000000?ooo`3o
ool0ooooF@3o001T003oo`<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooom@0?l0
0003003oo`3o0000o`0000H0o`00I000ool30?ooo`4000000@3oool001X0oooo00@000000?ooo`3o
ool0ooooD03o00000`00ool0o`000?l000050?l006D00?oo0`3oool100000040oooo000J0?ooo`04
0000003oool0oooo0?oooeP0o`00I@00ool30?ooo`4000000@3oool001X0oooo00@000000?ooo`3o
ool0ooooD@3o0002003oo`<0o`0000<00?oo0?l00000ool0I000ool30?ooo`4000000@3oool001X0
oooo00@000000?ooo`3oool0ooooE`3o001V003oo`<0oooo0@0000010?ooo`006P3oool200000080
ooooE`3o001V003oo`<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooomC0?l006X0
0?oo0`3oool100000040oooo000J0?ooo`040000003oool0oooo0?oooe40o`00K000ool30?ooo`40
00000@3oool001X0oooo00@000000?ooo`3oool0ooooD@3o001/003oo`<0oooo0@0000010?ooo`00
6P3oool010000000oooo0?ooo`3ooom>0?l00003003oo`3o0000o`0006`00?oo0`3oool100000040
oooo000J0?ooo`040000003oool0oooo0?oooe40o`00K000ool30?ooo`4000000@3oool001X0oooo
00@000000?ooo`3oool0ooooD03o001]003oo`<0oooo0@0000010?ooo`006P3oool010000000oooo
0?ooo`3ooom70?l00003003oo`3o0000o`0000D0o`00KP00ool30?ooo`4000000@3oool001X0oooo
0P0000020?ooodH0o`0000<00?oo0?l0003o00001`3o001]003oo`<0oooo0@0000010?ooo`006P3o
ool010000000oooo0?ooo`3ooom60?l00003003oo`3o0000o`0000L0o`00K@00ool30?ooo`400000
0@3oool001X0oooo00@000000?ooo`3oool0ooooA@3o00000`00ool0o`000?l000080?l006d00?oo
0`3oool100000040oooo000J0?ooo`040000003oool0oooo0?oooe40o`00K000ool30?ooo`400000
0@3oool001X0oooo00@000000?ooo`3oool0ooooD@3o001/003oo`<0oooo0@0000010?ooo`00203o
ool2000000@0oooo0P0000040?ooo`800000103oool010000000oooo0?ooo`3ooolj0?l000D00?oo
4P3o001/003oo`<0oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000<0oooo00@000000?ooo`3oool0oooo>`3o0003003ooa<0o`00K000ool30?oo
o`4000000@3oool000L0oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`3oool2
00000080oooo>`3o0003003ooa80o`00K@00ool20?ooo`8000000@3oool000L0oooo00@000000?oo
o`3oool000002@3oool2000000@0oooo00@000000?ooo`3oool0oooo?03o00000`00ool0o`000?l0
000A0?l006d00?oo0`3oool100000040oooo00070?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`3oooll0?l00003003oo`3o0000o`000140o`00
K@00ool30?ooo`4000000@3oool000P0oooo0P00000:0?ooo`<000000`3oool010000000oooo0?oo
o`3oooll0?l00003003oo`3o0000o`000140o`00K@00ool30?ooo`4000000@3oool001X0oooo00@0
00000?ooo`3oool0ooooD03o001]003oo`<0oooo0@0000010?ooo`006P3oool010000000oooo0?oo
o`3ooom@0?l006d00?oo0`3oool100000040oooo000J0?ooo`040000003oool0oooo0?oooc`0o`00
0P00oolB0?l006d00?oo0`3oool100000040oooo000J0?ooo`040000003oool0oooo0?oooc`0o`00
0`00oolA0?l006d00?oo0`3oool100000040oooo000J0?ooo`8000000P3ooolm0?l000800?oo4P3o
001/003oo`<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooolm0?l000800?oo4P3o
001/003oo`<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooolm0?l000800?oo503o
001Z003oo`<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooolm0?l000800?oo503o
001Z003oo`<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3oooln0?l00003003oo`3o
0000o`0001<0o`00J@00ool30?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo?`3o
0002003oo`X0o`0000@00?oo0?l0003o00000?oo103o001Z003oo`<0oooo0@0000010?ooo`006P3o
ool010000000oooo0?ooo`3ooolo0?l000800?oo2`3o001a003oo`<0oooo0@0000010?ooo`006P3o
ool010000000oooo0?ooo`3ooom<0?l007400?oo0`3oool100000040oooo000J0?ooo`8000000P3o
oom10?l007`00?oo0`3oool100000040oooo000J0?ooo`040000003oool0oooo0?oood40o`00O000
ool30?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo?`3o001n003oo`<0oooo0@00
00010?ooo`006P3oool010000000oooo0?ooo`3ooolo0?l007h00?oo0`3oool100000040oooo000J
0?ooo`040000003oool0oooo0?ooocl0o`00OP00ool30?ooo`4000000@3oool001X0oooo00@00000
0?ooo`3oool0oooo?`3o001n003oo`<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3o
ooln0?l007l00?oo0`3oool100000040oooo000J0?ooo`8000000P3ooolj0?l00004003oo`3o0000
o`000?l007l00?oo0`3oool100000040oooo000J0?ooo`040000003oool0oooo0?oooch0o`00O`00
ool30?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo=`3o0002003oo`@0o`00P000
ool30?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo?@3o0016003oo`80003o>000
ool30?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo>@3o00001000ool0o`000?l0
003o0015003oo`@0003o=`00ool30?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo
>@3o00001000ool0o`000?l0003o0014003oo`H0003o=P00ool30?ooo`4000000@3oool001X0oooo
00@000000?ooo`3oool0oooo>P3o0017003oo`H0003o=P00ool30?ooo`4000000@3oool001X0oooo
00@000000?ooo`3oool0oooo=`3o001;003oo`@0003o=`00ool30?ooo`4000000@3oool001X0oooo
0P0000020?ooocT0o`00BP00ool20000ocP00?oo0`3oool100000040oooo000J0?ooo`040000003o
ool0oooo0?ooocT0o`00Q000ool30?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo
=`3o0026003oo`<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooola0?l00003003o
o`3o0000o`000080o`00Q`00ool30?ooo`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo
;P3o0002003oo`L0o`00QP00ool30?ooo`4000000@3oool001<0oooo1@0000020?ooo`040000003o
ool0oooo0?ooocT0o`00Q000ool30?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`3oooli0?l008@00?oo0`3oool100000040oooo000E0?ooo`030000003o
ool0oooo0080oooo0P0000020?ooob<0o`0000<00?oo0?l0003o00004`3o0024003oo`80oooo0P00
00010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooob<0o`001@00
oolA0?l008@00?oo0`3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool0oooo8`3o0005003ooa40o`00Q000ool30?ooo`4000000@3oool001@0oooo0P000004
0?ooo`040000003oool0oooo0?ooob<0o`000`00oolC0?l008@00?oo0`3oool100000040oooo000J
0?ooo`040000003oool0oooo0?ooocT0o`00Q000ool30?ooo`4000000@3oool001X0oooo00@00000
0?ooo`3oool0oooo903o00000`00ool0o`000?l0000B0?l008@00?oo0`3oool100000040oooo000J
0?ooo`040000003oool0oooo0?ooob@0o`0000<00?oo0?l0003o00004P3o0024003oo`<0oooo0@00
00010?ooo`006P3oool010000000oooo0?ooo`3ooolT0?l00003003oo`3o0000o`000180o`00Q000
ool30?ooo`4000000@3oool001X0oooo0P0000020?ooocT0o`00Q000ool30?ooo`4000000@3oool0
01X0oooo00@000000?ooo`3oool0oooo903o0002003ooa<0o`00Q000ool30?ooo`4000000@3oool0
01X0oooo00@000000?ooo`3oool0oooo903o0002003ooa<0o`00Q000ool30?ooo`4000000@3oool0
01X0oooo00@000000?ooo`3oool0oooo903o0002003ooa@0o`00P`00ool30?ooo`4000000@3oool0
01X0oooo00@000000?ooo`3oool0oooo903o0002003ooa40o`000P00ool20?l008800?oo0`3oool1
00000040oooo000J0?ooo`040000003oool0oooo0?ooobD0o`000`00oolD0?l008400?oo0`3oool1
00000040oooo000J0?ooo`040000003oool0oooo0?ooobD0o`000`00oolE0?l008000?oo0`3oool1
00000040oooo000J0?ooo`8000000P3ooolV0?l000800?oo2P3o00000`00ool0o`000?l000020?l0
00800?oo0P3o0022003oo`<0oooo0@0000010?ooo`006P3oool010000000oooo0?ooo`3ooolV0?l0
00800?oo2P3o00000`00ool0o`000?l000020?l000800?oo0P3o0022003oo`<0oooo0@0000010?oo
o`006P3oool010000000oooo0?ooo`3ooolV0?l000800?oo303o0029003oo`<0oooo0@0000010?oo
o`006P3oool010000000oooo0?ooo`3ooolX0?l00003003oo`3o0000o`0000T0o`00R@00ool30?oo
o`4000000@3oool001X0oooo00@000000?ooo`3oool0oooo<P3o00000`00ool0o`00003oo`28003o
o`<0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`310?ooo`4000000@3oool001X0oooo
00<000000?ooo`3oool0`@3oool100000040oooo000J0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool100000040oooo000J0?ooolD000000@3oool00>00oooo003P0?ooo`00
h03oool00>00oooo003P0?ooo`00h03oool00>00oooo0000\
\>"],
  ImageRangeCache->{{{0, 223}, {223, 0}} -> {-1.65021, -1.55175, 0.0132371, \
0.0132371}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Mandelbrot and Function Iteration \[FivePointedStar]\[FivePointedStar]\
\>", "Section",
  CounterAssignments->{{"Chapter", 8}, {"ExerciseNumber", 6}}],

Cell[TextData[{
  "In this exercise we will investigate some functions that exhibit \
interesting properties on iteration. We will assume you have some familiarity \
with the arithmetic of complex numbers. We begin by defining a function ",
  StyleBox["Mandelbrot", "MR"],
  "."
}], "Text"],

Cell[BoxData[
    \(Mandelbrot[x_, c_] := \ x\^2 + \ c\)], "Input"],

Cell[TextData[{
  "Let\[CloseCurlyQuote]s look at what happens with several examples of this \
for specific values of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NestList[Mandelbrot[#, 1] &, 0, 9]\)], "Input"],

Cell[BoxData[
    \({0, 1, 2, 5, 26, 677, 458330, 210066388901, 44127887745906175987802, 
      1947270476915296449559703445493848930452791205}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The results seem to be growing rapidly. Here is another example where we \
change ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " from 1 to ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NestList[Mandelbrot[#, \(-1\)] &, 0, 10]\)], "Input"],

Cell[BoxData[
    \({0, \(-1\), 0, \(-1\), 0, \(-1\), 0, \(-1\), 0, \(-1\), 0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Interestingly, this seems to oscillate between 0 and ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  ". What happens if ",
  Cell[BoxData[
      \(TraditionalForm\`c = 1\/4\)]],
  "?"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NestList[Mandelbrot[#, 1/4] &, 0, 5]\)], "Input"],

Cell[BoxData[
    \({0, 1\/4, 5\/16, 89\/256, 24305\/65536, 
      1664474849\/4294967296}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NestList[Mandelbrot[#, 1/4] &, 0, 10] // N\)], "Input"],

Cell[BoxData[
    \({0.`, 0.25`, 0.3125`, 0.34765625`, 0.3708648681640625`, 
      0.38754075043834746`, 0.4001878332503175`, 0.4101503018815839`, 
      0.4182232701335544`, 0.42491070368120404`, 
      0.43054910610285596`}\)], "Output"]
}, Open  ]],

Cell["\<\
Can you show that in this case the result will always be less than 1/2?\
\>", "Exercise"],

Cell[TextData[{
  "Mandelbrot sets: Mandelbrot sets are composed of all the points in the \
complex plane for which iterating the function ",
  StyleBox["Mandelbrot", "MR"],
  " with differing values for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\)\(,\)\)\)]],
  " the results remain bounded. (It can be shown that the values taken by the \
function will remain less than 2. See ",
  StyleBox["The ",
    FontSlant->"Italic"],
  StyleBox["Nature and Power of Mathematics", "TI"],
  " by Donald M. Davis.) "
}], "Text"],

Cell[TextData[{
  "We will construct a matrix of values for a region in the complex plane \
taking the value 1 if we believe the point is in the Mandelbrot set and 0 \
otherwise. Keep in mind we can only carry out finitely many iterations, and \
so a point where the function grows very slowly without bound will still be \
seen as being in the set. Look up the function ",
  StyleBox["NestWhile", "MR"],
  " in the Help Browser. We will use the form that includes a test, the \
number of previous outputs to bring along, and a maximum number of outputs."
}], "Exercise"],

Cell[BoxData[
    \(\(?NestWhile\ \)\)], "Input",
  Evaluatable->False],

Cell[TextData[{
  StyleBox["NestWhile[", "MR"],
  StyleBox["f", "IT"],
  StyleBox[",", "MR"],
  StyleBox["expr", "IT"],
  StyleBox[",", "MR"],
  StyleBox["test", "IT"],
  StyleBox[",", "MR"],
  StyleBox["m", "IT"],
  StyleBox[",", "MR"],
  StyleBox["max", "IT"],
  StyleBox["]", "MR"],
  " starts with ",
  StyleBox["expr",
    FontSlant->"Italic"],
  ", then repeatedly applies ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " until applying ",
  StyleBox["test",
    FontSlant->"Italic"],
  " to the result no longer yields true.  At each step, the value ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " supplies the most recent ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " results as arguments for ",
  StyleBox["test",
    FontSlant->"Italic"],
  " and the argument ",
  StyleBox["max",
    FontSlant->"Italic"],
  " limits ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " to at most, ",
  StyleBox["max",
    FontSlant->"Italic"],
  " iterations. "
}], "Text"],

Cell[TextData[{
  "Write a ",
  StyleBox["NestWhile", "MR"],
  " function that applies ",
  StyleBox["Mandelbrot", "MR"],
  " to a starting value of zero and gives the argument ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " in the form ",
  Cell[BoxData[
      \(TraditionalForm\`a + b\ \[ImaginaryI]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\^2\)]],
  "= -1. We will assume that if an iteration gives a result larger than 2 the \
point is not in the set, so your test should be of the form ",
  StyleBox["(Abs[#1]<2)&", "MR"],
  ", and you should limit the number of iterations to 100."
}], "Exercise"],

Cell[TextData[{
  "Use your ",
  StyleBox["NestWhile", "MR"],
  " function inside an ",
  StyleBox["If", "MR"],
  " statement as an argument for ",
  StyleBox["Table", "MR"],
  " where you take the iterators to be ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " with limits ",
  StyleBox["{a,-2.,1/2,1/80}", "MR"],
  " and ",
  StyleBox["{b,-5/4.,5/4,1/80}", "MR"],
  ". (If you are on a very fast computer you can change the step size to \
1/160.) You should have something like:"
}], "Exercise"],

Cell[BoxData[
    \(mat = 
      Table[If[NestWhile[Mandelbrot[\[Ellipsis]] &, 0, 1, \[Ellipsis]] < 2, 
          1, 0], {a, \[Ellipsis]}, {b, \[Ellipsis]}]\)], "Input",
  Evaluatable->False],

Cell["\<\
Evaluate your function, and don\[CloseCurlyQuote]t be surprised if it takes a \
minute or two to evaluate.\
\>", "Text"],

Cell[TextData[{
  "You should be able to plot this using ",
  StyleBox["ListDensityPlot", "MR"],
  ". If you specify ",
  StyleBox["MeshRange,", "MR"],
  " you should be able to add any details that you wish to add."
}], "Exercise"],

Cell[BoxData[
    \(Mandelbrot[x_, c_] := \ x\^2 + \ c\)], "Input"],

Cell[BoxData[
    \(mat\  = \ 
      Table[If[Abs[
              NestWhile[Mandelbrot[#, a\  + \ b\ I] &, 
                0, \((Abs[#1] < 2)\) &, 1, 100]] < 2, 1, 0], {a, \(-2. \), 
          1/2, 1/80}, {b, \(-5\)/4. , 5/4, 1/80}]; \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListDensityPlot[Transpose[mat], ColorFunction\  \[Rule] \ GrayLevel, 
      Mesh \[Rule] \ False, 
      MeshRange\  \[Rule] \ {{\(-2\), 1/2}, {\(-5\)/4, 5/4}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.788462 0.384615 0.5 0.384615 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.21154 -0.0125 -12 -9 ]
[.21154 -0.0125 12 0 ]
[.40385 -0.0125 -6 -9 ]
[.40385 -0.0125 6 0 ]
[.59615 -0.0125 -12 -9 ]
[.59615 -0.0125 12 0 ]
[.78846 -0.0125 -3 -9 ]
[.78846 -0.0125 3 0 ]
[.98077 -0.0125 -9 -9 ]
[.98077 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11538 -12 -4.5 ]
[-0.0125 .11538 0 4.5 ]
[-0.0125 .30769 -24 -4.5 ]
[-0.0125 .30769 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .69231 -18 -4.5 ]
[-0.0125 .69231 0 4.5 ]
[-0.0125 .88462 -6 -4.5 ]
[-0.0125 .88462 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-2)] .01923 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(-1.5)] .21154 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(-1)] .40385 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(-0.5)] .59615 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(0)] .78846 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(0.5)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.05769 0 m
.05769 .00375 L
s
.09615 0 m
.09615 .00375 L
s
.13462 0 m
.13462 .00375 L
s
.17308 0 m
.17308 .00375 L
s
.25 0 m
.25 .00375 L
s
.28846 0 m
.28846 .00375 L
s
.32692 0 m
.32692 .00375 L
s
.36538 0 m
.36538 .00375 L
s
.44231 0 m
.44231 .00375 L
s
.48077 0 m
.48077 .00375 L
s
.51923 0 m
.51923 .00375 L
s
.55769 0 m
.55769 .00375 L
s
.63462 0 m
.63462 .00375 L
s
.67308 0 m
.67308 .00375 L
s
.71154 0 m
.71154 .00375 L
s
.75 0 m
.75 .00375 L
s
.82692 0 m
.82692 .00375 L
s
.86538 0 m
.86538 .00375 L
s
.90385 0 m
.90385 .00375 L
s
.94231 0 m
.94231 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11538 m
.00625 .11538 L
s
[(-1)] -0.0125 .11538 1 0 Mshowa
0 .30769 m
.00625 .30769 L
s
[(-0.5)] -0.0125 .30769 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .69231 m
.00625 .69231 L
s
[(0.5)] -0.0125 .69231 1 0 Mshowa
0 .88462 m
.00625 .88462 L
s
[(1)] -0.0125 .88462 1 0 Mshowa
.125 Mabswid
0 .15385 m
.00375 .15385 L
s
0 .19231 m
.00375 .19231 L
s
0 .23077 m
.00375 .23077 L
s
0 .26923 m
.00375 .26923 L
s
0 .34615 m
.00375 .34615 L
s
0 .38462 m
.00375 .38462 L
s
0 .42308 m
.00375 .42308 L
s
0 .46154 m
.00375 .46154 L
s
0 .53846 m
.00375 .53846 L
s
0 .57692 m
.00375 .57692 L
s
0 .61538 m
.00375 .61538 L
s
0 .65385 m
.00375 .65385 L
s
0 .73077 m
.00375 .73077 L
s
0 .76923 m
.00375 .76923 L
s
0 .80769 m
.00375 .80769 L
s
0 .84615 m
.00375 .84615 L
s
0 .07692 m
.00375 .07692 L
s
0 .03846 m
.00375 .03846 L
s
0 .92308 m
.00375 .92308 L
s
0 .96154 m
.00375 .96154 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.21154 .99375 m
.21154 1 L
s
.40385 .99375 m
.40385 1 L
s
.59615 .99375 m
.59615 1 L
s
.78846 .99375 m
.78846 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.05769 .99625 m
.05769 1 L
s
.09615 .99625 m
.09615 1 L
s
.13462 .99625 m
.13462 1 L
s
.17308 .99625 m
.17308 1 L
s
.25 .99625 m
.25 1 L
s
.28846 .99625 m
.28846 1 L
s
.32692 .99625 m
.32692 1 L
s
.36538 .99625 m
.36538 1 L
s
.44231 .99625 m
.44231 1 L
s
.48077 .99625 m
.48077 1 L
s
.51923 .99625 m
.51923 1 L
s
.55769 .99625 m
.55769 1 L
s
.63462 .99625 m
.63462 1 L
s
.67308 .99625 m
.67308 1 L
s
.71154 .99625 m
.71154 1 L
s
.75 .99625 m
.75 1 L
s
.82692 .99625 m
.82692 1 L
s
.86538 .99625 m
.86538 1 L
s
.90385 .99625 m
.90385 1 L
s
.94231 .99625 m
.94231 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .15385 m
1 .15385 L
s
.99625 .19231 m
1 .19231 L
s
.99625 .23077 m
1 .23077 L
s
.99625 .26923 m
1 .26923 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .38462 m
1 .38462 L
s
.99625 .42308 m
1 .42308 L
s
.99625 .46154 m
1 .46154 L
s
.99625 .53846 m
1 .53846 L
s
.99625 .57692 m
1 .57692 L
s
.99625 .61538 m
1 .61538 L
s
.99625 .65385 m
1 .65385 L
s
.99625 .73077 m
1 .73077 L
s
.99625 .76923 m
1 .76923 L
s
.99625 .80769 m
1 .80769 L
s
.99625 .84615 m
1 .84615 L
s
.99625 .07692 m
1 .07692 L
s
.99625 .03846 m
1 .03846 L
s
.99625 .92308 m
1 .92308 L
s
.99625 .96154 m
1 .96154 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
201 string
201 201 8 [201 0 0 201 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
00FFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF000000FF000000
00FF00FF00FFFFFF00FFFFFFFF00FFFF00FF000000FF0000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF00000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFF00FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF0000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000000000000000
00FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000000000
0000FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000
0000FFFF0000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFF0000000000000000000000000000000000000000FFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
00000000000000FFFFFF0000000000000000000000000000000000000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFF00
00000000000000FFFFFF00000000FF0000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF
000000FFFFFFFFFFFFFFFF00FF00FFFF0000000000000000000000000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000000000000000000000000000000000
0000000000000000000000FF0000000000FFFFFFFF0000000000000000FFFF0000FFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF
000000FFFFFFFFFFFFFFFF00FF00FFFF0000000000000000000000000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFF00
00000000000000FFFFFF00000000FF0000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
00000000000000FFFFFF0000000000000000000000000000000000000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFF0000000000000000000000000000000000000000FFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000
0000FFFF0000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000000000
0000FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000000000000000
00FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFF00FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF0000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF00000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF000000FF000000
00FF00FF00FFFFFF00FFFFFFFF00FFFF00FF000000FF0000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
00FFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`008@3oool4000002L0oooo1@0000020?ooo`800000103oool2000002P0oooo1@00000W0?oo
o`800000103oool2000000@0oooo0P00000V0?ooo`800000:P3oool2000000@0oooo0P0000040?oo
o`8000000`3oool00240oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo000002T0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000002@0oooo00@000000?ooo`3oool00000:03oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo00000080oooo000R0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo
000002P0oooo00@000000?ooo`3oool000002`3oool100000040oooo0@3oool001/0oooo10000004
0?ooo`030000003oool0oooo0200oooo100000040?ooo`030000003oool0oooo00P0oooo0P00000R
0?ooo`@00000103oool00`000000oooo0?ooo`0P0?ooo`@000000P3oool010000000oooo0?ooo`00
00090?ooo`8000009@3oool010000000oooo0?ooo`00000X0?ooo`040000003oool0oooo000000T0
oooo0P0000030?ooo`008@3oool010000000oooo0?ooo`00000Y0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000X0?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool00P3oool00280oooo0P00000Y0?ooo`8000002P3oool3
000002P0oooo0P00000Y0?ooo`8000002P3oool3000002D0oooo0P00000Z0?ooo`8000002P3oool3
00000080oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo000K0?ooool000000@0000050?ooo`006`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000050?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;`3oool01@000000
oooo0?ooo`3oool0000000D0oooo000K0?ooo`030000003oool0oooo0?`0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool0o03oool00`000000oooo0?ooo`030?ooo`006`3o
ool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080oooomP0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo
0080oooomP0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooomP0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo
mP0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3oooof000000<0oooo0P00
00050?ooo`006`3oool00`000000oooo0?ooo`020?ooooH00000103oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?ooooH00000103oool00`000000oooo0?ooo`030?oo
o`006`3oool00`000000oooo0?ooo`020?ooooH00000103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?ooooH00000103oool00`000000oooo0?ooo`030?ooo`006`3o
ool00`000000oooo0?ooo`020?ooooH00000103oool00`000000oooo0?ooo`030?ooo`006`3oool0
0`000000oooo0?ooo`020?ooooH00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?ooooH00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?ooooH00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo
0?ooo`020?ooooH00000103oool00`000000oooo0?ooo`030?ooo`006`3oool2000000<0oooomP00
00030?ooo`8000001@3oool001/0oooo00<000000?ooo`3oool00P3oooof000000@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oooof000000@0oooo00<000000?oo
o`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oooof000000@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3oooof000000@0oooo00<000000?ooo`3oool0
0`3oool001/0oooo00<000000?ooo`3oool00P3oooof000000@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3oooof000000@0oooo00<000000?ooo`3oool00`3oool0
01/0oooo00<000000?ooo`3oool00P3ooond000000030?ooo`000000000003l00000103oool00`00
0000oooo0?ooo`030?ooo`004`3oool5000000<0oooo00<000000?ooo`3oool00P3oooof000000@0
oooo00<000000?ooo`3oool00`3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooooH00000103oool00`000000oooo0?ooo`030?ooo`005@3oool00`000000oooo0?oo
o`030?ooo`8000000`3oooof000000<0oooo0P0000050?ooo`003@3oool4000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooooH00000103oool00`000000oooo0?ooo`03
0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooomP0000040?oo
o`030000003oool0oooo00<0oooo000D0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooooH0
0000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooooH00000
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooooH00000103o
ool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooooH00000103oool0
0`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooooH00000103oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooooH00000103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooooH00000103oool00`000000oooo
0?ooo`030?ooo`006`3oool2000000<0oooomP0000030?ooo`8000001@3oool001/0oooo00<00000
0?ooo`3oool00P3oooni000000030?ooo`000000000003X00000103oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?oookT0000000<0oooo000000000000>P0000040?oo
o`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo^00000030?oooc/0
0000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oookH00000
1@3ooolk000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3o
oonh000000<0oooo>`0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080oooo]@0000050?oooc`00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?oookD000001@3oooll000000@0oooo00<000000?ooo`3oool00`3oool001/0
oooo00<000000?ooo`3oool00P3ooonc000000`0oooo=`0000040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`8000000`3ooon^00000080oooo00<000000?ooo`3oool0303ooolg000000<0oooo
0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?ooojl000004@3oool00`000000oooo0?oo
o`0c000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooon`
000001<0oooo<`0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo
0080oooo/000000C0?oooc<00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?oooj/000000P3oool200000180oooo=@0000040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo[`00000D0?oooc<00000103oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooojd00000503ooole000000@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooon_000001@0oooo<`000004
0?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo[`00000B0?oo
ocD00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooojl0
00004P3ooole000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P0000030?ooojl00000
4P3ooole000000<0oooo0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?ooojh000004P3o
oolf000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooon`
00000100oooo=P0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo
0080oooo/000000@0?ooocH00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?oook000000403ooolf000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3ooonc000000T0oooo>P0000040?ooo`030000003oool0oooo00<0oooo
000K0?ooo`030000003oool0oooo0080ooooYP0000020?ooo`<000000P3oool400000080oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0?ooo`000000
oooo100000000`3oool000000000000Y000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3ooonP00000080oooo1000000P0?ooo`<0000000<0oooo000000000000
0`0000000`3oool000000000000T000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3ooonN000000D0oooo00<000000?ooo`3oool00P00000S0?ooo`@00000103o
oolS000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooon?
000000030?ooo`000000000000d00000;@3oool3000000@0oooo2`0000000`3oool000000000000E
000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P0000030?ooohl0000000<0oooo0000
000000003@00000]0?ooo`<00000103oool;000000030?ooo`000000000001D000000`3oool20000
00D0oooo000K0?ooo`030000003oool0oooo0080ooooS`0000060?ooo`/00000<@3ooolU000000@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooon@000000L0oooo
1000000f0?ooo`80000000<0oooo0000000000002@0000000`3oool000000000000D000000@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooon?000000T0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0000000800000080oooo0`0000000`3oool000000000
000?000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooon?
000000T0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`03000000T0oooo4@000004
0?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080ooooS`0000090?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool00`0000090?oooa400000103oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooohh000002@3oool00`000000
oooo0?ooo`100?ooo`800000203ooolB000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3ooon?000004X0oooo0P00000:0?oooa400000103oool00`000000oooo
0?ooo`030?ooo`00203oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?oo
o`020?oooi000000E@3ooolA000000@0oooo00<000000?ooo`3oool00`3oool000L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo
TP00001C0?oooa400000103oool00`000000oooo0?ooo`030?ooo`001`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo0080oooo0P0000030?oooi000000E03ooolB000000<0oooo
0P0000050?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000T0oooo
0P0000050?ooo`030000003oool0oooo0080ooooT000001D0?oooa800000103oool00`000000oooo
0?ooo`030?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3ooon?000005<0oooo500000040?ooo`030000003oool0oooo00<0oooo
00080?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool00P3ooon<000005<0oooo5`00
00040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080ooooS@00001D
0?oooaD00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
oh@0000000<0oooo0000000000000`00001G0?ooo`030000003oool0oooo01800000103oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooh@0000000<0oooo00000000
00000`00001G0?ooo`030000003oool0oooo01800000103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?oooh8000001`3oool00`000000oooo0?ooo`1F0?ooo`<00000
00<0oooo0000000000003P0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003o
ool0oooo0080ooooQ@0000040?ooo`030000003oool0oooo05P0oooo4P0000040?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080ooooQ000001R0?oooa000000103oool0
0`000000oooo0?ooo`030?ooo`006`3oool2000000<0ooooR000001M0?oooa4000000`3oool20000
00D0oooo000K0?ooo`030000003oool0oooo0080ooooQ@00001P0?oooa400000103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooohD00000H03ooolA000000@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooon4000000030?ooo`00
0000000005l0oooo400000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080ooooPP0000000`3oool000000?ooo`1Q0?ooo`<000000P3oool;000000@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooomo000006d0oooo2P0000040?oo
o`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080ooooP@00001^0?ooo`L0
0000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooh400000
KP3oool7000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3o
oon2000006X0oooo2P0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080ooooPP00001U0?ooo`80000000<0oooo0000000000002P0000040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`8000000`3ooon2000006L0oooo3@0000030?ooo`8000001@3oool001/0
oooo00<000000?ooo`3oool00P3ooomR00000080oooo6@0000040?ooo`030000003oool0oooo06D0
oooo3@0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo
D`0000000`3oool000000000000;000000<0oooo6@0000000`3oool000000?ooo`1Y0?ooo`d00000
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooe<0000000<0
oooo0000000000002`0000030?oooaT0000000<0oooo0000003oool0J@3oool=000000@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooomC000000@0oooo2P000003
0?ooo`D0000000<0oooo0000000000004`00001[0?ooo``00000103oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?oooe8000001P3oool4000000X0oooo00<000000?oo
o`0000000`3ooolA000000030?ooo`000000oooo06X0oooo300000040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080ooooDP0000060?ooo`030000003oool0oooo00l0
oooo1@0000020?ooo``00000K@3oool<000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3ooomC000001`0oooo3`00001^0?ooo`X00000103oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooe<00000703oool?000006h0oooo2P00
00040?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3ooomD000001d0oooo3000001b
0?ooo`L000000`3oool2000000D0oooo000K0?ooo`030000003oool0oooo0080ooooD`00000P0?oo
o`/00000K@3oool;000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3ooomB00000240oooo2@0000000`3oool000000?ooo`1[0?ooo``00000103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooe4000008`3oool9000006d0oooo
300000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080ooooC@00
00000`3oool000000000000U0?ooo`L00000K@3oool=000000@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3ooom=000000030?ooo`000000000002D0oooo1`00001]
0?ooo`d00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
odd00000:P3oool5000006h0oooo300000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`03
0000003oool0oooo0080ooooCP00000Z0?ooo`@00000KP3oool<000000@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3ooom=000002/0oooo1000001]0?ooo`d00000
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oood/00000;P3o
ool3000006/0oooo3`0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3ooom;
000002h0oooo0`00001[0?ooo`l000000`3oool2000000D0oooo000K0?ooo`030000003oool0oooo
0080ooooC000000]0?ooo`<00000K@3oool=000000@0oooo00<000000?ooo`3oool00`3oool001/0
oooo00<000000?ooo`3oool00P3ooom;000002l0oooo0P00001Z0?oooa000000103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oood/00000;`3oool2000006X0oooo
400000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo@`00
00020?ooo`H00000;`3oool2000006T0oooo4@0000040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo@00000080?ooo`<00000;`3oool2000006T0oooo4@000004
0?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo@00000080?oo
o`<00000;`3oool2000006T0oooo4@0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`03
0000003oool0oooo0080oooo?P00000l0?ooo`800000J03ooolB000000@0oooo00<000000?ooo`3o
ool00`3oool001@0oooo0P0000050?ooo`030000003oool0oooo0080oooo?P00002T0?oooa@00000
103oool00`000000oooo0?ooo`030?ooo`004`3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0080oooo?000002U0?oooaD00000103oool00`000000oooo0?ooo`030?ooo`004`3o
ool010000000oooo0?ooo`0000040?ooo`8000000`3oool=00000080oooo1P0000050?ooo`T00000
0`3oool2000000<0oooo0P00002a0?oooaP000000`3oool2000000D0oooo000C0?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00P3oool=00000080oooo1P0000050?ooo`T00000
0`3oool2000000<0oooo0P00002a0?oooaP00000103oool00`000000oooo0?ooo`030?ooo`004`3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo?000002U0?oooaD00000
103oool00`000000oooo0?ooo`030?ooo`00503oool2000000D0oooo00<000000?ooo`3oool00P3o
ooln00000:@0oooo500000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080oooo?P00000l0?ooo`800000J03ooolB000000@0oooo00<000000?ooo`3oool00`3oool0
01/0oooo00<000000?ooo`3oool00P3ooom0000000P0oooo0`00000_0?ooo`800000J@3ooolA0000
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooom0000000P0
oooo0`00000_0?ooo`800000J@3ooolA000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3ooom300000080oooo1P00000_0?ooo`800000J@3ooolA000000@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooom;000002l0oooo0P00
001Z0?oooa000000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?oood/00000;`3oool2000006X0oooo400000040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`8000000`3ooom<000002d0oooo0`00001]0?ooo`d000000`3oool2000000D0oooo000K0?ooo`03
0000003oool0oooo0080ooooB`00000^0?ooo`<00000J`3oool?000000@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3ooom;000002h0oooo0`00001[0?ooo`l00000
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooodd00000:`3o
ool4000006d0oooo3@0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080ooooCP00000Z0?ooo`@00000KP3oool<000000@0oooo00<000000?ooo`3oool00`3oool0
01/0oooo00<000000?ooo`3oool00P3ooom=000002X0oooo1@00001^0?ooo``00000103oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooodd0000000<0oooo00000000
00009@3oool7000006d0oooo3@0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000
003oool0oooo0080ooooC@0000000`3oool000000000000U0?ooo`L00000K@3oool=000000@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooomA000002<0oooo2@00
001]0?ooo``00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?oooe8000008@3oool9000000030?ooo`000000oooo06/0oooo300000040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`8000000`3ooomC00000200oooo2`00001]0?ooo`/000000`3oool20000
00D0oooo000K0?ooo`030000003oool0oooo0080ooooE000000M0?ooo``00000LP3oool7000000@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooomC000001`0oooo
3`00001^0?ooo`X00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?oo
o`020?oooe<00000703oool?000006h0oooo2P0000040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080ooooDP0000060?ooo`030000003oool0oooo00l0oooo1@000002
0?ooo``00000K@3oool<000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool00P3ooomB000000H0oooo1000000:0?ooo`030000003oool0000000<0oooo4@0000000`3o
ool000000?ooo`1Z0?ooo``00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?oooe<00000103oool:000000<0oooo1@0000000`3oool000000000000C000006/0
oooo300000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo
D`0000000`3oool000000000000;000000<0oooo6@0000000`3oool000000?ooo`1Y0?ooo`d00000
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooe<0000000<0
oooo0000000000002`0000030?oooaT0000000<0oooo0000003oool0J@3oool=000000@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooomR00000080oooo6@000004
0?ooo`030000003oool0oooo06D0oooo3@0000040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`8000000`3ooon2000006L0oooo3@0000030?ooo`8000001@3oool001/0oooo00<000000?ooo`3o
ool00P3ooon2000006D0oooo0P0000000`3oool000000000000:000000@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3ooon2000006X0oooo2P0000040?ooo`030000
003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080ooooP@00001^0?ooo`L00000103o
ool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooh400000KP3oool7
000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooomo0000
06d0oooo2P0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
ooooPP0000000`3oool000000?ooo`1Q0?ooo`<000000P3oool;000000@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3ooon4000000030?ooo`000000000005l0oooo
400000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080ooooQ@00
001P0?oooa400000103oool00`000000oooo0?ooo`030?ooo`006`3oool2000000<0ooooQ@00001P
0?oooa4000000`3oool2000000D0oooo000K0?ooo`030000003oool0oooo0080ooooR000001M0?oo
oa400000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooh@0
0000HP3oool@000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool0
0P3ooon5000000@0oooo00<000000?ooo`3oool0F03ooolB000000@0oooo00<000000?ooo`3oool0
0`3oool001/0oooo00<000000?ooo`3oool00P3ooon2000000L0oooo00<000000?ooo`3oool0EP3o
ool3000000030?ooo`000000000000h00000103oool00`000000oooo0?ooo`030?ooo`006`3oool0
0`000000oooo0?ooo`020?oooh@0000000<0oooo0000000000000`00001G0?ooo`030000003oool0
oooo01800000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
oh@0000000<0oooo0000000000000`00001G0?ooo`030000003oool0oooo01800000103oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooohd00000E03ooolE000000@0
oooo00<000000?ooo`3oool00`3oool000P0oooo0P0000040?ooo`800000103oool2000000D0oooo
00<000000?ooo`3oool00P3ooon<000005<0oooo5`0000040?ooo`030000003oool0oooo00<0oooo
00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`020?ooohl00000D`3ooolD000000@0oooo00<000000?ooo`3oool00`3oool000L0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`8000000`3ooon@000005@0
oooo4P0000030?ooo`8000001@3oool000L0oooo00@000000?ooo`3oool000002@3oool2000000D0
oooo00<000000?ooo`3oool00P3ooon@000005@0oooo4P0000040?ooo`030000003oool0oooo00<0
oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?oooi800000D`3ooolA000000@0oooo00<000000?ooo`3oool00`3oool000P0oooo
0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`020?oooi000000E@3ooolA000000@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooon?000004X0oooo0P00
000:0?oooa400000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?ooohh000002@3oool00`000000oooo0?ooo`100?ooo`800000203ooolB000000@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooon?000000T0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`03000000T0oooo4@0000040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080ooooS`0000090?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool00`0000090?oooa400000103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?ooohl000002@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0000000P000000P3oool3000000030?ooo`000000000000l00000103oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooi0000001`3oool4000003H0oooo0P00
00000`3oool0000000000009000000030?ooo`000000000001@00000103oool00`000000oooo0?oo
o`030?ooo`006`3oool2000000<0ooooS`0000060?ooo`/00000<@3ooolU000000<0oooo0P000005
0?ooo`006`3oool00`000000oooo0?ooo`020?ooohl0000000<0oooo0000000000003@00000]0?oo
o`<00000103oool;000000030?ooo`000000000001D00000103oool00`000000oooo0?ooo`030?oo
o`006`3oool00`000000oooo0?ooo`020?ooohl0000000<0oooo0000000000003@00000]0?ooo`<0
0000103oool;000000030?ooo`000000000001D00000103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?oooih000001@3oool00`000000oooo0?ooo`02000002<0oooo
100000040?ooob<00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?oo
o`020?oooj0000000P3oool400000200oooo0`0000000`3oool0000000000003000000030?ooo`00
0000000002@00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?ooojH000000P3oool300000080oooo100000020?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool00`3oool01P000000oooo0?ooo`3oool000000?ooo`@0000000<0oooo000000000000
:@0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo/`00
00090?ooocX00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?oook000000403ooolf000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool00P3ooon`00000100oooo=P0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`03
0000003oool0oooo0080oooo/000000@0?ooocH00000103oool00`000000oooo0?ooo`030?ooo`00
6`3oool2000000<0oooo[P00000B0?ooocH000000`3oool2000000D0oooo000K0?ooo`030000003o
ool0oooo0080oooo[`00000B0?ooocD00000103oool00`000000oooo0?ooo`030?ooo`006`3oool0
0`000000oooo0?ooo`020?ooojl000004P3ooole000000@0oooo00<000000?ooo`3oool00`3oool0
01/0oooo00<000000?ooo`3oool00P3ooon_00000180oooo=@0000040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo[`00000D0?oooc<00000103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooojd00000503ooole000000@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooon_000001@0oooo<`00
00040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080ooooZ`000002
0?ooo`8000004P3ooole000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool00P3ooon`000001<0oooo<`0000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`03
0000003oool0oooo0080oooo/000000C0?oooc<00000103oool00`000000oooo0?ooo`030?ooo`00
6`3oool2000000<0oooo[`00000A0?ooo`030000003oool0oooo03<000000`3oool2000000D0oooo
000K0?ooo`030000003oool0oooo0080oooo[P0000020?ooo`030000003oool0oooo00`0oooo=`00
00040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo/`00000<
0?ooocL00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
okD000001@3oooll000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3ooone000000D0oooo?00000040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000
003oool0oooo0080oooo^00000030?oooc/00000103oool00`000000oooo0?ooo`030?ooo`006`3o
ool00`000000oooo0?ooo`020?oookH000001@3ooolk000000@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3ooonh000000<0oooo>`0000040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo^@0000000`3oool000000000000j0000
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oooni00000003
0?ooo`000000000003X00000103oool00`000000oooo0?ooo`030?ooo`006`3oool2000000<0oooo
mP0000030?ooo`8000001@3oool001/0oooo00<000000?ooo`3oool00P3oooof000000@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oooof000000@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oooof000000@0oooo00<000000?oo
o`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oooof000000@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3oooof000000@0oooo00<000000?ooo`3oool0
0`3oool001/0oooo00<000000?ooo`3oool00P3oooof000000@0oooo00<000000?ooo`3oool00`3o
ool001<0oooo1@0000030?ooo`030000003oool0oooo0080oooomP0000040?ooo`030000003oool0
oooo00<0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oooof0000
00@0oooo00<000000?ooo`3oool00`3oool001D0oooo00<000000?ooo`3oool00`3oool2000000<0
oooomP0000030?ooo`8000001@3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooooH00000103oool00`000000oooo0?ooo`030?ooo`005@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooomP0000040?ooo`030000003oool0oooo00<0oooo000D
0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooooH00000103oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?oook@0000000<0oooo000000000000?`0000040?oo
o`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooomP0000040?ooo`03
0000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooomP0000040?ooo`030000
003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooomP0000040?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooomP0000040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooomP0000040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`8000000`3oooof000000<0oooo0P0000050?ooo`006`3oool00`000000oooo
0?ooo`020?ooooH00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?oo
o`020?ooooH00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?ooooH00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
ooH00000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooooH0
0000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooooH00000
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooooH00000103o
ool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooooH00000103oool0
0`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooooH00000103oool00`00
0000oooo0?ooo`030?ooo`006`3oool2000000<0oooomP0000030?ooo`8000001@3oool001/0oooo
00<000000?ooo`3oool00P3oooof000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3oooof000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<00000
0?ooo`3oool00P3oooof000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool00P3oooof000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3oooof000000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool0
o03oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`3l0?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0_0?ooo`050000003oool0oooo0?ooo`0000001@3oool001/0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000001@3o
ool001/0ooooo`000001000000D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.32653, -1.52103, 0.0101674, \
0.0101674}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  DensityGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{793, 527},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "M50.8.1"->{
    Cell[1776, 53, 81, 1, 95, "Title",
      CellTags->{"M50.8.1", "M50.8.2", "M50.8.3"}],
    Cell[1882, 58, 50, 1, 73, "Section",
      CellTags->"M50.8.1"],
    Cell[1935, 61, 69, 1, 33, "Text",
      CellTags->"M50.8.1"],
    Cell[2007, 64, 142, 5, 25, "BulletItem",
      CellTags->"M50.8.1"],
    Cell[2152, 71, 135, 6, 25, "BulletItem",
      CellTags->"M50.8.1"],
    Cell[2290, 79, 75, 1, 25, "BulletItem",
      CellTags->"M50.8.1"],
    Cell[2368, 82, 70, 1, 25, "BulletItem",
      CellTags->"M50.8.1"]},
  "M50.8.2"->{
    Cell[1776, 53, 81, 1, 95, "Title",
      CellTags->{"M50.8.1", "M50.8.2", "M50.8.3"}],
    Cell[2475, 88, 56, 1, 73, "Section",
      CellTags->"M50.8.2"],
    Cell[2556, 93, 64, 1, 38, "Subsection",
      CellTags->"M50.8.2"],
    Cell[2623, 96, 569, 10, 90, "Text",
      CellTags->"M50.8.2"],
    Cell[3195, 108, 74, 2, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[3294, 114, 71, 2, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[3368, 118, 76, 2, 29, "Output",
      CellTags->"M50.8.2"],
    Cell[3459, 123, 144, 5, 33, "Text",
      CellTags->"M50.8.2"],
    Cell[3628, 132, 75, 2, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[3706, 136, 138, 3, 29, "Output",
      CellTags->"M50.8.2"],
    Cell[3859, 142, 64, 2, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[3960, 149, 66, 1, 38, "Subsection",
      CellTags->"M50.8.2"],
    Cell[4029, 152, 296, 6, 52, "Text",
      CellTags->"M50.8.2"],
    Cell[4328, 160, 154, 5, 25, "BulletItem",
      CellTags->"M50.8.2"],
    Cell[4485, 167, 203, 8, 25, "BulletItem",
      CellTags->"M50.8.2"],
    Cell[4691, 177, 174, 5, 33, "Text",
      CellTags->"M50.8.2"],
    Cell[4868, 184, 537, 14, 71, "Text",
      CellTags->"M50.8.2"],
    Cell[5430, 202, 89, 2, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[5522, 206, 153681, 3253, 556, 47370, 1935, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"M50.8.2"],
    Cell[159252, 3465, 62, 1, 38, "Subsection",
      CellTags->"M50.8.2"],
    Cell[159317, 3468, 384, 12, 52, "Text",
      CellTags->"M50.8.2"],
    Cell[159726, 3484, 94, 2, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[159823, 3488, 85, 2, 41, "Output",
      CellTags->"M50.8.2"],
    Cell[159957, 3496, 55, 1, 38, "Subsection",
      CellTags->"M50.8.2"],
    Cell[160015, 3499, 435, 9, 71, "Text",
      CellTags->"M50.8.2"],
    Cell[160475, 3512, 158, 4, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[160636, 3518, 310, 5, 48, "Output",
      CellTags->"M50.8.2"],
    Cell[160983, 3528, 174, 4, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[161160, 3534, 44620, 748, 147, 3131, 231, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"M50.8.2"],
    Cell[211413, 4469, 58, 1, 73, "Section",
      CellTags->"M50.8.2"],
    Cell[211474, 4472, 345, 8, 52, "Text",
      CellTags->"M50.8.2"],
    Cell[211844, 4484, 81, 2, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[211928, 4488, 90, 2, 29, "Output",
      CellTags->"M50.8.2"],
    Cell[212033, 4493, 208, 6, 33, "Text",
      CellTags->"M50.8.2"],
    Cell[212266, 4503, 85, 2, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[212354, 4507, 85, 2, 29, "Output",
      CellTags->"M50.8.2"],
    Cell[212476, 4514, 62, 1, 38, "Subsection",
      CellTags->"M50.8.2"],
    Cell[212541, 4517, 350, 8, 52, "Text",
      CellTags->"M50.8.2"],
    Cell[212916, 4529, 110, 2, 31, "Input",
      CellTags->"M50.8.2"],
    Cell[213029, 4533, 101, 2, 42, "Output",
      CellTags->"M50.8.2"],
    Cell[213145, 4538, 222, 6, 33, "Text",
      CellTags->"M50.8.2"],
    Cell[213392, 4548, 130, 3, 33, "Input",
      CellTags->"M50.8.2"],
    Cell[213525, 4553, 171, 3, 42, "Output",
      CellTags->"M50.8.2"],
    Cell[213745, 4562, 82, 1, 38, "Subsection",
      CellTags->"M50.8.2"],
    Cell[213830, 4565, 233, 5, 52, "Text",
      CellTags->"M50.8.2"],
    Cell[214088, 4574, 92, 2, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[214183, 4578, 96, 2, 29, "Output",
      CellTags->"M50.8.2"],
    Cell[214294, 4583, 286, 10, 52, "Text",
      CellTags->"M50.8.2"],
    Cell[214617, 4598, 50, 1, 38, "Subsection",
      CellTags->"M50.8.2"],
    Cell[214670, 4601, 404, 13, 52, "Text",
      CellTags->"M50.8.2"],
    Cell[215099, 4618, 99, 2, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[215201, 4622, 90, 2, 29, "Output",
      CellTags->"M50.8.2"],
    Cell[215306, 4627, 102, 2, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[215433, 4633, 98, 2, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[215534, 4637, 99, 2, 29, "Output",
      CellTags->"M50.8.2"],
    Cell[215670, 4644, 100, 2, 30, "Input",
      CellTags->"M50.8.2"],
    Cell[215773, 4648, 98, 2, 29, "Output",
      CellTags->"M50.8.2"],
    Cell[215886, 4653, 216, 7, 33, "Text",
      CellTags->"M50.8.2"],
    Cell[216105, 4662, 65, 2, 30, "Input",
      CellTags->"M50.8.2"]},
  "M50.8.3"->{
    Cell[1776, 53, 81, 1, 95, "Title",
      CellTags->{"M50.8.1", "M50.8.2", "M50.8.3"}],
    Cell[216219, 4670, 125, 2, 73, "Section",
      CellTags->"M50.8.3"],
    Cell[216347, 4674, 650, 19, 71, "Text",
      CellTags->"M50.8.3"],
    Cell[217000, 4695, 201, 4, 50, "Input",
      CellTags->"M50.8.3"],
    Cell[217226, 4703, 83, 2, 30, "Input",
      CellTags->"M50.8.3"],
    Cell[217312, 4707, 76, 2, 29, "Output",
      CellTags->"M50.8.3"],
    Cell[217403, 4712, 159, 5, 33, "Text",
      CellTags->"M50.8.3"],
    Cell[217587, 4721, 62, 2, 30, "Input",
      CellTags->"M50.8.3"],
    Cell[217652, 4725, 62, 2, 29, "Output",
      CellTags->"M50.8.3"],
    Cell[217729, 4730, 80, 2, 30, "Input",
      CellTags->"M50.8.3"],
    Cell[217834, 4736, 62, 2, 30, "Input",
      CellTags->"M50.8.3"],
    Cell[217899, 4740, 64, 2, 29, "Output",
      CellTags->"M50.8.3"],
    Cell[218000, 4747, 51, 1, 38, "Subsection",
      CellTags->"M50.8.3"],
    Cell[218054, 4750, 460, 12, 52, "Text",
      CellTags->"M50.8.3"],
    Cell[218517, 4764, 269, 5, 90, "Input",
      CellTags->"M50.8.3"],
    Cell[218811, 4773, 85, 2, 30, "Input",
      CellTags->"M50.8.3"],
    Cell[218899, 4777, 75, 2, 29, "Output",
      CellTags->"M50.8.3"],
    Cell[218989, 4782, 167, 7, 33, "Text",
      CellTags->"M50.8.3"],
    Cell[219181, 4793, 60, 2, 30, "Input",
      CellTags->"M50.8.3"],
    Cell[219244, 4797, 61, 2, 29, "Output",
      CellTags->"M50.8.3"],
    Cell[219320, 4802, 77, 2, 30, "Input",
      CellTags->"M50.8.3"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"M50.8.1", 544376, 10294},
  {"M50.8.2", 544908, 10309},
  {"M50.8.3", 549268, 10430}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 81, 1, 95, "Title",
  CellTags->{"M50.8.1", "M50.8.2", "M50.8.3"}],

Cell[CellGroupData[{
Cell[1882, 58, 50, 1, 73, "Section",
  CellTags->"M50.8.1"],
Cell[1935, 61, 69, 1, 33, "Text",
  CellTags->"M50.8.1"],
Cell[2007, 64, 142, 5, 25, "BulletItem",
  CellTags->"M50.8.1"],
Cell[2152, 71, 135, 6, 25, "BulletItem",
  CellTags->"M50.8.1"],
Cell[2290, 79, 75, 1, 25, "BulletItem",
  CellTags->"M50.8.1"],
Cell[2368, 82, 70, 1, 25, "BulletItem",
  CellTags->"M50.8.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2475, 88, 56, 1, 73, "Section",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{
Cell[2556, 93, 64, 1, 38, "Subsection",
  CellTags->"M50.8.2"],
Cell[2623, 96, 569, 10, 90, "Text",
  CellTags->"M50.8.2"],
Cell[3195, 108, 74, 2, 30, "Input",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{
Cell[3294, 114, 71, 2, 30, "Input",
  CellTags->"M50.8.2"],
Cell[3368, 118, 76, 2, 29, "Output",
  CellTags->"M50.8.2"]
}, Open  ]],
Cell[3459, 123, 144, 5, 33, "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{
Cell[3628, 132, 75, 2, 30, "Input",
  CellTags->"M50.8.2"],
Cell[3706, 136, 138, 3, 29, "Output",
  CellTags->"M50.8.2"]
}, Open  ]],
Cell[3859, 142, 64, 2, 30, "Input",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3960, 149, 66, 1, 38, "Subsection",
  CellTags->"M50.8.2"],
Cell[4029, 152, 296, 6, 52, "Text",
  CellTags->"M50.8.2"],
Cell[4328, 160, 154, 5, 25, "BulletItem",
  CellTags->"M50.8.2"],
Cell[4485, 167, 203, 8, 25, "BulletItem",
  CellTags->"M50.8.2"],
Cell[4691, 177, 174, 5, 33, "Text",
  CellTags->"M50.8.2"],
Cell[4868, 184, 537, 14, 71, "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{
Cell[5430, 202, 89, 2, 30, "Input",
  CellTags->"M50.8.2"],
Cell[5522, 206, 153681, 3253, 556, 47370, 1935, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"M50.8.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[159252, 3465, 62, 1, 38, "Subsection",
  CellTags->"M50.8.2"],
Cell[159317, 3468, 384, 12, 52, "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{
Cell[159726, 3484, 94, 2, 30, "Input",
  CellTags->"M50.8.2"],
Cell[159823, 3488, 85, 2, 41, "Output",
  CellTags->"M50.8.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[159957, 3496, 55, 1, 38, "Subsection",
  CellTags->"M50.8.2"],
Cell[160015, 3499, 435, 9, 71, "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{
Cell[160475, 3512, 158, 4, 30, "Input",
  CellTags->"M50.8.2"],
Cell[160636, 3518, 310, 5, 48, "Output",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[160983, 3528, 174, 4, 30, "Input",
  CellTags->"M50.8.2"],
Cell[161160, 3534, 44620, 748, 147, 3131, 231, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"M50.8.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[205841, 4289, 117, 1, 73, "Section",
  CounterAssignments->{{"Chapter", 8}, {"ExerciseNumber", 1}}],
Cell[205961, 4292, 185, 5, 25, "Exercise"],
Cell[206149, 4299, 207, 5, 25, "Exercise"]
}, Open  ]],

Cell[CellGroupData[{
Cell[206393, 4309, 104, 1, 73, "Section",
  CounterAssignments->{{"Chapter", 8}, {"ExerciseNumber", 3}}],
Cell[206500, 4312, 491, 12, 59, "Exercise"],
Cell[206994, 4326, 69, 1, 30, "Input"],
Cell[207066, 4329, 343, 10, 42, "Exercise"],
Cell[207412, 4341, 280, 5, 90, "Input"],
Cell[207695, 4348, 299, 9, 42, "Exercise"],
Cell[207997, 4359, 60, 1, 30, "Input"],
Cell[208060, 4362, 455, 10, 71, "Text"],
Cell[208518, 4374, 62, 1, 30, "Input"],
Cell[208583, 4377, 129, 2, 30, "Input"],
Cell[208715, 4381, 129, 2, 30, "Input"],
Cell[208847, 4385, 164, 3, 33, "Text"],
Cell[209014, 4390, 404, 7, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[209455, 4402, 117, 1, 73, "Section",
  CounterAssignments->{{"Chapter", 8}, {"ExerciseNumber", 4}}],
Cell[209575, 4405, 286, 6, 42, "Exercise"],
Cell[209864, 4413, 130, 2, 30, "Input"],
Cell[209997, 4417, 163, 5, 25, "Exercise"],
Cell[210163, 4424, 95, 4, 25, "Exercise"],
Cell[210261, 4430, 285, 8, 42, "Exercise"],
Cell[210549, 4440, 422, 13, 42, "Exercise"],
Cell[210974, 4455, 267, 5, 72, "Input"],
Cell[211244, 4462, 132, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[211413, 4469, 58, 1, 73, "Section",
  CellTags->"M50.8.2"],
Cell[211474, 4472, 345, 8, 52, "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{
Cell[211844, 4484, 81, 2, 30, "Input",
  CellTags->"M50.8.2"],
Cell[211928, 4488, 90, 2, 29, "Output",
  CellTags->"M50.8.2"]
}, Open  ]],
Cell[212033, 4493, 208, 6, 33, "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{
Cell[212266, 4503, 85, 2, 30, "Input",
  CellTags->"M50.8.2"],
Cell[212354, 4507, 85, 2, 29, "Output",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[212476, 4514, 62, 1, 38, "Subsection",
  CellTags->"M50.8.2"],
Cell[212541, 4517, 350, 8, 52, "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{
Cell[212916, 4529, 110, 2, 31, "Input",
  CellTags->"M50.8.2"],
Cell[213029, 4533, 101, 2, 42, "Output",
  CellTags->"M50.8.2"]
}, Open  ]],
Cell[213145, 4538, 222, 6, 33, "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{
Cell[213392, 4548, 130, 3, 33, "Input",
  CellTags->"M50.8.2"],
Cell[213525, 4553, 171, 3, 42, "Output",
  CellTags->"M50.8.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[213745, 4562, 82, 1, 38, "Subsection",
  CellTags->"M50.8.2"],
Cell[213830, 4565, 233, 5, 52, "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{
Cell[214088, 4574, 92, 2, 30, "Input",
  CellTags->"M50.8.2"],
Cell[214183, 4578, 96, 2, 29, "Output",
  CellTags->"M50.8.2"]
}, Open  ]],
Cell[214294, 4583, 286, 10, 52, "Text",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[214617, 4598, 50, 1, 38, "Subsection",
  CellTags->"M50.8.2"],
Cell[214670, 4601, 404, 13, 52, "Text",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{
Cell[215099, 4618, 99, 2, 30, "Input",
  CellTags->"M50.8.2"],
Cell[215201, 4622, 90, 2, 29, "Output",
  CellTags->"M50.8.2"]
}, Open  ]],
Cell[215306, 4627, 102, 2, 30, "Input",
  CellTags->"M50.8.2"],

Cell[CellGroupData[{
Cell[215433, 4633, 98, 2, 30, "Input",
  CellTags->"M50.8.2"],
Cell[215534, 4637, 99, 2, 29, "Output",
  CellTags->"M50.8.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215670, 4644, 100, 2, 30, "Input",
  CellTags->"M50.8.2"],
Cell[215773, 4648, 98, 2, 29, "Output",
  CellTags->"M50.8.2"]
}, Open  ]],
Cell[215886, 4653, 216, 7, 33, "Text",
  CellTags->"M50.8.2"],
Cell[216105, 4662, 65, 2, 30, "Input",
  CellTags->"M50.8.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[216219, 4670, 125, 2, 73, "Section",
  CellTags->"M50.8.3"],
Cell[216347, 4674, 650, 19, 71, "Text",
  CellTags->"M50.8.3"],
Cell[217000, 4695, 201, 4, 50, "Input",
  CellTags->"M50.8.3"],

Cell[CellGroupData[{
Cell[217226, 4703, 83, 2, 30, "Input",
  CellTags->"M50.8.3"],
Cell[217312, 4707, 76, 2, 29, "Output",
  CellTags->"M50.8.3"]
}, Open  ]],
Cell[217403, 4712, 159, 5, 33, "Text",
  CellTags->"M50.8.3"],

Cell[CellGroupData[{
Cell[217587, 4721, 62, 2, 30, "Input",
  CellTags->"M50.8.3"],
Cell[217652, 4725, 62, 2, 29, "Output",
  CellTags->"M50.8.3"]
}, Open  ]],
Cell[217729, 4730, 80, 2, 30, "Input",
  CellTags->"M50.8.3"],

Cell[CellGroupData[{
Cell[217834, 4736, 62, 2, 30, "Input",
  CellTags->"M50.8.3"],
Cell[217899, 4740, 64, 2, 29, "Output",
  CellTags->"M50.8.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[218000, 4747, 51, 1, 38, "Subsection",
  CellTags->"M50.8.3"],
Cell[218054, 4750, 460, 12, 52, "Text",
  CellTags->"M50.8.3"],
Cell[218517, 4764, 269, 5, 90, "Input",
  CellTags->"M50.8.3"],

Cell[CellGroupData[{
Cell[218811, 4773, 85, 2, 30, "Input",
  CellTags->"M50.8.3"],
Cell[218899, 4777, 75, 2, 29, "Output",
  CellTags->"M50.8.3"]
}, Open  ]],
Cell[218989, 4782, 167, 7, 33, "Text",
  CellTags->"M50.8.3"],

Cell[CellGroupData[{
Cell[219181, 4793, 60, 2, 30, "Input",
  CellTags->"M50.8.3"],
Cell[219244, 4797, 61, 2, 29, "Output",
  CellTags->"M50.8.3"]
}, Open  ]],
Cell[219320, 4802, 77, 2, 30, "Input",
  CellTags->"M50.8.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[219446, 4810, 120, 1, 73, "Section",
  CounterAssignments->{{"Chapter", 8}, {"ExerciseNumber", 2}}],
Cell[219569, 4813, 206, 6, 25, "Exercise"],
Cell[219778, 4821, 187, 4, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[220002, 4830, 142, 3, 73, "Section",
  CounterAssignments->{{"Chapter", 8}, {"ExerciseNumber", 5}}],
Cell[220147, 4835, 512, 13, 42, "Exercise"],

Cell[CellGroupData[{
Cell[220684, 4852, 87, 1, 31, "Input"],
Cell[220774, 4855, 93, 1, 29, "Output"]
}, Open  ]],
Cell[220882, 4859, 871, 22, 93, "Text"],

Cell[CellGroupData[{
Cell[221778, 4885, 108, 2, 31, "Input"],
Cell[221889, 4889, 114, 2, 29, "Output"]
}, Open  ]],
Cell[222018, 4894, 126, 2, 30, "Input"],
Cell[222147, 4898, 118, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[222290, 4906, 131, 3, 30, "Input"],
Cell[222424, 4911, 38, 1, 29, "Output"]
}, Open  ]],
Cell[222477, 4915, 203, 6, 33, "Text"],
Cell[222683, 4923, 255, 6, 52, "Input"],

Cell[CellGroupData[{
Cell[222963, 4933, 103, 2, 30, "Input"],
Cell[223069, 4937, 52, 1, 29, "Output"]
}, Open  ]],
Cell[223136, 4941, 880, 27, 80, "Exercise"],
Cell[224019, 4970, 404, 7, 71, "Text"],
Cell[224426, 4979, 151, 5, 33, "Text"],

Cell[CellGroupData[{
Cell[224602, 4988, 87, 1, 31, "Input"],
Cell[224692, 4991, 93, 1, 29, "Output"]
}, Open  ]],
Cell[224800, 4995, 136, 3, 33, "Text"],
Cell[224939, 5000, 260, 6, 52, "Input"],
Cell[225202, 5008, 52, 0, 33, "Text"],
Cell[225257, 5010, 137, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[225419, 5017, 370, 6, 90, "Input"],
Cell[225792, 5025, 194251, 3001, 232, 174448, 2752, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[420092, 8032, 160, 3, 73, "Section",
  CounterAssignments->{{"Chapter", 8}, {"ExerciseNumber", 6}}],
Cell[420255, 8037, 290, 6, 52, "Text"],
Cell[420548, 8045, 67, 1, 30, "Input"],
Cell[420618, 8048, 245, 9, 33, "Text"],

Cell[CellGroupData[{
Cell[420888, 8061, 67, 1, 30, "Input"],
Cell[420958, 8064, 157, 2, 48, "Output"]
}, Open  ]],
Cell[421130, 8069, 239, 9, 33, "Text"],

Cell[CellGroupData[{
Cell[421394, 8082, 73, 1, 30, "Input"],
Cell[421470, 8085, 92, 1, 29, "Output"]
}, Open  ]],
Cell[421577, 8089, 224, 8, 36, "Text"],

Cell[CellGroupData[{
Cell[421826, 8101, 69, 1, 30, "Input"],
Cell[421898, 8104, 104, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[422039, 8111, 75, 1, 30, "Input"],
Cell[422117, 8114, 239, 4, 29, "Output"]
}, Open  ]],
Cell[422371, 8121, 99, 2, 25, "Exercise"],
Cell[422473, 8125, 525, 13, 71, "Text"],
Cell[423001, 8140, 571, 9, 76, "Exercise"],
Cell[423575, 8151, 71, 2, 30, "Input",
  Evaluatable->False],
Cell[423649, 8155, 993, 40, 52, "Text"],
Cell[424645, 8197, 643, 18, 59, "Exercise"],
Cell[425291, 8217, 563, 19, 59, "Exercise"],
Cell[425857, 8238, 191, 4, 30, "Input",
  Evaluatable->False],
Cell[426051, 8244, 130, 3, 33, "Text"],
Cell[426184, 8249, 232, 6, 25, "Exercise"],
Cell[426419, 8257, 67, 1, 30, "Input"],
Cell[426489, 8260, 247, 5, 50, "Input"],

Cell[CellGroupData[{
Cell[426761, 8269, 193, 3, 50, "Input"],
Cell[426957, 8274, 116648, 1995, 296, 86829, 1622, "GraphicsData", \
"PostScript", "Graphics"],
Cell[543608, 10271, 137, 3, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

