(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     68332,       2047]*)
(*NotebookOutlinePosition[     78572,       2343]*)
(*  CellTagsIndexPosition[     78328,       2331]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Working with Rules", "Title",
  CellTags->{
  "M50.7.1", "M50.7.2", "M50.7.3", "M50.7.4", "M50.7.5", "M50.7.6"}],

Cell[CellGroupData[{

Cell["Overview", "Section",
  CellTags->"M50.7.1"],

Cell["\<\
In this session we will learn how to work with lists. The topics will \
include:\
\>", "Text",
  CellTags->"M50.7.1"],

Cell["Rule notation", "BulletItem",
  CellTags->"M50.7.1"],

Cell["The reasons for using rules", "BulletItem",
  CellTags->"M50.7.1"],

Cell["Simple uses of rules", "BulletItem",
  CellTags->"M50.7.1"],

Cell["Rules as output of other functions", "BulletItem",
  CellTags->"M50.7.1"],

Cell["Rules in defining functions", "BulletItem",
  CellTags->"M50.7.1"],

Cell["Rules with patterns", "BulletItem",
  CellTags->"M50.7.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rule Basics", "Section",
  CellTags->"M50.7.2"],

Cell[CellGroupData[{

Cell["Rule Notation", "Subsection",
  CellTags->"M50.7.2"],

Cell[TextData[{
  "There are two kinds of rules in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Rule", "MR"],
  " (",
  StyleBox["\[Rule]", "MR"],
  ") and ",
  StyleBox["RuleDelayed", "MR"],
  " (",
  StyleBox["\[RuleDelayed]", "MR"],
  "). ",
  StyleBox["RuleDelayed", "MR"],
  " is generally preferred for reasons similar to those for using ",
  StyleBox["SetDelayed", "MR"],
  " (",
  StyleBox[":=", "MR"],
  ") for most of your function definitions. Don\[CloseCurlyQuote]t worry \
about the differences right now, just be aware that the two kinds exist."
}], "Text",
  CellTags->"M50.7.2"],

Cell[TextData[{
  "So why do we use rules? Rules allow us to transform occurrences of a \
symbol or value with another. Here is an example of a simple application of a \
",
  StyleBox["RuleDelayed", "MR"],
  ". (Type a colon followed by the greater than sign >.) We apply the rule \
using ",
  StyleBox["/.,", "MR"],
  " which is just slash (",
  StyleBox["/", "MR"],
  ") followed by a period. "
}], "Text",
  CellTags->"M50.7.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, a\ b, \ a\ a, 3/x, 3/a} /. a \[RuleDelayed] \ rr\)], "Input",
  CellTags->"M50.7.2"],

Cell[BoxData[
    \({rr, b\ rr, rr\^2, 3\/x, 3\/rr}\)], "Output",
  CellTags->"M50.7.2"]
}, Open  ]],

Cell[TextData[{
  "Note that every occurrence of the symbol ",
  StyleBox["a", "MR"],
  " has been replaced by the symbol ",
  StyleBox["rr", "MR"],
  "."
}], "Text",
  CellTags->"M50.7.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using Several Rules", "Subsection",
  CellTags->{"LastSlide", "M50.7.2"}],

Cell["\<\
Sometimes you will need to replace more than one symbol or value. In this \
case, use a list of rules.\
\>", "Text",
  CellTags->"M50.7.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c} /. {a \[RuleDelayed] \ 3, c \[RuleDelayed] \ rr}\)], "Input",
  CellTags->"M50.7.2"],

Cell[BoxData[
    \({3, b, rr}\)], "Output",
  CellTags->"M50.7.2"]
}, Open  ]],

Cell[TextData[{
  "We can also use the ",
  StyleBox["Part", "MR"],
  " function with a list of rules which will be handy later. Note that the \
rule for ",
  StyleBox["r", "MR"],
  " is not applied in the following example."
}], "Text",
  CellTags->"M50.7.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \({1, 2\ r, {r, s}, 
        5} /. {r \[RuleDelayed] 3, 2 \[RuleDelayed] v}[\([2]\)]\)], "Input",
  CellTags->"M50.7.2"],

Cell[BoxData[
    \({1, r\ v, {r, s}, 5}\)], "Output",
  CellTags->"M50.7.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise: Working with Rules", "Section",
  CounterAssignments->{{"Chapter", 7}, {"ExerciseNumber", 0}}],

Cell[TextData[{
  "Replace all the ",
  StyleBox["a", "MR"],
  "\[CloseCurlyQuote]s in the following list with the number 77."
}], "Exercise"],

Cell[BoxData[
    \({a, 3\ a\ b\ , r\ , s}\)], "Input"],

Cell[TextData[{
  "Replace the ",
  StyleBox["a", "MR"],
  "\[CloseCurlyQuote]s with ",
  StyleBox["cow", "MR"],
  " and the ",
  StyleBox["b", "MR"],
  "\[CloseCurlyQuote]s with ",
  StyleBox["dog", "MR"],
  "."
}], "Exercise"],

Cell[BoxData[
    \({a, 3\ a\ b, r, \ aa, \ 25}\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rules as Output of Functions", "Section",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{

Cell["The Solve Function", "Subsection",
  CellTags->"M50.7.3"],

Cell[TextData[{
  StyleBox["Solve", "MR"],
  " is one of the many functions in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that gives rules for output. To be able to extract the values associated \
with these rules, we first name our solutions."
}], "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol1 = Solve[3\ x + 4 \[Equal] 5, x]\)], "Input",
  CellTags->"M50.7.3"],

Cell[BoxData[
    \({{x \[Rule] 1\/3}}\)], "Output",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell["\<\
We can use this solution to convert expressions. Note that when we do this we \
get a list and not a number.\
\>", "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(3\ x + 4 /. \[InvisibleSpace]sol1\)], "Input",
  CellTags->"M50.7.3"],

Cell[BoxData[
    \({5}\)], "Output",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell[TextData[{
  "We can correct this using the ",
  StyleBox["Part", "MR"],
  " function on our rule."
}], "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(3\ x + 
        4 /. \[InvisibleSpace]sol1\[LeftDoubleBracket]1\[RightDoubleBracket]\)\
], "Input",
  CellTags->"M50.7.3"],

Cell[BoxData[
    \(5\)], "Output",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell[BoxData[
    \(Clear[sol1]\)], "Input",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More on Working with Levels", "Subsection",
  CellTags->"M50.7.3"],

Cell[TextData[{
  "If there is more than one solution in your output from ",
  StyleBox["Solve", "MR"],
  ", the reason for giving solutions as lists of rules becomes apparent."
}], "Text",
  CellTags->"M50.7.3"],

Cell["\<\
The following example gives the intersection of a parabola and a unit circle.\
\
\>", "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol2 = 
      Solve[{y \[Equal] x\^2, x\^2 + y\^2 \[Equal] 2}, {x, y}]\)], "Input",
  CellTags->"M50.7.3"],

Cell[BoxData[
    \({{y \[Rule] \(-2\), 
        x \[Rule] \(-\[ImaginaryI]\)\ \@2}, {y \[Rule] \(-2\), 
        x \[Rule] \[ImaginaryI]\ \@2}, {y \[Rule] 1, 
        x \[Rule] \(-1\)}, {y \[Rule] 1, x \[Rule] 1}}\)], "Output",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell["\<\
Note that there are four solutions here, two of which are complex. We will \
work with the last two.\
\>", "Text",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Getting Information From Our Solution", "Subsection",
  CellTags->"M50.7.3"],

Cell["\<\
First we will get the points of intersection that satisfy our system of \
equations.\
\>", "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \({x, y} /. sol2[\([{3, 4}]\)]\)], "Input",
  CellTags->"M50.7.3"],

Cell[BoxData[
    \({{\(-1\), 1}, {1, 1}}\)], "Output",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell["\<\
We can also check to see that the solutions we have are correct.\
\>", "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \({y\  \[Equal] x\^2, x\^2 + \ y\^2 \[Equal] 2} /. sol2\)], "Input",
  CellTags->"M50.7.3"],

Cell[BoxData[
    \({{True, True}, {True, True}, {True, True}, {True, True}}\)], "Output",
  CellTags->"M50.7.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The FindRoot Function", "Subsection",
  CellTags->"M50.7.3"],

Cell[TextData[{
  "The ",
  StyleBox["FindRoot", "MR"],
  " function is used to find numerical solutions for equations that do not \
have algebraic solutions."
}], "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol3 = \ FindRoot[Sin[t] \[Equal] Exp[\(-t\^2\)], {t, 1}]\)], "Input",
  CellTags->"M50.7.3"],

Cell[BoxData[
    \({t \[Rule] 0.6805981743784542`}\)], "Output",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell["\<\
Here we use our solution to find the point of intersection of the two \
expressions.\
\>", "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \({t, Sin[t]} /. sol3\)], "Input",
  CellTags->"M50.7.3"],

Cell[BoxData[
    \({0.6805981743784542`, 0.6292580355734464`}\)], "Output",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell[TextData[{
  "These functions have other points of intersection, and ",
  StyleBox["FindRoot", "MR"],
  " uses Newton\[CloseCurlyQuote]s method for finding roots, so we need to \
try a different starting value to find other solutions."
}], "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol3 = \ FindRoot[Sin[t] \[Equal] Exp[\(-t\^2\)], {t, 4}]\)], "Input",
  CellTags->"M50.7.3"],

Cell[BoxData[
    \({t \[Rule] 3.1415409135861756`}\)], "Output",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({t, Sin[t]} /. sol3\)], "Input",
  CellTags->"M50.7.3"],

Cell[BoxData[
    \({3.1415409135861756`, 0.000051740003594555076`}\)], "Output",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell[BoxData[
    \(Clear[sol3]\)], "Input",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindMinimum", "Subsection",
  CellTags->"M50.7.3"],

Cell[TextData[{
  "Another function that gives numerical answers is ",
  StyleBox["FindMinimum", "MR"],
  ". We use it here, to find a minimal value for a cubic polynomial. There is \
an error message generated here, but it is just a warning that the answer \
should be checked."
}], "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol4 = FindMinimum[\(-15\) + 23\ x - 9\ x\^2 + x\^3, {x, 4}]\)], "Input",\

  CellTags->"M50.7.3"],

Cell[BoxData[
    RowBox[{\(FindMinimum::"lstol"\), \(\(:\)\(\ \)\), "\<\"The line search \
decreased the step size to within tolerance specified by AccuracyGoal and \
PrecisionGoal but was unable to find a sufficient decrease in the function.  \
You may need more than \\!\\(MachinePrecision\\) digits of working precision \
to meet these tolerances. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"FindMinimum::lstol\\\"]\\)\"\>"}]], "Message",
  CellTags->"M50.7.3"],

Cell[BoxData[
    \({\(-3.0792014356780157`\), {x \[Rule] 4.1547005248964055`}}\)], "Output",\

  CellTags->"M50.7.3"]
}, Open  ]],

Cell["\<\
Note that the first part of the answer is the minimal value of the function, \
while the second gives the location of the minimum.\
\>", "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \({x, \(-15\) + 23\ x - 9\ x\^2 + x\^3} /. sol4[\([2]\)]\)], "Input",
  CellTags->"M50.7.3"],

Cell[BoxData[
    \({4.1547005248964055`, \(-3.0792014356780157`\)}\)], "Output",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell[BoxData[
    \(Clear[sol4]\)], "Input",
  CellTags->"M50.7.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining Functions from Rules", "Section",
  CellTags->"M50.7.4"],

Cell[CellGroupData[{

Cell["Drawing a Circle", "Subsection",
  CellTags->"M50.7.4"],

Cell[TextData[{
  "If we want to plot a circle in Cartesian coordinates, we need two \
functions. These functions are easily found using ",
  StyleBox["Solve", "MR"],
  "."
}], "Text",
  CellTags->"M50.7.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol5 = 
      Solve[\((x - 3)\)\^2 + \ \((y + 1)\)\^2 \[Equal] 4, y]\)], "Input",
  CellTags->"M50.7.4"],

Cell[BoxData[
    \({{y \[Rule] \(-1\) - \@\(\(-5\) + 6\ x - x\^2\)}, {y \[Rule] \(-1\) + \
\@\(\(-5\) + 6\ x - x\^2\)}}\)], "Output",
  CellTags->"M50.7.4"]
}, Open  ]],

Cell[TextData[{
  "We now use this solution to define our functions. This is one place where \
we want to use ",
  StyleBox["Set", "MR"],
  " and not ",
  StyleBox["SetDelayed", "MR"],
  "."
}], "Text",
  CellTags->"M50.7.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fUpper[x_]\  = \ y /. sol5[\([2]\)]\)], "Input",
  CellTags->"M50.7.4"],

Cell[BoxData[
    \(\(-1\) + \@\(\(-5\) + 6\ x - x\^2\)\)], "Output",
  CellTags->"M50.7.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fLower[x_]\  = \ y /. sol5[\([1]\)]\)], "Input",
  CellTags->"M50.7.4"],

Cell[BoxData[
    \(\(-1\) - \@\(\(-5\) + 6\ x - x\^2\)\)], "Output",
  CellTags->"M50.7.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using Our Functions", "Subsection",
  CellTags->"M50.7.4"],

Cell[TextData[{
  "These functions work like any other in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and make it possible to plot our circle."
}], "Text",
  CellTags->"M50.7.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{fUpper[x], fLower[x]}, {x, 1, 5}]\)], "Input",
  CellTags->"M50.7.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 0.456168 0.147151 [
[.2619 .44367 -3 -9 ]
[.2619 .44367 3 0 ]
[.5 .44367 -3 -9 ]
[.5 .44367 3 0 ]
[.7381 .44367 -3 -9 ]
[.7381 .44367 3 0 ]
[.97619 .44367 -3 -9 ]
[.97619 .44367 3 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -12 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .45617 m
.2619 .46242 L
s
[(2)] .2619 .44367 0 1 Mshowa
.5 .45617 m
.5 .46242 L
s
[(3)] .5 .44367 0 1 Mshowa
.7381 .45617 m
.7381 .46242 L
s
[(4)] .7381 .44367 0 1 Mshowa
.97619 .45617 m
.97619 .46242 L
s
[(5)] .97619 .44367 0 1 Mshowa
.125 Mabswid
.07143 .45617 m
.07143 .45992 L
s
.11905 .45617 m
.11905 .45992 L
s
.16667 .45617 m
.16667 .45992 L
s
.21429 .45617 m
.21429 .45992 L
s
.30952 .45617 m
.30952 .45992 L
s
.35714 .45617 m
.35714 .45992 L
s
.40476 .45617 m
.40476 .45992 L
s
.45238 .45617 m
.45238 .45992 L
s
.54762 .45617 m
.54762 .45992 L
s
.59524 .45617 m
.59524 .45992 L
s
.64286 .45617 m
.64286 .45992 L
s
.69048 .45617 m
.69048 .45992 L
s
.78571 .45617 m
.78571 .45992 L
s
.83333 .45617 m
.83333 .45992 L
s
.88095 .45617 m
.88095 .45992 L
s
.92857 .45617 m
.92857 .45992 L
s
.25 Mabswid
0 .45617 m
1 .45617 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-3)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-2)] .01131 .16187 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-1)] .01131 .30902 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30914 m
.02499 .32968 L
.02605 .33756 L
.02846 .35003 L
.03279 .36589 L
.03784 .37993 L
.04262 .39091 L
.06244 .42514 L
.08265 .45073 L
.10458 .473 L
.14545 .50548 L
.1848 .52962 L
.22263 .54824 L
.26292 .56425 L
.30169 .57658 L
.34292 .58685 L
.36351 .59097 L
.38262 .59424 L
.40229 .59706 L
.42082 .59922 L
.44134 .60108 L
.45995 .60228 L
.46971 .60272 L
.47505 .60291 L
.48003 .60306 L
.48428 .60316 L
.48883 .60324 L
.49143 .60327 L
.49271 .60328 L
.49389 .60329 L
.49494 .6033 L
.4961 .60331 L
.49726 .60331 L
.4985 .60332 L
.49971 .60332 L
.50085 .60332 L
.50209 .60332 L
.50278 .60331 L
.50341 .60331 L
.50469 .6033 L
.50608 .60329 L
.50859 .60327 L
.51093 .60324 L
.51341 .6032 L
.51785 .60311 L
.52298 .60298 L
.52778 .60282 L
.5387 .60235 L
.54911 .60175 L
.55899 .60105 L
Mistroke
.57753 .59939 L
.59737 .5971 L
.61577 .59449 L
.65495 .5873 L
.69659 .57707 L
.73671 .56438 L
.77531 .54915 L
.81636 .52898 L
.8559 .50454 L
.89393 .47437 L
.91511 .45322 L
.9344 .42957 L
.944 .41539 L
.95442 .39698 L
.9592 .38693 L
.96427 .37446 L
.9686 .36137 L
.97089 .3528 L
.97336 .34103 L
.97408 .33667 L
.97484 .33117 L
.97549 .32503 L
.97619 .30914 L
Mfstroke
.02381 .3089 m
.02499 .28835 L
.02605 .28047 L
.02846 .268 L
.03279 .25214 L
.03784 .2381 L
.04262 .22712 L
.06244 .19289 L
.08265 .16731 L
.10458 .14503 L
.14545 .11255 L
.1848 .08842 L
.22263 .06979 L
.26292 .05378 L
.30169 .04145 L
.34292 .03119 L
.36351 .02706 L
.38262 .0238 L
.40229 .02098 L
.42082 .01881 L
.44134 .01696 L
.45995 .01576 L
.46971 .01531 L
.47505 .01512 L
.48003 .01497 L
.48428 .01488 L
.48883 .0148 L
.49143 .01476 L
.49271 .01475 L
.49389 .01474 L
.49494 .01473 L
.4961 .01472 L
.49726 .01472 L
.4985 .01472 L
.49971 .01472 L
.50085 .01472 L
.50209 .01472 L
.50278 .01472 L
.50341 .01472 L
.50469 .01473 L
.50608 .01474 L
.50859 .01476 L
.51093 .01479 L
.51341 .01483 L
.51785 .01492 L
.52298 .01506 L
.52778 .01522 L
.5387 .01569 L
.54911 .01628 L
.55899 .01698 L
Mistroke
.57753 .01864 L
.59737 .02093 L
.61577 .02355 L
.65495 .03073 L
.69659 .04096 L
.73671 .05365 L
.77531 .06889 L
.81636 .08905 L
.8559 .11349 L
.89393 .14367 L
.91511 .16482 L
.9344 .18846 L
.944 .20265 L
.95442 .22106 L
.9592 .23111 L
.96427 .24358 L
.9686 .25666 L
.97089 .26524 L
.97336 .277 L
.97408 .28136 L
.97484 .28687 L
.97549 .29301 L
.97619 .3089 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{224, 138.438},
  ImageMargins->{{52, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005@0000cb000`400?l00000o`00003ooooooomA
ooooo`00oooooomAooooo`00oooooomAooooo`00oooooomAooooo`005_ooool00ol0003ooooooooo
o`3oooooocSooooo000Fooooo`03o`000?oooooooooo0?oooooo>?ooool000[ooooo00KoZJVYob4Q
8Ol0003o0000oeEEEOo^k^h6ooooo`03o`000?oooooooooo0?oooooo>?ooool000[ooooo00Ko410@
ojVYZOooooooooooogMgMolb<S86ooooo`03o`000?oooooooooo0?oooooo>?ooool000oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooocSooooo00000ooooooo0000o`000005
o`0000Kooooo00?oMgMgob4Q8Oooool01Oooool3o`0008Gooooo8ol0002?ooooo`003?ooool01?lQ
8B7o0000o`000?nj^[X6ooooo`03o`000?oooooooooo07Wooooo3?l0000Sooooo`[o0000QOooool0
00gooooo00?ok^k^ogMgMolb<S801_ooool00ol0003oooooooooo`1cooooo`Ko0000>Oooool6o`00
07oooooo000?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0KOooool6o`0004Go
oooo1_l0001iooooo`002_ooool01_lQ8B7oQhN7ooooooooooooIVIVoc8b<PKooooo00?o0000oooo
ooooool0I_ooool7o`00057ooooo1ol0001booooo`002_ooool01_nj^[[oA4A4o`000?l0003oA4A4
onk^kPKooooo00?o0000ooooooooool0HOooool5o`0005oooooo1Ol0001]ooooo`005_ooool00ol0
003oooooooooo`1Looooo`Go0000JOooool5o`0006Sooooo000Fooooo`03o`000?oooooooooo05So
oooo1?l0001cooooo`Co0000I?ooool001Kooooo00?o0000ooooooooool0E?ooool4o`0007_ooooo
1?l0001Pooooo`005_ooool2o`0005;ooooo0ol00023ooooo`?o0000GOooool001Kooooo00?o0000
ooooooooool0C_ooool3o`0008Wooooo0ol0001Jooooo`005_ooool00ol0003oooooooooo`1;oooo
o`?o0000Soooool3o`0005Oooooo000Fooooo`03o`000?oooooooooo04Sooooo0ol0002Eooooo`?o
0000E?ooool001Kooooo00?o0000ooooooooool0AOooool3o`0009_ooooo0ol0001Aooooo`005_oo
ool00ol0003oooooooooo`12ooooo`?o0000XOooool2o`0004oooooo000Fooooo`03o`000?oooooo
oooo043ooooo0_l0002Vooooo`;o0000COooool001Kooooo00?o0000ooooooooool0?Oooool3o`00
0:[ooooo0ol0001:ooooo`005_ooool00ol0003oooooooooo`0kooooo`;o0000/?ooool2o`0004So
oooo000Fooooo`03o`000?oooooooooo03Wooooo0_l0002dooooo`;o0000A_ooool001Kooooo0_l0
000hooooo`;o0000^?ooool2o`0004Cooooo000Fooooo`03o`000?oooooooooo03Gooooo0_l0002l
ooooo`;o0000@_ooool001Kooooo00?o0000ooooooooool0<oooool2o`000<3ooooo0_l00010oooo
o`005_ooool00ol0003oooooooooo`0aooooo`;o0000a?ooool2o`0003kooooo000Fooooo`03o`00
0?oooooooooo02oooooo0_l00038ooooo`;o0000??ooool001Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`3:ooooo`;o0000>_ooool001Kooooo00?o0000ooooooooool0;?ooool2
o`000<oooooo0_l0000hooooo`005_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
0=7ooooo00?o0000ooooooooool0=Oooool001Kooooo00?o0000ooooooooool0:Oooool2o`000=Go
oooo0_l0000eooooo`005_ooool2o`0002Wooooo00?o0000ooooooooool0eoooool2o`0003?ooooo
000Fooooo`03o`000?oooooooooo02Kooooo0_l0003Looooo`03o`000?oooooooooo033ooooo000F
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0gOooool2o`00033ooooo000Foooo
o`03o`000?oooooooooo02?ooooo0_l0003Rooooo`;o0000;_ooool001Kooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`3Tooooo`03o`000?oooooooooo02_ooooo000Fooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0i_ooool00ol0003oooooooooo`0Zooooo`005_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0>Sooooo00?o0000ooooooooool0:Ooo
ool001Kooooo00?o0000ooooooooool07_ooool2o`000>cooooo00?o0000ooooooooool0:?ooool0
01Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`3]ooooo`;o0000:?ooool001Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`3`ooooo`03o`000?oooooooooo02Go
oooo000Fooooo`;o00006oooool2o`000?Cooooo00?o0000ooooooooool09?ooool001Kooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`3eooooo`03o`000?oooooooooo02?ooooo000F
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0moooool00ol0003oooooooooo`0R
ooooo`005_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0?Wooooo00?o0000oooo
ooooool08Oooool001Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3kooooo`03
o`000?oooooooooo023ooooo000Fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
oOooool00ol0003oooooooooo`0Oooooo`005_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo0?oooooo00?o0000ooooooooool07_ooool000[ooooo1_l00006ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0ooooool2ooooo`03o`000?oooooooooo01gooooo000:oooo
o`03oiRHV?l0003oc<c<00;ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo0?oooooo1?ooool00ol0003oooooooooo`0Looooo`002oooool00onHV9So
0000olc<c008ooooo`?o00004Oooool00ol0003oooooooooo`3oooooo`Kooooo00?o0000oooooooo
ool06oooool00003ooooool0003o000000Go00001?ooool00onYZJWo410@olc<c007ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0ooooool8ooooo`03o`000?oooooooooo01[ooooo
000=ooooo`03olc<c?l@413oc<c<00Kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`3oooooo`Wooooo00?o0000ooooooooool06_ooool000kooooo00?oZJVYoc8b<_ooool01Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?oooooo2_ooool00ol0003oooooooooo`0I
ooooo`003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0ooooool<ooooo`03o`000?oooooooooo01Sooooo000:ooooo`06o`000?n7QhOok^k^oooo
oomgMgOo<S8b1_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?oooooo3_ooool0
0ol0003oooooooooo`0Gooooo`002_ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPKooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05ooo
ool001Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000
ooooooooool05_ooool001Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3ooooo
oa;ooooo00?o0000ooooooooool05Oooool001Kooooo0_l0000;ooooo`03o`000?oooooooooo0?oo
oooo5?ooool00ol0003oooooooooo`0Dooooo`005_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0?oooooo5_ooool00ol0003oooooooooo`0Cooooo`005_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo0?oooooo5oooool00ol0003oooooooooo`0Booooo`005_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo6Oooool00ol0003oooooooooo`0A
ooooo`005_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0
003oooooooooo`0@ooooo`005_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo6oooool00ol0003oooooooooo`0@ooooo`005_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo7?ooool00ol0003oooooooooo`0?ooooo`005_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo7Oooool00ol0003oooooooooo`0?ooooo`005_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo7oooool00ol0003oooooooooo`0>
ooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo7oooool00ol0
003oooooooooo`0>ooooo`005_ooool2o`0000Gooooo00?o0000ooooooooool0oooooolQooooo`03
o`000?oooooooooo00gooooo000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolQooooo`03o`000?oooooooooo00gooooo000Fooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolSooooo`03o`000?oooooooooo00cooooo000Fooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0oooooolSooooo`03o`000?oooooooooo00cooooo000Foooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolTooooo`03o`000?oooooooooo
00cooooo000Fooooo`05o`000?ooooooooooooooool00000oooooolXooooo`03o`000?oooooooooo
00_ooooo000Fooooo`05o`000?ooooooooooooooool00000oooooolXooooo`03o`000?oooooooooo
00_ooooo000Fooooo`04o`000?ooooooooooo`000?oooooo:_ooool00ol0003oooooooooo`0:oooo
o`005_ooool01?l0003oooooooooool0003oooooob[ooooo00?o0000ooooooooool02_ooool001Ko
oooo0_l000000ooooooo0000ooooo`3oooooobWooooo00?o0000ooooooooool02_ooool001Kooooo
00?o0000ooooool00000ooooool/ooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oo
oooo00000?oooooo;?ooool00ol0003oooooooooo`09ooooo`005_ooool00ol0003oooooo`00003o
ooooobcooooo00?o0000ooooooooool02Oooool001Kooooo0_l0003oooooobkooooo00?o0000oooo
ooooool02?ooool001Kooooo0_l0003oooooobkooooo00?o0000ooooooooool02?ooool001Kooooo
0_l0003oooooobkooooo00?o0000ooooooooool02?ooool001Kooooo0_l0003oooooobkooooo00?o
0000ooooooooool02?ooool001Kooooo0_l0003ooooooboooooo00?o0000ooooooooool01oooool0
01Kooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo00Oooooo000Fooooo`;o
0000ooooool_ooooo`03o`000?oooooooooo00Oooooo000Fooooo`03o`000?oooooooooo0?oooooo
;_ooool00ol0003oooooooooo`07ooooo`005_ooool00ol0003oooooooooo`3oooooobkooooo00?o
0000ooooooooool01oooool001Kooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooo
oooo00Oooooo000Fooooo`03o`000?oooooooooo0?oooooo;oooool00ol0003oooooooooo`06oooo
o`005_ooool00ol0003oooooooooo`3ooooooboooooo00?o0000ooooooooool01_ooool001Kooooo
00?o0000ooooooooool0ooooool_ooooo`03o`000?oooooooooo00Kooooo000;ooooo`Co000000?o
410@ooooooooool01?ooool00ol0003oooooooooo`3ooooooboooooo00?o0000ooooooooool01_oo
ool000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooboooooo00?o0000
ooooooooool01_ooool000gooooo00?o0000ooooooooool01_ooool3o`000?oooooo;oooool00ol0
003oooooooooo`06ooooo`0000?oooooo`000?l000001Ol00005ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0ooooool_ooooo`03o`000?oooooooooo00Kooooo000=ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0ooooool_ooooo`03o`000?oooooooooo00Kooooo
000=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool_ooooo`03o`000?oo
oooooooo00Kooooo000=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool_
ooooo`03o`000?oooooooooo00Kooooo000;ooooo`03o`000?m4A4Co000000Sooooo00?o0000oooo
ooooool0ooooool_ooooo`03o`000?oooooooooo00Kooooo000;ooooo`03olc<c?mEEEGo000000So
oooo00?o0000ooooooooool0ooooool_ooooo`03o`000?oooooooooo00Kooooo000Fooooo`03o`00
0?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`07ooooo`005_ooool00ol0003ooooooooo
o`3oooooobkooooo00?o0000ooooooooool01oooool001Kooooo00?o0000ooooooooool0ooooool^
ooooo`03o`000?oooooooooo00Oooooo000Fooooo`;o0000ooooool_ooooo`03o`000?oooooooooo
00Oooooo000Fooooo`03o`000?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`07ooooo`00
5_ooool2o`000?oooooo;oooool00ol0003oooooooooo`07ooooo`005_ooool2o`000?oooooo;_oo
ool00ol0003oooooooooo`08ooooo`005_ooool2o`000?oooooo;_ooool00ol0003oooooooooo`08
ooooo`005_ooool2o`000?oooooo;_ooool00ol0003oooooooooo`08ooooo`005_ooool00ol0003o
ooooo`00003oooooobcooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000ooooool00000
ooooool/ooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooo00000?oooooo;?oo
ool00ol0003oooooooooo`09ooooo`005_ooool3o`000?oooooo;?ooool00ol0003oooooooooo`09
ooooo`005_ooool01?l0003oooooooooool0003oooooob[ooooo00?o0000ooooooooool02_ooool0
01Kooooo00Co0000oooooooooooo0000oooooolZooooo`03o`000?oooooooooo00[ooooo000Foooo
o`04o`000?ooooooooooo`000?oooooo:_ooool00ol0003oooooooooo`0:ooooo`005_ooool01Ol0
003ooooooooooooooooo00000?oooooo:?ooool00ol0003oooooooooo`0;ooooo`005_ooool01Ol0
003ooooooooooooooooo00000?oooooo:?ooool00ol0003oooooooooo`0;ooooo`005_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo9?ooool00ol0003oooooooooo`0<oooo
o`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo8oooool00ol0003o
ooooooooo`0<ooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
8_ooool00ol0003oooooooooo`0=ooooo`005_ooool2o`0000Gooooo00?o0000ooooooooool0oooo
oolQooooo`03o`000?oooooooooo00gooooo000Fooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooolQooooo`03o`000?oooooooooo00gooooo000Fooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooolOooooo`03o`000?oooooooooo00kooooo000Fooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolOooooo`03o`000?oooooooooo00ko
oooo000Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolMooooo`03o`00
0?oooooooooo00oooooo000Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>ooo
ool6o`0004Oooooo00KoZJVYob4Q8Ol0003o0000oeEEEOo^k^i9ooooo`;o000000?o410@oooooooo
ool0?oooool00ol0003oooooooooo`02ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1oooool0
01Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03oiRHV?l0003oc<c<
00;ooooo00?o410@ooooooooool0AOooool01_l@413oZJVYooooooooooooMgMgoc8b<T[ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`03ooooo`06oa0@4?n7QhOooooooooooomgMgOo
A4A41oooool001Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0kooooo`03oiRH
V?l0003oc<c<04kooooo00?o0000ooooooooool0A?ooool6o`00043ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`05ooooo`005_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03cooooo00?oZJVYoa0@4?o<c<`0C?ooool00omgMgOo8B4Qooooo`15ooooo`05ofIVI_nY
ZJWoooooooooool00000@?ooool00ol0003oooooooooo`08ooooo`03onk^k_l0003ooooo00Kooooo
000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0??ooool00oo<c<co410@olc<
c019ooooo`04ob4Q8Ol0003o0000okZj^TKooooo00Gok^k^ob4Q8Oo^k^koooooo`00000oooooo`03
o`000?oooooooooo00Gooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH7ooooo`005_ooool2o`00
00[ooooo00?o0000ooooooooool0?Oooool00onYZJWo<S8booooo`19ooooo`03onk^k_mgMgOo<S8b
04Oooooo00CoZJVYofIVI_oooooo0000?_ooool00ol0003oooooooooo`06ooooo`05o`000?lQ8B7o
0000o`000?mVIVH02?ooool001Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0A_ooool00om4A4Coc<c<o`00000m
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool001Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0gooooo`06o`000?n7QhOok^k^oooooomgMgOo<S8bAooo
ool01_lQ8B7oQhN7ooooooooooooIVIVoc8b<TSooooo00?ogMgModA4A?l00000?Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00[ooooo000Fooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0=oooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kTOooooo00Ko^[ZjodA4
A?l0003o0000odA4A?o^k^i9ooooo`03ohN7Qol0003ooooo03_ooooo00?o0000ooooooooool02?oo
ool5o`0000Sooooo000Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0ooooool@
ooooo`03o`000?oooooooooo01Kooooo000Fooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0ooooool>ooooo`03o`000?oooooooooo01Oooooo000Fooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0ooooool=ooooo`03o`000?oooooooooo01Sooooo000Fooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0ooooool;ooooo`03o`000?oooooooooo01Wooooo
000Fooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0ooooool9ooooo`03o`000?oo
oooooooo01[ooooo000>oooooooo0000@ol0000001Kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`06ooooo`005_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Ko
oooo000Fooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0ooooool1ooooo`03o`00
0?oooooooooo01kooooo000Fooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0o_oo
ool00ol0003oooooooooo`0Oooooo`005_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo0?cooooo00?o0000ooooooooool08?ooool001Kooooo00?o0000ooooooooool05_ooool2o`00
0?[ooooo0_l0000Sooooo`005_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0?Ko
oooo00?o0000ooooooooool08oooool001Kooooo00?o0000ooooooooool06Oooool2o`000?Gooooo
00?o0000ooooooooool09?ooool001Kooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`3aooooo`03o`000?oooooooooo02Gooooo000Fooooo`;o00007Oooool00ol0003oooooooooo`3_
ooooo`03o`000?oooooooooo02Kooooo000Fooooo`03o`000?oooooooooo01gooooo0_l0003]oooo
o`;o0000:Oooool001Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`3Yooooo`03
o`000?oooooooooo02Wooooo000Fooooo`03o`000?oooooooooo023ooooo0_l0003Xooooo`03o`00
0?oooooooooo02[ooooo000Fooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0i?oo
ool00ol0003oooooooooo`0[ooooo`005_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo0>;ooooo00?o0000ooooooooool0;?ooool001Kooooo00?o0000ooooooooool09?ooool2o`00
0>3ooooo0_l0000_ooooo`005_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0=co
oooo00?o0000ooooooooool0;oooool001Kooooo00?o0000ooooooooool09oooool2o`000=[ooooo
0_l0000booooo`005_ooool2o`0002[ooooo00?o0000ooooooooool0e_ooool00ol0003ooooooooo
o`0booooo`005_ooool00ol0003oooooooooo`0Zooooo`;o0000e?ooool2o`0003Gooooo000Foooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0d?ooool00ol0003oooooooooo`0eoooo
o`005_ooool00ol0003oooooooooo`0]ooooo`;o0000c_ooool2o`0003Sooooo000Fooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0b_ooool00ol0003oooooooooo`0hooooo`005_oo
ool00ol0003oooooooooo`0`ooooo`;o0000b?ooool2o`0003_ooooo000Fooooo`03o`000?oooooo
oooo03;ooooo0_l00033ooooo`?o0000?Oooool001Kooooo00?o0000ooooooooool0=?ooool2o`00
0;oooooo0_l00010ooooo`005_ooool00ol0003oooooooooo`0fooooo`;o0000^oooool2o`0004;o
oooo000Fooooo`03o`000?oooooooooo03Sooooo0_l0002fooooo`?o0000A?ooool001Kooooo0_l0
000kooooo`;o0000/_ooool2o`0004Oooooo000Fooooo`03o`000?oooooooooo03cooooo0_l0002^
ooooo`;o0000BOooool001Kooooo00?o0000ooooooooool0?_ooool3o`000:Sooooo0ol0001;oooo
o`005_ooool00ol0003oooooooooo`11ooooo`?o0000Xoooool2o`0004kooooo000Fooooo`03o`00
0?oooooooooo04Cooooo0_l0002Oooooo`;o0000D?ooool001Kooooo00?o0000ooooooooool0A_oo
ool3o`0009Wooooo0ol0001Booooo`005_ooool00ol0003oooooooooo`19ooooo`?o0000Toooool3
o`0005Gooooo000Fooooo`03o`000?oooooooooo04cooooo0ol0002=ooooo`?o0000F?ooool001Ko
oooo00?o0000ooooooooool0Coooool3o`0008Oooooo0ol0001Kooooo`005_ooool2o`0005?ooooo
0ol00021ooooo`?o0000G_ooool001Kooooo00?o0000ooooooooool0EOooool4o`0007Wooooo1?l0
001Qooooo`005_ooool00ol0003oooooooooo`1Iooooo`Go0000Koooool5o`0006Gooooo000Foooo
o`03o`000?oooooooooo05kooooo1?l0001Wooooo`Co0000J_ooool001Kooooo00?o0000oooooooo
ool0H_ooool4o`0005oooooo1?l0001^ooooo`005_ooool00ol0003oooooooooo`1Vooooo`?o0000
Eoooool5o`0007;ooooo000Fooooo`03o`000?oooooooooo06Wooooo1Ol0001>ooooo`Co0000Mooo
ool000_ooooo1?l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo06kooooo1_l00013
ooooo`Go0000Noooool000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1doooo
o`co0000:oooool<o`00083ooooo000=ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0P?oooolBo`0000Sooooo4Ol0002<ooooo`003Oooool00ol0003oooooooooo`06ooooo`?o0000
T_ooool8o`0009gooooo000=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolhooooo`003Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo>?ooool0
00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooocSooooo000;ooooo`03
o`000?m4A4Co000000Sooooo00?o0000ooooooooool0oooooolhooooo`002oooool00oo<c<coEEEE
o`00003ooooood?ooooo003ooooooe7ooooo003ooooooe7ooooo003ooooooe7ooooo0000\
\>"],
  ImageRangeCache->{{{99.875, 255.625}, {181.313, 85.4375}} -> {-2.10387, \
0.709966, 0.019727, 0.031919}},
  CellTags->"M50.7.4"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->"M50.7.4"]
}, Open  ]],

Cell["\<\
Okay, so we have a squashed circle; we will look at how we might correct this \
in the exercises.\
\>", "Text",
  CellTags->"M50.7.4"],

Cell[BoxData[
    \(Clear[sol5]\)], "Input",
  CellTags->"M50.7.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise: Rules from Solve", "Section",
  CounterAssignments->{{"Chapter", 7}, {"ExerciseNumber", 1}}],

Cell["\<\
Define a function that describes the upper half of the circle given by:\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`x\^2 + y\^2 = 7\)]]], "DisplayFormula"],

Cell["\<\
Define a function that describes the left half of the circle.\
\>", "Exercise"],

Cell["\<\
Here is the equation of an ellipse. Find a function for the upper half of the \
ellipse and plot it. Make sure you show the ellipse with correct proportions \
so we can be sure it is not a circle. How would you plot the complete \
ellipse?\
\>", "Exercise"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\((x - 3)\)\^2\/16 + \((y - 1)\)\^2\/9 = 
      1\)]]], "DisplayFormula"],

Cell[TextData[{
  "Here is a rotated ellipse. Find the minimum and maximum values for ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " on the ellipse."
}], "Exercise"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`3  x\^2 + 2  x\ y + 3  y\^2 = 8\)]]], "DisplayFormula"],

Cell["\<\
Find functions to plot the ellipse, and use the information from the first \
part of the exercise to create a plot without generating any errors having to \
do with real numbers.\
\>", "Exercise"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Change of Variables", "Section",
  CellTags->"M50.7.5"],

Cell[CellGroupData[{

Cell["Polar Coordinates", "Subsection",
  CellTags->"M50.7.5"],

Cell["\<\
We can use these same ideas to convert to polar or other coordinate \
systems.\
\>", "Text",
  CellTags->"M50.7.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fCirc[
        t_] = {x, \@\(4\  - \ x\^2\)} /. {x \[RuleDelayed] \ 
            2\ Cos[t]}\)], "Input",
  CellTags->"M50.7.5"],

Cell[BoxData[
    \({2\ Cos[t], \@\(4 - 4\ Cos[t]\^2\)}\)], "Output",
  CellTags->"M50.7.5"]
}, Open  ]],

Cell[TextData[{
  "We can use ",
  StyleBox["Simplify", "MR"],
  " to get the values we expect here."
}], "Text",
  CellTags->"M50.7.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[fCirc[t], t \[Element] \ Reals]\)], "Input",
  CellTags->"M50.7.5"],

Cell[BoxData[
    \({2\ Cos[t], 2\ Abs[Sin[t]]}\)], "Output",
  CellTags->"M50.7.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ParametricPlot[fCirc[t], {t, 0, \ 2\ \[Pi]}]\)], "Input",
  CellTags->"M50.7.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499998 0.238096 0.0147151 0.294302 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.73809 .00222 -3 -9 ]
[.73809 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.4875 .16187 -18 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-2)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-1)] .2619 .00222 0 1 Mshowa
.73809 .01472 m
.73809 .02097 L
s
[(1)] .73809 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11904 .01472 m
.11904 .01847 L
s
.16666 .01472 m
.16666 .01847 L
s
.21428 .01472 m
.21428 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .16187 m
.50625 .16187 L
s
[(0.5)] .4875 .16187 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(1.5)] .4875 .45617 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(2)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.97619 .01472 m
.97618 .01928 L
.97614 .02343 L
.97606 .02823 L
.97597 .03276 L
.97572 .04081 L
.97536 .04955 L
.97483 .05917 L
.97414 .06934 L
.97253 .08756 L
.97039 .10629 L
.96795 .12376 L
.96081 .16313 L
.95129 .20256 L
.94065 .23785 L
.91017 .31373 L
.87673 .37472 L
.83352 .43483 L
.78673 .48466 L
.73155 .52905 L
.7028 .54727 L
.67066 .56422 L
.64214 .57649 L
.61017 .58735 L
.5949 .59151 L
.57842 .59528 L
.5641 .59796 L
.54845 .60026 L
.53926 .60132 L
.53074 .60209 L
.52259 .60266 L
.51847 .60288 L
.51392 .60307 L
.50983 .60319 L
.50609 .60327 L
.50197 .60331 L
.4999 .60332 L
.49764 .60331 L
.49381 .60327 L
.48973 .60318 L
.48587 .60306 L
.48236 .60292 L
.47512 .60251 L
.46715 .60192 L
.45109 .60021 L
.43626 .59802 L
.42244 .59546 L
.39155 .58785 L
.3589 .57689 L
.32884 .56398 L
Mistroke
.29695 .54713 L
.24178 .50926 L
.19207 .4637 L
.14489 .40687 L
.10369 .34104 L
.07215 .27312 L
.05955 .23845 L
.04825 .20086 L
.03956 .16486 L
.03328 .13155 L
.02828 .09517 L
.02631 .07502 L
.0256 .06574 L
.02497 .05588 L
.02454 .04746 L
.02436 .04298 L
.02418 .03816 L
.02406 .03375 L
.02396 .0297 L
.02389 .02583 L
.02384 .02177 L
.02381 .01732 L
.02381 .01685 L
.02384 .02133 L
.02388 .02539 L
.02397 .03018 L
.0241 .03536 L
.02443 .04475 L
.02486 .05392 L
.02546 .06375 L
.02688 .08147 L
.02913 .10245 L
.03171 .1215 L
.03905 .16247 L
.04818 .20062 L
.07174 .27208 L
.10012 .33433 L
.13486 .39254 L
.17963 .45019 L
.22702 .497 L
.28309 .53871 L
.3408 .56945 L
.37094 .58129 L
.38817 .58686 L
.40459 .59138 L
.41978 .59491 L
.43635 .59804 L
.45149 .60026 L
.4655 .60177 L
.47334 .6024 L
Mistroke
.48068 .60283 L
.48489 .60302 L
.48874 .60315 L
.49087 .60321 L
.49319 .60326 L
.49538 .60329 L
.49741 .60331 L
.49954 .60332 L
.50184 .60331 L
.50401 .6033 L
.50601 .60327 L
.5098 .60319 L
.5138 .60307 L
.5181 .60289 L
.52212 .60268 L
.53124 .60205 L
.5394 .6013 L
.54693 .60045 L
.56393 .59799 L
.57886 .59519 L
.59461 .59158 L
.62161 .5838 L
.65091 .57298 L
.70722 .54467 L
.76408 .50452 L
.81405 .45717 L
.86069 .39902 L
.89804 .33781 L
.92672 .27595 L
.94037 .2387 L
.95129 .20255 L
.95954 .16899 L
.9665 .13289 L
.9707 .10386 L
.97256 .08726 L
.97395 .07169 L
.97494 .05736 L
.97559 .04425 L
.97585 .037 L
.97596 .03317 L
.97605 .0291 L
.97612 .02518 L
.97616 .02163 L
.97618 .01807 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{224, 138.438},
  ImageMargins->{{52, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005@0000cb000`400?l00000o`00003ooooooomA
ooooo`00oooooomAooooo`00oooooomAooooo`005Oooool6o`0004Gooooo1?l000000ol@413ooooo
ooooo`28ooooo`Co000000?o410@ooooooooool0@_ooool6o`0001;ooooo000Eooooo`03oiRHV?l0
003oc<c<00;ooooo00?o410@ooooooooool0AOooool00ol0003oooooooooo`2<ooooo`03o`000?oo
oooooooo04Cooooo00?oV9RHo`000?o<c<`00_ooool00ol@413oooooooooo`0@ooooo`005_ooool0
0onHV9So0000olc<c019ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0AOooool0
0onHV9So0000olc<c00Dooooo`003?ooool7o`0000Cooooo00?oZJVYoa0@4?o<c<`0??ooool7o`00
00Gooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`16ooooo`03ojVYZOl@413oc<c<
01?ooooo000Hooooo`03olc<c?l@413oc<c<04Oooooo00?o0000ooooooooool0S?ooool00ol0003o
ooooooooo`17ooooo`03olc<c?l@413oc<c<01;ooooo000Iooooo`03ojVYZOlb<S;ooooo04Kooooo
00?o0000ooooooooool0S?ooool00ol0003oooooooooo`18ooooo`03ojVYZOlb<S;ooooo017ooooo
000Jooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0S?ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo013ooooo000Eooooo`06o`000?n7QhOok^k^oooooomgMgOo<S8b
AOooool00ol0003oA4A4o`00002<ooooo`03o`000?m4A4Co000004Kooooo00Ko0000ohN7Qoo^k^ko
ooooogMgMolb<S8Booooo`005Oooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kTGooooo00?oc<c<
oeEEEOl00000S?ooool00oo<c<coEEEEo`000016ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^
4_ooool00?ooooooDOooool00:Sooooo00?o0000ooooooooool0YOooool00:Sooooo00?o0000oooo
ooooool0YOooool00:Sooooo00?o0000ooooooooool0YOooool00:Sooooo00?o0000ooooooooool0
YOooool000goooooool0000ho`0000cooooo000Dooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Booooo`005?ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo01;ooooo000Dooooo`03o`000?oooooooooo097ooooo00?o0000oooooooo
ool0T?ooool00ol0003oooooooooo`0Booooo`005?ooool00ol0003oooooooooo`2Aooooo`03o`00
0?oooooooooo093ooooo00?o0000ooooooooool04_ooool001Cooooo00?o0000ooooooooool0TOoo
ool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo01;ooooo000Dooooo`03o`000?oooooo
oooo097ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Booooo`005?ooool00ol0
003oooooooooo`2Aooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool04_ooool001Co
oooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo01;o
oooo000Dooooo`03o`000?oooooooooo097ooooo0_l0002Aooooo`03o`000?oooooooooo01;ooooo
000Dooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0T?ooool00ol0003ooooooooo
o`0Booooo`005?ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo093ooooo00?o0000
ooooooooool04_ooool001Cooooo0_l0002Booooo`03o`000?oooooooooo093ooooo00?o0000oooo
ooooool04_ooool001Cooooo0_l0002Booooo`03o`000?oooooooooo093ooooo00?o0000oooooooo
ool04_ooool001Gooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`2@ooooo`03o`00
0?oooooooooo01;ooooo000Eooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0T?oo
ool00ol0003oooooooooo`0Booooo`005Oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooo
oooo093ooooo00?o0000ooooooooool04_ooool001Gooooo00?o0000ooooooooool0T?ooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo01;ooooo000Eooooo`03o`000?oooooooooo093o
oooo0_l0002Aooooo`03o`000?oooooooooo01;ooooo000Eooooo`03o`000?oooooooooo093ooooo
00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Booooo`005Oooool00ol0003ooooooooo
o`2@ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool04_ooool001Gooooo00?o0000
ooooooooool0T?ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo01?ooooo000Eoooo
o`03o`000?oooooooooo093ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`0Coooo
o`005Oooool2o`00097ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`0Cooooo`00
5Oooool2o`00097ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`0Cooooo`005_oo
ool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool04ooo
ool001Kooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`2?ooooo`03o`000?oooooo
oooo01?ooooo000Fooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0Soooool00ol0
003oooooooooo`0Cooooo`005_ooool00ol0003oooooooooo`2?ooooo`;o0000T?ooool00ol0003o
ooooooooo`0Cooooo`005_ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo08oooooo
00?o0000ooooooooool04oooool001Kooooo00?o0000ooooooooool0Soooool00ol0003ooooooooo
o`2?ooooo`03o`000?oooooooooo01?ooooo000Gooooo`03o`000?oooooooooo08kooooo00?o0000
ooooooooool0S_ooool2o`0001Gooooo000Gooooo`03o`000?oooooooooo08kooooo00?o0000oooo
ooooool0S_ooool00ol0003oooooooooo`0Dooooo`005oooool00ol0003oooooooooo`2>ooooo`03
o`000?oooooooooo08kooooo00?o0000ooooooooool05?ooool001Oooooo00?o0000ooooooooool0
S_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo01Cooooo000Gooooo`03o`000?oo
oooooooo08kooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0Dooooo`005oooool0
0ol0003oooooooooo`2>ooooo`03o`000?oooooooooo08gooooo0_l0000Fooooo`005oooool2o`00
08oooooo0_l0002>ooooo`;o00005_ooool001Oooooo0_l0002?ooooo`03o`000?oooooooooo08go
oooo00?o0000ooooooooool05Oooool001Oooooo0_l0002?ooooo`03o`000?oooooooooo08gooooo
00?o0000ooooooooool05Oooool001Sooooo00?o0000ooooooooool0SOooool00ol0003ooooooooo
o`2=ooooo`03o`000?oooooooooo01Gooooo000Hooooo`03o`000?oooooooooo08gooooo00?o0000
ooooooooool0S?ooool2o`0001Oooooo000Hooooo`03o`000?oooooooooo08gooooo00?o0000oooo
ooooool0S?ooool2o`0001Oooooo000Hooooo`03o`000?oooooooooo073ooooo00Co^[Zjoa0@4?l0
003oMgMg1_ooool00omEEEGo0000oeEEE@04ooooo`06oiRHV?l@413o0000o`000?m4A4Cok^k^1_oo
ool00ol0003oooooooooo`2<ooooo`;o00005oooool001Sooooo0_l0001`ooooo`06olc<c?lb<S;o
k^k^onk^k_lQ8B7oZJVY1Oooool3o`0000Cooooo00Ko410@ohN7QoooooooooooogMgMom4A4@6oooo
o`03o`000?oooooooooo08cooooo00?o0000ooooooooool05_ooool001Wooooo00?o0000oooooooo
ool0K_ooool01_m4A4CoZJVYooooooooooooZJVYoc8b<PGooooo00?oEEEEo`000?mEEED02Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool05_ooool0
01Wooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00kooooo00?ok^k^o`000?ooool01Oooool3o`0008_ooooo0_l0000Hooooo`006Oooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01_l@413o
V9RHooooooooooooMgMgofIVIPKooooo00?o0000ooooooooool0Roooool2o`0001Sooooo000Ioooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:oooo
o`05o`000?lQ8B7o0000o`000?mVIVH01oooool00ol0003oooooooooo`2;ooooo`;o00006?ooool0
01Wooooo0_l0001_ooooo`06odA4A?nYZJWooooooooooonYZJWoA4A43?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool05oooool001[ooooo00?o0000
ooooooooool0KOooool01_o<c<co<S8bonk^k_o^k^ko<S8bolc<c0cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo01Oooooo000Jooooo`03o`000?oo
oooooooo06kooooo00Co^[Zjoa0@4?l@413oc<c<3Oooool5o`0000Oooooo00?o0000ooooooooool0
R_ooool2o`0001Wooooo000Jooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0R_oo
ool2o`0001Wooooo000Kooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0R_ooool0
0ol0003oooooooooo`0Hooooo`006oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo
08[ooooo00?o0000ooooooooool06?ooool001_ooooo00?o0000ooooooooool0R_ooool2o`0008_o
oooo00?o0000ooooooooool06?ooool001_ooooo00?o0000ooooooooool0R_ooool00ol0003ooooo
ooooo`29ooooo`;o00006_ooool001cooooo00?o0000ooooooooool0ROooool00ol0003ooooooooo
o`29ooooo`03o`000?oooooooooo01Wooooo000Looooo`03o`000?oooooooooo08Wooooo00?o0000
ooooooooool0ROooool00ol0003oooooooooo`0Iooooo`007?ooool00ol0003oooooooooo`29oooo
o`03o`000?oooooooooo08Wooooo00?o0000ooooooooool06Oooool001cooooo00?o0000oooooooo
ool0ROooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo01[ooooo000Mooooo`03o`00
0?oooooooooo08Sooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0Jooooo`007Ooo
ool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool06_oo
ool001gooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`27ooooo`03o`000?oooooo
oooo01_ooooo000Mooooo`;o0000ROooool2o`0008Sooooo00?o0000ooooooooool06oooool001ko
oooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo01_o
oooo000Nooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0Q_ooool00ol0003ooooo
ooooo`0Looooo`007_ooool2o`0008Sooooo00?o0000ooooooooool0Q_ooool00ol0003ooooooooo
o`0Looooo`007_ooool2o`0008Sooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0L
ooooo`007oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool07Oooool001oooooo0_l00027ooooo`03o`000?oooooooooo08Gooooo00?o0000oooooooo
ool07Oooool001oooooo0_l00027ooooo`03o`000?oooooooooo08Cooooo0_l0000Oooooo`008?oo
ool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool07_oo
ool0023ooooo0_l00026ooooo`;o0000QOooool00ol0003oooooooooo`0Nooooo`008?ooool2o`00
08Kooooo00?o0000ooooooooool0Poooool2o`00023ooooo000Qooooo`03o`000?oooooooooo08Co
oooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Oooooo`008Oooool2o`0008Gooooo
00?o0000ooooooooool0Poooool00ol0003oooooooooo`0Oooooo`008_ooool00ol0003ooooooooo
o`23ooooo`03o`000?oooooooooo08;ooooo0_l0000Qooooo`008_ooool00ol0003oooooooooo`23
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool08?ooool002;ooooo0_l00024oooo
o`03o`000?oooooooooo087ooooo0_l0000Rooooo`008oooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo087ooooo0_l0000Rooooo`008oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo087ooooo00?o0000ooooooooool08Oooool002Cooooo00?o0000ooooooooool0POoo
ool2o`00087ooooo0_l0000Sooooo`009?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo083ooooo00?o0000ooooooooool08_ooool002Gooooo00?o0000ooooooooool0P?ooool00ol0
003oooooooooo`20ooooo`03o`000?oooooooooo02;ooooo000Uooooo`03o`000?oooooooooo083o
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0Sooooo`009_ooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool08oooool002Kooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo02Cooooo000W
ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0T
ooooo`009oooool00ol0003oooooooooo`1cooooo`Co000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`1mooooo`;o00009_ooool002Sooooo00?o0000ooooooooool0M?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool09Oooool002Sooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`06ooooo`?o0000O?ooool2o`0002Oooooo
000Xooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1looooo`;o00009oooool002Wooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool09_ooool002Wooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07_ooooo0_l0000Xoooo
o`00:_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Noooool00ol0003oooooooooo`0Wooooo`00:_ooool00ol0003oooooooooo`1`ooooo`03o`00
0?m4A4Co000000Sooooo00?o0000ooooooooool0N_ooool2o`0002Wooooo000[ooooo`03o`000?oo
oooooooo06oooooo00?oc<c<oeEEEOl000002?ooool00ol0003oooooooooo`1jooooo`03o`000?oo
oooooooo02Sooooo000[ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0NOooool2
o`0002[ooooo000/ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`0Yooooo`00;?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo07So
oooo0_l0000[ooooo`00;Oooool00ol0003oooooooooo`1hooooo`;o0000NOooool00ol0003ooooo
ooooo`0Zooooo`00;Oooool2o`0007Wooooo00?o0000ooooooooool0Moooool2o`0002cooooo000^
ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0[
ooooo`00;oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo07Kooooo00?o0000oooo
ooooool0;?ooool002oooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`1eooooo`;o
0000;_ooool0033ooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`1eooooo`03o`00
0?oooooooooo02gooooo000`ooooo`;o0000M_ooool00ol0003oooooooooo`1dooooo`;o0000;ooo
ool0037ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`1dooooo`03o`000?oooooo
oooo02kooooo000booooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0Loooool2o`00
033ooooo000booooo`03o`000?oooooooooo07?ooooo0_l0001cooooo`;o0000<Oooool003?ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1booooo`;o0000<Oooool003Cooooo00?o
0000ooooooooool0LOooool00ol0003oooooooooo`1aooooo`;o0000<_ooool003Cooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`1aooooo`;o0000<_ooool003Gooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`1`ooooo`;o0000<oooool003Gooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo03;ooooo000fooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0cooooo`00=ooo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06kooooo0_l0000eooooo`00=oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0=?ooool0
03Sooooo00?o0000ooooooooool0KOooool2o`0006kooooo00?o0000ooooooooool0=Oooool003So
oooo0_l0001^ooooo`03o`000?oooooooooo06cooooo0_l0000gooooo`00>Oooool2o`0006gooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0fooooo`00>_ooool00ol0003ooooooooo
o`1[ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0=oooool003[ooooo0_l0001/
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0>?ooool003_ooooo0_l0001[oooo
o`03o`000?oooooooooo06Wooooo0_l0000jooooo`00??ooool00ol0003oooooooooo`1Yooooo`03
o`000?oooooooooo06Sooooo0_l0000kooooo`00?Oooool00ol0003oooooooooo`1Xooooo`03o`00
0?oooooooooo06Sooooo00?o0000ooooooooool0>_ooool003kooooo00?o0000ooooooooool0Iooo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo03_ooooo000oooooo`03o`000?oooooo
oooo06Kooooo0_l0001Wooooo`;o0000?Oooool003oooooo00?o0000ooooooooool0I_ooool00ol0
003oooooooooo`1Uooooo`;o0000?_ooool0043ooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`1Tooooo`;o0000?oooool0047ooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`1Sooooo`;o0000@?ooool0047ooooo0_l0001Uooooo`03o`000?oooooooooo06?ooooo0_l0
0010ooooo`00@_ooool2o`0006Cooooo00?o0000ooooooooool0H_ooool2o`00047ooooo0013oooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0HOooool2o`0004;ooooo0014ooooo`03
o`000?oooooooooo04Cooooo1?l000000ol@413oooooooooo`03ooooo`03oeEEEOl0003oEEEE00Co
oooo00KoV9RHoa0@4?l0003o0000odA4A?o^k^h6ooooo`03o`000?oooooooooo063ooooo0_l00013
ooooo`00AOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Gooooo0ol00004oooo
o`06oa0@4?n7QhOooooooooooomgMgOoA4A41_ooool00ol0003oooooooooo`1Oooooo`;o0000A?oo
ool004Kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`05ooooo`03oeEEEOl0003o
EEEE00Wooooo00?o0000ooooooooool01?ooool3o`0005kooooo0_l00015ooooo`00Aoooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo013ooooo00?ok^k^o`000?ooool01Oooool00ol0
003oooooooooo`1Mooooo`;o0000A_ooool004Sooooo0_l00013ooooo`03o`000?oooooooooo00co
oooo00Ko410@oiRHV?ooooooooooogMgMomVIVH6ooooo`03o`000?oooooooooo05cooooo0_l00017
ooooo`00BOooool2o`0004;ooooo00?o0000ooooooooool03?ooool01Ol0003o8B4Qo`000?l0003o
IVIV00Oooooo00?o0000ooooooooool0Foooool2o`0004Sooooo001:ooooo`;o0000@Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0F_ooool2o`00
04Wooooo001;ooooo`;o0000?_ooool00ol0003oA4A4o`00000>ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0FOooool2o`0004[ooooo001<ooooo`;o0000?Oooool00oo<c<coEEEE
o`00000>ooooo`Go00001oooool00ol0003oooooooooo`1Hooooo`;o0000Boooool004gooooo0_l0
001Iooooo`03o`000?oooooooooo05Oooooo0_l0001<ooooo`00C_ooool2o`0005Sooooo00?o0000
ooooooooool0E_ooool2o`0004gooooo001?ooooo`;o0000Eoooool2o`0005Kooooo0_l0001>oooo
o`00D?ooool2o`0005Kooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1>ooooo`00
DOooool2o`0005Gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1?ooooo`00D_oo
ool2o`0005Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1@ooooo`00Doooool2
o`0005?ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Aooooo`00EOooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo04oooooo0_l0001Dooooo`00E_ooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo04kooooo0_l0001Eooooo`00Eoooool2o`0004oooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`1Eooooo`00F?ooool2o`0004kooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`1Fooooo`00F_ooool2o`0004cooooo0_l0001;
ooooo`;o0000FOooool005_ooooo0_l0001;ooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0FOooool005gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`17ooooo`;o
0000G?ooool005kooooo0_l00018ooooo`03o`000?oooooooooo04Kooooo0_l0001Mooooo`00H?oo
ool2o`0004Kooooo00?o0000ooooooooool0AOooool2o`0005kooooo001Qooooo`;o0000AOooool0
0ol0003oooooooooo`13ooooo`?o0000Goooool006?ooooo0_l00013ooooo`03o`000?oooooooooo
04;ooooo0_l0001Qooooo`00I?ooool2o`0004;ooooo00?o0000ooooooooool0@?ooool2o`0006?o
oooo001Uooooo`?o0000@?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo06?ooooo
001Wooooo`;o0000?oooool2o`0003kooooo0_l0001Vooooo`00JOooool2o`0003gooooo00?o0000
ooooooooool0>oooool3o`0006Oooooo001[ooooo`;o0000>oooool00ol0003oooooooooo`0ioooo
o`?o0000JOooool006gooooo0_l0000iooooo`03o`000?oooooooooo03Sooooo0_l0001[ooooo`00
K_ooool2o`0003Sooooo00?o0000ooooooooool0=_ooool2o`0006gooooo001`ooooo`;o0000=_oo
ool00ol0003oooooooooo`0cooooo`?o0000Koooool007;ooooo0_l0000dooooo`03o`000?oooooo
oooo037ooooo0ol0001aooooo`00Loooool3o`0003;ooooo00?o0000ooooooooool0;oooool4o`00
07;ooooo001eooooo`?o0000<?ooool00ol0003oooooooooo`0]ooooo`Co0000M?ooool007Oooooo
1?l0000]ooooo`03o`000?oooooooooo02_ooooo0ol0001gooooo`00N_ooool3o`0002_ooooo0_l0
000Yooooo`?o0000N_ooool007cooooo1?l0000Xooooo`03o`000?oooooooooo02Gooooo1?l0001l
ooooo`00Ooooool3o`0002Kooooo00?o0000ooooooooool08oooool3o`0007oooooo0022ooooo`?o
00008oooool00ol0003oooooooooo`0Pooooo`Co0000POooool008Gooooo1Ol0000Nooooo`03o`00
0?oooooooooo01cooooo1Ol00024ooooo`00ROooool6o`0001Wooooo00?o0000ooooooooool06?oo
ool5o`0008Sooooo002>ooooo`Go00002Oooool6o`0000Kooooo00?o0000ooooooooool04oooool5
o`0008gooooo002Cooooo`Go00001?ooool00onHV9So0000olc<c002ooooo`03oa0@4?oooooooooo
00Cooooo00?o0000ooooooooool03_ooool5o`0009;ooooo002Hooooo`[o00001_ooool00ol0003o
ooooooooo`05ooooo`[o0000U_ooool009kooooo00CoZJVYoa0@4?o<c<cooooo3_l0002Pooooo`00
Woooool00oo<c<co410@olc<c006ooooo`03o`000?oooooooooo0:Gooooo002Pooooo`03ojVYZOlb
<S;ooooo00Gooooo00?o0000ooooooooool0YOooool00:7ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`2Uooooo`00W?ooool01_l0003oQhN7onk^k_ooooooMgMgoc8b<PKooooo00?o
0000ooooooooool0YOooool009cooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^j^ooooo`00oooo
oomAooooo`00\
\>"],
  ImageRangeCache->{{{99.875, 255.625}, {181.313, 85.4375}} -> {-5.20375, \
1.82779, 0.0204483, 0.0165431}},
  CellTags->"M50.7.5"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->"M50.7.5"]
}, Open  ]],

Cell["\<\
Why does this give only the upper part of the circle? Computers do not \
eliminate the need for thought.\
\>", "Text",
  CellTags->"M50.7.5"],

Cell[BoxData[
    \(Clear[sol5, fUpper, fLower, fCirc]\)], "Input",
  CellTags->"M50.7.5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rules With Patterns (Advanced Topic)", "Section",
  CellTags->"M50.7.6"],

Cell[CellGroupData[{

Cell["The Underscore Character", "Subsection",
  CellTags->"M50.7.6"],

Cell["\<\
Just as we can use the underscore character to designate arguments in a \
function, we can also use them as arguments to rules.\
\>", "Text",
  CellTags->"M50.7.6"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c, d} /. _ \[RuleDelayed] \ 7\)], "Input",
  CellTags->"M50.7.6"],

Cell[BoxData[
    \(7\)], "Output",
  CellTags->"M50.7.6"]
}, Open  ]],

Cell["\<\
Again, just as we did when we defined functions, we will find it more \
convenient to give the underscore a name.\
\>", "Text",
  CellTags->"M50.7.6"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c, d} /. x_ \[RuleDelayed] \ 7\^x\)], "Input",
  CellTags->"M50.7.6"],

Cell[BoxData[
    \({7\^a, 7\^b, 7\^c, 7\^d}\)], "Output",
  CellTags->"M50.7.6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conditions", "Subsection",
  CellTags->"M50.7.6"],

Cell["\<\
We can specify that the rules should only be applied to elements that have \
particular properties.\
\>", "Text",
  CellTags->"M50.7.6"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, 1, b, 2, c, 3} /. _Integer \[RuleDelayed] \ cow\)], "Input",
  CellTags->"M50.7.6"],

Cell[BoxData[
    \({a, cow, b, cow, c, cow}\)], "Output",
  CellTags->"M50.7.6"]
}, Open  ]],

Cell["\<\
If we give the underscore a name, we can use it as an argument.\
\>", "Text",
  CellTags->"M50.7.6"],

Cell[CellGroupData[{

Cell[BoxData[
    \({3, \(-2\), 5, 6, \(-2\)} /. 
      x_?Positive \[RuleDelayed] \ \@x\)], "Input",
  CellTags->"M50.7.6"],

Cell[BoxData[
    \({\@3, \(-2\), \@5, \@6, \(-2\)}\)], "Output",
  CellTags->"M50.7.6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lists of Rules", "Subsection",
  CellTags->"M50.7.6"],

Cell["\<\
We can also give a list of rules to apply when we are working with the \
underscore character.\
\>", "Text",
  CellTags->"M50.7.6"],

Cell[CellGroupData[{

Cell[BoxData[
    \({2, \(-3\), 5, \(-2.3\), 8.2} /. {x_?Positive \[RuleDelayed] \ \@x, 
        x_?Negative \[RuleDelayed] \ Sin[x]}\)], "Input",
  CellTags->"M50.7.6"],

Cell[BoxData[
    \({\@2, \(-Sin[3]\), \@5, \(-0.7457052121767203`\), 
      2.8635642126552705`}\)], "Output",
  CellTags->"M50.7.6"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise: Patterns and Rules", "Section",
  CounterAssignments->{{"Chapter", 7}, {"ExerciseNumber", 3}}],

Cell[TextData[{
  "Evaluate the assignment for ",
  StyleBox["lis1", "MR"],
  " by placing your cursor anywhere in the following cell and pressing  \
\[ShiftKey]\[KeyBar]\[EnterKey]."
}], "Exercise"],

Cell[BoxData[
    \(lis1\  = \ {2, 3.66, 2.0, 5, \(-7\), \(-3.4\), \(-4\)}\)], "Input"],

Cell[TextData[{
  "Replace all the even numbers in ",
  StyleBox["lis1", "MR"],
  " with ",
  StyleBox["dog", "MR"],
  ". Do you notice anything that surprises you?"
}], "Exercise"],

Cell["Replace all the negative numbers with 0.", "Exercise"],

Cell[TextData[{
  "Replace all the real numbers with ten times their value. (Note that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\[CloseCurlyQuote]s notion of what constitutes a real number may not \
conform to what you see in textbooks.)"
}], "Exercise"],

Cell["\<\
Replace the even numbers with the next odd number and all the odd numbers \
with the preceding even number.\
\>", "Exercise"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{495, 527},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "M50.7.1"->{
    Cell[1776, 53, 121, 2, 95, "Title",
      CellTags->{
      "M50.7.1", "M50.7.2", "M50.7.3", "M50.7.4", "M50.7.5", "M50.7.6"}],
    Cell[1922, 59, 50, 1, 73, "Section",
      CellTags->"M50.7.1"],
    Cell[1975, 62, 127, 4, 33, "Text",
      CellTags->"M50.7.1"],
    Cell[2105, 68, 58, 1, 25, "BulletItem",
      CellTags->"M50.7.1"],
    Cell[2166, 71, 72, 1, 25, "BulletItem",
      CellTags->"M50.7.1"],
    Cell[2241, 74, 65, 1, 25, "BulletItem",
      CellTags->"M50.7.1"],
    Cell[2309, 77, 79, 1, 25, "BulletItem",
      CellTags->"M50.7.1"],
    Cell[2391, 80, 72, 1, 25, "BulletItem",
      CellTags->"M50.7.1"],
    Cell[2466, 83, 64, 1, 25, "BulletItem",
      CellTags->"M50.7.1"]},
  "M50.7.2"->{
    Cell[1776, 53, 121, 2, 95, "Title",
      CellTags->{
      "M50.7.1", "M50.7.2", "M50.7.3", "M50.7.4", "M50.7.5", "M50.7.6"}],
    Cell[2567, 89, 53, 1, 73, "Section",
      CellTags->"M50.7.2"],
    Cell[2645, 94, 58, 1, 38, "Subsection",
      CellTags->"M50.7.2"],
    Cell[2706, 97, 624, 21, 90, "Text",
      CellTags->"M50.7.2"],
    Cell[3333, 120, 431, 12, 90, "Text",
      CellTags->"M50.7.2"],
    Cell[3789, 136, 108, 2, 30, "Input",
      CellTags->"M50.7.2"],
    Cell[3900, 140, 88, 2, 42, "Output",
      CellTags->"M50.7.2"],
    Cell[4003, 145, 189, 7, 52, "Text",
      CellTags->"M50.7.2"],
    Cell[4229, 157, 79, 1, 38, "Subsection",
      CellTags->{"LastSlide", "M50.7.2"}],
    Cell[4311, 160, 149, 4, 52, "Text",
      CellTags->"M50.7.2"],
    Cell[4485, 168, 114, 2, 30, "Input",
      CellTags->"M50.7.2"],
    Cell[4602, 172, 67, 2, 29, "Output",
      CellTags->"M50.7.2"],
    Cell[4684, 177, 260, 8, 52, "Text",
      CellTags->"M50.7.2"],
    Cell[4969, 189, 138, 3, 30, "Input",
      CellTags->"M50.7.2"],
    Cell[5110, 194, 77, 2, 29, "Output",
      CellTags->"M50.7.2"]},
  "M50.7.3"->{
    Cell[1776, 53, 121, 2, 95, "Title",
      CellTags->{
      "M50.7.1", "M50.7.2", "M50.7.3", "M50.7.4", "M50.7.5", "M50.7.6"}],
    Cell[5892, 233, 70, 1, 73, "Section",
      CellTags->"M50.7.3"],
    Cell[5987, 238, 63, 1, 38, "Subsection",
      CellTags->"M50.7.3"],
    Cell[6053, 241, 295, 8, 71, "Text",
      CellTags->"M50.7.3"],
    Cell[6373, 253, 92, 2, 30, "Input",
      CellTags->"M50.7.3"],
    Cell[6468, 257, 75, 2, 42, "Output",
      CellTags->"M50.7.3"],
    Cell[6558, 262, 155, 4, 52, "Text",
      CellTags->"M50.7.3"],
    Cell[6738, 270, 89, 2, 30, "Input",
      CellTags->"M50.7.3"],
    Cell[6830, 274, 60, 2, 29, "Output",
      CellTags->"M50.7.3"],
    Cell[6905, 279, 139, 5, 33, "Text",
      CellTags->"M50.7.3"],
    Cell[7069, 288, 142, 4, 30, "Input",
      CellTags->"M50.7.3"],
    Cell[7214, 294, 58, 2, 29, "Output",
      CellTags->"M50.7.3"],
    Cell[7287, 299, 67, 2, 30, "Input",
      CellTags->"M50.7.3"],
    Cell[7391, 306, 72, 1, 38, "Subsection",
      CellTags->"M50.7.3"],
    Cell[7466, 309, 212, 5, 52, "Text",
      CellTags->"M50.7.3"],
    Cell[7681, 316, 126, 4, 33, "Text",
      CellTags->"M50.7.3"],
    Cell[7832, 324, 126, 3, 31, "Input",
      CellTags->"M50.7.3"],
    Cell[7961, 329, 250, 5, 53, "Output",
      CellTags->"M50.7.3"],
    Cell[8226, 337, 147, 4, 52, "Text",
      CellTags->"M50.7.3"],
    Cell[8410, 346, 82, 1, 38, "Subsection",
      CellTags->"M50.7.3"],
    Cell[8495, 349, 131, 4, 52, "Text",
      CellTags->"M50.7.3"],
    Cell[8651, 357, 84, 2, 30, "Input",
      CellTags->"M50.7.3"],
    Cell[8738, 361, 78, 2, 29, "Output",
      CellTags->"M50.7.3"],
    Cell[8831, 366, 111, 3, 33, "Text",
      CellTags->"M50.7.3"],
    Cell[8967, 373, 109, 2, 31, "Input",
      CellTags->"M50.7.3"],
    Cell[9079, 377, 113, 2, 48, "Output",
      CellTags->"M50.7.3"],
    Cell[9241, 385, 66, 1, 38, "Subsection",
      CellTags->"M50.7.3"],
    Cell[9310, 388, 194, 6, 52, "Text",
      CellTags->"M50.7.3"],
    Cell[9529, 398, 113, 2, 31, "Input",
      CellTags->"M50.7.3"],
    Cell[9645, 402, 88, 2, 29, "Output",
      CellTags->"M50.7.3"],
    Cell[9748, 407, 131, 4, 52, "Text",
      CellTags->"M50.7.3"],
    Cell[9904, 415, 75, 2, 30, "Input",
      CellTags->"M50.7.3"],
    Cell[9982, 419, 99, 2, 29, "Output",
      CellTags->"M50.7.3"],
    Cell[10096, 424, 275, 6, 71, "Text",
      CellTags->"M50.7.3"],
    Cell[10396, 434, 113, 2, 31, "Input",
      CellTags->"M50.7.3"],
    Cell[10512, 438, 88, 2, 29, "Output",
      CellTags->"M50.7.3"],
    Cell[10637, 445, 75, 2, 30, "Input",
      CellTags->"M50.7.3"],
    Cell[10715, 449, 104, 2, 29, "Output",
      CellTags->"M50.7.3"],
    Cell[10834, 454, 67, 2, 30, "Input",
      CellTags->"M50.7.3"],
    Cell[10938, 461, 56, 1, 38, "Subsection",
      CellTags->"M50.7.3"],
    Cell[10997, 464, 314, 7, 71, "Text",
      CellTags->"M50.7.3"],
    Cell[11336, 475, 118, 3, 31, "Input",
      CellTags->"M50.7.3"],
    Cell[11457, 480, 543, 8, 97, "Message",
      CellTags->"M50.7.3"],
    Cell[12003, 490, 118, 3, 29, "Output",
      CellTags->"M50.7.3"],
    Cell[12136, 496, 177, 4, 52, "Text",
      CellTags->"M50.7.3"],
    Cell[12338, 504, 110, 2, 31, "Input",
      CellTags->"M50.7.3"],
    Cell[12451, 508, 104, 2, 29, "Output",
      CellTags->"M50.7.3"],
    Cell[12570, 513, 67, 2, 30, "Input",
      CellTags->"M50.7.3"]},
  "M50.7.4"->{
    Cell[1776, 53, 121, 2, 95, "Title",
      CellTags->{
      "M50.7.1", "M50.7.2", "M50.7.3", "M50.7.4", "M50.7.5", "M50.7.6"}],
    Cell[12686, 521, 71, 1, 73, "Section",
      CellTags->"M50.7.4"],
    Cell[12782, 526, 61, 1, 38, "Subsection",
      CellTags->"M50.7.4"],
    Cell[12846, 529, 207, 6, 52, "Text",
      CellTags->"M50.7.4"],
    Cell[13078, 539, 124, 3, 31, "Input",
      CellTags->"M50.7.4"],
    Cell[13205, 544, 157, 3, 38, "Output",
      CellTags->"M50.7.4"],
    Cell[13377, 550, 225, 8, 52, "Text",
      CellTags->"M50.7.4"],
    Cell[13627, 562, 91, 2, 30, "Input",
      CellTags->"M50.7.4"],
    Cell[13721, 566, 92, 2, 35, "Output",
      CellTags->"M50.7.4"],
    Cell[13850, 573, 91, 2, 30, "Input",
      CellTags->"M50.7.4"],
    Cell[13944, 577, 92, 2, 35, "Output",
      CellTags->"M50.7.4"],
    Cell[14085, 585, 64, 1, 38, "Subsection",
      CellTags->"M50.7.4"],
    Cell[14152, 588, 193, 6, 52, "Text",
      CellTags->"M50.7.4"],
    Cell[14370, 598, 95, 2, 30, "Input",
      CellTags->"M50.7.4"],
    Cell[14468, 602, 23680, 579, 147, 5024, 344, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"M50.7.4"],
    Cell[38151, 1183, 153, 4, 29, "Output",
      CellTags->"M50.7.4"],
    Cell[38319, 1190, 144, 4, 52, "Text",
      CellTags->"M50.7.4"],
    Cell[38466, 1196, 67, 2, 30, "Input",
      CellTags->"M50.7.4"]},
  "M50.7.5"->{
    Cell[1776, 53, 121, 2, 95, "Title",
      CellTags->{
      "M50.7.1", "M50.7.2", "M50.7.3", "M50.7.4", "M50.7.5", "M50.7.6"}],
    Cell[39901, 1248, 61, 1, 73, "Section",
      CellTags->"M50.7.5"],
    Cell[39987, 1253, 62, 1, 38, "Subsection",
      CellTags->"M50.7.5"],
    Cell[40052, 1256, 125, 4, 33, "Text",
      CellTags->"M50.7.5"],
    Cell[40202, 1264, 147, 4, 34, "Input",
      CellTags->"M50.7.5"],
    Cell[40352, 1270, 92, 2, 38, "Output",
      CellTags->"M50.7.5"],
    Cell[40459, 1275, 136, 5, 33, "Text",
      CellTags->"M50.7.5"],
    Cell[40620, 1284, 96, 2, 30, "Input",
      CellTags->"M50.7.5"],
    Cell[40719, 1288, 84, 2, 29, "Output",
      CellTags->"M50.7.5"],
    Cell[40840, 1295, 100, 2, 30, "Input",
      CellTags->"M50.7.5"],
    Cell[40943, 1299, 23451, 576, 147, 4935, 342, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"M50.7.5"],
    Cell[64397, 1877, 153, 4, 29, "Output",
      CellTags->"M50.7.5"],
    Cell[64565, 1884, 151, 4, 52, "Text",
      CellTags->"M50.7.5"],
    Cell[64719, 1890, 90, 2, 30, "Input",
      CellTags->"M50.7.5"]},
  "M50.7.6"->{
    Cell[1776, 53, 121, 2, 95, "Title",
      CellTags->{
      "M50.7.1", "M50.7.2", "M50.7.3", "M50.7.4", "M50.7.5", "M50.7.6"}],
    Cell[64858, 1898, 78, 1, 73, "Section",
      CellTags->"M50.7.6"],
    Cell[64961, 1903, 69, 1, 38, "Subsection",
      CellTags->"M50.7.6"],
    Cell[65033, 1906, 174, 4, 52, "Text",
      CellTags->"M50.7.6"],
    Cell[65232, 1914, 92, 2, 30, "Input",
      CellTags->"M50.7.6"],
    Cell[65327, 1918, 58, 2, 29, "Output",
      CellTags->"M50.7.6"],
    Cell[65400, 1923, 160, 4, 52, "Text",
      CellTags->"M50.7.6"],
    Cell[65585, 1931, 96, 2, 30, "Input",
      CellTags->"M50.7.6"],
    Cell[65684, 1935, 81, 2, 29, "Output",
      CellTags->"M50.7.6"],
    Cell[65814, 1943, 55, 1, 38, "Subsection",
      CellTags->"M50.7.6"],
    Cell[65872, 1946, 146, 4, 52, "Text",
      CellTags->"M50.7.6"],
    Cell[66043, 1954, 107, 2, 30, "Input",
      CellTags->"M50.7.6"],
    Cell[66153, 1958, 81, 2, 29, "Output",
      CellTags->"M50.7.6"],
    Cell[66249, 1963, 110, 3, 33, "Text",
      CellTags->"M50.7.6"],
    Cell[66384, 1970, 124, 3, 32, "Input",
      CellTags->"M50.7.6"],
    Cell[66511, 1975, 88, 2, 32, "Output",
      CellTags->"M50.7.6"],
    Cell[66648, 1983, 59, 1, 38, "Subsection",
      CellTags->"M50.7.6"],
    Cell[66710, 1986, 141, 4, 52, "Text",
      CellTags->"M50.7.6"],
    Cell[66876, 1994, 169, 3, 53, "Input",
      CellTags->"M50.7.6"],
    Cell[67048, 1999, 134, 3, 32, "Output",
      CellTags->"M50.7.6"]},
  "LastSlide"->{
    Cell[4229, 157, 79, 1, 38, "Subsection",
      CellTags->{"LastSlide", "M50.7.2"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"M50.7.1", 68923, 2062},
  {"M50.7.2", 69639, 2082},
  {"M50.7.3", 70771, 2114},
  {"M50.7.4", 74184, 2212},
  {"M50.7.5", 75582, 2251},
  {"M50.7.6", 76708, 2282},
  {"LastSlide", 78214, 2324}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 121, 2, 95, "Title",
  CellTags->{
  "M50.7.1", "M50.7.2", "M50.7.3", "M50.7.4", "M50.7.5", "M50.7.6"}],

Cell[CellGroupData[{
Cell[1922, 59, 50, 1, 73, "Section",
  CellTags->"M50.7.1"],
Cell[1975, 62, 127, 4, 33, "Text",
  CellTags->"M50.7.1"],
Cell[2105, 68, 58, 1, 25, "BulletItem",
  CellTags->"M50.7.1"],
Cell[2166, 71, 72, 1, 25, "BulletItem",
  CellTags->"M50.7.1"],
Cell[2241, 74, 65, 1, 25, "BulletItem",
  CellTags->"M50.7.1"],
Cell[2309, 77, 79, 1, 25, "BulletItem",
  CellTags->"M50.7.1"],
Cell[2391, 80, 72, 1, 25, "BulletItem",
  CellTags->"M50.7.1"],
Cell[2466, 83, 64, 1, 25, "BulletItem",
  CellTags->"M50.7.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2567, 89, 53, 1, 73, "Section",
  CellTags->"M50.7.2"],

Cell[CellGroupData[{
Cell[2645, 94, 58, 1, 38, "Subsection",
  CellTags->"M50.7.2"],
Cell[2706, 97, 624, 21, 90, "Text",
  CellTags->"M50.7.2"],
Cell[3333, 120, 431, 12, 90, "Text",
  CellTags->"M50.7.2"],

Cell[CellGroupData[{
Cell[3789, 136, 108, 2, 30, "Input",
  CellTags->"M50.7.2"],
Cell[3900, 140, 88, 2, 42, "Output",
  CellTags->"M50.7.2"]
}, Open  ]],
Cell[4003, 145, 189, 7, 52, "Text",
  CellTags->"M50.7.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4229, 157, 79, 1, 38, "Subsection",
  CellTags->{"LastSlide", "M50.7.2"}],
Cell[4311, 160, 149, 4, 52, "Text",
  CellTags->"M50.7.2"],

Cell[CellGroupData[{
Cell[4485, 168, 114, 2, 30, "Input",
  CellTags->"M50.7.2"],
Cell[4602, 172, 67, 2, 29, "Output",
  CellTags->"M50.7.2"]
}, Open  ]],
Cell[4684, 177, 260, 8, 52, "Text",
  CellTags->"M50.7.2"],

Cell[CellGroupData[{
Cell[4969, 189, 138, 3, 30, "Input",
  CellTags->"M50.7.2"],
Cell[5110, 194, 77, 2, 29, "Output",
  CellTags->"M50.7.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5248, 203, 110, 1, 73, "Section",
  CounterAssignments->{{"Chapter", 7}, {"ExerciseNumber", 0}}],
Cell[5361, 206, 142, 4, 25, "Exercise"],
Cell[5506, 212, 55, 1, 30, "Input"],
Cell[5564, 215, 228, 10, 25, "Exercise"],
Cell[5795, 227, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5892, 233, 70, 1, 73, "Section",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{
Cell[5987, 238, 63, 1, 38, "Subsection",
  CellTags->"M50.7.3"],
Cell[6053, 241, 295, 8, 71, "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{
Cell[6373, 253, 92, 2, 30, "Input",
  CellTags->"M50.7.3"],
Cell[6468, 257, 75, 2, 42, "Output",
  CellTags->"M50.7.3"]
}, Open  ]],
Cell[6558, 262, 155, 4, 52, "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{
Cell[6738, 270, 89, 2, 30, "Input",
  CellTags->"M50.7.3"],
Cell[6830, 274, 60, 2, 29, "Output",
  CellTags->"M50.7.3"]
}, Open  ]],
Cell[6905, 279, 139, 5, 33, "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{
Cell[7069, 288, 142, 4, 30, "Input",
  CellTags->"M50.7.3"],
Cell[7214, 294, 58, 2, 29, "Output",
  CellTags->"M50.7.3"]
}, Open  ]],
Cell[7287, 299, 67, 2, 30, "Input",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7391, 306, 72, 1, 38, "Subsection",
  CellTags->"M50.7.3"],
Cell[7466, 309, 212, 5, 52, "Text",
  CellTags->"M50.7.3"],
Cell[7681, 316, 126, 4, 33, "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{
Cell[7832, 324, 126, 3, 31, "Input",
  CellTags->"M50.7.3"],
Cell[7961, 329, 250, 5, 53, "Output",
  CellTags->"M50.7.3"]
}, Open  ]],
Cell[8226, 337, 147, 4, 52, "Text",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8410, 346, 82, 1, 38, "Subsection",
  CellTags->"M50.7.3"],
Cell[8495, 349, 131, 4, 52, "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{
Cell[8651, 357, 84, 2, 30, "Input",
  CellTags->"M50.7.3"],
Cell[8738, 361, 78, 2, 29, "Output",
  CellTags->"M50.7.3"]
}, Open  ]],
Cell[8831, 366, 111, 3, 33, "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{
Cell[8967, 373, 109, 2, 31, "Input",
  CellTags->"M50.7.3"],
Cell[9079, 377, 113, 2, 48, "Output",
  CellTags->"M50.7.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9241, 385, 66, 1, 38, "Subsection",
  CellTags->"M50.7.3"],
Cell[9310, 388, 194, 6, 52, "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{
Cell[9529, 398, 113, 2, 31, "Input",
  CellTags->"M50.7.3"],
Cell[9645, 402, 88, 2, 29, "Output",
  CellTags->"M50.7.3"]
}, Open  ]],
Cell[9748, 407, 131, 4, 52, "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{
Cell[9904, 415, 75, 2, 30, "Input",
  CellTags->"M50.7.3"],
Cell[9982, 419, 99, 2, 29, "Output",
  CellTags->"M50.7.3"]
}, Open  ]],
Cell[10096, 424, 275, 6, 71, "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{
Cell[10396, 434, 113, 2, 31, "Input",
  CellTags->"M50.7.3"],
Cell[10512, 438, 88, 2, 29, "Output",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10637, 445, 75, 2, 30, "Input",
  CellTags->"M50.7.3"],
Cell[10715, 449, 104, 2, 29, "Output",
  CellTags->"M50.7.3"]
}, Open  ]],
Cell[10834, 454, 67, 2, 30, "Input",
  CellTags->"M50.7.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10938, 461, 56, 1, 38, "Subsection",
  CellTags->"M50.7.3"],
Cell[10997, 464, 314, 7, 71, "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{
Cell[11336, 475, 118, 3, 31, "Input",
  CellTags->"M50.7.3"],
Cell[11457, 480, 543, 8, 97, "Message",
  CellTags->"M50.7.3"],
Cell[12003, 490, 118, 3, 29, "Output",
  CellTags->"M50.7.3"]
}, Open  ]],
Cell[12136, 496, 177, 4, 52, "Text",
  CellTags->"M50.7.3"],

Cell[CellGroupData[{
Cell[12338, 504, 110, 2, 31, "Input",
  CellTags->"M50.7.3"],
Cell[12451, 508, 104, 2, 29, "Output",
  CellTags->"M50.7.3"]
}, Open  ]],
Cell[12570, 513, 67, 2, 30, "Input",
  CellTags->"M50.7.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12686, 521, 71, 1, 73, "Section",
  CellTags->"M50.7.4"],

Cell[CellGroupData[{
Cell[12782, 526, 61, 1, 38, "Subsection",
  CellTags->"M50.7.4"],
Cell[12846, 529, 207, 6, 52, "Text",
  CellTags->"M50.7.4"],

Cell[CellGroupData[{
Cell[13078, 539, 124, 3, 31, "Input",
  CellTags->"M50.7.4"],
Cell[13205, 544, 157, 3, 38, "Output",
  CellTags->"M50.7.4"]
}, Open  ]],
Cell[13377, 550, 225, 8, 52, "Text",
  CellTags->"M50.7.4"],

Cell[CellGroupData[{
Cell[13627, 562, 91, 2, 30, "Input",
  CellTags->"M50.7.4"],
Cell[13721, 566, 92, 2, 35, "Output",
  CellTags->"M50.7.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13850, 573, 91, 2, 30, "Input",
  CellTags->"M50.7.4"],
Cell[13944, 577, 92, 2, 35, "Output",
  CellTags->"M50.7.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14085, 585, 64, 1, 38, "Subsection",
  CellTags->"M50.7.4"],
Cell[14152, 588, 193, 6, 52, "Text",
  CellTags->"M50.7.4"],

Cell[CellGroupData[{
Cell[14370, 598, 95, 2, 30, "Input",
  CellTags->"M50.7.4"],
Cell[14468, 602, 23680, 579, 147, 5024, 344, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"M50.7.4"],
Cell[38151, 1183, 153, 4, 29, "Output",
  CellTags->"M50.7.4"]
}, Open  ]],
Cell[38319, 1190, 144, 4, 52, "Text",
  CellTags->"M50.7.4"],
Cell[38466, 1196, 67, 2, 30, "Input",
  CellTags->"M50.7.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[38582, 1204, 108, 1, 73, "Section",
  CounterAssignments->{{"Chapter", 7}, {"ExerciseNumber", 1}}],
Cell[38693, 1207, 95, 2, 33, "Text"],
Cell[38791, 1211, 90, 1, 23, "DisplayFormula"],
Cell[38884, 1214, 89, 2, 25, "Exercise"],
Cell[38976, 1218, 267, 5, 59, "Exercise"],
Cell[39246, 1225, 124, 2, 34, "DisplayFormula"],
Cell[39373, 1229, 173, 5, 25, "Exercise"],
Cell[39549, 1236, 106, 1, 23, "DisplayFormula"],
Cell[39658, 1239, 206, 4, 42, "Exercise"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39901, 1248, 61, 1, 73, "Section",
  CellTags->"M50.7.5"],

Cell[CellGroupData[{
Cell[39987, 1253, 62, 1, 38, "Subsection",
  CellTags->"M50.7.5"],
Cell[40052, 1256, 125, 4, 33, "Text",
  CellTags->"M50.7.5"],

Cell[CellGroupData[{
Cell[40202, 1264, 147, 4, 34, "Input",
  CellTags->"M50.7.5"],
Cell[40352, 1270, 92, 2, 38, "Output",
  CellTags->"M50.7.5"]
}, Open  ]],
Cell[40459, 1275, 136, 5, 33, "Text",
  CellTags->"M50.7.5"],

Cell[CellGroupData[{
Cell[40620, 1284, 96, 2, 30, "Input",
  CellTags->"M50.7.5"],
Cell[40719, 1288, 84, 2, 29, "Output",
  CellTags->"M50.7.5"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40840, 1295, 100, 2, 30, "Input",
  CellTags->"M50.7.5"],
Cell[40943, 1299, 23451, 576, 147, 4935, 342, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"M50.7.5"],
Cell[64397, 1877, 153, 4, 29, "Output",
  CellTags->"M50.7.5"]
}, Open  ]],
Cell[64565, 1884, 151, 4, 52, "Text",
  CellTags->"M50.7.5"],
Cell[64719, 1890, 90, 2, 30, "Input",
  CellTags->"M50.7.5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[64858, 1898, 78, 1, 73, "Section",
  CellTags->"M50.7.6"],

Cell[CellGroupData[{
Cell[64961, 1903, 69, 1, 38, "Subsection",
  CellTags->"M50.7.6"],
Cell[65033, 1906, 174, 4, 52, "Text",
  CellTags->"M50.7.6"],

Cell[CellGroupData[{
Cell[65232, 1914, 92, 2, 30, "Input",
  CellTags->"M50.7.6"],
Cell[65327, 1918, 58, 2, 29, "Output",
  CellTags->"M50.7.6"]
}, Open  ]],
Cell[65400, 1923, 160, 4, 52, "Text",
  CellTags->"M50.7.6"],

Cell[CellGroupData[{
Cell[65585, 1931, 96, 2, 30, "Input",
  CellTags->"M50.7.6"],
Cell[65684, 1935, 81, 2, 29, "Output",
  CellTags->"M50.7.6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[65814, 1943, 55, 1, 38, "Subsection",
  CellTags->"M50.7.6"],
Cell[65872, 1946, 146, 4, 52, "Text",
  CellTags->"M50.7.6"],

Cell[CellGroupData[{
Cell[66043, 1954, 107, 2, 30, "Input",
  CellTags->"M50.7.6"],
Cell[66153, 1958, 81, 2, 29, "Output",
  CellTags->"M50.7.6"]
}, Open  ]],
Cell[66249, 1963, 110, 3, 33, "Text",
  CellTags->"M50.7.6"],

Cell[CellGroupData[{
Cell[66384, 1970, 124, 3, 32, "Input",
  CellTags->"M50.7.6"],
Cell[66511, 1975, 88, 2, 32, "Output",
  CellTags->"M50.7.6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[66648, 1983, 59, 1, 38, "Subsection",
  CellTags->"M50.7.6"],
Cell[66710, 1986, 141, 4, 52, "Text",
  CellTags->"M50.7.6"],

Cell[CellGroupData[{
Cell[66876, 1994, 169, 3, 53, "Input",
  CellTags->"M50.7.6"],
Cell[67048, 1999, 134, 3, 32, "Output",
  CellTags->"M50.7.6"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[67243, 2009, 110, 1, 73, "Section",
  CounterAssignments->{{"Chapter", 7}, {"ExerciseNumber", 3}}],
Cell[67356, 2012, 199, 5, 42, "Exercise"],
Cell[67558, 2019, 87, 1, 30, "Input"],
Cell[67648, 2022, 181, 6, 42, "Exercise"],
Cell[67832, 2030, 60, 0, 25, "Exercise"],
Cell[67895, 2032, 271, 6, 42, "Exercise"],
Cell[68169, 2040, 135, 3, 42, "Exercise"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

