(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     26996,       1113]*)
(*NotebookOutlinePosition[     35405,       1359]*)
(*  CellTagsIndexPosition[     35217,       1349]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["2. Working with Lists", "Title",
  CellTags->{"M50.2.1", "M50.2.2", "M50.2.3", "M50.2.4"}],

Cell[CellGroupData[{

Cell["Overview", "Section",
  CellTags->"M50.2.1"],

Cell["\<\
In this session we will learn how to work with lists. The topics will \
include:\
\>", "Text",
  CellTags->"M50.2.1"],

Cell["List notation", "Text",
  CellTags->"M50.2.1"],

Cell["The structure of lists", "Text",
  CellTags->"M50.2.1"],

Cell["Extracting parts of lists", "Text",
  CellTags->"M50.2.1"],

Cell["Constructing lists", "Text",
  CellTags->"M50.2.1"],

Cell["Lists as vectors and matrices", "Text",
  CellTags->"M50.2.1"],

Cell["Displaying and formatting lists", "Text",
  CellTags->"M50.2.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["List Structure and Syntax", "Section",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{

Cell["List Notation", "Subsection",
  CellTags->"M50.2.2"],

Cell["\<\
Lists are denoted using curly brackets. The elements are separated by commas. \
The elements can be anything: symbols, numbers, strings (words or sentences \
enclosed in double quotes), or other lists.\
\>", "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, 3, "\<This is my list.\>", {r, 5}}\)], "Input",
  CellTags->"M50.2.2"],

Cell[BoxData[
    \({a, 3, "This is my list.", {r, 5}}\)], "Output",
  CellTags->"M50.2.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Structure of Lists", "Subsection",
  CellTags->{"LastSlide", "M50.2.2"}],

Cell[TextData[{
  "To facilitate working with lists we designate levels in the lists. The \
elements of a list constitute the first level. For example, the symbols ",
  StyleBox["a", "MR"],
  ", ",
  StyleBox["b", "MR"],
  ", and ",
  StyleBox["c", "MR"],
  " in the following list are all at the first level."
}], "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c}\)], "Input",
  CellTags->"M50.2.2"],

Cell[BoxData[
    \({a, b, c}\)], "Output",
  CellTags->"M50.2.2"]
}, Open  ]],

Cell[TextData[{
  "The second level is made up of the elements of the first level. In the \
following list the elements ",
  StyleBox["r", "MR"],
  " and ",
  StyleBox["s", "MR"],
  " are at the second level."
}], "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \({1, 2, {r, s}, 5}\)], "Input",
  CellTags->"M50.2.2"],

Cell[BoxData[
    \({1, 2, {r, s}, 5}\)], "Output",
  CellTags->"M50.2.2"]
}, Open  ]],

Cell[TextData[{
  "In general, the ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\^st\)]],
  " level elements are the elements of the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " level."
}], "Text",
  CellTags->"M50.2.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Getting Parts of Lists: The Part Function", "Subsection",
  CellTags->"M50.2.2"],

Cell[TextData[{
  "The ",
  StyleBox["Part", "MR"],
  " function is used to extract the parts of a list. The first argument is \
the list and the remaining arguments specify the parts you wish to extract."
}], "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Part[{a, b, c, d}, 3]\)], "Input",
  CellTags->"M50.2.2"],

Cell[BoxData[
    \(c\)], "Output",
  CellTags->"M50.2.2"]
}, Open  ]],

Cell["If you want more than one part, put them in a list.", "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Part[{a, b, c, d}, {1, 3}]\)], "Input",
  CellTags->"M50.2.2"],

Cell[BoxData[
    \({a, c}\)], "Output",
  CellTags->"M50.2.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Working with Levels", "Subsection",
  CellTags->"M50.2.2"],

Cell[TextData[{
  "To get parts of a list that are at the second level, use three arguments \
with the ",
  StyleBox["Part", "MR"],
  " function. Again, the first argument is the list you are operating on, the \
second is a list of the first levels we want to look at, and the third \
argument is a list of the second level elements we want."
}], "Text",
  CellTags->"M50.2.2"],

Cell["\<\
The following example takes the first and third elements of the first and \
second levels.\
\>", "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Part[{{a, b, c}, {r, s, t}, {1, 2, 3}}, {1, 2}, {1, 3}]\)], "Input",
  CellTags->"M50.2.2"],

Cell[BoxData[
    \({{a, c}, {r, t}}\)], "Output",
  CellTags->"M50.2.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Special Notation for Part", "Subsection",
  CellTags->"M50.2.2"],

Cell[TextData[{
  "There is a special notation for ",
  StyleBox["Part", "MR"],
  ". We indicate the parts we want inside double square brackets following \
the list. (If you like fancy names, this is a ",
  StyleBox["postfix",
    FontSlant->"Italic"],
  StyleBox[" operator",
    FontSlant->"Italic"],
  ".)"
}], "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c}[\([2]\)]\)], "Input",
  CellTags->"M50.2.2"],

Cell[BoxData[
    \(b\)], "Output",
  CellTags->"M50.2.2"]
}, Open  ]],

Cell["\<\
You can work with multiple levels just as you do with the regular notation.\
\>", "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \({{a, b, c}, {r, s, t}, {1, 2, 3}}[\([{1, 2}, {1, 3}]\)]\)], "Input",
  CellTags->"M50.2.2"],

Cell[BoxData[
    \({{a, c}, {r, t}}\)], "Output",
  CellTags->"M50.2.2"]
}, Open  ]],

Cell[TextData[{
  "We will usually use the special notation for getting parts of lists, but \
you can always use ",
  StyleBox["Part", "MR"],
  " if you find that is easier."
}], "Text",
  CellTags->"M50.2.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

Exercise\
\>", "Section"],

Cell[CellGroupData[{

Cell["Operations with Lists", "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 0}}],

Cell[TextData[{
  "Evaluate the following input to define ",
  StyleBox["vec", "MR"],
  ". You can evaluate this input by clicking anywhere within the input and \
pressing ",
  "\[ShiftKey]\[KeyBar]\[EnterKey]",
  "."
}], "Text"],

Cell[BoxData[
    \(vec = {5, 2, 7, 2, 3, 7, 7, 2, 1}\)], "Input"],

Cell[TextData[{
  "Enter and evaluate an input that picks out the second element in ",
  StyleBox["vec", "MR"],
  "."
}], "Text"],

Cell["Evaluate the following inputs. What does each input do?", "Text"],

Cell[BoxData[
    \(Length[vec]\)], "Input"],

Cell[BoxData[
    \(First[vec]\)], "Input"],

Cell[BoxData[
    \(Rest[vec]\)], "Input"],

Cell[BoxData[
    \(Last[vec]\)], "Input"],

Cell[BoxData[
    \(Reverse[vec]\)], "Input"],

Cell[BoxData[
    \(Sort[vec]\)], "Input"],

Cell[BoxData[
    \(Reverse[Sort[vec]]\)], "Input"],

Cell[BoxData[
    \(Count[vec, 2]\)], "Input"],

Cell[BoxData[
    \(Append[vec, 99]\)], "Input"],

Cell[BoxData[
    \(Prepend[vec, 0]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Building Up Calculations", "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 1}}],

Cell[TextData[{
  "There are many ways of organizing ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programs."
}], "Text"],

Cell[TextData[{
  "For example, here is a program that picks out the second largest element \
in a list. This program works by sorting the list, and then picking out the \
element that is second from the end of the sorted list. (The position \
specification ",
  StyleBox["-2", "MR"],
  " indicates a position counted from the ",
  StyleBox["end",
    FontSlant->"Italic"],
  " of the list.)"
}], "Text"],

Cell[BoxData[
    \(Part[Sort[{5, 7, 9, 4, 5, 3, 1}], \(-2\)]\)], "Input"],

Cell["\<\
This same calculation can also be organized as two separate steps, but \
introducing a variable to store the sorted list as an intermediate result.\
\>", "Text"],

Cell[BoxData[
    \(temp = Sort[{5, 7, 9, 4, 5, 3, 1}]\)], "Input"],

Cell[BoxData[
    \(Part[temp, \(-2\)]\)], "Input"],

Cell["\<\
Here is another program, organized into four separate inputs. Evaluate the \
next four inputs to run this program. What does this program do?\
\>", "Exercise"],

Cell[BoxData[
    \(pts = {3, 9, 23, 51, 85, 97}\)], "Input"],

Cell[BoxData[
    \(response = {58, 38, 5, 107, 151, 200}\)], "Input"],

Cell[BoxData[
    \(temp = Transpose[{pts, response}]\)], "Input"],

Cell[BoxData[
    \(ListPlot[temp]\)], "Input"],

Cell["\<\
Rewrite this program as a single input that does not make any assignments to \
variables.\
\>", "Exercise"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Modifying List Structures", "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 2}}],

Cell[TextData[{
  "You will often find that you need to modify the structure of a list by \
adding or removing curly brackets. The function ",
  StyleBox["Flatten", "MR"],
  " can be used to remove brackets beginning with level one and working on \
down in the list. If you give an integer ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " as a second argument, the process stops after reaching level ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". First, evaluate the following to get a list to work with."
}], "Exercise"],

Cell[BoxData[
    \(lis = 
      Outer[List, {{1, 2}, {2, 3}, {3, 4}}, {{1, 3}, {2, 4}}]\)], "Input"],

Cell[TextData[{
  StyleBox["Try ",
    FontWeight->"Bold"],
  StyleBox["Flatten", "MR",
    FontWeight->"Bold"],
  StyleBox[" on ",
    FontWeight->"Bold"],
  StyleBox["lis", "MR",
    FontWeight->"Bold"],
  StyleBox[" to see what happens. Can you use ",
    FontWeight->"Bold"],
  StyleBox["Flatten", "MR",
    FontWeight->"Bold"],
  StyleBox[" to get a list of ordered pairs? Can you use ",
    FontWeight->"Bold"],
  StyleBox["Flatten", "MR",
    FontWeight->"Bold"],
  StyleBox[" to get a rectangular matrix with ordered pairs as elements?",
    FontWeight->"Bold"]
}], "Exercise"],

Cell[TextData[{
  StyleBox["Partition", "MR"],
  " is another function that is often useful in working with lists. ",
  StyleBox["Partition", "MR"],
  " can take several arguments, and you will find it useful to work with ",
  StyleBox["Partition", "MR"],
  " with up to four arguments. Evaluate the following to get a list to work \
with."
}], "Exercise"],

Cell[BoxData[
    \(lis\  = \ FromCharacterCode /@ Range[65, 88]\)], "Input"],

Cell[TextData[{
  StyleBox["Partition ",
    FontWeight->"Bold"],
  StyleBox["lis", "MR",
    FontWeight->"Bold"],
  StyleBox[" into groups of triples which are non-overlapping. Partition ",
    FontWeight->"Bold"],
  StyleBox["lis", "MR",
    FontWeight->"Bold"],
  StyleBox[" into groups of four which have two elements in common. (The last \
two of the first four-tuple will be the same as the first two of the second \
four-tuple.) What happens if you partition ",
    FontWeight->"Bold"],
  StyleBox["lis", "MR",
    FontWeight->"Bold"],
  StyleBox[" into groups of five with no overlap?",
    FontWeight->"Bold"]
}], "Exercise"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Building Lists", "Section",
  CellTags->"M50.2.3"],

Cell[TextData[{
  "There are two functions which make it easy to construct lists: ",
  StyleBox["Table", "MR"],
  " and ",
  StyleBox["Array", "MR"],
  ". We look first at ",
  StyleBox["Table", "MR"],
  "."
}], "Text",
  CellTags->"M50.2.3"],

Cell[CellGroupData[{

Cell["The Table Function", "Subsection",
  CellTags->"M50.2.3"],

Cell[TextData[{
  "The first argument to ",
  StyleBox["Table", "MR"],
  " gives the form of the elements we want. The remaining arguments are used \
to indicate how many of the elements to generate. Note that the number of \
elements is indicated as a list."
}], "Text",
  CellTags->"M50.2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Random[], {3}]\)], "Input",
  CellTags->"M50.2.3"],

Cell[BoxData[
    \({0.04290203457895395`, 0.24421159163204256`, 
      0.7843891415258897`}\)], "Output",
  CellTags->"M50.2.3"]
}, Open  ]],

Cell["\<\
Here we use an iterator to specify the form of the elements in the list. Note \
that the iterator is given as a list indicating the name of the iterator and \
minimum and maximum values the iterator should take.\
\>", "Text",
  CellTags->"M50.2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[i\^2, {i, 1, 5}]\)], "Input",
  CellTags->"M50.2.3"],

Cell[BoxData[
    \({1, 4, 9, 16, 25}\)], "Output",
  CellTags->"M50.2.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Multilevel Lists", "Subsection",
  CellTags->"M50.2.3"],

Cell["\<\
We can build lists of ordered pairs by specifying that the elements be \
ordered pairs.\
\>", "Text",
  CellTags->"M50.2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{i, i\^2}, {i, 1, 5}]\)], "Input",
  CellTags->"M50.2.3"],

Cell[BoxData[
    \({{1, 1}, {2, 4}, {3, 9}, {4, 16}, {5, 25}}\)], "Output",
  CellTags->"M50.2.3"]
}, Open  ]],

Cell["A second approach would be to use two iterators.", "Text",
  CellTags->"M50.2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{i, j}, {i, 1, 3}, {j, 6, 8}]\)], "Input",
  CellTags->"M50.2.3"],

Cell[BoxData[
    \({{{1, 6}, {1, 7}, {1, 8}}, {{2, 6}, {2, 7}, {2, 8}}, {{3, 6}, {3, 
          7}, {3, 8}}}\)], "Output",
  CellTags->"M50.2.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Array Function", "Subsection",
  CellTags->"M50.2.3"],

Cell[TextData[{
  "The ",
  StyleBox["Array", "MR"],
  " function creates arrays of the form ",
  StyleBox["M[", "MR"],
  StyleBox["i", "IT"],
  StyleBox[",", "MR"],
  StyleBox["j", "IT"],
  StyleBox["]", "MR"],
  ". The first argument is the name of the element; the second argument is a \
list containing the dimensions of the array."
}], "Text",
  CellTags->"M50.2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Array[M, {2, 3}]\)], "Input",
  CellTags->"M50.2.3"],

Cell[BoxData[
    \({{M[1, 1], M[1, 2], M[1, 3]}, {M[2, 1], M[2, 2], M[2, 3]}}\)], "Output",\

  CellTags->"M50.2.3"]
}, Open  ]],

Cell["\<\
We will see some examples of how to make use of this in the programming \
exercises.\
\>", "Text",
  CellTags->"M50.2.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vectors and Matrices", "Section",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{

Cell["Vectors", "Subsection",
  CellTags->"M50.2.4"],

Cell[TextData[{
  "Any single level list of length ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " can serve as an ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-dimensional vector. We can test a list to see if it is a vector using ",
  StyleBox["VectorQ", "MR"],
  "."
}], "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(VectorQ[{a, b, {c, d}}]\)], "Input",
  CellTags->"M50.2.4"],

Cell[BoxData[
    \(False\)], "Output",
  CellTags->"M50.2.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(VectorQ[{a, b, c}]\)], "Input",
  CellTags->"M50.2.4"],

Cell[BoxData[
    \(True\)], "Output",
  CellTags->"M50.2.4"]
}, Open  ]],

Cell["\<\
We can work with vectors using ordinary arithmetic operators.\
\>", "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c} + {r, s, t}\)], "Input",
  CellTags->"M50.2.4"],

Cell[BoxData[
    \({a + r, b + s, c + t}\)], "Output",
  CellTags->"M50.2.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c}\ s\)], "Input",
  CellTags->"M50.2.4"],

Cell[BoxData[
    \({a\ s, b\ s, c\ s}\)], "Output",
  CellTags->"M50.2.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Matrices", "Subsection",
  CellTags->"M50.2.4"],

Cell[TextData[{
  "Matrices are lists of lists in which all the first level elements are the \
same size. We can test to see if we have a matrix using ",
  StyleBox["MatrixQ", "MR"],
  "."
}], "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixQ[{{a, b, c}, {r, s, t}}]\)], "Input",
  CellTags->"M50.2.4"],

Cell[BoxData[
    \(True\)], "Output",
  CellTags->"M50.2.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixQ[{{a, b, c}, {r, s}}]\)], "Input",
  CellTags->"M50.2.4"],

Cell[BoxData[
    \(False\)], "Output",
  CellTags->"M50.2.4"]
}, Open  ]],

Cell["\<\
As with vectors, if the dimensions agree we can perform arithmetic operations \
on matrices.\
\>", "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \({{a, b, c}, {r, s, t}} + {{1, 2, 3}, {4, 5, 6}}\)], "Input",
  CellTags->"M50.2.4"],

Cell[BoxData[
    \({{1 + a, 2 + b, 3 + c}, {4 + r, 5 + s, 6 + t}}\)], "Output",
  CellTags->"M50.2.4"]
}, Open  ]],

Cell["Matrix multiplication (dot product) is done using a period.", "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \({{a, b}, {c, d}} . {{2, 3}, {4, 5}}\)], "Input",
  CellTags->"M50.2.4"],

Cell[BoxData[
    \({{2\ a + 4\ b, 3\ a + 5\ b}, {2\ c + 4\ d, 3\ c + 5\ d}}\)], "Output",
  CellTags->"M50.2.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Formatting Matrices", "Subsection",
  CellTags->"M50.2.4"],

Cell[TextData[{
  "For many purposes it is desirable to display matrices so they look like a \
traditional matrix much as you might see in your mathematics textbooks. You \
can do that with ",
  StyleBox["MatrixForm", "MR"],
  ". You should keep in mind that this is for display only and cannot be used \
in calculations."
}], "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[{{a, b, c}, {r, s, t}}]\)], "Input",
  CellTags->"M50.2.4"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"a", "b", "c"},
            {"r", "s", "t"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellTags->"M50.2.4"]
}, Open  ]],

Cell["\<\
To get a vector to display as a column vector you need to enter it as a list \
of lists.\
\>", "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[{{a}, {b}, {c}}]\)], "Input",
  CellTags->"M50.2.4"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"a"},
            {"b"},
            {"c"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellTags->"M50.2.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Formatting Tables", "Subsection",
  CellTags->"M50.2.4"],

Cell[TextData[{
  "You can display lists in the form of a table and include headings using ",
  StyleBox["TableForm", "MR"],
  "."
}], "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[{{"\<Wheat\>", 20, 1.5}, {"\<Corn\>", 32, 1.2}, {"\<Rice\>", 
          12,  .8}}, 
      TableHeadings\  \[Rule] \ {None, {"\<Grain\>", "\<Weight\>", \
"\<Cost\>"}}]\)], "Input",
  CellTags->"M50.2.4"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"Grain\"\>", "\<\"Weight\"\>", "\<\"Cost\"\>"},
          {"\<\"Wheat\"\>", "20", "1.5`"},
          {"\<\"Corn\"\>", "32", "1.2`"},
          {"\<\"Rice\"\>", "12", "0.8`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Grain", "Weight", 
          "Cost"}}]]]], "Output",
  CellTags->"M50.2.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unequal Rows", "Subsection",
  CellTags->"M50.2.4"],

Cell[TextData[{
  "The rows of tables need not be of equal length. ",
  StyleBox["TableForm", "MR"],
  " will still work in this situation."
}], "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[Table[i\^\(1/j\), {i, 1, 4}, {j, 1, i}]]\)], "Input",
  CellTags->"M50.2.4"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"1", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
          {"2", \(\@2\), "\<\"\"\>", "\<\"\"\>"},
          {"3", \(\@3\), \(3\^\(1/3\)\), "\<\"\"\>"},
          {"4", "2", \(2\^\(2/3\)\), \(\@2\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{1}, {2, 
        Power[ 2, 
          Rational[ 1, 2]]}, {3, 
        Power[ 3, 
          Rational[ 1, 2]], 
        Power[ 3, 
          Rational[ 1, 3]]}, {4, 2, 
        Power[ 2, 
          Rational[ 2, 3]], 
        Power[ 2, 
          Rational[ 1, 2]]}}]]], "Output",
  CellTags->"M50.2.4"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercise", "Section"],

Cell[CellGroupData[{

Cell["Picking Out Parts of a Matrix", "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 3}}],

Cell["Evaluate the following input to construct a sample matrix.", "Exercise"],

Cell[BoxData[
    \(mat = Array[a, {3, 3}]\)], "Input"],

Cell[TextData[{
  "Recall that ",
  StyleBox["mat[[", "MR"],
  StyleBox["k", "IT"],
  StyleBox["]]", "MR"],
  " picks out a row from a matrix and ",
  StyleBox["mat[[All,", "MR"],
  StyleBox["k", "IT"],
  StyleBox["]]", "MR"],
  " picks out a column from a matrix. (For more information or additional \
examples, see the documentation for ",
  ButtonBox["Part",
    ButtonStyle->"RefGuideLink"],
  " in the Help Browser.) For example, evaluate the following input to pick \
out the second column from the matrix ",
  StyleBox["mat", "MR"],
  "."
}], "Exercise"],

Cell[BoxData[
    \(mat[\([All, 2]\)]\)], "Input"],

Cell[TextData[{
  "Often it is useful to pick out several elements from a list, or several \
rows or columns from a matrix. This can be done by listing the positions of \
the desired elements. For example, evaluate the following input ",
  StyleBox["mat[[{1,2}]]", "MR"],
  " to get a list containing the first and second rows from the matrix ",
  StyleBox["mat", "MR"],
  "."
}], "Exercise"],

Cell[BoxData[
    \(mat[\([{1, 2}]\)]\)], "Input"],

Cell[TextData[{
  "Evaluate the following input to get a list containing the first and second \
columns from the matrix ",
  StyleBox["mat", "MR"],
  "."
}], "Exercise"],

Cell[BoxData[
    \(mat[\([All, {1, 2}]\)]\)], "Input"],

Cell[TextData[{
  "The effect of these operations may be easier to see if the results are \
displayed using ",
  StyleBox["MatrixForm", "MR"],
  ". Evaluate the following two inputs and compare the matrix ",
  StyleBox["mat", "MR"],
  " with the matrix ",
  StyleBox["mat[[All,{1,2}]]", "MR"],
  "."
}], "Exercise"],

Cell[BoxData[
    \(MatrixForm[mat]\)], "Input"],

Cell[BoxData[
    \(MatrixForm[mat[\([All, {1, 2}]\)]]\)], "Input"],

Cell["\<\
Experiment with the last input in the previous example to familiarize \
yourself with the effect of different position specifications.\
\>", "Exercise"],

Cell[TextData[{
  StyleBox["Find an input that returns the ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`2\[Cross]2\)],
    FontWeight->"Bold"],
  StyleBox[" matrix consisting of the elements from the corners of the ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`3\[Cross]3\)],
    FontWeight->"Bold"],
  StyleBox[" matrix ",
    FontWeight->"Bold"],
  StyleBox["mat", "MR",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"]
}], "Exercise"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Non-Rectangular Arrays", "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 4}}],

Cell[TextData[{
  "Generate the list",
  " ",
  StyleBox["{{0},{0,2},{0,2,4},{0,2,4,6},{0,2,4,6,8}}", "MR"],
  " ",
  "in two different ways using the ",
  StyleBox["Table", "MR"],
  " function."
}], "Exercise"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dimensions", "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 5}}],

Cell[TextData[{
  "Predict the dimensions of the list",
  " ",
  StyleBox["{{{1,a},{4,d}},{{2,b},{3,c}}}", "MR"],
  ". Use the ",
  StyleBox["Dimensions", "MR"],
  " function to check your answer."
}], "Exercise"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pascal\[CloseCurlyQuote]s Triangle", "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 6}}],

Cell[TextData[{
  "Look up the function ",
  StyleBox["Binomial", "MR"],
  " in the Help Browser. Use the ",
  StyleBox["Table", "MR"],
  " function with two iterators to construct the first seven rows of Pascal\
\[CloseCurlyQuote]s triangle and display it using ",
  StyleBox["TableForm", "MR"],
  "."
}], "Exercise"],

Cell[TextData[{
  "Construct rows 5 through 8 of Pascal\[CloseCurlyQuote]s triangle and \
display it using ",
  StyleBox["TableForm", "MR"],
  "."
}], "Exercise"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solving a Linear System", "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 7}}],

Cell["\<\
Given the following system of equations construct the coefficient matrix and \
the constant vector for the system. You should give your matrix and constant \
vector names.\
\>", "Exercise"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(3  x + 2  y - z = 7\)},
          {\(2  x - y + z = 4\)},
          {\(x + 4  y - 3  z = 2\)}
          }], TraditionalForm]]]], "DisplayFormula",
  GridBoxOptions->{ColumnAlignments->{"="}}],

Cell[TextData[{
  "Solve your system using the function ",
  StyleBox["LinearSolve", "MR"],
  ". Make sure you give your solution a name."
}], "Exercise"],

Cell["\<\
Check your solution by multiplying your matrix by the solution vector.\
\>", "Exercise"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 693}},
WindowSize->{496, 597},
WindowMargins->{{8, Automatic}, {Automatic, 7}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "M50.2.1"->{
    Cell[1776, 53, 96, 1, 95, "Title",
      CellTags->{"M50.2.1", "M50.2.2", "M50.2.3", "M50.2.4"}],
    Cell[1897, 58, 50, 1, 73, "Section",
      CellTags->"M50.2.1"],
    Cell[1950, 61, 127, 4, 33, "Text",
      CellTags->"M50.2.1"],
    Cell[2080, 67, 52, 1, 33, "Text",
      CellTags->"M50.2.1"],
    Cell[2135, 70, 61, 1, 33, "Text",
      CellTags->"M50.2.1"],
    Cell[2199, 73, 64, 1, 33, "Text",
      CellTags->"M50.2.1"],
    Cell[2266, 76, 57, 1, 33, "Text",
      CellTags->"M50.2.1"],
    Cell[2326, 79, 68, 1, 33, "Text",
      CellTags->"M50.2.1"],
    Cell[2397, 82, 70, 1, 33, "Text",
      CellTags->"M50.2.1"]},
  "M50.2.2"->{
    Cell[1776, 53, 96, 1, 95, "Title",
      CellTags->{"M50.2.1", "M50.2.2", "M50.2.3", "M50.2.4"}],
    Cell[2504, 88, 67, 1, 73, "Section",
      CellTags->"M50.2.2"],
    Cell[2596, 93, 58, 1, 38, "Subsection",
      CellTags->"M50.2.2"],
    Cell[2657, 96, 248, 5, 71, "Text",
      CellTags->"M50.2.2"],
    Cell[2930, 105, 94, 2, 30, "Input",
      CellTags->"M50.2.2"],
    Cell[3027, 109, 91, 2, 29, "Output",
      CellTags->"M50.2.2"],
    Cell[3167, 117, 82, 1, 38, "Subsection",
      CellTags->{"LastSlide", "M50.2.2"}],
    Cell[3252, 120, 345, 10, 71, "Text",
      CellTags->"M50.2.2"],
    Cell[3622, 134, 65, 2, 30, "Input",
      CellTags->"M50.2.2"],
    Cell[3690, 138, 66, 2, 29, "Output",
      CellTags->"M50.2.2"],
    Cell[3771, 143, 244, 8, 52, "Text",
      CellTags->"M50.2.2"],
    Cell[4040, 155, 73, 2, 30, "Input",
      CellTags->"M50.2.2"],
    Cell[4116, 159, 74, 2, 29, "Output",
      CellTags->"M50.2.2"],
    Cell[4205, 164, 238, 9, 33, "Text",
      CellTags->"M50.2.2"],
    Cell[4480, 178, 86, 1, 38, "Subsection",
      CellTags->"M50.2.2"],
    Cell[4569, 181, 240, 6, 52, "Text",
      CellTags->"M50.2.2"],
    Cell[4834, 191, 77, 2, 30, "Input",
      CellTags->"M50.2.2"],
    Cell[4914, 195, 58, 2, 29, "Output",
      CellTags->"M50.2.2"],
    Cell[4987, 200, 90, 1, 33, "Text",
      CellTags->"M50.2.2"],
    Cell[5102, 205, 82, 2, 30, "Input",
      CellTags->"M50.2.2"],
    Cell[5187, 209, 63, 2, 29, "Output",
      CellTags->"M50.2.2"],
    Cell[5299, 217, 64, 1, 38, "Subsection",
      CellTags->"M50.2.2"],
    Cell[5366, 220, 377, 8, 90, "Text",
      CellTags->"M50.2.2"],
    Cell[5746, 230, 137, 4, 52, "Text",
      CellTags->"M50.2.2"],
    Cell[5908, 238, 111, 2, 50, "Input",
      CellTags->"M50.2.2"],
    Cell[6022, 242, 73, 2, 29, "Output",
      CellTags->"M50.2.2"],
    Cell[6144, 250, 70, 1, 38, "Subsection",
      CellTags->"M50.2.2"],
    Cell[6217, 253, 345, 11, 71, "Text",
      CellTags->"M50.2.2"],
    Cell[6587, 268, 74, 2, 30, "Input",
      CellTags->"M50.2.2"],
    Cell[6664, 272, 58, 2, 29, "Output",
      CellTags->"M50.2.2"],
    Cell[6737, 277, 122, 3, 33, "Text",
      CellTags->"M50.2.2"],
    Cell[6884, 284, 111, 2, 30, "Input",
      CellTags->"M50.2.2"],
    Cell[6998, 288, 73, 2, 29, "Output",
      CellTags->"M50.2.2"],
    Cell[7086, 293, 209, 6, 52, "Text",
      CellTags->"M50.2.2"]},
  "M50.2.3"->{
    Cell[1776, 53, 96, 1, 95, "Title",
      CellTags->{"M50.2.1", "M50.2.2", "M50.2.3", "M50.2.4"}],
    Cell[12615, 507, 56, 1, 73, "Section",
      CellTags->"M50.2.3"],
    Cell[12674, 510, 242, 9, 52, "Text",
      CellTags->"M50.2.3"],
    Cell[12941, 523, 63, 1, 38, "Subsection",
      CellTags->"M50.2.3"],
    Cell[13007, 526, 294, 7, 71, "Text",
      CellTags->"M50.2.3"],
    Cell[13326, 537, 76, 2, 30, "Input",
      CellTags->"M50.2.3"],
    Cell[13405, 541, 129, 3, 29, "Output",
      CellTags->"M50.2.3"],
    Cell[13549, 547, 258, 5, 71, "Text",
      CellTags->"M50.2.3"],
    Cell[13832, 556, 78, 2, 31, "Input",
      CellTags->"M50.2.3"],
    Cell[13913, 560, 74, 2, 29, "Output",
      CellTags->"M50.2.3"],
    Cell[14036, 568, 61, 1, 38, "Subsection",
      CellTags->"M50.2.3"],
    Cell[14100, 571, 134, 4, 52, "Text",
      CellTags->"M50.2.3"],
    Cell[14259, 579, 83, 2, 31, "Input",
      CellTags->"M50.2.3"],
    Cell[14345, 583, 99, 2, 29, "Output",
      CellTags->"M50.2.3"],
    Cell[14459, 588, 87, 1, 33, "Text",
      CellTags->"M50.2.3"],
    Cell[14571, 593, 91, 2, 30, "Input",
      CellTags->"M50.2.3"],
    Cell[14665, 597, 146, 3, 48, "Output",
      CellTags->"M50.2.3"],
    Cell[14860, 606, 63, 1, 38, "Subsection",
      CellTags->"M50.2.3"],
    Cell[14926, 609, 371, 12, 71, "Text",
      CellTags->"M50.2.3"],
    Cell[15322, 625, 72, 2, 30, "Input",
      CellTags->"M50.2.3"],
    Cell[15397, 629, 117, 3, 48, "Output",
      CellTags->"M50.2.3"],
    Cell[15529, 635, 131, 4, 52, "Text",
      CellTags->"M50.2.3"]},
  "M50.2.4"->{
    Cell[1776, 53, 96, 1, 95, "Title",
      CellTags->{"M50.2.1", "M50.2.2", "M50.2.3", "M50.2.4"}],
    Cell[15709, 645, 62, 1, 73, "Section",
      CellTags->"M50.2.4"],
    Cell[15796, 650, 52, 1, 38, "Subsection",
      CellTags->"M50.2.4"],
    Cell[15851, 653, 319, 11, 52, "Text",
      CellTags->"M50.2.4"],
    Cell[16195, 668, 79, 2, 30, "Input",
      CellTags->"M50.2.4"],
    Cell[16277, 672, 62, 2, 29, "Output",
      CellTags->"M50.2.4"],
    Cell[16376, 679, 74, 2, 30, "Input",
      CellTags->"M50.2.4"],
    Cell[16453, 683, 61, 2, 29, "Output",
      CellTags->"M50.2.4"],
    Cell[16529, 688, 108, 3, 33, "Text",
      CellTags->"M50.2.4"],
    Cell[16662, 695, 77, 2, 30, "Input",
      CellTags->"M50.2.4"],
    Cell[16742, 699, 78, 2, 29, "Output",
      CellTags->"M50.2.4"],
    Cell[16857, 706, 68, 2, 30, "Input",
      CellTags->"M50.2.4"],
    Cell[16928, 710, 75, 2, 29, "Output",
      CellTags->"M50.2.4"],
    Cell[17052, 718, 53, 1, 38, "Subsection",
      CellTags->"M50.2.4"],
    Cell[17108, 721, 223, 6, 52, "Text",
      CellTags->"M50.2.4"],
    Cell[17356, 731, 87, 2, 30, "Input",
      CellTags->"M50.2.4"],
    Cell[17446, 735, 61, 2, 29, "Output",
      CellTags->"M50.2.4"],
    Cell[17544, 742, 84, 2, 30, "Input",
      CellTags->"M50.2.4"],
    Cell[17631, 746, 62, 2, 29, "Output",
      CellTags->"M50.2.4"],
    Cell[17708, 751, 139, 4, 52, "Text",
      CellTags->"M50.2.4"],
    Cell[17872, 759, 103, 2, 30, "Input",
      CellTags->"M50.2.4"],
    Cell[17978, 763, 103, 2, 29, "Output",
      CellTags->"M50.2.4"],
    Cell[18096, 768, 98, 1, 33, "Text",
      CellTags->"M50.2.4"],
    Cell[18219, 773, 91, 2, 30, "Input",
      CellTags->"M50.2.4"],
    Cell[18313, 777, 113, 2, 29, "Output",
      CellTags->"M50.2.4"],
    Cell[18475, 785, 64, 1, 38, "Subsection",
      CellTags->"M50.2.4"],
    Cell[18542, 788, 357, 8, 90, "Text",
      CellTags->"M50.2.4"],
    Cell[18924, 800, 90, 2, 30, "Input",
      CellTags->"M50.2.4"],
    Cell[19017, 804, 260, 8, 55, "Output",
      CellTags->"M50.2.4"],
    Cell[19292, 815, 135, 4, 52, "Text",
      CellTags->"M50.2.4"],
    Cell[19452, 823, 83, 2, 30, "Input",
      CellTags->"M50.2.4"],
    Cell[19538, 827, 259, 9, 71, "Output",
      CellTags->"M50.2.4"],
    Cell[19846, 842, 62, 1, 38, "Subsection",
      CellTags->"M50.2.4"],
    Cell[19911, 845, 165, 5, 52, "Text",
      CellTags->"M50.2.4"],
    Cell[20101, 854, 232, 5, 90, "Input",
      CellTags->"M50.2.4"],
    Cell[20336, 861, 526, 15, 87, "Output",
      CellTags->"M50.2.4"],
    Cell[20911, 882, 57, 1, 38, "Subsection",
      CellTags->"M50.2.4"],
    Cell[20971, 885, 175, 5, 52, "Text",
      CellTags->"M50.2.4"],
    Cell[21171, 894, 106, 2, 31, "Input",
      CellTags->"M50.2.4"],
    Cell[21280, 898, 698, 22, 101, "Output",
      CellTags->"M50.2.4"]},
  "LastSlide"->{
    Cell[3167, 117, 82, 1, 38, "Subsection",
      CellTags->{"LastSlide", "M50.2.2"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"M50.2.1", 27587, 1128},
  {"M50.2.2", 28237, 1147},
  {"M50.2.3", 30649, 1216},
  {"M50.2.4", 32241, 1261},
  {"LastSlide", 35103, 1342}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 96, 1, 95, "Title",
  CellTags->{"M50.2.1", "M50.2.2", "M50.2.3", "M50.2.4"}],

Cell[CellGroupData[{
Cell[1897, 58, 50, 1, 73, "Section",
  CellTags->"M50.2.1"],
Cell[1950, 61, 127, 4, 33, "Text",
  CellTags->"M50.2.1"],
Cell[2080, 67, 52, 1, 33, "Text",
  CellTags->"M50.2.1"],
Cell[2135, 70, 61, 1, 33, "Text",
  CellTags->"M50.2.1"],
Cell[2199, 73, 64, 1, 33, "Text",
  CellTags->"M50.2.1"],
Cell[2266, 76, 57, 1, 33, "Text",
  CellTags->"M50.2.1"],
Cell[2326, 79, 68, 1, 33, "Text",
  CellTags->"M50.2.1"],
Cell[2397, 82, 70, 1, 33, "Text",
  CellTags->"M50.2.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2504, 88, 67, 1, 73, "Section",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{
Cell[2596, 93, 58, 1, 38, "Subsection",
  CellTags->"M50.2.2"],
Cell[2657, 96, 248, 5, 71, "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{
Cell[2930, 105, 94, 2, 30, "Input",
  CellTags->"M50.2.2"],
Cell[3027, 109, 91, 2, 29, "Output",
  CellTags->"M50.2.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3167, 117, 82, 1, 38, "Subsection",
  CellTags->{"LastSlide", "M50.2.2"}],
Cell[3252, 120, 345, 10, 71, "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{
Cell[3622, 134, 65, 2, 30, "Input",
  CellTags->"M50.2.2"],
Cell[3690, 138, 66, 2, 29, "Output",
  CellTags->"M50.2.2"]
}, Open  ]],
Cell[3771, 143, 244, 8, 52, "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{
Cell[4040, 155, 73, 2, 30, "Input",
  CellTags->"M50.2.2"],
Cell[4116, 159, 74, 2, 29, "Output",
  CellTags->"M50.2.2"]
}, Open  ]],
Cell[4205, 164, 238, 9, 33, "Text",
  CellTags->"M50.2.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4480, 178, 86, 1, 38, "Subsection",
  CellTags->"M50.2.2"],
Cell[4569, 181, 240, 6, 52, "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{
Cell[4834, 191, 77, 2, 30, "Input",
  CellTags->"M50.2.2"],
Cell[4914, 195, 58, 2, 29, "Output",
  CellTags->"M50.2.2"]
}, Open  ]],
Cell[4987, 200, 90, 1, 33, "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{
Cell[5102, 205, 82, 2, 30, "Input",
  CellTags->"M50.2.2"],
Cell[5187, 209, 63, 2, 29, "Output",
  CellTags->"M50.2.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5299, 217, 64, 1, 38, "Subsection",
  CellTags->"M50.2.2"],
Cell[5366, 220, 377, 8, 90, "Text",
  CellTags->"M50.2.2"],
Cell[5746, 230, 137, 4, 52, "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{
Cell[5908, 238, 111, 2, 50, "Input",
  CellTags->"M50.2.2"],
Cell[6022, 242, 73, 2, 29, "Output",
  CellTags->"M50.2.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6144, 250, 70, 1, 38, "Subsection",
  CellTags->"M50.2.2"],
Cell[6217, 253, 345, 11, 71, "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{
Cell[6587, 268, 74, 2, 30, "Input",
  CellTags->"M50.2.2"],
Cell[6664, 272, 58, 2, 29, "Output",
  CellTags->"M50.2.2"]
}, Open  ]],
Cell[6737, 277, 122, 3, 33, "Text",
  CellTags->"M50.2.2"],

Cell[CellGroupData[{
Cell[6884, 284, 111, 2, 30, "Input",
  CellTags->"M50.2.2"],
Cell[6998, 288, 73, 2, 29, "Output",
  CellTags->"M50.2.2"]
}, Open  ]],
Cell[7086, 293, 209, 6, 52, "Text",
  CellTags->"M50.2.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7344, 305, 36, 3, 99, "Section"],

Cell[CellGroupData[{
Cell[7405, 312, 106, 1, 38, "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 0}}],
Cell[7514, 315, 229, 7, 52, "Text"],
Cell[7746, 324, 66, 1, 30, "Input"],
Cell[7815, 327, 129, 4, 33, "Text"],
Cell[7947, 333, 71, 0, 33, "Text"],
Cell[8021, 335, 44, 1, 30, "Input"],
Cell[8068, 338, 43, 1, 30, "Input"],
Cell[8114, 341, 42, 1, 30, "Input"],
Cell[8159, 344, 42, 1, 30, "Input"],
Cell[8204, 347, 45, 1, 30, "Input"],
Cell[8252, 350, 42, 1, 30, "Input"],
Cell[8297, 353, 51, 1, 30, "Input"],
Cell[8351, 356, 46, 1, 30, "Input"],
Cell[8400, 359, 48, 1, 30, "Input"],
Cell[8451, 362, 48, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8536, 368, 109, 1, 38, "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 1}}],
Cell[8648, 371, 134, 5, 33, "Text"],
Cell[8785, 378, 404, 10, 90, "Text"],
Cell[9192, 390, 74, 1, 30, "Input"],
Cell[9269, 393, 171, 3, 52, "Text"],
Cell[9443, 398, 67, 1, 30, "Input"],
Cell[9513, 401, 51, 1, 30, "Input"],
Cell[9567, 404, 169, 3, 42, "Exercise"],
Cell[9739, 409, 61, 1, 30, "Input"],
Cell[9803, 412, 70, 1, 30, "Input"],
Cell[9876, 415, 66, 1, 30, "Input"],
Cell[9945, 418, 47, 1, 30, "Input"],
Cell[9995, 421, 117, 3, 25, "Exercise"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10149, 429, 110, 1, 38, "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 2}}],
Cell[10262, 432, 536, 12, 93, "Exercise"],
Cell[10801, 446, 101, 2, 50, "Input"],
Cell[10905, 450, 585, 19, 61, "Exercise"],
Cell[11493, 471, 356, 8, 59, "Exercise"],
Cell[11852, 481, 77, 1, 30, "Input"],
Cell[11932, 484, 634, 17, 78, "Exercise"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12615, 507, 56, 1, 73, "Section",
  CellTags->"M50.2.3"],
Cell[12674, 510, 242, 9, 52, "Text",
  CellTags->"M50.2.3"],

Cell[CellGroupData[{
Cell[12941, 523, 63, 1, 38, "Subsection",
  CellTags->"M50.2.3"],
Cell[13007, 526, 294, 7, 71, "Text",
  CellTags->"M50.2.3"],

Cell[CellGroupData[{
Cell[13326, 537, 76, 2, 30, "Input",
  CellTags->"M50.2.3"],
Cell[13405, 541, 129, 3, 29, "Output",
  CellTags->"M50.2.3"]
}, Open  ]],
Cell[13549, 547, 258, 5, 71, "Text",
  CellTags->"M50.2.3"],

Cell[CellGroupData[{
Cell[13832, 556, 78, 2, 31, "Input",
  CellTags->"M50.2.3"],
Cell[13913, 560, 74, 2, 29, "Output",
  CellTags->"M50.2.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14036, 568, 61, 1, 38, "Subsection",
  CellTags->"M50.2.3"],
Cell[14100, 571, 134, 4, 52, "Text",
  CellTags->"M50.2.3"],

Cell[CellGroupData[{
Cell[14259, 579, 83, 2, 31, "Input",
  CellTags->"M50.2.3"],
Cell[14345, 583, 99, 2, 29, "Output",
  CellTags->"M50.2.3"]
}, Open  ]],
Cell[14459, 588, 87, 1, 33, "Text",
  CellTags->"M50.2.3"],

Cell[CellGroupData[{
Cell[14571, 593, 91, 2, 30, "Input",
  CellTags->"M50.2.3"],
Cell[14665, 597, 146, 3, 48, "Output",
  CellTags->"M50.2.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14860, 606, 63, 1, 38, "Subsection",
  CellTags->"M50.2.3"],
Cell[14926, 609, 371, 12, 71, "Text",
  CellTags->"M50.2.3"],

Cell[CellGroupData[{
Cell[15322, 625, 72, 2, 30, "Input",
  CellTags->"M50.2.3"],
Cell[15397, 629, 117, 3, 48, "Output",
  CellTags->"M50.2.3"]
}, Open  ]],
Cell[15529, 635, 131, 4, 52, "Text",
  CellTags->"M50.2.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15709, 645, 62, 1, 73, "Section",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{
Cell[15796, 650, 52, 1, 38, "Subsection",
  CellTags->"M50.2.4"],
Cell[15851, 653, 319, 11, 52, "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{
Cell[16195, 668, 79, 2, 30, "Input",
  CellTags->"M50.2.4"],
Cell[16277, 672, 62, 2, 29, "Output",
  CellTags->"M50.2.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16376, 679, 74, 2, 30, "Input",
  CellTags->"M50.2.4"],
Cell[16453, 683, 61, 2, 29, "Output",
  CellTags->"M50.2.4"]
}, Open  ]],
Cell[16529, 688, 108, 3, 33, "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{
Cell[16662, 695, 77, 2, 30, "Input",
  CellTags->"M50.2.4"],
Cell[16742, 699, 78, 2, 29, "Output",
  CellTags->"M50.2.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16857, 706, 68, 2, 30, "Input",
  CellTags->"M50.2.4"],
Cell[16928, 710, 75, 2, 29, "Output",
  CellTags->"M50.2.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17052, 718, 53, 1, 38, "Subsection",
  CellTags->"M50.2.4"],
Cell[17108, 721, 223, 6, 52, "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{
Cell[17356, 731, 87, 2, 30, "Input",
  CellTags->"M50.2.4"],
Cell[17446, 735, 61, 2, 29, "Output",
  CellTags->"M50.2.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17544, 742, 84, 2, 30, "Input",
  CellTags->"M50.2.4"],
Cell[17631, 746, 62, 2, 29, "Output",
  CellTags->"M50.2.4"]
}, Open  ]],
Cell[17708, 751, 139, 4, 52, "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{
Cell[17872, 759, 103, 2, 30, "Input",
  CellTags->"M50.2.4"],
Cell[17978, 763, 103, 2, 29, "Output",
  CellTags->"M50.2.4"]
}, Open  ]],
Cell[18096, 768, 98, 1, 33, "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{
Cell[18219, 773, 91, 2, 30, "Input",
  CellTags->"M50.2.4"],
Cell[18313, 777, 113, 2, 29, "Output",
  CellTags->"M50.2.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18475, 785, 64, 1, 38, "Subsection",
  CellTags->"M50.2.4"],
Cell[18542, 788, 357, 8, 90, "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{
Cell[18924, 800, 90, 2, 30, "Input",
  CellTags->"M50.2.4"],
Cell[19017, 804, 260, 8, 55, "Output",
  CellTags->"M50.2.4"]
}, Open  ]],
Cell[19292, 815, 135, 4, 52, "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{
Cell[19452, 823, 83, 2, 30, "Input",
  CellTags->"M50.2.4"],
Cell[19538, 827, 259, 9, 71, "Output",
  CellTags->"M50.2.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19846, 842, 62, 1, 38, "Subsection",
  CellTags->"M50.2.4"],
Cell[19911, 845, 165, 5, 52, "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{
Cell[20101, 854, 232, 5, 90, "Input",
  CellTags->"M50.2.4"],
Cell[20336, 861, 526, 15, 87, "Output",
  CellTags->"M50.2.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20911, 882, 57, 1, 38, "Subsection",
  CellTags->"M50.2.4"],
Cell[20971, 885, 175, 5, 52, "Text",
  CellTags->"M50.2.4"],

Cell[CellGroupData[{
Cell[21171, 894, 106, 2, 31, "Input",
  CellTags->"M50.2.4"],
Cell[21280, 898, 698, 22, 101, "Output",
  CellTags->"M50.2.4"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22039, 927, 27, 0, 73, "Section"],

Cell[CellGroupData[{
Cell[22091, 931, 114, 1, 38, "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 3}}],
Cell[22208, 934, 78, 0, 25, "Exercise"],
Cell[22289, 936, 55, 1, 30, "Input"],
Cell[22347, 939, 561, 17, 76, "Exercise"],
Cell[22911, 958, 50, 1, 30, "Input"],
Cell[22964, 961, 392, 8, 76, "Exercise"],
Cell[23359, 971, 50, 1, 30, "Input"],
Cell[23412, 974, 169, 5, 42, "Exercise"],
Cell[23584, 981, 55, 1, 30, "Input"],
Cell[23642, 984, 315, 9, 59, "Exercise"],
Cell[23960, 995, 48, 1, 30, "Input"],
Cell[24011, 998, 67, 1, 30, "Input"],
Cell[24081, 1001, 162, 3, 42, "Exercise"],
Cell[24246, 1006, 500, 17, 43, "Exercise"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24783, 1028, 107, 1, 38, "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 4}}],
Cell[24893, 1031, 211, 8, 42, "Exercise"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25141, 1044, 95, 1, 38, "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 5}}],
Cell[25239, 1047, 213, 7, 42, "Exercise"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25489, 1059, 119, 1, 38, "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 6}}],
Cell[25611, 1062, 318, 9, 59, "Exercise"],
Cell[25932, 1073, 162, 5, 25, "Exercise"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26131, 1083, 108, 1, 38, "Subsection",
  CounterAssignments->{{"Chapter", 2}, {"ExerciseNumber", 7}}],
Cell[26242, 1086, 199, 4, 42, "Exercise"],
Cell[26444, 1092, 254, 6, 57, "DisplayFormula"],
Cell[26701, 1100, 154, 4, 42, "Exercise"],
Cell[26858, 1106, 98, 2, 25, "Exercise"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

